
/* package: dojo.js.uncompressed */
/*
	Copyright (c) 2004-2011, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/

/*
	This is an optimized version of Dojo, built for deployment and not for
	development. To get sources and documentation, please visit:

		http://dojotoolkit.org
*/

;(function(){

	/*
	dojo, dijit, and dojox must always be the first three, and in that order.
	djConfig.scopeMap = [
		["dojo", "fojo"],
		["dijit", "fijit"],
		["dojox", "fojox"]
	
	]
	*/

	/**Build will replace this comment with a scoped djConfig **/

	//The null below can be relaced by a build-time value used instead of djConfig.scopeMap.
	var sMap = null;

	//See if new scopes need to be defined.
	if((sMap || (typeof djConfig != "undefined" && djConfig.scopeMap)) && (typeof window != "undefined")){
		var scopeDef = "", scopePrefix = "", scopeSuffix = "", scopeMap = {}, scopeMapRev = {};
		sMap = sMap || djConfig.scopeMap;
		for(var i = 0; i < sMap.length; i++){
			//Make local variables, then global variables that use the locals.
			var newScope = sMap[i];
			scopeDef += "var " + newScope[0] + " = {}; " + newScope[1] + " = " + newScope[0] + ";" + newScope[1] + "._scopeName = '" + newScope[1] + "';";
			scopePrefix += (i == 0 ? "" : ",") + newScope[0];
			scopeSuffix += (i == 0 ? "" : ",") + newScope[1];
			scopeMap[newScope[0]] = newScope[1];
			scopeMapRev[newScope[1]] = newScope[0];
		}

		eval(scopeDef + "dojo._scopeArgs = [" + scopeSuffix + "];");

		dojo._scopePrefixArgs = scopePrefix;
		dojo._scopePrefix = "(function(" + scopePrefix + "){";
		dojo._scopeSuffix = "})(" + scopeSuffix + ")";
		dojo._scopeMap = scopeMap;
		dojo._scopeMapRev = scopeMapRev;
	}

/*=====
// note:
//		'djConfig' does not exist under 'dojo.*' so that it can be set before the
//		'dojo' variable exists.
// note:
//		Setting any of these variables *after* the library has loaded does
//		nothing at all.

djConfig = {
	// summary:
	//		Application code can set the global 'djConfig' prior to loading
	//		the library to override certain global settings for how dojo works.
	//
	// isDebug: Boolean
	//		Defaults to `false`. If set to `true`, ensures that Dojo provides
	//		extended debugging feedback via Firebug. If Firebug is not available
	//		on your platform, setting `isDebug` to `true` will force Dojo to
	//		pull in (and display) the version of Firebug Lite which is
	//		integrated into the Dojo distribution, thereby always providing a
	//		debugging/logging console when `isDebug` is enabled. Note that
	//		Firebug's `console.*` methods are ALWAYS defined by Dojo. If
	//		`isDebug` is false and you are on a platform without Firebug, these
	//		methods will be defined as no-ops.
	isDebug: false,
	// debugAtAllCosts: Boolean
	//		Defaults to `false`. If set to `true`, this triggers an alternate
	//		mode of the package system in which dependencies are detected and
	//		only then are resources evaluated in dependency order via
	//		`<script>` tag inclusion. This may double-request resources and
	//		cause problems with scripts which expect `dojo.require()` to
	//		preform synchronously. `debugAtAllCosts` can be an invaluable
	//		debugging aid, but when using it, ensure that all code which
	//		depends on Dojo modules is wrapped in `dojo.addOnLoad()` handlers.
	//		Due to the somewhat unpredictable side-effects of using
	//		`debugAtAllCosts`, it is strongly recommended that you enable this
	//		flag as a last resort. `debugAtAllCosts` has no effect when loading
	//		resources across domains. For usage information, see the
	//		[Dojo Book](http://dojotoolkit.org/book/book-dojo/part-4-meta-dojo-making-your-dojo-code-run-faster-and-better/debugging-facilities/deb)
	debugAtAllCosts: false,
	// locale: String
	//		The locale to assume for loading localized resources in this page,
	//		specified according to [RFC 3066](http://www.ietf.org/rfc/rfc3066.txt).
	//		Must be specified entirely in lowercase, e.g. `en-us` and `zh-cn`.
	//		See the documentation for `dojo.i18n` and `dojo.requireLocalization`
	//		for details on loading localized resources. If no locale is specified,
	//		Dojo assumes the locale of the user agent, according to `navigator.userLanguage`
	//		or `navigator.language` properties.
	locale: undefined,
	// extraLocale: Array
	//		No default value. Specifies additional locales whose
	//		resources should also be loaded alongside the default locale when
	//		calls to `dojo.requireLocalization()` are processed.
	extraLocale: undefined,
	// baseUrl: String
	//		The directory in which `dojo.js` is located. Under normal
	//		conditions, Dojo auto-detects the correct location from which it
	//		was loaded. You may need to manually configure `baseUrl` in cases
	//		where you have renamed `dojo.js` or in which `<base>` tags confuse
	//		some browsers (e.g. IE 6). The variable `dojo.baseUrl` is assigned
	//		either the value of `djConfig.baseUrl` if one is provided or the
	//		auto-detected root if not. Other modules are located relative to
	//		this path. The path should end in a slash.
	baseUrl: undefined,
	// modulePaths: Object
	//		A map of module names to paths relative to `dojo.baseUrl`. The
	//		key/value pairs correspond directly to the arguments which
	//		`dojo.registerModulePath` accepts. Specifiying
	//		`djConfig.modulePaths = { "foo": "../../bar" }` is the equivalent
	//		of calling `dojo.registerModulePath("foo", "../../bar");`. Multiple
	//		modules may be configured via `djConfig.modulePaths`.
	modulePaths: {},
	// afterOnLoad: Boolean
	//		Indicates Dojo was added to the page after the page load. In this case
	//		Dojo will not wait for the page DOMContentLoad/load events and fire
	//		its dojo.addOnLoad callbacks after making sure all outstanding
	//		dojo.required modules have loaded. Only works with a built dojo.js,
	//		it does not work the dojo.js directly from source control.
	afterOnLoad: false,
	// addOnLoad: Function or Array
	//		Adds a callback via dojo.addOnLoad. Useful when Dojo is added after
	//		the page loads and djConfig.afterOnLoad is true. Supports the same
	//		arguments as dojo.addOnLoad. When using a function reference, use
	//		`djConfig.addOnLoad = function(){};`. For object with function name use
	//		`djConfig.addOnLoad = [myObject, "functionName"];` and for object with
	//		function reference use
	//		`djConfig.addOnLoad = [myObject, function(){}];`
	addOnLoad: null,
	// require: Array
	//		An array of module names to be loaded immediately after dojo.js has been included
	//		in a page.
	require: [],
	// defaultDuration: Array
	//		Default duration, in milliseconds, for wipe and fade animations within dijits.
	//		Assigned to dijit.defaultDuration.
	defaultDuration: 200,
	// dojoBlankHtmlUrl: String
	//		Used by some modules to configure an empty iframe. Used by dojo.io.iframe and
	//		dojo.back, and dijit popup support in IE where an iframe is needed to make sure native
	//		controls do not bleed through the popups. Normally this configuration variable
	//		does not need to be set, except when using cross-domain/CDN Dojo builds.
	//		Save dojo/resources/blank.html to your domain and set `djConfig.dojoBlankHtmlUrl`
	//		to the path on your domain your copy of blank.html.
	dojoBlankHtmlUrl: undefined,
	//	ioPublish: Boolean?
	//		Set this to true to enable publishing of topics for the different phases of
	// 		IO operations. Publishing is done via dojo.publish. See dojo.__IoPublish for a list
	// 		of topics that are published.
	ioPublish: false,
	//  useCustomLogger: Anything?
	//		If set to a value that evaluates to true such as a string or array and
	//		isDebug is true and Firebug is not available or running, then it bypasses
	//		the creation of Firebug Lite allowing you to define your own console object.
	useCustomLogger: undefined,
	// transparentColor: Array
	//		Array containing the r, g, b components used as transparent color in dojo.Color;
	//		if undefined, [255,255,255] (white) will be used.
	transparentColor: undefined,
	// skipIeDomLoaded: Boolean
	//		For IE only, skip the DOMContentLoaded hack used. Sometimes it can cause an Operation
	//		Aborted error if the rest of the page triggers script defers before the DOM is ready.
	//		If this is config value is set to true, then dojo.addOnLoad callbacks will not be
	//		triggered until the page load event, which is after images and iframes load. If you
	//		want to trigger the callbacks sooner, you can put a script block in the bottom of
	//		your HTML that calls dojo._loadInit();. If you are using multiversion support, change
	//		"dojo." to the appropriate scope name for dojo.
	skipIeDomLoaded: false
}
=====*/

(function(){
	// firebug stubs

	if(typeof this["loadFirebugConsole"] == "function"){
		// for Firebug 1.2
		this["loadFirebugConsole"]();
	}else{
		this.console = this.console || {};

		//	Be careful to leave 'log' always at the end
		var cn = [
			"assert", "count", "debug", "dir", "dirxml", "error", "group",
			"groupEnd", "info", "profile", "profileEnd", "time", "timeEnd",
			"trace", "warn", "log"
		];
		var i = 0, tn;
		while((tn=cn[i++])){
			if(!console[tn]){
				(function(){
					var tcn = tn+"";
					console[tcn] = ('log' in console) ? function(){
						var a = Array.apply({}, arguments);
						a.unshift(tcn+":");
						console["log"](a.join(" "));
					} : function(){}
					console[tcn]._fake = true;
				})();
			}
		}
	}

	//TODOC:  HOW TO DOC THIS?
	// dojo is the root variable of (almost all) our public symbols -- make sure it is defined.
	if(typeof dojo == "undefined"){
		dojo = {
			_scopeName: "dojo",
			_scopePrefix: "",
			_scopePrefixArgs: "",
			_scopeSuffix: "",
			_scopeMap: {},
			_scopeMapRev: {}
		};
	}

	var d = dojo;

	//Need placeholders for dijit and dojox for scoping code.
	if(typeof dijit == "undefined"){
		dijit = {_scopeName: "dijit"};
	}
	if(typeof dojox == "undefined"){
		dojox = {_scopeName: "dojox"};
	}

	if(!d._scopeArgs){
		d._scopeArgs = [dojo, dijit, dojox];
	}

/*=====
dojo.global = {
	//	summary:
	//		Alias for the global scope
	//		(e.g. the window object in a browser).
	//	description:
	//		Refer to 'dojo.global' rather than referring to window to ensure your
	//		code runs correctly in contexts other than web browsers (e.g. Rhino on a server).
}
=====*/
	d.global = this;

	d.config =/*===== djConfig = =====*/{
		isDebug: false,
		debugAtAllCosts: false
	};

	// FIXME: 2.0, drop djConfig support. Use dojoConfig exclusively for global config.
	var cfg = typeof djConfig != "undefined" ? djConfig :
		typeof dojoConfig != "undefined" ? dojoConfig : null;
		
	if(cfg){
		for(var c in cfg){
			d.config[c] = cfg[c];
		}
	}

/*=====
	// Override locale setting, if specified
	dojo.locale = {
		// summary: the locale as defined by Dojo (read-only)
	};
=====*/
	dojo.locale = d.config.locale;

	var rev = "$Rev: 24595 $".match(/\d+/);

/*=====
	dojo.version = function(){
		// summary:
		//		Version number of the Dojo Toolkit
		// major: Integer
		//		Major version. If total version is "1.2.0beta1", will be 1
		// minor: Integer
		//		Minor version. If total version is "1.2.0beta1", will be 2
		// patch: Integer
		//		Patch version. If total version is "1.2.0beta1", will be 0
		// flag: String
		//		Descriptor flag. If total version is "1.2.0beta1", will be "beta1"
		// revision: Number
		//		The SVN rev from which dojo was pulled
		this.major = 0;
		this.minor = 0;
		this.patch = 0;
		this.flag = "";
		this.revision = 0;
	}
=====*/
	dojo.version = {
		major: 7, minor: 53, patch: 0, flag: "",
		revision: rev ? +rev[0] : NaN,
		toString: function(){
			with(d.version){
				return major + "." + minor + "." + patch + flag + " (" + revision + ")";	// String
			}
		}
	}

		// Register with the OpenAjax hub
	if(typeof OpenAjax != "undefined"){
		OpenAjax.hub.registerLibrary(dojo._scopeName, "http://dojotoolkit.org", d.version.toString());
	}
	
	var extraNames, extraLen, empty = {};
	for(var i in {toString: 1}){ extraNames = []; break; }
	dojo._extraNames = extraNames = extraNames || ["hasOwnProperty", "valueOf", "isPrototypeOf",
		"propertyIsEnumerable", "toLocaleString", "toString", "constructor"];
	extraLen = extraNames.length;

	dojo._mixin = function(/*Object*/ target, /*Object*/ source){
		// summary:
		//		Adds all properties and methods of source to target. This addition
		//		is "prototype extension safe", so that instances of objects
		//		will not pass along prototype defaults.
		var name, s, i;
		for(name in source){
			// the "tobj" condition avoid copying properties in "source"
			// inherited from Object.prototype.  For example, if target has a custom
			// toString() method, don't overwrite it with the toString() method
			// that source inherited from Object.prototype
			s = source[name];
			if(!(name in target) || (target[name] !== s && (!(name in empty) || empty[name] !== s))){
				target[name] = s;
			}
		}
				// IE doesn't recognize some custom functions in for..in
		if(extraLen && source){
			for(i = 0; i < extraLen; ++i){
				name = extraNames[i];
				s = source[name];
				if(!(name in target) || (target[name] !== s && (!(name in empty) || empty[name] !== s))){
					target[name] = s;
				}
			}
		}
				return target; // Object
	}

	dojo.mixin = function(/*Object*/obj, /*Object...*/props){
		// summary:
		//		Adds all properties and methods of props to obj and returns the
		//		(now modified) obj.
		//	description:
		//		`dojo.mixin` can mix multiple source objects into a
		//		destination object which is then returned. Unlike regular
		//		`for...in` iteration, `dojo.mixin` is also smart about avoiding
		//		extensions which other toolkits may unwisely add to the root
		//		object prototype
		//	obj:
		//		The object to mix properties into. Also the return value.
		//	props:
		//		One or more objects whose values are successively copied into
		//		obj. If more than one of these objects contain the same value,
		//		the one specified last in the function call will "win".
		//	example:
		//		make a shallow copy of an object
		//	|	var copy = dojo.mixin({}, source);
		//	example:
		//		many class constructors often take an object which specifies
		//		values to be configured on the object. In this case, it is
		//		often simplest to call `dojo.mixin` on the `this` object:
		//	|	dojo.declare("acme.Base", null, {
		//	|		constructor: function(properties){
		//	|			// property configuration:
		//	|			dojo.mixin(this, properties);
		//	|
		//	|			console.log(this.quip);
		//	|			//  ...
		//	|		},
		//	|		quip: "I wasn't born yesterday, you know - I've seen movies.",
		//	|		// ...
		//	|	});
		//	|
		//	|	// create an instance of the class and configure it
		//	|	var b = new acme.Base({quip: "That's what it does!" });
		//	example:
		//		copy in properties from multiple objects
		//	|	var flattened = dojo.mixin(
		//	|		{
		//	|			name: "Frylock",
		//	|			braces: true
		//	|		},
		//	|		{
		//	|			name: "Carl Brutanananadilewski"
		//	|		}
		//	|	);
		//	|
		//	|	// will print "Carl Brutanananadilewski"
		//	|	console.log(flattened.name);
		//	|	// will print "true"
		//	|	console.log(flattened.braces);
		if(!obj){ obj = {}; }
		for(var i=1, l=arguments.length; i<l; i++){
			d._mixin(obj, arguments[i]);
		}
		return obj; // Object
	}

	dojo._getProp = function(/*Array*/parts, /*Boolean*/create, /*Object*/context){
		var obj=context || d.global;
		for(var i=0, p; obj && (p=parts[i]); i++){
			if(i == 0 && d._scopeMap[p]){
				p = d._scopeMap[p];
			}
			obj = (p in obj ? obj[p] : (create ? obj[p]={} : undefined));
		}
		return obj; // mixed
	}

	dojo.setObject = function(/*String*/name, /*Object*/value, /*Object?*/context){
		// summary:
		//		Set a property from a dot-separated string, such as "A.B.C"
		//	description:
		//		Useful for longer api chains where you have to test each object in
		//		the chain, or when you have an object reference in string format.
		//		Objects are created as needed along `path`. Returns the passed
		//		value if setting is successful or `undefined` if not.
		//	name:
		//		Path to a property, in the form "A.B.C".
		//	context:
		//		Optional. Object to use as root of path. Defaults to
		//		`dojo.global`.
		//	example:
		//		set the value of `foo.bar.baz`, regardless of whether
		//		intermediate objects already exist:
		//	|	dojo.setObject("foo.bar.baz", value);
		//	example:
		//		without `dojo.setObject`, we often see code like this:
		//	|	// ensure that intermediate objects are available
		//	|	if(!obj["parent"]){ obj.parent = {}; }
		//	|	if(!obj.parent["child"]){ obj.parent.child= {}; }
		//	|	// now we can safely set the property
		//	|	obj.parent.child.prop = "some value";
		//		wheras with `dojo.setObject`, we can shorten that to:
		//	|	dojo.setObject("parent.child.prop", "some value", obj);
		var parts=name.split("."), p=parts.pop(), obj=d._getProp(parts, true, context);
		return obj && p ? (obj[p]=value) : undefined; // Object
	}

	dojo.getObject = function(/*String*/name, /*Boolean?*/create, /*Object?*/context){
		// summary:
		//		Get a property from a dot-separated string, such as "A.B.C"
		//	description:
		//		Useful for longer api chains where you have to test each object in
		//		the chain, or when you have an object reference in string format.
		//	name:
		//		Path to an property, in the form "A.B.C".
		//	create:
		//		Optional. Defaults to `false`. If `true`, Objects will be
		//		created at any point along the 'path' that is undefined.
		//	context:
		//		Optional. Object to use as root of path. Defaults to
		//		'dojo.global'. Null may be passed.
		return d._getProp(name.split("."), create, context); // Object
	}

	dojo.exists = function(/*String*/name, /*Object?*/obj){
		//	summary:
		//		determine if an object supports a given method
		//	description:
		//		useful for longer api chains where you have to test each object in
		//		the chain. Useful for object and method detection.
		//	name:
		//		Path to an object, in the form "A.B.C".
		//	obj:
		//		Object to use as root of path. Defaults to
		//		'dojo.global'. Null may be passed.
		//	example:
		//	|	// define an object
		//	|	var foo = {
		//	|		bar: { }
		//	|	};
		//	|
		//	|	// search the global scope
		//	|	dojo.exists("foo.bar"); // true
		//	|	dojo.exists("foo.bar.baz"); // false
		//	|
		//	|	// search from a particular scope
		//	|	dojo.exists("bar", foo); // true
		//	|	dojo.exists("bar.baz", foo); // false
		return d.getObject(name, false, obj) !== undefined; // Boolean
	}

	dojo["eval"] = function(/*String*/ scriptFragment){
		//	summary:
		//		A legacy method created for use exclusively by internal Dojo methods. Do not use
		//		this method directly, the behavior of this eval will differ from the normal
		//		browser eval.
		//	description:
		//		Placed in a separate function to minimize size of trapped
		//		exceptions. Calling eval() directly from some other scope may
		//		complicate tracebacks on some platforms.
		//	returns:
		//		The result of the evaluation. Often `undefined`
		return d.global.eval ? d.global.eval(scriptFragment) : eval(scriptFragment); 	// Object
	}

	/*=====
		dojo.deprecated = function(behaviour, extra, removal){
			//	summary:
			//		Log a debug message to indicate that a behavior has been
			//		deprecated.
			//	behaviour: String
			//		The API or behavior being deprecated. Usually in the form
			//		of "myApp.someFunction()".
			//	extra: String?
			//		Text to append to the message. Often provides advice on a
			//		new function or facility to achieve the same goal during
			//		the deprecation period.
			//	removal: String?
			//		Text to indicate when in the future the behavior will be
			//		removed. Usually a version number.
			//	example:
			//	|	dojo.deprecated("myApp.getTemp()", "use myApp.getLocaleTemp() instead", "1.0");
		}

		dojo.experimental = function(moduleName, extra){
			//	summary: Marks code as experimental.
			//	description:
			//	 	This can be used to mark a function, file, or module as
			//	 	experimental.  Experimental code is not ready to be used, and the
			//	 	APIs are subject to change without notice.  Experimental code may be
			//	 	completed deleted without going through the normal deprecation
			//	 	process.
			//	moduleName: String
			//	 	The name of a module, or the name of a module file or a specific
			//	 	function
			//	extra: String?
			//	 	some additional message for the user
			//	example:
			//	|	dojo.experimental("dojo.data.Result");
			//	example:
			//	|	dojo.experimental("dojo.weather.toKelvin()", "PENDING approval from NOAA");
		}
	=====*/

	//Real functions declared in dojo._firebug.firebug.
	d.deprecated = d.experimental = function(){};

})();
// vim:ai:ts=4:noet

/*
 * loader.js - A bootstrap module.  Runs before the hostenv_*.js file. Contains
 * all of the package loading methods.
 */
(function(){
	var d = dojo, currentModule;

	d.mixin(d, {
		_loadedModules: {},
		_inFlightCount: 0,
		_hasResource: {},

		_modulePrefixes: {
			dojo: 	{	name: "dojo", value: "." },
			// dojox: 	{	name: "dojox", value: "../dojox" },
			// dijit: 	{	name: "dijit", value: "../dijit" },
			doh: 	{	name: "doh", value: "../util/doh" },
			tests: 	{	name: "tests", value: "tests" }
		},

		_moduleHasPrefix: function(/*String*/module){
			// summary: checks to see if module has been established
			var mp = d._modulePrefixes;
			return !!(mp[module] && mp[module].value); // Boolean
		},

		_getModulePrefix: function(/*String*/module){
			// summary: gets the prefix associated with module
			var mp = d._modulePrefixes;
			if(d._moduleHasPrefix(module)){
				return mp[module].value; // String
			}
			return module; // String
		},

		_loadedUrls: [],

		//WARNING:
		//		This variable is referenced by packages outside of bootstrap:
		//		FloatingPane.js and undo/browser.js
		_postLoad: false,

		//Egad! Lots of test files push on this directly instead of using dojo.addOnLoad.
		_loaders: [],
		_unloaders: [],
		_loadNotifying: false
	});


		dojo._loadPath = function(/*String*/relpath, /*String?*/module, /*Function?*/cb){
		// 	summary:
		//		Load a Javascript module given a relative path
		//
		//	description:
		//		Loads and interprets the script located at relpath, which is
		//		relative to the script root directory.  If the script is found but
		//		its interpretation causes a runtime exception, that exception is
		//		not caught by us, so the caller will see it.  We return a true
		//		value if and only if the script is found.
		//
		// relpath:
		//		A relative path to a script (no leading '/', and typically ending
		//		in '.js').
		// module:
		//		A module whose existance to check for after loading a path.  Can be
		//		used to determine success or failure of the load.
		// cb:
		//		a callback function to pass the result of evaluating the script

		var uri = ((relpath.charAt(0) == '/' || relpath.match(/^\w+:/)) ? "" : d.baseUrl) + relpath;
		try{
			currentModule = module;
			return !module ? d._loadUri(uri, cb) : d._loadUriAndCheck(uri, module, cb); // Boolean
		}catch(e){
			console.error(e);
			return false; // Boolean
		}finally{
			currentModule = null;
		}
	}

	dojo._loadUri = function(/*String*/uri, /*Function?*/cb){
		//	summary:
		//		Loads JavaScript from a URI
		//	description:
		//		Reads the contents of the URI, and evaluates the contents.  This is
		//		used to load modules as well as resource bundles. Returns true if
		//		it succeeded. Returns false if the URI reading failed.  Throws if
		//		the evaluation throws.
		//	uri: a uri which points at the script to be loaded
		//	cb:
		//		a callback function to process the result of evaluating the script
		//		as an expression, typically used by the resource bundle loader to
		//		load JSON-style resources

		if(d._loadedUrls[uri]){
			return true; // Boolean
		}
		d._inFlightCount++; // block addOnLoad calls that arrive while we're busy downloading
		var contents = d._getText(uri, true);
		if(contents){ // not 404, et al
			d._loadedUrls[uri] = true;
			d._loadedUrls.push(uri);
			if(cb){
				//conditional to support script-inject i18n bundle format
				contents = /^define\(/.test(contents) ? contents : '('+contents+')';
			}else{
				//Only do the scoping if no callback. If a callback is specified,
				//it is most likely the i18n bundle stuff.
				contents = d._scopePrefix + contents + d._scopeSuffix;
			}
			if(!d.isIE){ contents += "\r\n//@ sourceURL=" + uri; } // debugging assist for Firebug
			var value = d["eval"](contents);
			if(cb){ cb(value); }
		}
		// Check to see if we need to call _callLoaded() due to an addOnLoad() that arrived while we were busy downloading
		if(--d._inFlightCount == 0 && d._postLoad && d._loaders.length){
			// We shouldn't be allowed to get here but Firefox allows an event
			// (mouse, keybd, async xhrGet) to interrupt a synchronous xhrGet.
			// If the current script block contains multiple require() statements, then after each
			// require() returns, inFlightCount == 0, but we want to hold the _callLoaded() until
			// all require()s are done since the out-of-sequence addOnLoad() presumably needs them all.
			// setTimeout allows the next require() to start (if needed), and then we check this again.
			setTimeout(function(){
				// If inFlightCount > 0, then multiple require()s are running sequentially and
				// the next require() started after setTimeout() was executed but before we got here.
				if(d._inFlightCount == 0){
					d._callLoaded();
				}
			}, 0);
		}
		return !!contents; // Boolean: contents? true : false
	}
	
	// FIXME: probably need to add logging to this method
	dojo._loadUriAndCheck = function(/*String*/uri, /*String*/moduleName, /*Function?*/cb){
		// summary: calls loadUri then findModule and returns true if both succeed
		var ok = false;
		try{
			ok = d._loadUri(uri, cb);
		}catch(e){
			console.error("failed loading " + uri + " with error: " + e);
		}
		return !!(ok && d._loadedModules[moduleName]); // Boolean
	}

	dojo.loaded = function(){
		// summary:
		//		signal fired when initial environment and package loading is
		//		complete. You should use dojo.addOnLoad() instead of doing a
		//		direct dojo.connect() to this method in order to handle
		//		initialization tasks that require the environment to be
		//		initialized. In a browser host,	declarative widgets will
		//		be constructed when this function finishes runing.
		d._loadNotifying = true;
		d._postLoad = true;
		var mll = d._loaders;

		//Clear listeners so new ones can be added
		//For other xdomain package loads after the initial load.
		d._loaders = [];

		for(var x = 0; x < mll.length; x++){
			mll[x]();
		}

		d._loadNotifying = false;
		
		//Make sure nothing else got added to the onload queue
		//after this first run. If something did, and we are not waiting for any
		//more inflight resources, run again.
		if(d._postLoad && d._inFlightCount == 0 && mll.length){
			d._callLoaded();
		}
	}

	dojo.unloaded = function(){
		// summary:
		//		signal fired by impending environment destruction. You should use
		//		dojo.addOnUnload() instead of doing a direct dojo.connect() to this
		//		method to perform page/application cleanup methods. See
		//		dojo.addOnUnload for more info.
		var mll = d._unloaders;
		while(mll.length){
			(mll.pop())();
		}
	}

	d._onto = function(arr, obj, fn){
		if(!fn){
			arr.push(obj);
		}else if(fn){
			var func = (typeof fn == "string") ? obj[fn] : fn;
			arr.push(function(){ func.call(obj); });
		}
	}

	dojo.ready = dojo.addOnLoad = function(/*Object*/obj, /*String|Function?*/functionName){
		// summary:
		//		Registers a function to be triggered after the DOM and dojo.require() calls
		//		have finished loading.
		//
		// description:
		//		Registers a function to be triggered after the DOM has finished
		//		loading and `dojo.require` modules have loaded. Widgets declared in markup
		//		have been instantiated if `djConfig.parseOnLoad` is true when this fires.
		//
		//		Images and CSS files may or may not have finished downloading when
		//		the specified function is called.  (Note that widgets' CSS and HTML
		//		code is guaranteed to be downloaded before said widgets are
		//		instantiated, though including css resouces BEFORE any script elements
		//		is highly recommended).
		//
		// example:
		//	Register an anonymous function to run when everything is ready
		//	|	dojo.addOnLoad(function(){ doStuff(); });
		//
		// example:
		//	Register a function to run when everything is ready by pointer:
		//	|	var init = function(){ doStuff(); }
		//	|	dojo.addOnLoad(init);
		//
		// example:
		//	Register a function to run scoped to `object`, either by name or anonymously:
		//	|	dojo.addOnLoad(object, "functionName");
		//	|	dojo.addOnLoad(object, function(){ doStuff(); });

		d._onto(d._loaders, obj, functionName);

		//Added for xdomain loading. dojo.addOnLoad is used to
		//indicate callbacks after doing some dojo.require() statements.
		//In the xdomain case, if all the requires are loaded (after initial
		//page load), then immediately call any listeners.
		if(d._postLoad && d._inFlightCount == 0 && !d._loadNotifying){
			d._callLoaded();
		}
	}

	//Support calling dojo.addOnLoad via djConfig.addOnLoad. Support all the
	//call permutations of dojo.addOnLoad. Mainly useful when dojo is added
	//to the page after the page has loaded.
	var dca = d.config.addOnLoad;
	if(dca){
		d.addOnLoad[(dca instanceof Array ? "apply" : "call")](d, dca);
	}

	dojo._modulesLoaded = function(){
		if(d._postLoad){ return; }
		if(d._inFlightCount > 0){
			console.warn("files still in flight!");
			return;
		}
		d._callLoaded();
	}

	dojo._callLoaded = function(){

		// The "object" check is for IE, and the other opera check fixes an
		// issue in Opera where it could not find the body element in some
		// widget test cases.  For 0.9, maybe route all browsers through the
		// setTimeout (need protection still for non-browser environments
		// though). This might also help the issue with FF 2.0 and freezing
		// issues where we try to do sync xhr while background css images are
		// being loaded (trac #2572)? Consider for 0.9.
		if(typeof setTimeout == "object" || (d.config.useXDomain && d.isOpera)){
			setTimeout(
				d.isAIR ? function(){ d.loaded(); } : d._scopeName + ".loaded();",
				0);
		}else{
			d.loaded();
		}
	}

	dojo._getModuleSymbols = function(/*String*/modulename){
		// summary:
		//		Converts a module name in dotted JS notation to an array
		//		representing the path in the source tree
		var syms = modulename.split(".");
		for(var i = syms.length; i>0; i--){
			var parentModule = syms.slice(0, i).join(".");
			if(i == 1 && !d._moduleHasPrefix(parentModule)){
				// Support default module directory (sibling of dojo) for top-level modules
				syms[0] = "../" + syms[0];
			}else{
				var parentModulePath = d._getModulePrefix(parentModule);
				if(parentModulePath != parentModule){
					syms.splice(0, i, parentModulePath);
					break;
				}
			}
		}
		return syms; // Array
	}

	dojo._global_omit_module_check = false;

	dojo.loadInit = function(/*Function*/init){
		//	summary:
		//		Executes a function that needs to be executed for the loader's dojo.requireIf
		//		resolutions to work. This is needed mostly for the xdomain loader case where
		//		a function needs to be executed to set up the possible values for a dojo.requireIf
		//		call.
		//	init:
		//		a function reference. Executed immediately.
		//	description: This function is mainly a marker for the xdomain loader to know parts of
		//		code that needs be executed outside the function wrappper that is placed around modules.
		//		The init function could be executed more than once, and it should make no assumptions
		//		on what is loaded, or what modules are available. Only the functionality in Dojo Base
		//		is allowed to be used. Avoid using this method. For a valid use case,
		//		see the source for dojox.gfx.
		init();
	}

	dojo._loadModule = dojo.require = function(/*String*/moduleName, /*Boolean?*/omitModuleCheck){
		//	summary:
		//		loads a Javascript module from the appropriate URI
		//
		//	moduleName: String
		//		module name to load, using periods for separators,
		//		 e.g. "dojo.date.locale".  Module paths are de-referenced by dojo's
		//		internal mapping of locations to names and are disambiguated by
		//		longest prefix. See `dojo.registerModulePath()` for details on
		//		registering new modules.
		//
		//	omitModuleCheck: Boolean?
		//		if `true`, omitModuleCheck skips the step of ensuring that the
		//		loaded file actually defines the symbol it is referenced by.
		//		For example if it called as `dojo.require("a.b.c")` and the
		//		file located at `a/b/c.js` does not define an object `a.b.c`,
		//		and exception will be throws whereas no exception is raised
		//		when called as `dojo.require("a.b.c", true)`
		//
		//	description:
		// 		Modules are loaded via dojo.require by using one of two loaders: the normal loader
		// 		and the xdomain loader. The xdomain loader is used when dojo was built with a
		// 		custom build that specified loader=xdomain and the module lives on a modulePath
		// 		that is a whole URL, with protocol and a domain. The versions of Dojo that are on
		// 		the Google and AOL CDNs use the xdomain loader.
		//
		// 		If the module is loaded via the xdomain loader, it is an asynchronous load, since
		// 		the module is added via a dynamically created script tag. This
		// 		means that dojo.require() can return before the module has loaded. However, this
		// 		should only happen in the case where you do dojo.require calls in the top-level
		// 		HTML page, or if you purposely avoid the loader checking for dojo.require
		// 		dependencies in your module by using a syntax like dojo["require"] to load the module.
		//
		// 		Sometimes it is useful to not have the loader detect the dojo.require calls in the
		// 		module so that you can dynamically load the modules as a result of an action on the
		// 		page, instead of right at module load time.
		//
		// 		Also, for script blocks in an HTML page, the loader does not pre-process them, so
		// 		it does not know to download the modules before the dojo.require calls occur.
		//
		// 		So, in those two cases, when you want on-the-fly module loading or for script blocks
		// 		in the HTML page, special care must be taken if the dojo.required code is loaded
		// 		asynchronously. To make sure you can execute code that depends on the dojo.required
		// 		modules, be sure to add the code that depends on the modules in a dojo.addOnLoad()
		// 		callback. dojo.addOnLoad waits for all outstanding modules to finish loading before
		// 		executing.
		//
		// 		This type of syntax works with both xdomain and normal loaders, so it is good
		// 		practice to always use this idiom for on-the-fly code loading and in HTML script
		// 		blocks. If at some point you change loaders and where the code is loaded from,
		// 		it will all still work.
		//
		// 		More on how dojo.require
		//		`dojo.require("A.B")` first checks to see if symbol A.B is
		//		defined. If it is, it is simply returned (nothing to do).
		//
		//		If it is not defined, it will look for `A/B.js` in the script root
		//		directory.
		//
		//		`dojo.require` throws an exception if it cannot find a file
		//		to load, or if the symbol `A.B` is not defined after loading.
		//
		//		It returns the object `A.B`, but note the caveats above about on-the-fly loading and
		// 		HTML script blocks when the xdomain loader is loading a module.
		//
		//		`dojo.require()` does nothing about importing symbols into
		//		the current namespace.  It is presumed that the caller will
		//		take care of that.
		//
		// 	example:
		// 		To use dojo.require in conjunction with dojo.ready:
		//
		//		|	dojo.require("foo");
		//		|	dojo.require("bar");
		//	   	|	dojo.addOnLoad(function(){
		//	   	|		//you can now safely do something with foo and bar
		//	   	|	});
		//
		//	example:
		//		For example, to import all symbols into a local block, you might write:
		//
		//		|	with (dojo.require("A.B")) {
		//		|		...
		//		|	}
		//
		//		And to import just the leaf symbol to a local variable:
		//
		//		|	var B = dojo.require("A.B");
		//	   	|	...
		//
		//	returns:
		//		the required namespace object
		omitModuleCheck = d._global_omit_module_check || omitModuleCheck;

		//Check if it is already loaded.
		var module = d._loadedModules[moduleName];
		if(module){
			return module;
		}

		// convert periods to slashes
		var relpath = d._getModuleSymbols(moduleName).join("/") + '.js';
		var modArg = !omitModuleCheck ? moduleName : null;
		var ok = d._loadPath(relpath, modArg);
		if(!ok && !omitModuleCheck){
			throw new Error("Could not load '" + moduleName + "'; last tried '" + relpath + "'");
		}

		// check that the symbol was defined
		// Don't bother if we're doing xdomain (asynchronous) loading.
		if(!omitModuleCheck && !d._isXDomain){
			// pass in false so we can give better error
			module = d._loadedModules[moduleName];
			if(!module){
				throw new Error("symbol '" + moduleName + "' is not defined after loading '" + relpath + "'");
			}
		}

		return module;
	}

	dojo.provide = function(/*String*/ resourceName){
		//	summary:
		//		Register a resource with the package system. Works in conjunction with `dojo.require`
		//
		//	description:
		//		Each javascript source file is called a resource.  When a
		//		resource is loaded by the browser, `dojo.provide()` registers
		//		that it has been loaded.
		//
		//		Each javascript source file must have at least one
		//		`dojo.provide()` call at the top of the file, corresponding to
		//		the file name.  For example, `js/dojo/foo.js` must have
		//		`dojo.provide("dojo.foo");` before any calls to
		//		`dojo.require()` are made.
		//
		//		For backwards compatibility reasons, in addition to registering
		//		the resource, `dojo.provide()` also ensures that the javascript
		//		object for the module exists.  For example,
		//		`dojo.provide("dojox.data.FlickrStore")`, in addition to
		//		registering that `FlickrStore.js` is a resource for the
		//		`dojox.data` module, will ensure that the `dojox.data`
		//		javascript object exists, so that calls like
		//		`dojo.data.foo = function(){ ... }` don't fail.
		//
		//		In the case of a build where multiple javascript source files
		//		are combined into one bigger file (similar to a .lib or .jar
		//		file), that file may contain multiple dojo.provide() calls, to
		//		note that it includes multiple resources.
		//
		// resourceName: String
		//		A dot-sperated string identifying a resource.
		//
		// example:
		//	Safely create a `my` object, and make dojo.require("my.CustomModule") work
		//	|	dojo.provide("my.CustomModule");

		//Make sure we have a string.
		resourceName = resourceName + "";
		return (d._loadedModules[resourceName] = d.getObject(resourceName, true)); // Object
	}

	//Start of old bootstrap2:

	dojo.platformRequire = function(/*Object*/modMap){
		//	summary:
		//		require one or more modules based on which host environment
		//		Dojo is currently operating in
		//	description:
		//		This method takes a "map" of arrays which one can use to
		//		optionally load dojo modules. The map is indexed by the
		//		possible dojo.name_ values, with two additional values:
		//		"default" and "common". The items in the "default" array will
		//		be loaded if none of the other items have been choosen based on
		//		dojo.name_, set by your host environment. The items in the
		//		"common" array will *always* be loaded, regardless of which
		//		list is chosen.
		//	example:
		//		|	dojo.platformRequire({
		//		|		browser: [
		//		|			"foo.sample", // simple module
		//		|			"foo.test",
		//		|			["foo.bar.baz", true] // skip object check in _loadModule (dojo.require)
		//		|		],
		//		|		default: [ "foo.sample._base" ],
		//		|		common: [ "important.module.common" ]
		//		|	});

		var common = modMap.common || [];
		var result = common.concat(modMap[d._name] || modMap["default"] || []);

		for(var x=0; x<result.length; x++){
			var curr = result[x];
			if(curr.constructor == Array){
				d._loadModule.apply(d, curr);
			}else{
				d._loadModule(curr);
			}
		}
	}

	dojo.requireIf = function(/*Boolean*/ condition, /*String*/ resourceName){
		// summary:
		//		If the condition is true then call `dojo.require()` for the specified
		//		resource
		//
		// example:
		//	|	dojo.requireIf(dojo.isBrowser, "my.special.Module");
		
		if(condition === true){
			// FIXME: why do we support chained require()'s here? does the build system?
			var args = [];
			for(var i = 1; i < arguments.length; i++){
				args.push(arguments[i]);
			}
			d.require.apply(d, args);
		}
	}

	dojo.requireAfterIf = d.requireIf;

	dojo.registerModulePath = function(/*String*/module, /*String*/prefix){
		//	summary:
		//		Maps a module name to a path
		//	description:
		//		An unregistered module is given the default path of ../[module],
		//		relative to Dojo root. For example, module acme is mapped to
		//		../acme.  If you want to use a different module name, use
		//		dojo.registerModulePath.
		//	example:
		//		If your dojo.js is located at this location in the web root:
		//	|	/myapp/js/dojo/dojo/dojo.js
		//		and your modules are located at:
		//	|	/myapp/js/foo/bar.js
		//	|	/myapp/js/foo/baz.js
		//	|	/myapp/js/foo/thud/xyzzy.js
		//		Your application can tell Dojo to locate the "foo" namespace by calling:
		//	|	dojo.registerModulePath("foo", "../../foo");
		//		At which point you can then use dojo.require() to load the
		//		modules (assuming they provide() the same things which are
		//		required). The full code might be:
		//	|	<script type="text/javascript"
		//	|		src="/myapp/js/dojo/dojo/dojo.js"></script>
		//	|	<script type="text/javascript">
		//	|		dojo.registerModulePath("foo", "../../foo");
		//	|		dojo.require("foo.bar");
		//	|		dojo.require("foo.baz");
		//	|		dojo.require("foo.thud.xyzzy");
		//	|	</script>
		d._modulePrefixes[module] = { name: module, value: prefix };
	};
	
	dojo.requireLocalization = function(/*String*/moduleName, /*String*/bundleName, /*String?*/locale, /*String?*/availableFlatLocales){
		// summary:
		//		Declares translated resources and loads them if necessary, in the
		//		same style as dojo.require.  Contents of the resource bundle are
		//		typically strings, but may be any name/value pair, represented in
		//		JSON format.  See also `dojo.i18n.getLocalization`.
		//
		// description:
		//		Load translated resource bundles provided underneath the "nls"
		//		directory within a package.  Translated resources may be located in
		//		different packages throughout the source tree.
		//
		//		Each directory is named for a locale as specified by RFC 3066,
		//		(http://www.ietf.org/rfc/rfc3066.txt), normalized in lowercase.
		//		Note that the two bundles in the example do not define all the
		//		same variants.  For a given locale, bundles will be loaded for
		//		that locale and all more general locales above it, including a
		//		fallback at the root directory.  For example, a declaration for
		//		the "de-at" locale will first load `nls/de-at/bundleone.js`,
		//		then `nls/de/bundleone.js` and finally `nls/bundleone.js`.  The
		//		data will be flattened into a single Object so that lookups
		//		will follow this cascading pattern.  An optional build step can
		//		preload the bundles to avoid data redundancy and the multiple
		//		network hits normally required to load these resources.
		//
		// moduleName:
		//		name of the package containing the "nls" directory in which the
		//		bundle is found
		//
		// bundleName:
		//		bundle name, i.e. the filename without the '.js' suffix. Using "nls" as a
		//		a bundle name is not supported, since "nls" is the name of the folder
		//		that holds bundles. Using "nls" as the bundle name will cause problems
		//		with the custom build.
		//
		// locale:
		//		the locale to load (optional)  By default, the browser's user
		//		locale as defined by dojo.locale
		//
		// availableFlatLocales:
		//		A comma-separated list of the available, flattened locales for this
		//		bundle. This argument should only be set by the build process.
		//
		//	example:
		//		A particular widget may define one or more resource bundles,
		//		structured in a program as follows, where moduleName is
		//		mycode.mywidget and bundleNames available include bundleone and
		//		bundletwo:
		//	|		...
		//	|	mycode/
		//	|		mywidget/
		//	|			nls/
		//	|				bundleone.js (the fallback translation, English in this example)
		//	|				bundletwo.js (also a fallback translation)
		//	|				de/
		//	|					bundleone.js
		//	|					bundletwo.js
		//	|				de-at/
		//	|					bundleone.js
		//	|				en/
		//	|					(empty; use the fallback translation)
		//	|				en-us/
		//	|					bundleone.js
		//	|				en-gb/
		//	|					bundleone.js
		//	|				es/
		//	|					bundleone.js
		//	|					bundletwo.js
		//	|				  ...etc
		//	|				...
		//

		d.require("dojo.i18n");
		d.i18n._requireLocalization.apply(d.hostenv, arguments);
	};


	var ore = new RegExp("^(([^:/?#]+):)?(//([^/?#]*))?([^?#]*)(\\?([^#]*))?(#(.*))?$"),
		ire = new RegExp("^((([^\\[:]+):)?([^@]+)@)?(\\[([^\\]]+)\\]|([^\\[:]*))(:([0-9]+))?$");

	dojo._Url = function(/*dojo._Url|String...*/){
		// summary:
		//		Constructor to create an object representing a URL.
		//		It is marked as private, since we might consider removing
		//		or simplifying it.
		// description:
		//		Each argument is evaluated in order relative to the next until
		//		a canonical uri is produced. To get an absolute Uri relative to
		//		the current document use:
		//      	new dojo._Url(document.baseURI, url)

		var n = null,
			_a = arguments,
			uri = [_a[0]];
		// resolve uri components relative to each other
		for(var i = 1; i<_a.length; i++){
			if(!_a[i]){ continue; }

			// Safari doesn't support this.constructor so we have to be explicit
			// FIXME: Tracked (and fixed) in Webkit bug 3537.
			//		http://bugs.webkit.org/show_bug.cgi?id=3537
			var relobj = new d._Url(_a[i]+""),
				uriobj = new d._Url(uri[0]+"");

			if(
				relobj.path == "" &&
				!relobj.scheme &&
				!relobj.authority &&
				!relobj.query
			){
				if(relobj.fragment != n){
					uriobj.fragment = relobj.fragment;
				}
				relobj = uriobj;
			}else if(!relobj.scheme){
				relobj.scheme = uriobj.scheme;

				if(!relobj.authority){
					relobj.authority = uriobj.authority;

					if(relobj.path.charAt(0) != "/"){
						var path = uriobj.path.substring(0,
							uriobj.path.lastIndexOf("/") + 1) + relobj.path;

						var segs = path.split("/");
						for(var j = 0; j < segs.length; j++){
							if(segs[j] == "."){
								// flatten "./" references
								if(j == segs.length - 1){
									segs[j] = "";
								}else{
									segs.splice(j, 1);
									j--;
								}
							}else if(j > 0 && !(j == 1 && segs[0] == "") &&
								segs[j] == ".." && segs[j-1] != ".."){
								// flatten "../" references
								if(j == (segs.length - 1)){
									segs.splice(j, 1);
									segs[j - 1] = "";
								}else{
									segs.splice(j - 1, 2);
									j -= 2;
								}
							}
						}
						relobj.path = segs.join("/");
					}
				}
			}

			uri = [];
			if(relobj.scheme){
				uri.push(relobj.scheme, ":");
			}
			if(relobj.authority){
				uri.push("//", relobj.authority);
			}
			uri.push(relobj.path);
			if(relobj.query){
				uri.push("?", relobj.query);
			}
			if(relobj.fragment){
				uri.push("#", relobj.fragment);
			}
		}

		this.uri = uri.join("");

		// break the uri into its main components
		var r = this.uri.match(ore);

		this.scheme = r[2] || (r[1] ? "" : n);
		this.authority = r[4] || (r[3] ? "" : n);
		this.path = r[5]; // can never be undefined
		this.query = r[7] || (r[6] ? "" : n);
		this.fragment  = r[9] || (r[8] ? "" : n);

		if(this.authority != n){
			// server based naming authority
			r = this.authority.match(ire);

			this.user = r[3] || n;
			this.password = r[4] || n;
			this.host = r[6] || r[7]; // ipv6 || ipv4
			this.port = r[9] || n;
		}
	}

	dojo._Url.prototype.toString = function(){ return this.uri; };

	dojo.moduleUrl = function(/*String*/module, /*dojo._Url||String*/url){
		//	summary:
		//		Returns a `dojo._Url` object relative to a module.
		//	example:
		//	|	var pngPath = dojo.moduleUrl("acme","images/small.png");
		//	|	console.dir(pngPath); // list the object properties
		//	|	// create an image and set it's source to pngPath's value:
		//	|	var img = document.createElement("img");
		// 	|	// NOTE: we assign the string representation of the url object
		//	|	img.src = pngPath.toString();
		//	|	// add our image to the document
		//	|	dojo.body().appendChild(img);
		//	example:
		//		you may de-reference as far as you like down the package
		//		hierarchy.  This is sometimes handy to avoid lenghty relative
		//		urls or for building portable sub-packages. In this example,
		//		the `acme.widget` and `acme.util` directories may be located
		//		under different roots (see `dojo.registerModulePath`) but the
		//		the modules which reference them can be unaware of their
		//		relative locations on the filesystem:
		//	|	// somewhere in a configuration block
		//	|	dojo.registerModulePath("acme.widget", "../../acme/widget");
		//	|	dojo.registerModulePath("acme.util", "../../util");
		//	|
		//	|	// ...
		//	|
		//	|	// code in a module using acme resources
		//	|	var tmpltPath = dojo.moduleUrl("acme.widget","templates/template.html");
		//	|	var dataPath = dojo.moduleUrl("acme.util","resources/data.json");

		var loc = d._getModuleSymbols(module).join('/');
		if(!loc){ return null; }
		if(loc.lastIndexOf("/") != loc.length-1){
			loc += "/";
		}
		
		//If the path is an absolute path (starts with a / or is on another
		//domain/xdomain) then don't add the baseUrl.
		var colonIndex = loc.indexOf(":");
		if(loc.charAt(0) != "/" && (colonIndex == -1 || colonIndex > loc.indexOf("/"))){
			loc = d.baseUrl + loc;
		}

		return new d._Url(loc, url); // dojo._Url
	};



})();

/*=====
dojo.isBrowser = {
	//	example:
	//	|	if(dojo.isBrowser){ ... }
};

dojo.isFF = {
	//	example:
	//	|	if(dojo.isFF > 1){ ... }
};

dojo.isIE = {
	// example:
	//	|	if(dojo.isIE > 6){
	//	|		// we are IE7
	// 	|	}
};

dojo.isSafari = {
	//	example:
	//	|	if(dojo.isSafari){ ... }
	//	example:
	//		Detect iPhone:
	//	|	if(dojo.isSafari && navigator.userAgent.indexOf("iPhone") != -1){
	//	|		// we are iPhone. Note, iPod touch reports "iPod" above and fails this test.
	//	|	}
};

dojo = {
	// isBrowser: Boolean
	//		True if the client is a web-browser
	isBrowser: true,
	//	isFF: Number | undefined
	//		Version as a Number if client is FireFox. undefined otherwise. Corresponds to
	//		major detected FireFox version (1.5, 2, 3, etc.)
	isFF: 2,
	//	isIE: Number | undefined
	//		Version as a Number if client is MSIE(PC). undefined otherwise. Corresponds to
	//		major detected IE version (6, 7, 8, etc.)
	isIE: 6,
	//	isKhtml: Number | undefined
	//		Version as a Number if client is a KHTML browser. undefined otherwise. Corresponds to major
	//		detected version.
	isKhtml: 0,
	//	isWebKit: Number | undefined
	//		Version as a Number if client is a WebKit-derived browser (Konqueror,
	//		Safari, Chrome, etc.). undefined otherwise.
	isWebKit: 0,
	//	isMozilla: Number | undefined
	//		Version as a Number if client is a Mozilla-based browser (Firefox,
	//		SeaMonkey). undefined otherwise. Corresponds to major detected version.
	isMozilla: 0,
	//	isOpera: Number | undefined
	//		Version as a Number if client is Opera. undefined otherwise. Corresponds to
	//		major detected version.
	isOpera: 0,
	//	isSafari: Number | undefined
	//		Version as a Number if client is Safari or iPhone. undefined otherwise.
	isSafari: 0,
	//	isChrome: Number | undefined
	//		Version as a Number if client is Chrome browser. undefined otherwise.
	isChrome: 0
	//	isMac: Boolean
	//		True if the client runs on Mac
}
=====*/
if(typeof window != 'undefined'){
	dojo.isBrowser = true;
	dojo._name = "browser";


	// attempt to figure out the path to dojo if it isn't set in the config
	(function(){
		var d = dojo;

		// this is a scope protection closure. We set browser versions and grab
		// the URL we were loaded from here.

		// grab the node we were loaded from
		if(document && document.getElementsByTagName){
			var scripts = document.getElementsByTagName("script");
			var rePkg = /dojo(\.xd)?\.js(\W|$)/i;
			for(var i = 0; i < scripts.length; i++){
				var src = scripts[i].getAttribute("src");
				if(!src){ continue; }
				var m = src.match(rePkg);
				if(m){
					// find out where we came from
					if(!d.config.baseUrl){
						d.config.baseUrl = src.substring(0, m.index);
					}
					// and find out if we need to modify our behavior
					var cfg = (scripts[i].getAttribute("djConfig") || scripts[i].getAttribute("data-dojo-config"));
					if(cfg){
						var cfgo = eval("({ "+cfg+" })");
						for(var x in cfgo){
							dojo.config[x] = cfgo[x];
						}
					}
					break; // "first Dojo wins"
				}
			}
		}
		d.baseUrl = d.config.baseUrl;

		// fill in the rendering support information in dojo.render.*
		var n = navigator;
		var dua = n.userAgent,
			dav = n.appVersion,
			tv = parseFloat(dav);

		if(dua.indexOf("Opera") >= 0){ d.isOpera = tv; }
		if(dua.indexOf("AdobeAIR") >= 0){ d.isAIR = 1; }
		d.isKhtml = (dav.indexOf("Konqueror") >= 0) ? tv : 0;
		d.isWebKit = parseFloat(dua.split("WebKit/")[1]) || undefined;
		d.isChrome = parseFloat(dua.split("Chrome/")[1]) || undefined;
		d.isMac = dav.indexOf("Macintosh") >= 0;

		// safari detection derived from:
		//		http://developer.apple.com/internet/safari/faq.html#anchor2
		//		http://developer.apple.com/internet/safari/uamatrix.html
		var index = Math.max(dav.indexOf("WebKit"), dav.indexOf("Safari"), 0);
		if(index && !dojo.isChrome){
			// try to grab the explicit Safari version first. If we don't get
			// one, look for less than 419.3 as the indication that we're on something
			// "Safari 2-ish".
			d.isSafari = parseFloat(dav.split("Version/")[1]);
			if(!d.isSafari || parseFloat(dav.substr(index + 7)) <= 419.3){
				d.isSafari = 2;
			}
		}

				if(dua.indexOf("Gecko") >= 0 && !d.isKhtml && !d.isWebKit){ d.isMozilla = d.isMoz = tv; }
		if(d.isMoz){
			//We really need to get away from this. Consider a sane isGecko approach for the future.
			d.isFF = parseFloat(dua.split("Firefox/")[1] || dua.split("Minefield/")[1]) || undefined;
		}
		if(document.all && !d.isOpera){
			d.isIE = parseFloat(dav.split("MSIE ")[1]) || undefined;
			//In cases where the page has an HTTP header or META tag with
			//X-UA-Compatible, then it is in emulation mode.
			//Make sure isIE reflects the desired version.
			//document.documentMode of 5 means quirks mode.
			//Only switch the value if documentMode's major version
			//is different from isIE's major version.
			var mode = document.documentMode;
			if(mode && mode != 5 && Math.floor(d.isIE) != mode){
				d.isIE = mode;
			}
		}

		//Workaround to get local file loads of dojo to work on IE 7
		//by forcing to not use native xhr.
		if(dojo.isIE && window.location.protocol === "file:"){
			dojo.config.ieForceActiveXXhr=true;
		}
		
		d.isQuirks = document.compatMode == "BackCompat";

		// TODO: is the HTML LANG attribute relevant?
		d.locale = dojo.config.locale || (d.isIE ? n.userLanguage : n.language).toLowerCase();

		// These are in order of decreasing likelihood; this will change in time.
				d._XMLHTTP_PROGIDS = ['Msxml2.XMLHTTP', 'Microsoft.XMLHTTP', 'Msxml2.XMLHTTP.4.0'];
		
		d._xhrObj = function(){
			// summary:
			//		does the work of portably generating a new XMLHTTPRequest object.
			var http, last_e;
						if(!dojo.isIE || !dojo.config.ieForceActiveXXhr){
							try{ http = new XMLHttpRequest(); }catch(e){}
						}
			if(!http){
				for(var i=0; i<3; ++i){
					var progid = d._XMLHTTP_PROGIDS[i];
					try{
						http = new ActiveXObject(progid);
					}catch(e){
						last_e = e;
					}

					if(http){
						d._XMLHTTP_PROGIDS = [progid];  // so faster next time
						break;
					}
				}
			}
			
			if(!http){
				throw new Error("XMLHTTP not available: "+last_e);
			}

			return http; // XMLHTTPRequest instance
		}

		d._isDocumentOk = function(http){
			var stat = http.status || 0,
				lp = location.protocol;
			return (stat >= 200 && stat < 300) || 	// Boolean
				stat == 304 ||			// allow any 2XX response code
				stat == 1223 ||			// get it out of the cache
								// Internet Explorer mangled the status code
				// Internet Explorer mangled the status code OR we're Titanium/browser chrome/chrome extension requesting a local file
				(!stat && (lp == "file:" || lp == "chrome:" || lp == "chrome-extension:" || lp == "app:"));
		}

		//See if base tag is in use.
		//This is to fix http://trac.dojotoolkit.org/ticket/3973,
		//but really, we need to find out how to get rid of the dojo._Url reference
		//below and still have DOH work with the dojo.i18n test following some other
		//test that uses the test frame to load a document (trac #2757).
		//Opera still has problems, but perhaps a larger issue of base tag support
		//with XHR requests (hasBase is true, but the request is still made to document
		//path, not base path).
		var owloc = window.location+"";
		var base = document.getElementsByTagName("base");
		var hasBase = (base && base.length > 0);

		d._getText = function(/*URI*/ uri, /*Boolean*/ fail_ok){
			// summary: Read the contents of the specified uri and return those contents.
			// uri:
			//		A relative or absolute uri. If absolute, it still must be in
			//		the same "domain" as we are.
			// fail_ok:
			//		Default false. If fail_ok and loading fails, return null
			//		instead of throwing.
			// returns: The response text. null is returned when there is a
			//		failure and failure is okay (an exception otherwise)

			// NOTE: must be declared before scope switches ie. this._xhrObj()
			var http = d._xhrObj();

			if(!hasBase && dojo._Url){
				uri = (new dojo._Url(owloc, uri)).toString();
			}

			if(d.config.cacheBust){
				//Make sure we have a string before string methods are used on uri
				uri += "";
				uri += (uri.indexOf("?") == -1 ? "?" : "&") + String(d.config.cacheBust).replace(/\W+/g,"");
			}

			http.open('GET', uri, false);
			try{
				http.send(null);
				if(!d._isDocumentOk(http)){
					var err = Error("Unable to load "+uri+" status:"+ http.status);
					err.status = http.status;
					err.responseText = http.responseText;
					throw err;
				}
			}catch(e){
				if(fail_ok){ return null; } // null
				// rethrow the exception
				throw e;
			}
			return http.responseText; // String
		}
		

		var _w = window;
		var _handleNodeEvent = function(/*String*/evtName, /*Function*/fp){
			// summary:
			//		non-destructively adds the specified function to the node's
			//		evtName handler.
			// evtName: should be in the form "onclick" for "onclick" handlers.
			// Make sure you pass in the "on" part.
			var _a = _w.attachEvent || _w.addEventListener;
			evtName = _w.attachEvent ? evtName : evtName.substring(2);
			_a(evtName, function(){
				fp.apply(_w, arguments);
			}, false);
		};


		d._windowUnloaders = [];
		
		d.windowUnloaded = function(){
			// summary:
			//		signal fired by impending window destruction. You may use
			//		dojo.addOnWindowUnload() to register a listener for this
			//		event. NOTE: if you wish to dojo.connect() to this method
			//		to perform page/application cleanup, be aware that this
			//		event WILL NOT fire if no handler has been registered with
			//		dojo.addOnWindowUnload. This behavior started in Dojo 1.3.
			//		Previous versions always triggered dojo.windowUnloaded. See
			//		dojo.addOnWindowUnload for more info.
			var mll = d._windowUnloaders;
			while(mll.length){
				(mll.pop())();
			}
			d = null;
		};

		var _onWindowUnloadAttached = 0;
		d.addOnWindowUnload = function(/*Object?|Function?*/obj, /*String|Function?*/functionName){
			// summary:
			//		registers a function to be triggered when window.onunload
			//		fires.
			//	description:
			//		The first time that addOnWindowUnload is called Dojo
			//		will register a page listener to trigger your unload
			//		handler with. Note that registering these handlers may
			//		destory "fastback" page caching in browsers that support
			//		it. Be careful trying to modify the DOM or access
			//		JavaScript properties during this phase of page unloading:
			//		they may not always be available. Consider
			//		dojo.addOnUnload() if you need to modify the DOM or do
			//		heavy JavaScript work since it fires at the eqivalent of
			//		the page's "onbeforeunload" event.
			// example:
			//	|	dojo.addOnWindowUnload(functionPointer)
			//	|	dojo.addOnWindowUnload(object, "functionName");
			//	|	dojo.addOnWindowUnload(object, function(){ /* ... */});

			d._onto(d._windowUnloaders, obj, functionName);
			if(!_onWindowUnloadAttached){
				_onWindowUnloadAttached = 1;
				_handleNodeEvent("onunload", d.windowUnloaded);
			}
		};

		var _onUnloadAttached = 0;
		d.addOnUnload = function(/*Object?|Function?*/obj, /*String|Function?*/functionName){
			// summary:
			//		registers a function to be triggered when the page unloads.
			//	description:
			//		The first time that addOnUnload is called Dojo will
			//		register a page listener to trigger your unload handler
			//		with.
			//
			//		In a browser enviroment, the functions will be triggered
			//		during the window.onbeforeunload event. Be careful of doing
			//		too much work in an unload handler. onbeforeunload can be
			//		triggered if a link to download a file is clicked, or if
			//		the link is a javascript: link. In these cases, the
			//		onbeforeunload event fires, but the document is not
			//		actually destroyed. So be careful about doing destructive
			//		operations in a dojo.addOnUnload callback.
			//
			//		Further note that calling dojo.addOnUnload will prevent
			//		browsers from using a "fast back" cache to make page
			//		loading via back button instantaneous.
			// example:
			//	|	dojo.addOnUnload(functionPointer)
			//	|	dojo.addOnUnload(object, "functionName")
			//	|	dojo.addOnUnload(object, function(){ /* ... */});

			d._onto(d._unloaders, obj, functionName);
			if(!_onUnloadAttached){
				_onUnloadAttached = 1;
				_handleNodeEvent("onbeforeunload", dojo.unloaded);
			}
		};

	})();

	//START DOMContentLoaded
	dojo._initFired = false;
	dojo._loadInit = function(e){
		if(dojo._scrollIntervalId){
			clearInterval(dojo._scrollIntervalId);
			dojo._scrollIntervalId = 0;
		}

		if(!dojo._initFired){
			dojo._initFired = true;

			//Help out IE to avoid memory leak.
			if(!dojo.config.afterOnLoad && window.detachEvent){
				window.detachEvent("onload", dojo._loadInit);
			}

			if(dojo._inFlightCount == 0){
				dojo._modulesLoaded();
			}
		}
	}

	if(!dojo.config.afterOnLoad){
		if(document.addEventListener){
			//Standards. Hooray! Assumption here that if standards based,
			//it knows about DOMContentLoaded. It is OK if it does not, the fall through
			//to window onload should be good enough.
			document.addEventListener("DOMContentLoaded", dojo._loadInit, false);
			window.addEventListener("load", dojo._loadInit, false);
		}else if(window.attachEvent){
			window.attachEvent("onload", dojo._loadInit);

			//DOMContentLoaded approximation. Diego Perini found this MSDN article
			//that indicates doScroll is available after DOM ready, so do a setTimeout
			//to check when it is available.
			//http://msdn.microsoft.com/en-us/library/ms531426.aspx
			if(!dojo.config.skipIeDomLoaded && self === self.top){
				dojo._scrollIntervalId = setInterval(function (){
					try{
						//When dojo is loaded into an iframe in an IE HTML Application
						//(HTA), such as in a selenium test, javascript in the iframe
						//can't see anything outside of it, so self===self.top is true,
						//but the iframe is not the top window and doScroll will be
						//available before document.body is set. Test document.body
						//before trying the doScroll trick
						if(document.body){
							document.documentElement.doScroll("left");
							dojo._loadInit();
						}
					}catch (e){}
				}, 30);
			}
		}
	}

		if(dojo.isIE){
		try{
			(function(){
				document.namespaces.add("v", "urn:schemas-microsoft-com:vml");
				var vmlElems = ["*", "group", "roundrect", "oval", "shape", "rect", "imagedata", "path", "textpath", "text"],
					i = 0, l = 1, s = document.createStyleSheet();
				if(dojo.isIE >= 8){
					i = 1;
					l = vmlElems.length;
				}
				for(; i < l; ++i){
					s.addRule("v\\:" + vmlElems[i], "behavior:url(#default#VML); display:inline-block");
				}
			})();
		}catch(e){}
	}
		//END DOMContentLoaded


	/*
	OpenAjax.subscribe("OpenAjax", "onload", function(){
		if(dojo._inFlightCount == 0){
			dojo._modulesLoaded();
		}
	});

	OpenAjax.subscribe("OpenAjax", "onunload", function(){
		dojo.unloaded();
	});
	*/
} //if (typeof window != 'undefined')

//Register any module paths set up in djConfig. Need to do this
//in the hostenvs since hostenv_browser can read djConfig from a
//script tag's attribute.
(function(){
	var mp = dojo.config["modulePaths"];
	if(mp){
		for(var param in mp){
			dojo.registerModulePath(param, mp[param]);
		}
	}
})();

//Load debug code if necessary.
if(dojo.config.isDebug){
	dojo.require("dojo._firebug.firebug");
}

if(dojo.config.debugAtAllCosts){
	// this breaks the new AMD based module loader. The XDomain won't be necessary
	// anyway if you switch to the asynchronous loader
	//dojo.config.useXDomain = true;
	//dojo.require("dojo._base._loader.loader_xd");
	dojo.require("dojo._base._loader.loader_debug");
	dojo.require("dojo.i18n");
}


if(!dojo._hasResource["dojo._base.lang"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.lang"] = true;
dojo.provide("dojo._base.lang");


(function(){
	var d = dojo, opts = Object.prototype.toString;

	// Crockford (ish) functions

	dojo.isString = function(/*anything*/ it){
		//	summary:
		//		Return true if it is a String
		return (typeof it == "string" || it instanceof String); // Boolean
	};

	dojo.isArray = function(/*anything*/ it){
		//	summary:
		//		Return true if it is an Array.
		//		Does not work on Arrays created in other windows.
		return it && (it instanceof Array || typeof it == "array"); // Boolean
	};

	dojo.isFunction = function(/*anything*/ it){
		// summary:
		//		Return true if it is a Function
		return opts.call(it) === "[object Function]";
	};

	dojo.isObject = function(/*anything*/ it){
		// summary:
		//		Returns true if it is a JavaScript object (or an Array, a Function
		//		or null)
		return it !== undefined &&
			(it === null || typeof it == "object" || d.isArray(it) || d.isFunction(it)); // Boolean
	};

	dojo.isArrayLike = function(/*anything*/ it){
		//	summary:
		//		similar to dojo.isArray() but more permissive
		//	description:
		//		Doesn't strongly test for "arrayness".  Instead, settles for "isn't
		//		a string or number and has a length property". Arguments objects
		//		and DOM collections will return true when passed to
		//		dojo.isArrayLike(), but will return false when passed to
		//		dojo.isArray().
		//	returns:
		//		If it walks like a duck and quacks like a duck, return `true`
		return it && it !== undefined && // Boolean
			// keep out built-in constructors (Number, String, ...) which have length
			// properties
			!d.isString(it) && !d.isFunction(it) &&
			!(it.tagName && it.tagName.toLowerCase() == 'form') &&
			(d.isArray(it) || isFinite(it.length));
	};

	dojo.isAlien = function(/*anything*/ it){
		// summary:
		//		Returns true if it is a built-in function or some other kind of
		//		oddball that *should* report as a function but doesn't
		return it && !d.isFunction(it) && /\{\s*\[native code\]\s*\}/.test(String(it)); // Boolean
	};

	dojo.extend = function(/*Object*/ constructor, /*Object...*/ props){
		// summary:
		//		Adds all properties and methods of props to constructor's
		//		prototype, making them available to all instances created with
		//		constructor.
		for(var i=1, l=arguments.length; i<l; i++){
			d._mixin(constructor.prototype, arguments[i]);
		}
		return constructor; // Object
	};

	dojo._hitchArgs = function(scope, method /*,...*/){
		var pre = d._toArray(arguments, 2);
		var named = d.isString(method);
		return function(){
			// arrayify arguments
			var args = d._toArray(arguments);
			// locate our method
			var f = named ? (scope||d.global)[method] : method;
			// invoke with collected args
			return f && f.apply(scope || this, pre.concat(args)); // mixed
		}; // Function
	};

	dojo.hitch = function(/*Object*/scope, /*Function|String*/method /*,...*/){
		//	summary:
		//		Returns a function that will only ever execute in the a given scope.
		//		This allows for easy use of object member functions
		//		in callbacks and other places in which the "this" keyword may
		//		otherwise not reference the expected scope.
		//		Any number of default positional arguments may be passed as parameters
		//		beyond "method".
		//		Each of these values will be used to "placehold" (similar to curry)
		//		for the hitched function.
		//	scope:
		//		The scope to use when method executes. If method is a string,
		//		scope is also the object containing method.
		//	method:
		//		A function to be hitched to scope, or the name of the method in
		//		scope to be hitched.
		//	example:
		//	|	dojo.hitch(foo, "bar")();
		//		runs foo.bar() in the scope of foo
		//	example:
		//	|	dojo.hitch(foo, myFunction);
		//		returns a function that runs myFunction in the scope of foo
		//	example:
		//		Expansion on the default positional arguments passed along from
		//		hitch. Passed args are mixed first, additional args after.
		//	|	var foo = { bar: function(a, b, c){ console.log(a, b, c); } };
		//	|	var fn = dojo.hitch(foo, "bar", 1, 2);
		//	|	fn(3); // logs "1, 2, 3"
		//	example:
		//	|	var foo = { bar: 2 };
		//	|	dojo.hitch(foo, function(){ this.bar = 10; })();
		//		execute an anonymous function in scope of foo
		
		if(arguments.length > 2){
			return d._hitchArgs.apply(d, arguments); // Function
		}
		if(!method){
			method = scope;
			scope = null;
		}
		if(d.isString(method)){
			scope = scope || d.global;
			if(!scope[method]){ throw(['dojo.hitch: scope["', method, '"] is null (scope="', scope, '")'].join('')); }
			return function(){ return scope[method].apply(scope, arguments || []); }; // Function
		}
		return !scope ? method : function(){ return method.apply(scope, arguments || []); }; // Function
	};

	/*=====
	dojo.delegate = function(obj, props){
		//	summary:
		//		Returns a new object which "looks" to obj for properties which it
		//		does not have a value for. Optionally takes a bag of properties to
		//		seed the returned object with initially.
		//	description:
		//		This is a small implementaton of the Boodman/Crockford delegation
		//		pattern in JavaScript. An intermediate object constructor mediates
		//		the prototype chain for the returned object, using it to delegate
		//		down to obj for property lookup when object-local lookup fails.
		//		This can be thought of similarly to ES4's "wrap", save that it does
		//		not act on types but rather on pure objects.
		//	obj:
		//		The object to delegate to for properties not found directly on the
		//		return object or in props.
		//	props:
		//		an object containing properties to assign to the returned object
		//	returns:
		//		an Object of anonymous type
		//	example:
		//	|	var foo = { bar: "baz" };
		//	|	var thinger = dojo.delegate(foo, { thud: "xyzzy"});
		//	|	thinger.bar == "baz"; // delegated to foo
		//	|	foo.thud == undefined; // by definition
		//	|	thinger.thud == "xyzzy"; // mixed in from props
		//	|	foo.bar = "thonk";
		//	|	thinger.bar == "thonk"; // still delegated to foo's bar
	}
	=====*/

	dojo.delegate = dojo._delegate = (function(){
		// boodman/crockford delegation w/ cornford optimization
		function TMP(){}
		return function(obj, props){
			TMP.prototype = obj;
			var tmp = new TMP();
			TMP.prototype = null;
			if(props){
				d._mixin(tmp, props);
			}
			return tmp; // Object
		};
	})();

	/*=====
	dojo._toArray = function(obj, offset, startWith){
		//	summary:
		//		Converts an array-like object (i.e. arguments, DOMCollection) to an
		//		array. Returns a new Array with the elements of obj.
		//	obj: Object
		//		the object to "arrayify". We expect the object to have, at a
		//		minimum, a length property which corresponds to integer-indexed
		//		properties.
		//	offset: Number?
		//		the location in obj to start iterating from. Defaults to 0.
		//		Optional.
		//	startWith: Array?
		//		An array to pack with the properties of obj. If provided,
		//		properties in obj are appended at the end of startWith and
		//		startWith is the returned array.
	}
	=====*/

	var efficient = function(obj, offset, startWith){
		return (startWith||[]).concat(Array.prototype.slice.call(obj, offset||0));
	};

		var slow = function(obj, offset, startWith){
		var arr = startWith||[];
		for(var x = offset || 0; x < obj.length; x++){
			arr.push(obj[x]);
		}
		return arr;
	};
	
	dojo._toArray =
				d.isIE ?  function(obj){
			return ((obj.item) ? slow : efficient).apply(this, arguments);
		} :
				efficient;

	dojo.partial = function(/*Function|String*/method /*, ...*/){
		//	summary:
		//		similar to hitch() except that the scope object is left to be
		//		whatever the execution context eventually becomes.
		//	description:
		//		Calling dojo.partial is the functional equivalent of calling:
		//		|	dojo.hitch(null, funcName, ...);
		var arr = [ null ];
		return d.hitch.apply(d, arr.concat(d._toArray(arguments))); // Function
	};

	var extraNames = d._extraNames, extraLen = extraNames.length, empty = {};

	dojo.clone = function(/*anything*/ o){
		// summary:
		//		Clones objects (including DOM nodes) and all children.
		//		Warning: do not clone cyclic structures.
		if(!o || typeof o != "object" || d.isFunction(o)){
			// null, undefined, any non-object, or function
			return o;	// anything
		}
		if(o.nodeType && "cloneNode" in o){
			// DOM Node
			return o.cloneNode(true); // Node
		}
		if(o instanceof Date){
			// Date
			return new Date(o.getTime());	// Date
		}
		if(o instanceof RegExp){
			// RegExp
			return new RegExp(o);   // RegExp
		}
		var r, i, l, s, name;
		if(d.isArray(o)){
			// array
			r = [];
			for(i = 0, l = o.length; i < l; ++i){
				if(i in o){
					r.push(d.clone(o[i]));
				}
			}
// we don't clone functions for performance reasons
//		}else if(d.isFunction(o)){
//			// function
//			r = function(){ return o.apply(this, arguments); };
		}else{
			// generic objects
			r = o.constructor ? new o.constructor() : {};
		}
		for(name in o){
			// the "tobj" condition avoid copying properties in "source"
			// inherited from Object.prototype.  For example, if target has a custom
			// toString() method, don't overwrite it with the toString() method
			// that source inherited from Object.prototype
			s = o[name];
			if(!(name in r) || (r[name] !== s && (!(name in empty) || empty[name] !== s))){
				r[name] = d.clone(s);
			}
		}
				// IE doesn't recognize some custom functions in for..in
		if(extraLen){
			for(i = 0; i < extraLen; ++i){
				name = extraNames[i];
				s = o[name];
				if(!(name in r) || (r[name] !== s && (!(name in empty) || empty[name] !== s))){
					r[name] = s; // functions only, we don't clone them
				}
			}
		}
				return r; // Object
	};

	/*=====
	dojo.trim = function(str){
		//	summary:
		//		Trims whitespace from both sides of the string
		//	str: String
		//		String to be trimmed
		//	returns: String
		//		Returns the trimmed string
		//	description:
		//		This version of trim() was selected for inclusion into the base due
		//		to its compact size and relatively good performance
		//		(see [Steven Levithan's blog](http://blog.stevenlevithan.com/archives/faster-trim-javascript)
		//		Uses String.prototype.trim instead, if available.
		//		The fastest but longest version of this function is located at
		//		dojo.string.trim()
		return "";	// String
	}
	=====*/

	dojo.trim = String.prototype.trim ?
		function(str){ return str.trim(); } :
		function(str){ return str.replace(/^\s\s*/, '').replace(/\s\s*$/, ''); };

	/*=====
	dojo.replace = function(tmpl, map, pattern){
		//	summary:
		//		Performs parameterized substitutions on a string. Throws an
		//		exception if any parameter is unmatched.
		//	tmpl: String
		//		String to be used as a template.
		//	map: Object|Function
		//		If an object, it is used as a dictionary to look up substitutions.
		//		If a function, it is called for every substitution with following
		//		parameters: a whole match, a name, an offset, and the whole template
		//		string (see https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Global_Objects/String/replace
		//		for more details).
		//	pattern: RegEx?
		//		Optional regular expression objects that overrides the default pattern.
		//		Must be global and match one item. The default is: /\{([^\}]+)\}/g,
		//		which matches patterns like that: "{xxx}", where "xxx" is any sequence
		//		of characters, which doesn't include "}".
		//	returns: String
		//		Returns the substituted string.
		//	example:
		//	|	// uses a dictionary for substitutions:
		//	|	dojo.replace("Hello, {name.first} {name.last} AKA {nick}!",
		//	|	  {
		//	|	    nick: "Bob",
		//	|	    name: {
		//	|	      first:  "Robert",
		//	|	      middle: "X",
		//	|	      last:   "Cringely"
		//	|	    }
		//	|	  });
		//	|	// returns: Hello, Robert Cringely AKA Bob!
		//	example:
		//	|	// uses an array for substitutions:
		//	|	dojo.replace("Hello, {0} {2}!",
		//	|	  ["Robert", "X", "Cringely"]);
		//	|	// returns: Hello, Robert Cringely!
		//	example:
		//	|	// uses a function for substitutions:
		//	|	function sum(a){
		//	|	  var t = 0;
		//	|	  dojo.forEach(a, function(x){ t += x; });
		//	|	  return t;
		//	|	}
		//	|	dojo.replace(
		//	|	  "{count} payments averaging {avg} USD per payment.",
		//	|	  dojo.hitch(
		//	|	    { payments: [11, 16, 12] },
		//	|	    function(_, key){
		//	|	      switch(key){
		//	|	        case "count": return this.payments.length;
		//	|	        case "min":   return Math.min.apply(Math, this.payments);
		//	|	        case "max":   return Math.max.apply(Math, this.payments);
		//	|	        case "sum":   return sum(this.payments);
		//	|	        case "avg":   return sum(this.payments) / this.payments.length;
		//	|	      }
		//	|	    }
		//	|	  )
		//	|	);
		//	|	// prints: 3 payments averaging 13 USD per payment.
		//	example:
		//	|	// uses an alternative PHP-like pattern for substitutions:
		//	|	dojo.replace("Hello, ${0} ${2}!",
		//	|	  ["Robert", "X", "Cringely"], /\$\{([^\}]+)\}/g);
		//	|	// returns: Hello, Robert Cringely!
		return "";	// String
	}
	=====*/

	var _pattern = /\{([^\}]+)\}/g;
	dojo.replace = function(tmpl, map, pattern){
		return tmpl.replace(pattern || _pattern, d.isFunction(map) ?
			map : function(_, k){ return d.getObject(k, false, map); });
	};
})();

}

if(!dojo._hasResource["dojo._base.array"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.array"] = true;
dojo.provide("dojo._base.array");



(function(){
	var _getParts = function(arr, obj, cb){
		return [
			(typeof arr == "string") ? arr.split("") : arr,
			obj || dojo.global,
			// FIXME: cache the anonymous functions we create here?
			(typeof cb == "string") ? new Function("item", "index", "array", cb) : cb
		];
	};

	var everyOrSome = function(/*Boolean*/every, /*Array|String*/arr, /*Function|String*/callback, /*Object?*/thisObject){
		var _p = _getParts(arr, thisObject, callback); arr = _p[0];
		for(var i=0,l=arr.length; i<l; ++i){
			var result = !!_p[2].call(_p[1], arr[i], i, arr);
			if(every ^ result){
				return result; // Boolean
			}
		}
		return every; // Boolean
	};

	dojo.mixin(dojo, {
		indexOf: function(	/*Array*/		array,
							/*Object*/		value,
							/*Integer?*/	fromIndex,
							/*Boolean?*/	findLast){
			// summary:
			//		locates the first index of the provided value in the
			//		passed array. If the value is not found, -1 is returned.
			// description:
			//		This method corresponds to the JavaScript 1.6 Array.indexOf method, with one difference: when
			//		run over sparse arrays, the Dojo function invokes the callback for every index whereas JavaScript
			//		1.6's indexOf skips the holes in the sparse array.
			//		For details on this method, see:
			//			https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/indexOf

			var step = 1, end = array.length || 0, i = 0;
			if(findLast){
				i = end - 1;
				step = end = -1;
			}
			if(fromIndex != undefined){ i = fromIndex; }
			if((findLast && i > end) || i < end){
				for(; i != end; i += step){
					if(array[i] == value){ return i; }
				}
			}
			return -1;	// Number
		},

		lastIndexOf: function(/*Array*/array, /*Object*/value, /*Integer?*/fromIndex){
			// summary:
			//		locates the last index of the provided value in the passed
			//		array. If the value is not found, -1 is returned.
			// description:
			//		This method corresponds to the JavaScript 1.6 Array.lastIndexOf method, with one difference: when
			//		run over sparse arrays, the Dojo function invokes the callback for every index whereas JavaScript
			//		1.6's lastIndexOf skips the holes in the sparse array.
			//		For details on this method, see:
			// 			https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/lastIndexOf
			return dojo.indexOf(array, value, fromIndex, true); // Number
		},

		forEach: function(/*Array|String*/arr, /*Function|String*/callback, /*Object?*/thisObject){
			//	summary:
			//		for every item in arr, callback is invoked. Return values are ignored.
			//		If you want to break out of the loop, consider using dojo.every() or dojo.some().
			//		forEach does not allow breaking out of the loop over the items in arr.
			//	arr:
			//		the array to iterate over. If a string, operates on individual characters.
			//	callback:
			//		a function is invoked with three arguments: item, index, and array
			//	thisObject:
			//		may be used to scope the call to callback
			//	description:
			//		This function corresponds to the JavaScript 1.6 Array.forEach() method, with one difference: when
			//		run over sparse arrays, this implemenation passes the "holes" in the sparse array to
			//		the callback function with a value of undefined. JavaScript 1.6's forEach skips the holes in the sparse array.
			//		For more details, see:
			//			https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/forEach
			//	example:
			//	|	// log out all members of the array:
			//	|	dojo.forEach(
			//	|		[ "thinger", "blah", "howdy", 10 ],
			//	|		function(item){
			//	|			console.log(item);
			//	|		}
			//	|	);
			//	example:
			//	|	// log out the members and their indexes
			//	|	dojo.forEach(
			//	|		[ "thinger", "blah", "howdy", 10 ],
			//	|		function(item, idx, arr){
			//	|			console.log(item, "at index:", idx);
			//	|		}
			//	|	);
			//	example:
			//	|	// use a scoped object member as the callback
			//	|
			//	|	var obj = {
			//	|		prefix: "logged via obj.callback:",
			//	|		callback: function(item){
			//	|			console.log(this.prefix, item);
			//	|		}
			//	|	};
			//	|
			//	|	// specifying the scope function executes the callback in that scope
			//	|	dojo.forEach(
			//	|		[ "thinger", "blah", "howdy", 10 ],
			//	|		obj.callback,
			//	|		obj
			//	|	);
			//	|
			//	|	// alternately, we can accomplish the same thing with dojo.hitch()
			//	|	dojo.forEach(
			//	|		[ "thinger", "blah", "howdy", 10 ],
			//	|		dojo.hitch(obj, "callback")
			//	|	);

			// match the behavior of the built-in forEach WRT empty arrs
			if(!arr || !arr.length){ return; }

			// FIXME: there are several ways of handilng thisObject. Is
			// dojo.global always the default context?
			var _p = _getParts(arr, thisObject, callback); arr = _p[0];
			for(var i=0,l=arr.length; i<l; ++i){
				_p[2].call(_p[1], arr[i], i, arr);
			}
		},

		every: function(/*Array|String*/arr, /*Function|String*/callback, /*Object?*/thisObject){
			// summary:
			//		Determines whether or not every item in arr satisfies the
			//		condition implemented by callback.
			// arr:
			//		the array to iterate on. If a string, operates on individual characters.
			// callback:
			//		a function is invoked with three arguments: item, index,
			//		and array and returns true if the condition is met.
			// thisObject:
			//		may be used to scope the call to callback
			// description:
			//		This function corresponds to the JavaScript 1.6 Array.every() method, with one difference: when
			//		run over sparse arrays, this implemenation passes the "holes" in the sparse array to
			//		the callback function with a value of undefined. JavaScript 1.6's every skips the holes in the sparse array.
			//		For more details, see:
			//			https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/every
			// example:
			//	|	// returns false
			//	|	dojo.every([1, 2, 3, 4], function(item){ return item>1; });
			// example:
			//	|	// returns true
			//	|	dojo.every([1, 2, 3, 4], function(item){ return item>0; });
			return everyOrSome(true, arr, callback, thisObject); // Boolean
		},

		some: function(/*Array|String*/arr, /*Function|String*/callback, /*Object?*/thisObject){
			// summary:
			//		Determines whether or not any item in arr satisfies the
			//		condition implemented by callback.
			// arr:
			//		the array to iterate over. If a string, operates on individual characters.
			// callback:
			//		a function is invoked with three arguments: item, index,
			//		and array and returns true if the condition is met.
			// thisObject:
			//		may be used to scope the call to callback
			// description:
			//		This function corresponds to the JavaScript 1.6 Array.some() method, with one difference: when
			//		run over sparse arrays, this implemenation passes the "holes" in the sparse array to
			//		the callback function with a value of undefined. JavaScript 1.6's some skips the holes in the sparse array.
			//		For more details, see:
			//			https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/some
			// example:
			//	|	// is true
			//	|	dojo.some([1, 2, 3, 4], function(item){ return item>1; });
			// example:
			//	|	// is false
			//	|	dojo.some([1, 2, 3, 4], function(item){ return item<1; });
			return everyOrSome(false, arr, callback, thisObject); // Boolean
		},

		map: function(/*Array|String*/arr, /*Function|String*/callback, /*Function?*/thisObject){
			// summary:
			//		applies callback to each element of arr and returns
			//		an Array with the results
			// arr:
			//		the array to iterate on. If a string, operates on
			//		individual characters.
			// callback:
			//		a function is invoked with three arguments, (item, index,
			//		array),  and returns a value
			// thisObject:
			//		may be used to scope the call to callback
			// description:
			//		This function corresponds to the JavaScript 1.6 Array.map() method, with one difference: when
			//		run over sparse arrays, this implemenation passes the "holes" in the sparse array to
			//		the callback function with a value of undefined. JavaScript 1.6's map skips the holes in the sparse array.
			//		For more details, see:
			//			https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/map
			// example:
			//	|	// returns [2, 3, 4, 5]
			//	|	dojo.map([1, 2, 3, 4], function(item){ return item+1 });

			var _p = _getParts(arr, thisObject, callback); arr = _p[0];
			var outArr = (arguments[3] ? (new arguments[3]()) : []);
			for(var i=0,l=arr.length; i<l; ++i){
				outArr.push(_p[2].call(_p[1], arr[i], i, arr));
			}
			return outArr; // Array
		},

		filter: function(/*Array*/arr, /*Function|String*/callback, /*Object?*/thisObject){
			// summary:
			//		Returns a new Array with those items from arr that match the
			//		condition implemented by callback.
			// arr:
			//		the array to iterate over.
			// callback:
			//		a function that is invoked with three arguments (item,
			//		index, array). The return of this function is expected to
			//		be a boolean which determines whether the passed-in item
			//		will be included in the returned array.
			// thisObject:
			//		may be used to scope the call to callback
			// description:
			//		This function corresponds to the JavaScript 1.6 Array.filter() method, with one difference: when
			//		run over sparse arrays, this implemenation passes the "holes" in the sparse array to
			//		the callback function with a value of undefined. JavaScript 1.6's filter skips the holes in the sparse array.
			//		For more details, see:
			//			https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/filter
			// example:
			//	|	// returns [2, 3, 4]
			//	|	dojo.filter([1, 2, 3, 4], function(item){ return item>1; });

			var _p = _getParts(arr, thisObject, callback); arr = _p[0];
			var outArr = [];
			for(var i=0,l=arr.length; i<l; ++i){
				if(_p[2].call(_p[1], arr[i], i, arr)){
					outArr.push(arr[i]);
				}
			}
			return outArr; // Array
		}
	});
})();
/*
*/

}

if(!dojo._hasResource["dojo._base.declare"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.declare"] = true;
dojo.provide("dojo._base.declare");




(function(){
	var d = dojo, mix = d._mixin, op = Object.prototype, opts = op.toString,
		xtor = new Function, counter = 0, cname = "constructor";

	function err(msg, cls){ throw new Error("declare" + (cls ? " " + cls : "") + ": " + msg); }

	// C3 Method Resolution Order (see http://www.python.org/download/releases/2.3/mro/)
	function c3mro(bases, className){
		var result = [], roots = [{cls: 0, refs: []}], nameMap = {}, clsCount = 1,
			l = bases.length, i = 0, j, lin, base, top, proto, rec, name, refs;

		// build a list of bases naming them if needed
		for(; i < l; ++i){
			base = bases[i];
			if(!base){
				err("mixin #" + i + " is unknown. Did you use dojo.require to pull it in?", className);
			}else if(opts.call(base) != "[object Function]"){
				err("mixin #" + i + " is not a callable constructor.", className);
			}
			lin = base._meta ? base._meta.bases : [base];
			top = 0;
			// add bases to the name map
			for(j = lin.length - 1; j >= 0; --j){
				proto = lin[j].prototype;
				if(!proto.hasOwnProperty("declaredClass")){
					proto.declaredClass = "uniqName_" + (counter++);
				}
				name = proto.declaredClass;
				if(!nameMap.hasOwnProperty(name)){
					nameMap[name] = {count: 0, refs: [], cls: lin[j]};
					++clsCount;
				}
				rec = nameMap[name];
				if(top && top !== rec){
					rec.refs.push(top);
					++top.count;
				}
				top = rec;
			}
			++top.count;
			roots[0].refs.push(top);
		}

		// remove classes without external references recursively
		while(roots.length){
			top = roots.pop();
			result.push(top.cls);
			--clsCount;
			// optimization: follow a single-linked chain
			while(refs = top.refs, refs.length == 1){
				top = refs[0];
				if(!top || --top.count){
					// branch or end of chain => do not end to roots
					top = 0;
					break;
				}
				result.push(top.cls);
				--clsCount;
			}
			if(top){
				// branch
				for(i = 0, l = refs.length; i < l; ++i){
					top = refs[i];
					if(!--top.count){
						roots.push(top);
					}
				}
			}
		}
		if(clsCount){
			err("can't build consistent linearization", className);
		}

		// calculate the superclass offset
		base = bases[0];
		result[0] = base ?
			base._meta && base === result[result.length - base._meta.bases.length] ?
				base._meta.bases.length : 1 : 0;

		return result;
	}

	function inherited(args, a, f){
		var name, chains, bases, caller, meta, base, proto, opf, pos,
			cache = this._inherited = this._inherited || {};

		// crack arguments
		if(typeof args == "string"){
			name = args;
			args = a;
			a = f;
		}
		f = 0;

		caller = args.callee;
		name = name || caller.nom;
		if(!name){
			err("can't deduce a name to call inherited()", this.declaredClass);
		}

		meta = this.constructor._meta;
		bases = meta.bases;

		pos = cache.p;
		if(name != cname){
			// method
			if(cache.c !== caller){
				// cache bust
				pos = 0;
				base = bases[0];
				meta = base._meta;
				if(meta.hidden[name] !== caller){
					// error detection
					chains = meta.chains;
					if(chains && typeof chains[name] == "string"){
						err("calling chained method with inherited: " + name, this.declaredClass);
					}
					// find caller
					do{
						meta = base._meta;
						proto = base.prototype;
						if(meta && (proto[name] === caller && proto.hasOwnProperty(name) || meta.hidden[name] === caller)){
							break;
						}
					}while(base = bases[++pos]); // intentional assignment
					pos = base ? pos : -1;
				}
			}
			// find next
			base = bases[++pos];
			if(base){
				proto = base.prototype;
				if(base._meta && proto.hasOwnProperty(name)){
					f = proto[name];
				}else{
					opf = op[name];
					do{
						proto = base.prototype;
						f = proto[name];
						if(f && (base._meta ? proto.hasOwnProperty(name) : f !== opf)){
							break;
						}
					}while(base = bases[++pos]); // intentional assignment
				}
			}
			f = base && f || op[name];
		}else{
			// constructor
			if(cache.c !== caller){
				// cache bust
				pos = 0;
				meta = bases[0]._meta;
				if(meta && meta.ctor !== caller){
					// error detection
					chains = meta.chains;
					if(!chains || chains.constructor !== "manual"){
						err("calling chained constructor with inherited", this.declaredClass);
					}
					// find caller
					while(base = bases[++pos]){ // intentional assignment
						meta = base._meta;
						if(meta && meta.ctor === caller){
							break;
						}
					}
					pos = base ? pos : -1;
				}
			}
			// find next
			while(base = bases[++pos]){	// intentional assignment
				meta = base._meta;
				f = meta ? meta.ctor : base;
				if(f){
					break;
				}
			}
			f = base && f;
		}

		// cache the found super method
		cache.c = f;
		cache.p = pos;

		// now we have the result
		if(f){
			return a === true ? f : f.apply(this, a || args);
		}
		// intentionally if a super method was not found
	}

	function getInherited(name, args){
		if(typeof name == "string"){
			return this.inherited(name, args, true);
		}
		return this.inherited(name, true);
	}

	// emulation of "instanceof"
	function isInstanceOf(cls){
		var bases = this.constructor._meta.bases;
		for(var i = 0, l = bases.length; i < l; ++i){
			if(bases[i] === cls){
				return true;
			}
		}
		return this instanceof cls;
	}

	function mixOwn(target, source){
		var name, i = 0, l = d._extraNames.length;
		// add props adding metadata for incoming functions skipping a constructor
		for(name in source){
			if(name != cname && source.hasOwnProperty(name)){
				target[name] = source[name];
			}
		}
		// process unenumerable methods on IE
		for(; i < l; ++i){
			name = d._extraNames[i];
			if(name != cname && source.hasOwnProperty(name)){
				target[name] = source[name];
			}
		}
	}

	// implementation of safe mixin function
	function safeMixin(target, source){
		var name, t, i = 0, l = d._extraNames.length;
		// add props adding metadata for incoming functions skipping a constructor
		for(name in source){
			t = source[name];
			if((t !== op[name] || !(name in op)) && name != cname){
				if(opts.call(t) == "[object Function]"){
					// non-trivial function method => attach its name
					t.nom = name;
				}
				target[name] = t;
			}
		}
		// process unenumerable methods on IE
		for(; i < l; ++i){
			name = d._extraNames[i];
			t = source[name];
			if((t !== op[name] || !(name in op)) && name != cname){
				if(opts.call(t) == "[object Function]"){
					// non-trivial function method => attach its name
					t.nom = name;
				}
				target[name] = t;
			}
		}
		return target;
	}

	function extend(source){
		safeMixin(this.prototype, source);
		return this;
	}

	// chained constructor compatible with the legacy dojo.declare()
	function chainedConstructor(bases, ctorSpecial){
		return function(){
			var a = arguments, args = a, a0 = a[0], f, i, m,
				l = bases.length, preArgs;

			if(!(this instanceof a.callee)){
				// not called via new, so force it
				return applyNew(a);
			}

			//this._inherited = {};
			// perform the shaman's rituals of the original dojo.declare()
			// 1) call two types of the preamble
			if(ctorSpecial && (a0 && a0.preamble || this.preamble)){
				// full blown ritual
				preArgs = new Array(bases.length);
				// prepare parameters
				preArgs[0] = a;
				for(i = 0;;){
					// process the preamble of the 1st argument
					a0 = a[0];
					if(a0){
						f = a0.preamble;
						if(f){
							a = f.apply(this, a) || a;
						}
					}
					// process the preamble of this class
					f = bases[i].prototype;
					f = f.hasOwnProperty("preamble") && f.preamble;
					if(f){
						a = f.apply(this, a) || a;
					}
					// one peculiarity of the preamble:
					// it is called if it is not needed,
					// e.g., there is no constructor to call
					// let's watch for the last constructor
					// (see ticket #9795)
					if(++i == l){
						break;
					}
					preArgs[i] = a;
				}
			}
			// 2) call all non-trivial constructors using prepared arguments
			for(i = l - 1; i >= 0; --i){
				f = bases[i];
				m = f._meta;
				f = m ? m.ctor : f;
				if(f){
					f.apply(this, preArgs ? preArgs[i] : a);
				}
			}
			// 3) continue the original ritual: call the postscript
			f = this.postscript;
			if(f){
				f.apply(this, args);
			}
		};
	}


	// chained constructor compatible with the legacy dojo.declare()
	function singleConstructor(ctor, ctorSpecial){
		return function(){
			var a = arguments, t = a, a0 = a[0], f;

			if(!(this instanceof a.callee)){
				// not called via new, so force it
				return applyNew(a);
			}

			//this._inherited = {};
			// perform the shaman's rituals of the original dojo.declare()
			// 1) call two types of the preamble
			if(ctorSpecial){
				// full blown ritual
				if(a0){
					// process the preamble of the 1st argument
					f = a0.preamble;
					if(f){
						t = f.apply(this, t) || t;
					}
				}
				f = this.preamble;
				if(f){
					// process the preamble of this class
					f.apply(this, t);
					// one peculiarity of the preamble:
					// it is called even if it is not needed,
					// e.g., there is no constructor to call
					// let's watch for the last constructor
					// (see ticket #9795)
				}
			}
			// 2) call a constructor
			if(ctor){
				ctor.apply(this, a);
			}
			// 3) continue the original ritual: call the postscript
			f = this.postscript;
			if(f){
				f.apply(this, a);
			}
		};
	}

	// plain vanilla constructor (can use inherited() to call its base constructor)
	function simpleConstructor(bases){
		return function(){
			var a = arguments, i = 0, f, m;

			if(!(this instanceof a.callee)){
				// not called via new, so force it
				return applyNew(a);
			}

			//this._inherited = {};
			// perform the shaman's rituals of the original dojo.declare()
			// 1) do not call the preamble
			// 2) call the top constructor (it can use this.inherited())
			for(; f = bases[i]; ++i){ // intentional assignment
				m = f._meta;
				f = m ? m.ctor : f;
				if(f){
					f.apply(this, a);
					break;
				}
			}
			// 3) call the postscript
			f = this.postscript;
			if(f){
				f.apply(this, a);
			}
		};
	}

	function chain(name, bases, reversed){
		return function(){
			var b, m, f, i = 0, step = 1;
			if(reversed){
				i = bases.length - 1;
				step = -1;
			}
			for(; b = bases[i]; i += step){ // intentional assignment
				m = b._meta;
				f = (m ? m.hidden : b.prototype)[name];
				if(f){
					f.apply(this, arguments);
				}
			}
		};
	}

	// forceNew(ctor)
	// return a new object that inherits from ctor.prototype but
	// without actually running ctor on the object.
	function forceNew(ctor){
		// create object with correct prototype using a do-nothing
		// constructor
		xtor.prototype = ctor.prototype;
		var t = new xtor;
		xtor.prototype = null;	// clean up
		return t;
	}

	// applyNew(args)
	// just like 'new ctor()' except that the constructor and its arguments come
	// from args, which must be an array or an arguments object
	function applyNew(args){
		// create an object with ctor's prototype but without
		// calling ctor on it.
		var ctor = args.callee, t = forceNew(ctor);
		// execute the real constructor on the new object
		ctor.apply(t, args);
		return t;
	}

	d.declare = function(className, superclass, props){
		// crack parameters
		if(typeof className != "string"){
			props = superclass;
			superclass = className;
			className = "";
		}
		props = props || {};

		var proto, i, t, ctor, name, bases, chains, mixins = 1, parents = superclass;

		// build a prototype
		if(opts.call(superclass) == "[object Array]"){
			// C3 MRO
			bases = c3mro(superclass, className);
			t = bases[0];
			mixins = bases.length - t;
			superclass = bases[mixins];
		}else{
			bases = [0];
			if(superclass){
				if(opts.call(superclass) == "[object Function]"){
					t = superclass._meta;
					bases = bases.concat(t ? t.bases : superclass);
				}else{
					err("base class is not a callable constructor.", className);
				}
			}else if(superclass !== null){
				err("unknown base class. Did you use dojo.require to pull it in?", className);
			}
		}
		if(superclass){
			for(i = mixins - 1;; --i){
				proto = forceNew(superclass);
				if(!i){
					// stop if nothing to add (the last base)
					break;
				}
				// mix in properties
				t = bases[i];
				(t._meta ? mixOwn : mix)(proto, t.prototype);
				// chain in new constructor
				ctor = new Function;
				ctor.superclass = superclass;
				ctor.prototype = proto;
				superclass = proto.constructor = ctor;
			}
		}else{
			proto = {};
		}
		// add all properties
		safeMixin(proto, props);
		// add constructor
		t = props.constructor;
		if(t !== op.constructor){
			t.nom = cname;
			proto.constructor = t;
		}

		// collect chains and flags
		for(i = mixins - 1; i; --i){ // intentional assignment
			t = bases[i]._meta;
			if(t && t.chains){
				chains = mix(chains || {}, t.chains);
			}
		}
		if(proto["-chains-"]){
			chains = mix(chains || {}, proto["-chains-"]);
		}

		// build ctor
		t = !chains || !chains.hasOwnProperty(cname);
		bases[0] = ctor = (chains && chains.constructor === "manual") ? simpleConstructor(bases) :
			(bases.length == 1 ? singleConstructor(props.constructor, t) : chainedConstructor(bases, t));

		// add meta information to the constructor
		ctor._meta  = {bases: bases, hidden: props, chains: chains,
			parents: parents, ctor: props.constructor};
		ctor.superclass = superclass && superclass.prototype;
		ctor.extend = extend;
		ctor.prototype = proto;
		proto.constructor = ctor;

		// add "standard" methods to the prototype
		proto.getInherited = getInherited;
		proto.inherited = inherited;
		proto.isInstanceOf = isInstanceOf;

		// add name if specified
		if(className){
			proto.declaredClass = className;
			d.setObject(className, ctor);
		}

		// build chains and add them to the prototype
		if(chains){
			for(name in chains){
				if(proto[name] && typeof chains[name] == "string" && name != cname){
					t = proto[name] = chain(name, bases, chains[name] === "after");
					t.nom = name;
				}
			}
		}
		// chained methods do not return values
		// no need to chain "invisible" functions

		return ctor;	// Function
	};

	d.safeMixin = safeMixin;

	/*=====
	dojo.declare = function(className, superclass, props){
		//	summary:
		//		Create a feature-rich constructor from compact notation.
		//	className: String?:
		//		The optional name of the constructor (loosely, a "class")
		//		stored in the "declaredClass" property in the created prototype.
		//		It will be used as a global name for a created constructor.
		//	superclass: Function|Function[]:
		//		May be null, a Function, or an Array of Functions. This argument
		//		specifies a list of bases (the left-most one is the most deepest
		//		base).
		//	props: Object:
		//		An object whose properties are copied to the created prototype.
		//		Add an instance-initialization function by making it a property
		//		named "constructor".
		//	returns:
		//		New constructor function.
		//	description:
		//		Create a constructor using a compact notation for inheritance and
		//		prototype extension.
		//
		//		Mixin ancestors provide a type of multiple inheritance.
		//		Prototypes of mixin ancestors are copied to the new class:
		//		changes to mixin prototypes will not affect classes to which
		//		they have been mixed in.
		//
		//		Ancestors can be compound classes created by this version of
		//		dojo.declare. In complex cases all base classes are going to be
		//		linearized according to C3 MRO algorithm
		//		(see http://www.python.org/download/releases/2.3/mro/ for more
		//		details).
		//
		//		"className" is cached in "declaredClass" property of the new class,
		//		if it was supplied. The immediate super class will be cached in
		//		"superclass" property of the new class.
		//
		//		Methods in "props" will be copied and modified: "nom" property
		//		(the declared name of the method) will be added to all copied
		//		functions to help identify them for the internal machinery. Be
		//		very careful, while reusing methods: if you use the same
		//		function under different names, it can produce errors in some
		//		cases.
		//
		//		It is possible to use constructors created "manually" (without
		//		dojo.declare) as bases. They will be called as usual during the
		//		creation of an instance, their methods will be chained, and even
		//		called by "this.inherited()".
		//
		//		Special property "-chains-" governs how to chain methods. It is
		//		a dictionary, which uses method names as keys, and hint strings
		//		as values. If a hint string is "after", this method will be
		//		called after methods of its base classes. If a hint string is
		//		"before", this method will be called before methods of its base
		//		classes.
		//
		//		If "constructor" is not mentioned in "-chains-" property, it will
		//		be chained using the legacy mode: using "after" chaining,
		//		calling preamble() method before each constructor, if available,
		//		and calling postscript() after all constructors were executed.
		//		If the hint is "after", it is chained as a regular method, but
		//		postscript() will be called after the chain of constructors.
		//		"constructor" cannot be chained "before", but it allows
		//		a special hint string: "manual", which means that constructors
		//		are not going to be chained in any way, and programmer will call
		//		them manually using this.inherited(). In the latter case
		//		postscript() will be called after the construction.
		//
		//		All chaining hints are "inherited" from base classes and
		//		potentially can be overridden. Be very careful when overriding
		//		hints! Make sure that all chained methods can work in a proposed
		//		manner of chaining.
		//
		//		Once a method was chained, it is impossible to unchain it. The
		//		only exception is "constructor". You don't need to define a
		//		method in order to supply a chaining hint.
		//
		//		If a method is chained, it cannot use this.inherited() because
		//		all other methods in the hierarchy will be called automatically.
		//
		//		Usually constructors and initializers of any kind are chained
		//		using "after" and destructors of any kind are chained as
		//		"before". Note that chaining assumes that chained methods do not
		//		return any value: any returned value will be discarded.
		//
		//	example:
		//	|	dojo.declare("my.classes.bar", my.classes.foo, {
		//	|		// properties to be added to the class prototype
		//	|		someValue: 2,
		//	|		// initialization function
		//	|		constructor: function(){
		//	|			this.myComplicatedObject = new ReallyComplicatedObject();
		//	|		},
		//	|		// other functions
		//	|		someMethod: function(){
		//	|			doStuff();
		//	|		}
		//	|	});
		//
		//	example:
		//	|	var MyBase = dojo.declare(null, {
		//	|		// constructor, properties, and methods go here
		//	|		// ...
		//	|	});
		//	|	var MyClass1 = dojo.declare(MyBase, {
		//	|		// constructor, properties, and methods go here
		//	|		// ...
		//	|	});
		//	|	var MyClass2 = dojo.declare(MyBase, {
		//	|		// constructor, properties, and methods go here
		//	|		// ...
		//	|	});
		//	|	var MyDiamond = dojo.declare([MyClass1, MyClass2], {
		//	|		// constructor, properties, and methods go here
		//	|		// ...
		//	|	});
		//
		//	example:
		//	|	var F = function(){ console.log("raw constructor"); };
		//	|	F.prototype.method = function(){
		//	|		console.log("raw method");
		//	|	};
		//	|	var A = dojo.declare(F, {
		//	|		constructor: function(){
		//	|			console.log("A.constructor");
		//	|		},
		//	|		method: function(){
		//	|			console.log("before calling F.method...");
		//	|			this.inherited(arguments);
		//	|			console.log("...back in A");
		//	|		}
		//	|	});
		//	|	new A().method();
		//	|	// will print:
		//	|	// raw constructor
		//	|	// A.constructor
		//	|	// before calling F.method...
		//	|	// raw method
		//	|	// ...back in A
		//
		//	example:
		//	|	var A = dojo.declare(null, {
		//	|		"-chains-": {
		//	|			destroy: "before"
		//	|		}
		//	|	});
		//	|	var B = dojo.declare(A, {
		//	|		constructor: function(){
		//	|			console.log("B.constructor");
		//	|		},
		//	|		destroy: function(){
		//	|			console.log("B.destroy");
		//	|		}
		//	|	});
		//	|	var C = dojo.declare(B, {
		//	|		constructor: function(){
		//	|			console.log("C.constructor");
		//	|		},
		//	|		destroy: function(){
		//	|			console.log("C.destroy");
		//	|		}
		//	|	});
		//	|	new C().destroy();
		//	|	// prints:
		//	|	// B.constructor
		//	|	// C.constructor
		//	|	// C.destroy
		//	|	// B.destroy
		//
		//	example:
		//	|	var A = dojo.declare(null, {
		//	|		"-chains-": {
		//	|			constructor: "manual"
		//	|		}
		//	|	});
		//	|	var B = dojo.declare(A, {
		//	|		constructor: function(){
		//	|			// ...
		//	|			// call the base constructor with new parameters
		//	|			this.inherited(arguments, [1, 2, 3]);
		//	|			// ...
		//	|		}
		//	|	});
		//
		//	example:
		//	|	var A = dojo.declare(null, {
		//	|		"-chains-": {
		//	|			m1: "before"
		//	|		},
		//	|		m1: function(){
		//	|			console.log("A.m1");
		//	|		},
		//	|		m2: function(){
		//	|			console.log("A.m2");
		//	|		}
		//	|	});
		//	|	var B = dojo.declare(A, {
		//	|		"-chains-": {
		//	|			m2: "after"
		//	|		},
		//	|		m1: function(){
		//	|			console.log("B.m1");
		//	|		},
		//	|		m2: function(){
		//	|			console.log("B.m2");
		//	|		}
		//	|	});
		//	|	var x = new B();
		//	|	x.m1();
		//	|	// prints:
		//	|	// B.m1
		//	|	// A.m1
		//	|	x.m2();
		//	|	// prints:
		//	|	// A.m2
		//	|	// B.m2
		return new Function(); // Function
	};
	=====*/

	/*=====
	dojo.safeMixin = function(target, source){
		//	summary:
		//		Mix in properties skipping a constructor and decorating functions
		//		like it is done by dojo.declare.
		//	target: Object
		//		Target object to accept new properties.
		//	source: Object
		//		Source object for new properties.
		//	description:
		//		This function is used to mix in properties like dojo._mixin does,
		//		but it skips a constructor property and decorates functions like
		//		dojo.declare does.
		//
		//		It is meant to be used with classes and objects produced with
		//		dojo.declare. Functions mixed in with dojo.safeMixin can use
		//		this.inherited() like normal methods.
		//
		//		This function is used to implement extend() method of a constructor
		//		produced with dojo.declare().
		//
		//	example:
		//	|	var A = dojo.declare(null, {
		//	|		m1: function(){
		//	|			console.log("A.m1");
		//	|		},
		//	|		m2: function(){
		//	|			console.log("A.m2");
		//	|		}
		//	|	});
		//	|	var B = dojo.declare(A, {
		//	|		m1: function(){
		//	|			this.inherited(arguments);
		//	|			console.log("B.m1");
		//	|		}
		//	|	});
		//	|	B.extend({
		//	|		m2: function(){
		//	|			this.inherited(arguments);
		//	|			console.log("B.m2");
		//	|		}
		//	|	});
		//	|	var x = new B();
		//	|	dojo.safeMixin(x, {
		//	|		m1: function(){
		//	|			this.inherited(arguments);
		//	|			console.log("X.m1");
		//	|		},
		//	|		m2: function(){
		//	|			this.inherited(arguments);
		//	|			console.log("X.m2");
		//	|		}
		//	|	});
		//	|	x.m2();
		//	|	// prints:
		//	|	// A.m1
		//	|	// B.m1
		//	|	// X.m1
	};
	=====*/

	/*=====
	Object.inherited = function(name, args, newArgs){
		//	summary:
		//		Calls a super method.
		//	name: String?
		//		The optional method name. Should be the same as the caller's
		//		name. Usually "name" is specified in complex dynamic cases, when
		//		the calling method was dynamically added, undecorated by
		//		dojo.declare, and it cannot be determined.
		//	args: Arguments
		//		The caller supply this argument, which should be the original
		//		"arguments".
		//	newArgs: Object?
		//		If "true", the found function will be returned without
		//		executing it.
		//		If Array, it will be used to call a super method. Otherwise
		//		"args" will be used.
		//	returns:
		//		Whatever is returned by a super method, or a super method itself,
		//		if "true" was specified as newArgs.
		//	description:
		//		This method is used inside method of classes produced with
		//		dojo.declare to call a super method (next in the chain). It is
		//		used for manually controlled chaining. Consider using the regular
		//		chaining, because it is faster. Use "this.inherited()" only in
		//		complex cases.
		//
		//		This method cannot me called from automatically chained
		//		constructors including the case of a special (legacy)
		//		constructor chaining. It cannot be called from chained methods.
		//
		//		If "this.inherited()" cannot find the next-in-chain method, it
		//		does nothing and returns "undefined". The last method in chain
		//		can be a default method implemented in Object, which will be
		//		called last.
		//
		//		If "name" is specified, it is assumed that the method that
		//		received "args" is the parent method for this call. It is looked
		//		up in the chain list and if it is found the next-in-chain method
		//		is called. If it is not found, the first-in-chain method is
		//		called.
		//
		//		If "name" is not specified, it will be derived from the calling
		//		method (using a methoid property "nom").
		//
		//	example:
		//	|	var B = dojo.declare(A, {
		//	|		method1: function(a, b, c){
		//	|			this.inherited(arguments);
		//	|		},
		//	|		method2: function(a, b){
		//	|			return this.inherited(arguments, [a + b]);
		//	|		}
		//	|	});
		//	|	// next method is not in the chain list because it is added
		//	|	// manually after the class was created.
		//	|	B.prototype.method3 = function(){
		//	|		console.log("This is a dynamically-added method.");
		//	|		this.inherited("method3", arguments);
		//	|	};
		//	example:
		//	|	var B = dojo.declare(A, {
		//	|		method: function(a, b){
		//	|			var super = this.inherited(arguments, true);
		//	|			// ...
		//	|			if(!super){
		//	|				console.log("there is no super method");
		//	|				return 0;
		//	|			}
		//	|			return super.apply(this, arguments);
		//	|		}
		//	|	});
		return	{};	// Object
	}
	=====*/

	/*=====
	Object.getInherited = function(name, args){
		//	summary:
		//		Returns a super method.
		//	name: String?
		//		The optional method name. Should be the same as the caller's
		//		name. Usually "name" is specified in complex dynamic cases, when
		//		the calling method was dynamically added, undecorated by
		//		dojo.declare, and it cannot be determined.
		//	args: Arguments
		//		The caller supply this argument, which should be the original
		//		"arguments".
		//	returns:
		//		Returns a super method (Function) or "undefined".
		//	description:
		//		This method is a convenience method for "this.inherited()".
		//		It uses the same algorithm but instead of executing a super
		//		method, it returns it, or "undefined" if not found.
		//
		//	example:
		//	|	var B = dojo.declare(A, {
		//	|		method: function(a, b){
		//	|			var super = this.getInherited(arguments);
		//	|			// ...
		//	|			if(!super){
		//	|				console.log("there is no super method");
		//	|				return 0;
		//	|			}
		//	|			return super.apply(this, arguments);
		//	|		}
		//	|	});
		return	{};	// Object
	}
	=====*/

	/*=====
	Object.isInstanceOf = function(cls){
		//	summary:
		//		Checks the inheritance chain to see if it is inherited from this
		//		class.
		//	cls: Function
		//		Class constructor.
		//	returns:
		//		"true", if this object is inherited from this class, "false"
		//		otherwise.
		//	description:
		//		This method is used with instances of classes produced with
		//		dojo.declare to determine of they support a certain interface or
		//		not. It models "instanceof" operator.
		//
		//	example:
		//	|	var A = dojo.declare(null, {
		//	|		// constructor, properties, and methods go here
		//	|		// ...
		//	|	});
		//	|	var B = dojo.declare(null, {
		//	|		// constructor, properties, and methods go here
		//	|		// ...
		//	|	});
		//	|	var C = dojo.declare([A, B], {
		//	|		// constructor, properties, and methods go here
		//	|		// ...
		//	|	});
		//	|	var D = dojo.declare(A, {
		//	|		// constructor, properties, and methods go here
		//	|		// ...
		//	|	});
		//	|
		//	|	var a = new A(), b = new B(), c = new C(), d = new D();
		//	|
		//	|	console.log(a.isInstanceOf(A)); // true
		//	|	console.log(b.isInstanceOf(A)); // false
		//	|	console.log(c.isInstanceOf(A)); // true
		//	|	console.log(d.isInstanceOf(A)); // true
		//	|
		//	|	console.log(a.isInstanceOf(B)); // false
		//	|	console.log(b.isInstanceOf(B)); // true
		//	|	console.log(c.isInstanceOf(B)); // true
		//	|	console.log(d.isInstanceOf(B)); // false
		//	|
		//	|	console.log(a.isInstanceOf(C)); // false
		//	|	console.log(b.isInstanceOf(C)); // false
		//	|	console.log(c.isInstanceOf(C)); // true
		//	|	console.log(d.isInstanceOf(C)); // false
		//	|
		//	|	console.log(a.isInstanceOf(D)); // false
		//	|	console.log(b.isInstanceOf(D)); // false
		//	|	console.log(c.isInstanceOf(D)); // false
		//	|	console.log(d.isInstanceOf(D)); // true
		return	{};	// Object
	}
	=====*/

	/*=====
	Object.extend = function(source){
		//	summary:
		//		Adds all properties and methods of source to constructor's
		//		prototype, making them available to all instances created with
		//		constructor. This method is specific to constructors created with
		//		dojo.declare.
		//	source: Object
		//		Source object which properties are going to be copied to the
		//		constructor's prototype.
		//	description:
		//		Adds source properties to the constructor's prototype. It can
		//		override existing properties.
		//
		//		This method is similar to dojo.extend function, but it is specific
		//		to constructors produced by dojo.declare. It is implemented
		//		using dojo.safeMixin, and it skips a constructor property,
		//		and properly decorates copied functions.
		//
		//	example:
		//	|	var A = dojo.declare(null, {
		//	|		m1: function(){},
		//	|		s1: "Popokatepetl"
		//	|	});
		//	|	A.extend({
		//	|		m1: function(){},
		//	|		m2: function(){},
		//	|		f1: true,
		//	|		d1: 42
		//	|	});
	};
	=====*/
})();

}

if(!dojo._hasResource["dojo._base.connect"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.connect"] = true;
dojo.provide("dojo._base.connect");



// this file courtesy of the TurboAjax Group, licensed under a Dojo CLA

// low-level delegation machinery
dojo._listener = {
	// create a dispatcher function
	getDispatcher: function(){
		// following comments pulled out-of-line to prevent cloning them
		// in the returned function.
		// - indices (i) that are really in the array of listeners (ls) will
		//   not be in Array.prototype. This is the 'sparse array' trick
		//   that keeps us safe from libs that take liberties with built-in
		//   objects
		// - listener is invoked with current scope (this)
		return function(){
			var ap = Array.prototype, c = arguments.callee, ls = c._listeners, t = c.target,
			// return value comes from original target function
				r = t && t.apply(this, arguments),
			// make local copy of listener array so it is immutable during processing
				i, lls = [].concat(ls)
			;

			// invoke listeners after target function
			for(i in lls){
				if(!(i in ap)){
					lls[i].apply(this, arguments);
				}
			}
			// return value comes from original target function
			return r;
		};
	},
	// add a listener to an object
	add: function(/*Object*/ source, /*String*/ method, /*Function*/ listener){
		// Whenever 'method' is invoked, 'listener' will have the same scope.
		// Trying to supporting a context object for the listener led to
		// complexity.
		// Non trivial to provide 'once' functionality here
		// because listener could be the result of a dojo.hitch call,
		// in which case two references to the same hitch target would not
		// be equivalent.
		source = source || dojo.global;
		// The source method is either null, a dispatcher, or some other function
		var f = source[method];
		// Ensure a dispatcher
		if(!f || !f._listeners){
			var d = dojo._listener.getDispatcher();
			// original target function is special
			d.target = f;
			// dispatcher holds a list of listeners
			d._listeners = [];
			// redirect source to dispatcher
			f = source[method] = d;
		}
		// The contract is that a handle is returned that can
		// identify this listener for disconnect.
		//
		// The type of the handle is private. Here is it implemented as Integer.
		// DOM event code has this same contract but handle is Function
		// in non-IE browsers.
		//
		// We could have separate lists of before and after listeners.
		return f._listeners.push(listener); /*Handle*/
	},
	// remove a listener from an object
	remove: function(/*Object*/ source, /*String*/ method, /*Handle*/ handle){
		var f = (source || dojo.global)[method];
		// remember that handle is the index+1 (0 is not a valid handle)
		if(f && f._listeners && handle--){
			delete f._listeners[handle];
		}
	}
};

// Multiple delegation for arbitrary methods.

// This unit knows nothing about DOM, but we include DOM aware documentation
// and dontFix argument here to help the autodocs. Actual DOM aware code is in
// event.js.

dojo.connect = function(/*Object|null*/ obj,
						/*String*/ event,
						/*Object|null*/ context,
						/*String|Function*/ method,
						/*Boolean?*/ dontFix){
	// summary:
	//		`dojo.connect` is the core event handling and delegation method in
	//		Dojo. It allows one function to "listen in" on the execution of
	//		any other, triggering the second whenever the first is called. Many
	//		listeners may be attached to a function, and source functions may
	//		be either regular function calls or DOM events.
	//
	// description:
	//		Connects listeners to actions, so that after event fires, a
	//		listener is called with the same arguments passed to the original
	//		function.
	//
	//		Since `dojo.connect` allows the source of events to be either a
	//		"regular" JavaScript function or a DOM event, it provides a uniform
	//		interface for listening to all the types of events that an
	//		application is likely to deal with though a single, unified
	//		interface. DOM programmers may want to think of it as
	//		"addEventListener for everything and anything".
	//
	//		When setting up a connection, the `event` parameter must be a
	//		string that is the name of the method/event to be listened for. If
	//		`obj` is null, `dojo.global` is assumed, meaning that connections
	//		to global methods are supported but also that you may inadvertently
	//		connect to a global by passing an incorrect object name or invalid
	//		reference.
	//
	//		`dojo.connect` generally is forgiving. If you pass the name of a
	//		function or method that does not yet exist on `obj`, connect will
	//		not fail, but will instead set up a stub method. Similarly, null
	//		arguments may simply be omitted such that fewer than 4 arguments
	//		may be required to set up a connection See the examples for details.
	//
	//		The return value is a handle that is needed to
	//		remove this connection with `dojo.disconnect`.
	//
	// obj:
	//		The source object for the event function.
	//		Defaults to `dojo.global` if null.
	//		If obj is a DOM node, the connection is delegated
	//		to the DOM event manager (unless dontFix is true).
	//
	// event:
	//		String name of the event function in obj.
	//		I.e. identifies a property `obj[event]`.
	//
	// context:
	//		The object that method will receive as "this".
	//
	//		If context is null and method is a function, then method
	//		inherits the context of event.
	//
	//		If method is a string then context must be the source
	//		object object for method (context[method]). If context is null,
	//		dojo.global is used.
	//
	// method:
	//		A function reference, or name of a function in context.
	//		The function identified by method fires after event does.
	//		method receives the same arguments as the event.
	//		See context argument comments for information on method's scope.
	//
	// dontFix:
	//		If obj is a DOM node, set dontFix to true to prevent delegation
	//		of this connection to the DOM event manager.
	//
	// example:
	//		When obj.onchange(), do ui.update():
	//	|	dojo.connect(obj, "onchange", ui, "update");
	//	|	dojo.connect(obj, "onchange", ui, ui.update); // same
	//
	// example:
	//		Using return value for disconnect:
	//	|	var link = dojo.connect(obj, "onchange", ui, "update");
	//	|	...
	//	|	dojo.disconnect(link);
	//
	// example:
	//		When onglobalevent executes, watcher.handler is invoked:
	//	|	dojo.connect(null, "onglobalevent", watcher, "handler");
	//
	// example:
	//		When ob.onCustomEvent executes, customEventHandler is invoked:
	//	|	dojo.connect(ob, "onCustomEvent", null, "customEventHandler");
	//	|	dojo.connect(ob, "onCustomEvent", "customEventHandler"); // same
	//
	// example:
	//		When ob.onCustomEvent executes, customEventHandler is invoked
	//		with the same scope (this):
	//	|	dojo.connect(ob, "onCustomEvent", null, customEventHandler);
	//	|	dojo.connect(ob, "onCustomEvent", customEventHandler); // same
	//
	// example:
	//		When globalEvent executes, globalHandler is invoked
	//		with the same scope (this):
	//	|	dojo.connect(null, "globalEvent", null, globalHandler);
	//	|	dojo.connect("globalEvent", globalHandler); // same

	// normalize arguments
	var a=arguments, args=[], i=0;
	// if a[0] is a String, obj was omitted
	args.push(dojo.isString(a[0]) ? null : a[i++], a[i++]);
	// if the arg-after-next is a String or Function, context was NOT omitted
	var a1 = a[i+1];
	args.push(dojo.isString(a1)||dojo.isFunction(a1) ? a[i++] : null, a[i++]);
	// absorb any additional arguments
	for(var l=a.length; i<l; i++){	args.push(a[i]); }
	// do the actual work
	return dojo._connect.apply(this, args); /*Handle*/
}

// used by non-browser hostenvs. always overriden by event.js
dojo._connect = function(obj, event, context, method){
	var l=dojo._listener, h=l.add(obj, event, dojo.hitch(context, method));
	return [obj, event, h, l]; // Handle
};

dojo.disconnect = function(/*Handle*/ handle){
	// summary:
	//		Remove a link created by dojo.connect.
	// description:
	//		Removes the connection between event and the method referenced by handle.
	// handle:
	//		the return value of the dojo.connect call that created the connection.
	if(handle && handle[0] !== undefined){
		dojo._disconnect.apply(this, handle);
		// let's not keep this reference
		delete handle[0];
	}
};

dojo._disconnect = function(obj, event, handle, listener){
	listener.remove(obj, event, handle);
};

// topic publish/subscribe

dojo._topics = {};

dojo.subscribe = function(/*String*/ topic, /*Object|null*/ context, /*String|Function*/ method){
	//	summary:
	//		Attach a listener to a named topic. The listener function is invoked whenever the
	//		named topic is published (see: dojo.publish).
	//		Returns a handle which is needed to unsubscribe this listener.
	//	context:
	//		Scope in which method will be invoked, or null for default scope.
	//	method:
	//		The name of a function in context, or a function reference. This is the function that
	//		is invoked when topic is published.
	//	example:
	//	|	dojo.subscribe("alerts", null, function(caption, message){ alert(caption + "\n" + message); });
	//	|	dojo.publish("alerts", [ "read this", "hello world" ]);

	// support for 2 argument invocation (omitting context) depends on hitch
	return [topic, dojo._listener.add(dojo._topics, topic, dojo.hitch(context, method))]; /*Handle*/
};

dojo.unsubscribe = function(/*Handle*/ handle){
	//	summary:
	//	 	Remove a topic listener.
	//	handle:
	//	 	The handle returned from a call to subscribe.
	//	example:
	//	|	var alerter = dojo.subscribe("alerts", null, function(caption, message){ alert(caption + "\n" + message); };
	//	|	...
	//	|	dojo.unsubscribe(alerter);
	if(handle){
		dojo._listener.remove(dojo._topics, handle[0], handle[1]);
	}
};

dojo.publish = function(/*String*/ topic, /*Array*/ args){
	//	summary:
	//	 	Invoke all listener method subscribed to topic.
	//	topic:
	//	 	The name of the topic to publish.
	//	args:
	//	 	An array of arguments. The arguments will be applied
	//	 	to each topic subscriber (as first class parameters, via apply).
	//	example:
	//	|	dojo.subscribe("alerts", null, function(caption, message){ alert(caption + "\n" + message); };
	//	|	dojo.publish("alerts", [ "read this", "hello world" ]);

	// Note that args is an array, which is more efficient vs variable length
	// argument list.  Ideally, var args would be implemented via Array
	// throughout the APIs.
	var f = dojo._topics[topic];
	if(f){
		f.apply(this, args||[]);
	}
};

dojo.connectPublisher = function(	/*String*/ topic,
									/*Object|null*/ obj,
									/*String*/ event){
	//	summary:
	//	 	Ensure that every time obj.event() is called, a message is published
	//	 	on the topic. Returns a handle which can be passed to
	//	 	dojo.disconnect() to disable subsequent automatic publication on
	//	 	the topic.
	//	topic:
	//	 	The name of the topic to publish.
	//	obj:
	//	 	The source object for the event function. Defaults to dojo.global
	//	 	if null.
	//	event:
	//	 	The name of the event function in obj.
	//	 	I.e. identifies a property obj[event].
	//	example:
	//	|	dojo.connectPublisher("/ajax/start", dojo, "xhrGet");
	var pf = function(){ dojo.publish(topic, arguments); }
	return event ? dojo.connect(obj, event, pf) : dojo.connect(obj, pf); //Handle
};

}

if(!dojo._hasResource["dojo._base.Deferred"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.Deferred"] = true;
dojo.provide("dojo._base.Deferred");



(function(){
	var mutator = function(){};
	var freeze = Object.freeze || function(){};
	// A deferred provides an API for creating and resolving a promise.
	dojo.Deferred = function(/*Function?*/canceller){
	// summary:
	//		Deferreds provide a generic means for encapsulating an asynchronous
	// 		operation and notifying users of the completion and result of the operation.
	// description:
	//		The dojo.Deferred API is based on the concept of promises that provide a
	//		generic interface into the eventual completion of an asynchronous action.
	//		The motivation for promises fundamentally is about creating a
	//		separation of concerns that allows one to achieve the same type of
	//		call patterns and logical data flow in asynchronous code as can be
	//		achieved in synchronous code. Promises allows one
	//		to be able to call a function purely with arguments needed for
	//		execution, without conflating the call with concerns of whether it is
	//		sync or async. One shouldn't need to alter a call's arguments if the
	//		implementation switches from sync to async (or vice versa). By having
	//		async functions return promises, the concerns of making the call are
	//		separated from the concerns of asynchronous interaction (which are
	//		handled by the promise).
	//
	//  	The dojo.Deferred is a type of promise that provides methods for fulfilling the
	// 		promise with a successful result or an error. The most important method for
	// 		working with Dojo's promises is the then() method, which follows the
	// 		CommonJS proposed promise API. An example of using a Dojo promise:
	//
	//		| 	var resultingPromise = someAsyncOperation.then(function(result){
	//		|		... handle result ...
	//		|	},
	//		|	function(error){
	//		|		... handle error ...
	//		|	});
	//
	//		The .then() call returns a new promise that represents the result of the
	// 		execution of the callback. The callbacks will never affect the original promises value.
	//
	//		The dojo.Deferred instances also provide the following functions for backwards compatibility:
	//
	//			* addCallback(handler)
	//			* addErrback(handler)
	//			* callback(result)
	//			* errback(result)
	//
	//		Callbacks are allowed to return promises themselves, so
	//		you can build complicated sequences of events with ease.
	//
	//		The creator of the Deferred may specify a canceller.  The canceller
	//		is a function that will be called if Deferred.cancel is called
	//		before the Deferred fires. You can use this to implement clean
	//		aborting of an XMLHttpRequest, etc. Note that cancel will fire the
	//		deferred with a CancelledError (unless your canceller returns
	//		another kind of error), so the errbacks should be prepared to
	//		handle that error for cancellable Deferreds.
	// example:
	//	|	var deferred = new dojo.Deferred();
	//	|	setTimeout(function(){ deferred.callback({success: true}); }, 1000);
	//	|	return deferred;
	// example:
	//		Deferred objects are often used when making code asynchronous. It
	//		may be easiest to write functions in a synchronous manner and then
	//		split code using a deferred to trigger a response to a long-lived
	//		operation. For example, instead of register a callback function to
	//		denote when a rendering operation completes, the function can
	//		simply return a deferred:
	//
	//		|	// callback style:
	//		|	function renderLotsOfData(data, callback){
	//		|		var success = false
	//		|		try{
	//		|			for(var x in data){
	//		|				renderDataitem(data[x]);
	//		|			}
	//		|			success = true;
	//		|		}catch(e){ }
	//		|		if(callback){
	//		|			callback(success);
	//		|		}
	//		|	}
	//
	//		|	// using callback style
	//		|	renderLotsOfData(someDataObj, function(success){
	//		|		// handles success or failure
	//		|		if(!success){
	//		|			promptUserToRecover();
	//		|		}
	//		|	});
	//		|	// NOTE: no way to add another callback here!!
	// example:
	//		Using a Deferred doesn't simplify the sending code any, but it
	//		provides a standard interface for callers and senders alike,
	//		providing both with a simple way to service multiple callbacks for
	//		an operation and freeing both sides from worrying about details
	//		such as "did this get called already?". With Deferreds, new
	//		callbacks can be added at any time.
	//
	//		|	// Deferred style:
	//		|	function renderLotsOfData(data){
	//		|		var d = new dojo.Deferred();
	//		|		try{
	//		|			for(var x in data){
	//		|				renderDataitem(data[x]);
	//		|			}
	//		|			d.callback(true);
	//		|		}catch(e){
	//		|			d.errback(new Error("rendering failed"));
	//		|		}
	//		|		return d;
	//		|	}
	//
	//		|	// using Deferred style
	//		|	renderLotsOfData(someDataObj).then(null, function(){
	//		|		promptUserToRecover();
	//		|	});
	//		|	// NOTE: addErrback and addCallback both return the Deferred
	//		|	// again, so we could chain adding callbacks or save the
	//		|	// deferred for later should we need to be notified again.
	// example:
	//		In this example, renderLotsOfData is synchronous and so both
	//		versions are pretty artificial. Putting the data display on a
	//		timeout helps show why Deferreds rock:
	//
	//		|	// Deferred style and async func
	//		|	function renderLotsOfData(data){
	//		|		var d = new dojo.Deferred();
	//		|		setTimeout(function(){
	//		|			try{
	//		|				for(var x in data){
	//		|					renderDataitem(data[x]);
	//		|				}
	//		|				d.callback(true);
	//		|			}catch(e){
	//		|				d.errback(new Error("rendering failed"));
	//		|			}
	//		|		}, 100);
	//		|		return d;
	//		|	}
	//
	//		|	// using Deferred style
	//		|	renderLotsOfData(someDataObj).then(null, function(){
	//		|		promptUserToRecover();
	//		|	});
	//
	//		Note that the caller doesn't have to change his code at all to
	//		handle the asynchronous case.
		var result, finished, isError, head, nextListener;
		var promise = (this.promise = {});
		
		function complete(value){
			if(finished){
				throw new Error("This deferred has already been resolved");
			}
			result = value;
			finished = true;
			notify();
		}
		function notify(){
			var mutated;
			while(!mutated && nextListener){
				var listener = nextListener;
				nextListener = nextListener.next;
				if((mutated = (listener.progress == mutator))){ // assignment and check
					finished = false;
				}
				var func = (isError ? listener.error : listener.resolved);
				if (func) {
					try {
						var newResult = func(result);
						if (newResult && typeof newResult.then === "function") {
							newResult.then(dojo.hitch(listener.deferred, "resolve"), dojo.hitch(listener.deferred, "reject"));
							continue;
						}
						var unchanged = mutated && newResult === undefined;
						if(mutated && !unchanged){
							isError = newResult instanceof Error;
						}
						listener.deferred[unchanged && isError ? "reject" : "resolve"](unchanged ? result : newResult);
					}
					catch (e) {
						listener.deferred.reject(e);
					}
				}else {
					if(isError){
						listener.deferred.reject(result);
					}else{
						listener.deferred.resolve(result);
					}
				}
			}
		}
		// calling resolve will resolve the promise
		this.resolve = this.callback = function(value){
			// summary:
			//		Fulfills the Deferred instance successfully with the provide value
			this.fired = 0;
			this.results = [value, null];
			complete(value);
		};
		
		
		// calling error will indicate that the promise failed
		this.reject = this.errback = function(error){
			// summary:
			//		Fulfills the Deferred instance as an error with the provided error
			isError = true;
			this.fired = 1;
			complete(error);
			this.results = [null, error];
			if(!error || error.log !== false){
				(dojo.config.deferredOnError || function(x){ console.error(x); })(error);
			}
		};
		// call progress to provide updates on the progress on the completion of the promise
		this.progress = function(update){
			// summary
			//		Send progress events to all listeners
			var listener = nextListener;
			while(listener){
				var progress = listener.progress;
				progress && progress(update);
				listener = listener.next;
			}
		};
		this.addCallbacks = function(/*Function?*/callback, /*Function?*/errback){
			this.then(callback, errback, mutator);
			return this;
		};
		// provide the implementation of the promise
		this.then = promise.then = function(/*Function?*/resolvedCallback, /*Function?*/errorCallback, /*Function?*/progressCallback){
			// summary:
			// 		Adds a fulfilledHandler, errorHandler, and progressHandler to be called for
			// 		completion of a promise. The fulfilledHandler is called when the promise
			// 		is fulfilled. The errorHandler is called when a promise fails. The
			// 		progressHandler is called for progress events. All arguments are optional
			// 		and non-function values are ignored. The progressHandler is not only an
			// 		optional argument, but progress events are purely optional. Promise
			// 		providers are not required to ever create progress events.
			//
			// 		This function will return a new promise that is fulfilled when the given
			// 		fulfilledHandler or errorHandler callback is finished. This allows promise
			// 		operations to be chained together. The value returned from the callback
			// 		handler is the fulfillment value for the returned promise. If the callback
			// 		throws an error, the returned promise will be moved to failed state.
			//
			// example:
			// 		An example of using a CommonJS compliant promise:
  			//		|	asyncComputeTheAnswerToEverything().
			//		|		then(addTwo).
			//		|		then(printResult, onError);
  			//		|	>44
			//
			var returnDeferred = progressCallback == mutator ? this : new dojo.Deferred(promise.cancel);
			var listener = {
				resolved: resolvedCallback,
				error: errorCallback,
				progress: progressCallback,
				deferred: returnDeferred
			};
			if(nextListener){
				head = head.next = listener;
			}
			else{
				nextListener = head = listener;
			}
			if(finished){
				notify();
			}
			return returnDeferred.promise;
		};
		var deferred = this;
		this.cancel = promise.cancel = function () {
			// summary:
			//		Cancels the asynchronous operation
			if(!finished){
				var error = canceller && canceller(deferred);
				if(!finished){
					if (!(error instanceof Error)) {
						error = new Error(error);
					}
					error.log = false;
					deferred.reject(error);
				}
			}
		};
		freeze(promise);
	};
	dojo.extend(dojo.Deferred, {
		addCallback: function (/*Function*/callback) {
			return this.addCallbacks(dojo.hitch.apply(dojo, arguments));
		},
	
		addErrback: function (/*Function*/errback) {
			return this.addCallbacks(null, dojo.hitch.apply(dojo, arguments));
		},
	
		addBoth: function (/*Function*/callback) {
			var enclosed = dojo.hitch.apply(dojo, arguments);
			return this.addCallbacks(enclosed, enclosed);
		},
		fired: -1
	});
})();
dojo.when = function(promiseOrValue, /*Function?*/callback, /*Function?*/errback, /*Function?*/progressHandler){
	// summary:
	//		This provides normalization between normal synchronous values and
	//		asynchronous promises, so you can interact with them in a common way
	//	example:
	//		|	function printFirstAndList(items){
	//		|		dojo.when(findFirst(items), console.log);
	//		|		dojo.when(findLast(items), console.log);
	//		|	}
	//		|	function findFirst(items){
	//		|		return dojo.when(items, function(items){
	//		|			return items[0];
	//		|		});
	//		|	}
	//		|	function findLast(items){
	//		|		return dojo.when(items, function(items){
	//		|			return items[items.length];
	//		|		});
	//		|	}
	//		And now all three of his functions can be used sync or async.
	//		|	printFirstAndLast([1,2,3,4]) will work just as well as
	//		|	printFirstAndLast(dojo.xhrGet(...));
	
	if(promiseOrValue && typeof promiseOrValue.then === "function"){
		return promiseOrValue.then(callback, errback, progressHandler);
	}
	return callback(promiseOrValue);
};

}

if(!dojo._hasResource["dojo._base.json"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.json"] = true;
dojo.provide("dojo._base.json");


dojo.fromJson = function(/*String*/ json){
	// summary:
	// 		Parses a [JSON](http://json.org) string to return a JavaScript object.
	// description:
	// 		Throws for invalid JSON strings, but it does not use a strict JSON parser. It
	// 		delegates to eval().  The content passed to this method must therefore come
	//		from a trusted source.
	// json:
	//		a string literal of a JSON item, for instance:
	//			`'{ "foo": [ "bar", 1, { "baz": "thud" } ] }'`

	return eval("(" + json + ")"); // Object
};

dojo._escapeString = function(/*String*/str){
	//summary:
	//		Adds escape sequences for non-visual characters, double quote and
	//		backslash and surrounds with double quotes to form a valid string
	//		literal.
	return ('"' + str.replace(/(["\\])/g, '\\$1') + '"').
		replace(/[\f]/g, "\\f").replace(/[\b]/g, "\\b").replace(/[\n]/g, "\\n").
		replace(/[\t]/g, "\\t").replace(/[\r]/g, "\\r"); // string
};

dojo.toJsonIndentStr = "\t";
dojo.toJson = function(/*Object*/ it, /*Boolean?*/ prettyPrint, /*String?*/ _indentStr){
	//	summary:
	//		Returns a [JSON](http://json.org) serialization of an object.
	//	description:
	//		Returns a [JSON](http://json.org) serialization of an object.
	//		Note that this doesn't check for infinite recursion, so don't do that!
	//	it:
	//		an object to be serialized. Objects may define their own
	//		serialization via a special "__json__" or "json" function
	//		property. If a specialized serializer has been defined, it will
	//		be used as a fallback.
	//	prettyPrint:
	//		if true, we indent objects and arrays to make the output prettier.
	//		The variable `dojo.toJsonIndentStr` is used as the indent string --
	//		to use something other than the default (tab), change that variable
	//		before calling dojo.toJson().
	//	_indentStr:
	//		private variable for recursive calls when pretty printing, do not use.
	//	example:
	//		simple serialization of a trivial object
	//		|	var jsonStr = dojo.toJson({ howdy: "stranger!", isStrange: true });
	//		|	doh.is('{"howdy":"stranger!","isStrange":true}', jsonStr);
	//	example:
	//		a custom serializer for an objects of a particular class:
	//		|	dojo.declare("Furby", null, {
	//		|		furbies: "are strange",
	//		|		furbyCount: 10,
	//		|		__json__: function(){
	//		|		},
	//		|	});

	if(it === undefined){
		return "undefined";
	}
	var objtype = typeof it;
	if(objtype == "number" || objtype == "boolean"){
		return it + "";
	}
	if(it === null){
		return "null";
	}
	if(dojo.isString(it)){
		return dojo._escapeString(it);
	}
	// recurse
	var recurse = arguments.callee;
	// short-circuit for objects that support "json" serialization
	// if they return "self" then just pass-through...
	var newObj;
	_indentStr = _indentStr || "";
	var nextIndent = prettyPrint ? _indentStr + dojo.toJsonIndentStr : "";
	var tf = it.__json__||it.json;
	if(dojo.isFunction(tf)){
		newObj = tf.call(it);
		if(it !== newObj){
			return recurse(newObj, prettyPrint, nextIndent);
		}
	}
	if(it.nodeType && it.cloneNode){ // isNode
		// we can't seriailize DOM nodes as regular objects because they have cycles
		// DOM nodes could be serialized with something like outerHTML, but
		// that can be provided by users in the form of .json or .__json__ function.
		throw new Error("Can't serialize DOM nodes");
	}

	var sep = prettyPrint ? " " : "";
	var newLine = prettyPrint ? "\n" : "";

	// array
	if(dojo.isArray(it)){
		var res = dojo.map(it, function(obj){
			var val = recurse(obj, prettyPrint, nextIndent);
			if(typeof val != "string"){
				val = "undefined";
			}
			return newLine + nextIndent + val;
		});
		return "[" + res.join("," + sep) + newLine + _indentStr + "]";
	}
	/*
	// look in the registry
	try {
		window.o = it;
		newObj = dojo.json.jsonRegistry.match(it);
		return recurse(newObj, prettyPrint, nextIndent);
	}catch(e){
		// console.log(e);
	}
	// it's a function with no adapter, skip it
	*/
	if(objtype == "function"){
		return null; // null
	}
	// generic object code path
	var output = [], key;
	for(key in it){
		var keyStr, val;
		if(typeof key == "number"){
			keyStr = '"' + key + '"';
		}else if(typeof key == "string"){
			keyStr = dojo._escapeString(key);
		}else{
			// skip non-string or number keys
			continue;
		}
		val = recurse(it[key], prettyPrint, nextIndent);
		if(typeof val != "string"){
			// skip non-serializable values
			continue;
		}
		// FIXME: use += on Moz!!
		//	 MOW NOTE: using += is a pain because you have to account for the dangling comma...
		output.push(newLine + nextIndent + keyStr + ":" + sep + val);
	}
	return "{" + output.join("," + sep) + newLine + _indentStr + "}"; // String
};

}

if(!dojo._hasResource["dojo._base.Color"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.Color"] = true;
dojo.provide("dojo._base.Color");




(function(){

	var d = dojo;

	dojo.Color = function(/*Array|String|Object*/ color){
		// summary:
		//	 	Takes a named string, hex string, array of rgb or rgba values,
		//	 	an object with r, g, b, and a properties, or another `dojo.Color` object
		//	 	and creates a new Color instance to work from.
		//
		// example:
		//		Work with a Color instance:
		//	 | var c = new dojo.Color();
		//	 | c.setColor([0,0,0]); // black
		//	 | var hex = c.toHex(); // #000000
		//
		// example:
		//		Work with a node's color:
		//	 | var color = dojo.style("someNode", "backgroundColor");
		//	 | var n = new dojo.Color(color);
		//	 | // adjust the color some
		//	 | n.r *= .5;
		//	 | console.log(n.toString()); // rgb(128, 255, 255);
		if(color){ this.setColor(color); }
	};

	// FIXME:
	// 	there's got to be a more space-efficient way to encode or discover
	// 	these!!  Use hex?
	dojo.Color.named = {
		black:      [0,0,0],
		silver:     [192,192,192],
		gray:       [128,128,128],
		white:      [255,255,255],
		maroon:		[128,0,0],
		red:        [255,0,0],
		purple:		[128,0,128],
		fuchsia:	[255,0,255],
		green:	    [0,128,0],
		lime:	    [0,255,0],
		olive:		[128,128,0],
		yellow:		[255,255,0],
		navy:       [0,0,128],
		blue:       [0,0,255],
		teal:		[0,128,128],
		aqua:		[0,255,255],
		transparent: d.config.transparentColor || [255,255,255]
	};

	dojo.extend(dojo.Color, {
		r: 255, g: 255, b: 255, a: 1,
		_set: function(r, g, b, a){
			var t = this; t.r = r; t.g = g; t.b = b; t.a = a;
		},
		setColor: function(/*Array|String|Object*/ color){
			// summary:
			//		Takes a named string, hex string, array of rgb or rgba values,
			//		an object with r, g, b, and a properties, or another `dojo.Color` object
			//		and sets this color instance to that value.
			//
			// example:
			//	|	var c = new dojo.Color(); // no color
			//	|	c.setColor("#ededed"); // greyish
			if(d.isString(color)){
				d.colorFromString(color, this);
			}else if(d.isArray(color)){
				d.colorFromArray(color, this);
			}else{
				this._set(color.r, color.g, color.b, color.a);
				if(!(color instanceof d.Color)){ this.sanitize(); }
			}
			return this;	// dojo.Color
		},
		sanitize: function(){
			// summary:
			//		Ensures the object has correct attributes
			// description:
			//		the default implementation does nothing, include dojo.colors to
			//		augment it with real checks
			return this;	// dojo.Color
		},
		toRgb: function(){
			// summary:
			//		Returns 3 component array of rgb values
			// example:
			//	|	var c = new dojo.Color("#000000");
			//	| 	console.log(c.toRgb()); // [0,0,0]
			var t = this;
			return [t.r, t.g, t.b];	// Array
		},
		toRgba: function(){
			// summary:
			//		Returns a 4 component array of rgba values from the color
			//		represented by this object.
			var t = this;
			return [t.r, t.g, t.b, t.a];	// Array
		},
		toHex: function(){
			// summary:
			//		Returns a CSS color string in hexadecimal representation
			// example:
			//	| 	console.log(new dojo.Color([0,0,0]).toHex()); // #000000
			var arr = d.map(["r", "g", "b"], function(x){
				var s = this[x].toString(16);
				return s.length < 2 ? "0" + s : s;
			}, this);
			return "#" + arr.join("");	// String
		},
		toCss: function(/*Boolean?*/ includeAlpha){
			// summary:
			//		Returns a css color string in rgb(a) representation
			// example:
			//	|	var c = new dojo.Color("#FFF").toCss();
			//	|	console.log(c); // rgb('255','255','255')
			var t = this, rgb = t.r + ", " + t.g + ", " + t.b;
			return (includeAlpha ? "rgba(" + rgb + ", " + t.a : "rgb(" + rgb) + ")";	// String
		},
		toString: function(){
			// summary:
			//		Returns a visual representation of the color
			return this.toCss(true); // String
		}
	});

	dojo.blendColors = function(
		/*dojo.Color*/ start,
		/*dojo.Color*/ end,
		/*Number*/ weight,
		/*dojo.Color?*/ obj
	){
		// summary:
		//		Blend colors end and start with weight from 0 to 1, 0.5 being a 50/50 blend,
		//		can reuse a previously allocated dojo.Color object for the result
		var t = obj || new d.Color();
		d.forEach(["r", "g", "b", "a"], function(x){
			t[x] = start[x] + (end[x] - start[x]) * weight;
			if(x != "a"){ t[x] = Math.round(t[x]); }
		});
		return t.sanitize();	// dojo.Color
	};

	dojo.colorFromRgb = function(/*String*/ color, /*dojo.Color?*/ obj){
		// summary:
		//		Returns a `dojo.Color` instance from a string of the form
		//		"rgb(...)" or "rgba(...)". Optionally accepts a `dojo.Color`
		//		object to update with the parsed value and return instead of
		//		creating a new object.
		// returns:
		//		A dojo.Color object. If obj is passed, it will be the return value.
		var m = color.toLowerCase().match(/^rgba?\(([\s\.,0-9]+)\)/);
		return m && dojo.colorFromArray(m[1].split(/\s*,\s*/), obj);	// dojo.Color
	};

	dojo.colorFromHex = function(/*String*/ color, /*dojo.Color?*/ obj){
		// summary:
		//		Converts a hex string with a '#' prefix to a color object.
		//		Supports 12-bit #rgb shorthand. Optionally accepts a
		//		`dojo.Color` object to update with the parsed value.
		//
		// returns:
		//		A dojo.Color object. If obj is passed, it will be the return value.
		//
		// example:
		//	 | var thing = dojo.colorFromHex("#ededed"); // grey, longhand
		//
		// example:
		//	| var thing = dojo.colorFromHex("#000"); // black, shorthand
		var t = obj || new d.Color(),
			bits = (color.length == 4) ? 4 : 8,
			mask = (1 << bits) - 1;
		color = Number("0x" + color.substr(1));
		if(isNaN(color)){
			return null; // dojo.Color
		}
		d.forEach(["b", "g", "r"], function(x){
			var c = color & mask;
			color >>= bits;
			t[x] = bits == 4 ? 17 * c : c;
		});
		t.a = 1;
		return t;	// dojo.Color
	};

	dojo.colorFromArray = function(/*Array*/ a, /*dojo.Color?*/ obj){
		// summary:
		//		Builds a `dojo.Color` from a 3 or 4 element array, mapping each
		//		element in sequence to the rgb(a) values of the color.
		// example:
		//		| var myColor = dojo.colorFromArray([237,237,237,0.5]); // grey, 50% alpha
		// returns:
		//		A dojo.Color object. If obj is passed, it will be the return value.
		var t = obj || new d.Color();
		t._set(Number(a[0]), Number(a[1]), Number(a[2]), Number(a[3]));
		if(isNaN(t.a)){ t.a = 1; }
		return t.sanitize();	// dojo.Color
	};

	dojo.colorFromString = function(/*String*/ str, /*dojo.Color?*/ obj){
		// summary:
		//		Parses `str` for a color value. Accepts hex, rgb, and rgba
		//		style color values.
		// description:
		//		Acceptable input values for str may include arrays of any form
		//		accepted by dojo.colorFromArray, hex strings such as "#aaaaaa", or
		//		rgb or rgba strings such as "rgb(133, 200, 16)" or "rgba(10, 10,
		//		10, 50)"
		// returns:
		//		A dojo.Color object. If obj is passed, it will be the return value.
		var a = d.Color.named[str];
		return a && d.colorFromArray(a, obj) || d.colorFromRgb(str, obj) || d.colorFromHex(str, obj);
	};
})();

}

if(!dojo._hasResource["dojo._base.window"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.window"] = true;
dojo.provide("dojo._base.window");


/*=====
dojo.doc = {
	// summary:
	//		Alias for the current document. 'dojo.doc' can be modified
	//		for temporary context shifting. Also see dojo.withDoc().
	// description:
	//    Refer to dojo.doc rather
	//    than referring to 'window.document' to ensure your code runs
	//    correctly in managed contexts.
	// example:
	// 	|	n.appendChild(dojo.doc.createElement('div'));
}
=====*/
dojo.doc = window["document"] || null;

dojo.body = function(){
	// summary:
	//		Return the body element of the document
	//		return the body object associated with dojo.doc
	// example:
	// 	|	dojo.body().appendChild(dojo.doc.createElement('div'));

	// Note: document.body is not defined for a strict xhtml document
	// Would like to memoize this, but dojo.doc can change vi dojo.withDoc().
	return dojo.doc.body || dojo.doc.getElementsByTagName("body")[0]; // Node
};

dojo.setContext = function(/*Object*/globalObject, /*DocumentElement*/globalDocument){
	// summary:
	//		changes the behavior of many core Dojo functions that deal with
	//		namespace and DOM lookup, changing them to work in a new global
	//		context (e.g., an iframe). The varibles dojo.global and dojo.doc
	//		are modified as a result of calling this function and the result of
	//		`dojo.body()` likewise differs.
	dojo.global = globalObject;
	dojo.doc = globalDocument;
};

dojo.withGlobal = function(	/*Object*/globalObject,
							/*Function*/callback,
							/*Object?*/thisObject,
							/*Array?*/cbArguments){
	// summary:
	//		Invoke callback with globalObject as dojo.global and
	//		globalObject.document as dojo.doc.
	// description:
	//		Invoke callback with globalObject as dojo.global and
	//		globalObject.document as dojo.doc. If provided, globalObject
	//		will be executed in the context of object thisObject
	//		When callback() returns or throws an error, the dojo.global
	//		and dojo.doc will be restored to its previous state.

	var oldGlob = dojo.global;
	try{
		dojo.global = globalObject;
		return dojo.withDoc.call(null, globalObject.document, callback, thisObject, cbArguments);
	}finally{
		dojo.global = oldGlob;
	}
};

dojo.withDoc = function(	/*DocumentElement*/documentObject,
							/*Function*/callback,
							/*Object?*/thisObject,
							/*Array?*/cbArguments){
	// summary:
	//		Invoke callback with documentObject as dojo.doc.
	// description:
	//		Invoke callback with documentObject as dojo.doc. If provided,
	//		callback will be executed in the context of object thisObject
	//		When callback() returns or throws an error, the dojo.doc will
	//		be restored to its previous state.

	var oldDoc = dojo.doc,
		oldLtr = dojo._bodyLtr,
		oldQ = dojo.isQuirks;

	try{
		dojo.doc = documentObject;
		delete dojo._bodyLtr; // uncache
		dojo.isQuirks = dojo.doc.compatMode == "BackCompat"; // no need to check for QuirksMode which was Opera 7 only

		if(thisObject && typeof callback == "string"){
			callback = thisObject[callback];
		}

		return callback.apply(thisObject, cbArguments || []);
	}finally{
		dojo.doc = oldDoc;
		delete dojo._bodyLtr; // in case it was undefined originally, and set to true/false by the alternate document
		if(oldLtr !== undefined){ dojo._bodyLtr = oldLtr; }
		dojo.isQuirks = oldQ;
	}
};

}

if(!dojo._hasResource["dojo._base.event"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.event"] = true;
dojo.provide("dojo._base.event");



// this file courtesy of the TurboAjax Group, licensed under a Dojo CLA

(function(){
	// DOM event listener machinery
	var del = (dojo._event_listener = {
		add: function(/*DOMNode*/ node, /*String*/ name, /*Function*/ fp){
			if(!node){return;}
			name = del._normalizeEventName(name);
			fp = del._fixCallback(name, fp);
			if(
								!dojo.isIE &&
								(name == "mouseenter" || name == "mouseleave")
			){
				var ofp = fp;
				name = (name == "mouseenter") ? "mouseover" : "mouseout";
				fp = function(e){
					if(!dojo.isDescendant(e.relatedTarget, node)){
						// e.type = oname; // FIXME: doesn't take? SJM: event.type is generally immutable.
						return ofp.call(this, e);
					}
				}
			}
			node.addEventListener(name, fp, false);
			return fp; /*Handle*/
		},
		remove: function(/*DOMNode*/ node, /*String*/ event, /*Handle*/ handle){
			// summary:
			//		clobbers the listener from the node
			// node:
			//		DOM node to attach the event to
			// event:
			//		the name of the handler to remove the function from
			// handle:
			//		the handle returned from add
			if(node){
				event = del._normalizeEventName(event);
				if(!dojo.isIE && (event == "mouseenter" || event == "mouseleave")){
					event = (event == "mouseenter") ? "mouseover" : "mouseout";
				}

				node.removeEventListener(event, handle, false);
			}
		},
		_normalizeEventName: function(/*String*/ name){
			// Generally, name should be lower case, unless it is special
			// somehow (e.g. a Mozilla DOM event).
			// Remove 'on'.
			return name.slice(0,2) =="on" ? name.slice(2) : name;
		},
		_fixCallback: function(/*String*/ name, fp){
			// By default, we only invoke _fixEvent for 'keypress'
			// If code is added to _fixEvent for other events, we have
			// to revisit this optimization.
			// This also applies to _fixEvent overrides for Safari and Opera
			// below.
			return name != "keypress" ? fp : function(e){ return fp.call(this, del._fixEvent(e, this)); };
		},
		_fixEvent: function(evt, sender){
			// _fixCallback only attaches us to keypress.
			// Switch on evt.type anyway because we might
			// be called directly from dojo.fixEvent.
			switch(evt.type){
				case "keypress":
					del._setKeyChar(evt);
					break;
			}
			return evt;
		},
		_setKeyChar: function(evt){
			evt.keyChar = evt.charCode >= 32 ? String.fromCharCode(evt.charCode) : '';
			evt.charOrCode = evt.keyChar || evt.keyCode;
		},
		// For IE and Safari: some ctrl-key combinations (mostly w/punctuation) do not emit a char code in IE
		// we map those virtual key codes to ascii here
		// not valid for all (non-US) keyboards, so maybe we shouldn't bother
		_punctMap: {
			106:42,
			111:47,
			186:59,
			187:43,
			188:44,
			189:45,
			190:46,
			191:47,
			192:96,
			219:91,
			220:92,
			221:93,
			222:39
		}
	});

	// DOM events
	
	dojo.fixEvent = function(/*Event*/ evt, /*DOMNode*/ sender){
		// summary:
		//		normalizes properties on the event object including event
		//		bubbling methods, keystroke normalization, and x/y positions
		// evt: Event
		//		native event object
		// sender: DOMNode
		//		node to treat as "currentTarget"
		return del._fixEvent(evt, sender);
	};

	dojo.stopEvent = function(/*Event*/ evt){
		// summary:
		//		prevents propagation and clobbers the default action of the
		//		passed event
		// evt: Event
		//		The event object. If omitted, window.event is used on IE.
		evt.preventDefault();
		evt.stopPropagation();
		// NOTE: below, this method is overridden for IE
	};

	// the default listener to use on dontFix nodes, overriden for IE
	var node_listener = dojo._listener;
	
	// Unify connect and event listeners
	dojo._connect = function(obj, event, context, method, dontFix){
		// FIXME: need a more strict test
		var isNode = obj && (obj.nodeType||obj.attachEvent||obj.addEventListener);
		// choose one of three listener options: raw (connect.js), DOM event on a Node, custom event on a Node
		// we need the third option to provide leak prevention on broken browsers (IE)
		var lid = isNode ? (dontFix ? 2 : 1) : 0, l = [dojo._listener, del, node_listener][lid];
		// create a listener
		var h = l.add(obj, event, dojo.hitch(context, method));
		// formerly, the disconnect package contained "l" directly, but if client code
		// leaks the disconnect package (by connecting it to a node), referencing "l"
		// compounds the problem.
		// instead we return a listener id, which requires custom _disconnect below.
		// return disconnect package
		return [ obj, event, h, lid ];
	};

	dojo._disconnect = function(obj, event, handle, listener){
		([dojo._listener, del, node_listener][listener]).remove(obj, event, handle);
	};

	// Constants

	// Public: client code should test
	// keyCode against these named constants, as the
	// actual codes can vary by browser.
	dojo.keys = {
		// summary:
		//		Definitions for common key values
		BACKSPACE: 8,
		TAB: 9,
		CLEAR: 12,
		ENTER: 13,
		SHIFT: 16,
		CTRL: 17,
		ALT: 18,
		META: dojo.isSafari ? 91 : 224,		// the apple key on macs
		PAUSE: 19,
		CAPS_LOCK: 20,
		ESCAPE: 27,
		SPACE: 32,
		PAGE_UP: 33,
		PAGE_DOWN: 34,
		END: 35,
		HOME: 36,
		LEFT_ARROW: 37,
		UP_ARROW: 38,
		RIGHT_ARROW: 39,
		DOWN_ARROW: 40,
		INSERT: 45,
		DELETE: 46,
		HELP: 47,
		LEFT_WINDOW: 91,
		RIGHT_WINDOW: 92,
		SELECT: 93,
		NUMPAD_0: 96,
		NUMPAD_1: 97,
		NUMPAD_2: 98,
		NUMPAD_3: 99,
		NUMPAD_4: 100,
		NUMPAD_5: 101,
		NUMPAD_6: 102,
		NUMPAD_7: 103,
		NUMPAD_8: 104,
		NUMPAD_9: 105,
		NUMPAD_MULTIPLY: 106,
		NUMPAD_PLUS: 107,
		NUMPAD_ENTER: 108,
		NUMPAD_MINUS: 109,
		NUMPAD_PERIOD: 110,
		NUMPAD_DIVIDE: 111,
		F1: 112,
		F2: 113,
		F3: 114,
		F4: 115,
		F5: 116,
		F6: 117,
		F7: 118,
		F8: 119,
		F9: 120,
		F10: 121,
		F11: 122,
		F12: 123,
		F13: 124,
		F14: 125,
		F15: 126,
		NUM_LOCK: 144,
		SCROLL_LOCK: 145,
		// virtual key mapping
		copyKey: dojo.isMac && !dojo.isAIR ? (dojo.isSafari ? 91 : 224 ) : 17
	};
	
	var evtCopyKey = dojo.isMac ? "metaKey" : "ctrlKey";
	
	dojo.isCopyKey = function(e){
		// summary:
		//		Checks an event for the copy key (meta on Mac, and ctrl anywhere else)
		// e: Event
		//		Event object to examine
		return e[evtCopyKey];	// Boolean
	};

	// Public: decoding mouse buttons from events

/*=====
	dojo.mouseButtons = {
		// LEFT: Number
		//		Numeric value of the left mouse button for the platform.
		LEFT:   0,
		// MIDDLE: Number
		//		Numeric value of the middle mouse button for the platform.
		MIDDLE: 1,
		// RIGHT: Number
		//		Numeric value of the right mouse button for the platform.
		RIGHT:  2,
	
		isButton: function(e, button){
			// summary:
			//		Checks an event object for a pressed button
			// e: Event
			//		Event object to examine
			// button: Number
			//		The button value (example: dojo.mouseButton.LEFT)
			return e.button == button; // Boolean
		},
		isLeft: function(e){
			// summary:
			//		Checks an event object for the pressed left button
			// e: Event
			//		Event object to examine
			return e.button == 0; // Boolean
		},
		isMiddle: function(e){
			// summary:
			//		Checks an event object for the pressed middle button
			// e: Event
			//		Event object to examine
			return e.button == 1; // Boolean
		},
		isRight: function(e){
			// summary:
			//		Checks an event object for the pressed right button
			// e: Event
			//		Event object to examine
			return e.button == 2; // Boolean
		}
	};
=====*/

		if(dojo.isIE < 9 || (dojo.isIE && dojo.isQuirks)){
		dojo.mouseButtons = {
			LEFT:   1,
			MIDDLE: 4,
			RIGHT:  2,
			// helper functions
			isButton: function(e, button){ return e.button & button; },
			isLeft:   function(e){ return e.button & 1; },
			isMiddle: function(e){ return e.button & 4; },
			isRight:  function(e){ return e.button & 2; }
		};
	}else{
			dojo.mouseButtons = {
			LEFT:   0,
			MIDDLE: 1,
			RIGHT:  2,
			// helper functions
			isButton: function(e, button){ return e.button == button; },
			isLeft:   function(e){ return e.button == 0; },
			isMiddle: function(e){ return e.button == 1; },
			isRight:  function(e){ return e.button == 2; }
		};
		}
	
		// IE event normalization
	if(dojo.isIE){
		var _trySetKeyCode = function(e, code){
			try{
				// squelch errors when keyCode is read-only
				// (e.g. if keyCode is ctrl or shift)
				return (e.keyCode = code);
			}catch(e){
				return 0;
			}
		};

		// by default, use the standard listener
		var iel = dojo._listener;
		var listenersName = (dojo._ieListenersName = "_" + dojo._scopeName + "_listeners");
		// dispatcher tracking property
		if(!dojo.config._allow_leaks){
			// custom listener that handles leak protection for DOM events
			node_listener = iel = dojo._ie_listener = {
				// support handler indirection: event handler functions are
				// referenced here. Event dispatchers hold only indices.
				handlers: [],
				// add a listener to an object
				add: function(/*Object*/ source, /*String*/ method, /*Function*/ listener){
					source = source || dojo.global;
					var f = source[method];
					if(!f||!f[listenersName]){
						var d = dojo._getIeDispatcher();
						// original target function is special
						d.target = f && (ieh.push(f) - 1);
						// dispatcher holds a list of indices into handlers table
						d[listenersName] = [];
						// redirect source to dispatcher
						f = source[method] = d;
					}
					return f[listenersName].push(ieh.push(listener) - 1) ; /*Handle*/
				},
				// remove a listener from an object
				remove: function(/*Object*/ source, /*String*/ method, /*Handle*/ handle){
					var f = (source||dojo.global)[method], l = f && f[listenersName];
					if(f && l && handle--){
						delete ieh[l[handle]];
						delete l[handle];
					}
				}
			};
			// alias used above
			var ieh = iel.handlers;
		}

		dojo.mixin(del, {
			add: function(/*DOMNode*/ node, /*String*/ event, /*Function*/ fp){
				if(!node){return;} // undefined
				event = del._normalizeEventName(event);
				if(event=="onkeypress"){
					// we need to listen to onkeydown to synthesize
					// keypress events that otherwise won't fire
					// on IE
					var kd = node.onkeydown;
					if(!kd || !kd[listenersName] || !kd._stealthKeydownHandle){
						var h = del.add(node, "onkeydown", del._stealthKeyDown);
						kd = node.onkeydown;
						kd._stealthKeydownHandle = h;
						kd._stealthKeydownRefs = 1;
					}else{
						kd._stealthKeydownRefs++;
					}
				}
				return iel.add(node, event, del._fixCallback(fp));
			},
			remove: function(/*DOMNode*/ node, /*String*/ event, /*Handle*/ handle){
				event = del._normalizeEventName(event);
				iel.remove(node, event, handle);
				if(event=="onkeypress"){
					var kd = node.onkeydown;
					if(--kd._stealthKeydownRefs <= 0){
						iel.remove(node, "onkeydown", kd._stealthKeydownHandle);
						delete kd._stealthKeydownHandle;
					}
				}
			},
			_normalizeEventName: function(/*String*/ eventName){
				// Generally, eventName should be lower case, unless it is
				// special somehow (e.g. a Mozilla event)
				// ensure 'on'
				return eventName.slice(0,2) != "on" ? "on" + eventName : eventName;
			},
			_nop: function(){},
			_fixEvent: function(/*Event*/ evt, /*DOMNode*/ sender){
				// summary:
				//		normalizes properties on the event object including event
				//		bubbling methods, keystroke normalization, and x/y positions
				// evt:
				//		native event object
				// sender:
				//		node to treat as "currentTarget"
				if(!evt){
					var w = sender && (sender.ownerDocument || sender.document || sender).parentWindow || window;
					evt = w.event;
				}
				if(!evt){return(evt);}
				evt.target = evt.srcElement;
				evt.currentTarget = (sender || evt.srcElement);
				evt.layerX = evt.offsetX;
				evt.layerY = evt.offsetY;
				// FIXME: scroll position query is duped from dojo.html to
				// avoid dependency on that entire module. Now that HTML is in
				// Base, we should convert back to something similar there.
				var se = evt.srcElement, doc = (se && se.ownerDocument) || document;
				// DO NOT replace the following to use dojo.body(), in IE, document.documentElement should be used
				// here rather than document.body
				var docBody = ((dojo.isIE < 6) || (doc["compatMode"] == "BackCompat")) ? doc.body : doc.documentElement;
				var offset = dojo._getIeDocumentElementOffset();
				evt.pageX = evt.clientX + dojo._fixIeBiDiScrollLeft(docBody.scrollLeft || 0) - offset.x;
				evt.pageY = evt.clientY + (docBody.scrollTop || 0) - offset.y;
				if(evt.type == "mouseover"){
					evt.relatedTarget = evt.fromElement;
				}
				if(evt.type == "mouseout"){
					evt.relatedTarget = evt.toElement;
				}
				if (dojo.isIE < 9 || dojo.isQuirks) {
					evt.stopPropagation = del._stopPropagation;
					evt.preventDefault = del._preventDefault;
				}
				return del._fixKeys(evt);
			},
			_fixKeys: function(evt){
				switch(evt.type){
					case "keypress":
						var c = ("charCode" in evt ? evt.charCode : evt.keyCode);
						if (c==10){
							// CTRL-ENTER is CTRL-ASCII(10) on IE, but CTRL-ENTER on Mozilla
							c=0;
							evt.keyCode = 13;
						}else if(c==13||c==27){
							c=0; // Mozilla considers ENTER and ESC non-printable
						}else if(c==3){
							c=99; // Mozilla maps CTRL-BREAK to CTRL-c
						}
						// Mozilla sets keyCode to 0 when there is a charCode
						// but that stops the event on IE.
						evt.charCode = c;
						del._setKeyChar(evt);
						break;
				}
				return evt;
			},
			_stealthKeyDown: function(evt){
				// IE doesn't fire keypress for most non-printable characters.
				// other browsers do, we simulate it here.
				var kp = evt.currentTarget.onkeypress;
				// only works if kp exists and is a dispatcher
				if(!kp || !kp[listenersName]){ return; }
				// munge key/charCode
				var k=evt.keyCode;
				// These are Windows Virtual Key Codes
				// http://msdn.microsoft.com/library/default.asp?url=/library/en-us/winui/WinUI/WindowsUserInterface/UserInput/VirtualKeyCodes.asp
				var unprintable = (k!=13 || (dojo.isIE >= 9 && !dojo.isQuirks)) && k!=32 && k!=27 && (k<48||k>90) && (k<96||k>111) && (k<186||k>192) && (k<219||k>222);

				// synthesize keypress for most unprintables and CTRL-keys
				if(unprintable||evt.ctrlKey){
					var c = unprintable ? 0 : k;
					if(evt.ctrlKey){
						if(k==3 || k==13){
							return; // IE will post CTRL-BREAK, CTRL-ENTER as keypress natively
						}else if(c>95 && c<106){
							c -= 48; // map CTRL-[numpad 0-9] to ASCII
						}else if((!evt.shiftKey)&&(c>=65&&c<=90)){
							c += 32; // map CTRL-[A-Z] to lowercase
						}else{
							c = del._punctMap[c] || c; // map other problematic CTRL combinations to ASCII
						}
					}
					// simulate a keypress event
					var faux = del._synthesizeEvent(evt, {type: 'keypress', faux: true, charCode: c});
					kp.call(evt.currentTarget, faux);
					if(dojo.isIE < 9 || (dojo.isIE && dojo.isQuirks)){
						evt.cancelBubble = faux.cancelBubble;
					}
					evt.returnValue = faux.returnValue;
					_trySetKeyCode(evt, faux.keyCode);
				}
			},
			// Called in Event scope
			_stopPropagation: function(){
				this.cancelBubble = true;
			},
			_preventDefault: function(){
				// Setting keyCode to 0 is the only way to prevent certain keypresses (namely
				// ctrl-combinations that correspond to menu accelerator keys).
				// Otoh, it prevents upstream listeners from getting this information
				// Try to split the difference here by clobbering keyCode only for ctrl
				// combinations. If you still need to access the key upstream, bubbledKeyCode is
				// provided as a workaround.
				this.bubbledKeyCode = this.keyCode;
				if(this.ctrlKey){_trySetKeyCode(this, 0);}
				this.returnValue = false;
			}
		});
				
		// override stopEvent for IE
		dojo.stopEvent = (dojo.isIE < 9 || dojo.isQuirks) ? function(evt){
			evt = evt || window.event;
			del._stopPropagation.call(evt);
			del._preventDefault.call(evt);
		} : dojo.stopEvent;
	}
	
	del._synthesizeEvent = function(evt, props){
			var faux = dojo.mixin({}, evt, props);
			del._setKeyChar(faux);
			// FIXME: would prefer to use dojo.hitch: dojo.hitch(evt, evt.preventDefault);
			// but it throws an error when preventDefault is invoked on Safari
			// does Event.preventDefault not support "apply" on Safari?
			faux.preventDefault = function(){ evt.preventDefault(); };
			faux.stopPropagation = function(){ evt.stopPropagation(); };
			return faux;
	};
	
		// Opera event normalization
	if(dojo.isOpera){
		dojo.mixin(del, {
			_fixEvent: function(evt, sender){
				switch(evt.type){
					case "keypress":
						var c = evt.which;
						if(c==3){
							c=99; // Mozilla maps CTRL-BREAK to CTRL-c
						}
						// can't trap some keys at all, like INSERT and DELETE
						// there is no differentiating info between DELETE and ".", or INSERT and "-"
						c = c<41 && !evt.shiftKey ? 0 : c;
						if(evt.ctrlKey && !evt.shiftKey && c>=65 && c<=90){
							// lowercase CTRL-[A-Z] keys
							c += 32;
						}
						return del._synthesizeEvent(evt, { charCode: c });
				}
				return evt;
			}
		});
	}
	
		// Webkit event normalization
	if(dojo.isWebKit){
				del._add = del.add;
		del._remove = del.remove;

		dojo.mixin(del, {
			add: function(/*DOMNode*/ node, /*String*/ event, /*Function*/ fp){
				if(!node){return;} // undefined
				var handle = del._add(node, event, fp);
				if(del._normalizeEventName(event) == "keypress"){
					// we need to listen to onkeydown to synthesize
					// keypress events that otherwise won't fire
					// in Safari 3.1+: https://lists.webkit.org/pipermail/webkit-dev/2007-December/002992.html
					handle._stealthKeyDownHandle = del._add(node, "keydown", function(evt){
						//A variation on the IE _stealthKeydown function
						//Synthesize an onkeypress event, but only for unprintable characters.
						var k=evt.keyCode;
						// These are Windows Virtual Key Codes
						// http://msdn.microsoft.com/library/default.asp?url=/library/en-us/winui/WinUI/WindowsUserInterface/UserInput/VirtualKeyCodes.asp
						var unprintable = k!=13 && k!=32 && (k<48 || k>90) && (k<96 || k>111) && (k<186 || k>192) && (k<219 || k>222);
						// synthesize keypress for most unprintables and CTRL-keys
						if(unprintable || evt.ctrlKey){
							var c = unprintable ? 0 : k;
							if(evt.ctrlKey){
								if(k==3 || k==13){
									return; // IE will post CTRL-BREAK, CTRL-ENTER as keypress natively
								}else if(c>95 && c<106){
									c -= 48; // map CTRL-[numpad 0-9] to ASCII
								}else if(!evt.shiftKey && c>=65 && c<=90){
									c += 32; // map CTRL-[A-Z] to lowercase
								}else{
									c = del._punctMap[c] || c; // map other problematic CTRL combinations to ASCII
								}
							}
							// simulate a keypress event
							var faux = del._synthesizeEvent(evt, {type: 'keypress', faux: true, charCode: c});
							fp.call(evt.currentTarget, faux);
						}
					});
				}
				return handle; /*Handle*/
			},

			remove: function(/*DOMNode*/ node, /*String*/ event, /*Handle*/ handle){
				if(node){
					if(handle._stealthKeyDownHandle){
						del._remove(node, "keydown", handle._stealthKeyDownHandle);
					}
					del._remove(node, event, handle);
				}
			},
			_fixEvent: function(evt, sender){
				switch(evt.type){
					case "keypress":
						if(evt.faux){ return evt; }
						var c = evt.charCode;
						c = c>=32 ? c : 0;
						return del._synthesizeEvent(evt, {charCode: c, faux: true});
				}
				return evt;
			}
		});
		}
	})();

if(dojo.isIE){
	// keep this out of the closure
	// closing over 'iel' or 'ieh' b0rks leak prevention
	// ls[i] is an index into the master handler array
	dojo._ieDispatcher = function(args, sender){
		var ap = Array.prototype,
			h = dojo._ie_listener.handlers,
			c = args.callee,
			ls = c[dojo._ieListenersName],
			t = h[c.target];
		// return value comes from original target function
		var r = t && t.apply(sender, args);
		// make local copy of listener array so it's immutable during processing
		var lls = [].concat(ls);
		// invoke listeners after target function
		for(var i in lls){
			var f = h[lls[i]];
			if(!(i in ap) && f){
				f.apply(sender, args);
			}
		}
		return r;
	};
	dojo._getIeDispatcher = function(){
		// ensure the returned function closes over nothing ("new Function" apparently doesn't close)
		return new Function(dojo._scopeName + "._ieDispatcher(arguments, this)"); // function
	};
	// keep this out of the closure to reduce RAM allocation
	dojo._event_listener._fixCallback = function(fp){
		var f = dojo._event_listener._fixEvent;
		return function(e){ return fp.call(this, f(e, this)); };
	};
}

}

if(!dojo._hasResource["dojo._base.html"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.html"] = true;
dojo.provide("dojo._base.html");



// FIXME: need to add unit tests for all the semi-public methods

try{
	document.execCommand("BackgroundImageCache", false, true);
}catch(e){
	// sane browsers don't have cache "issues"
}

// =============================
// DOM Functions
// =============================

/*=====
dojo.byId = function(id, doc){
	//	summary:
	//		Returns DOM node with matching `id` attribute or `null`
	//		if not found. If `id` is a DomNode, this function is a no-op.
	//
	//	id: String|DOMNode
	//	 	A string to match an HTML id attribute or a reference to a DOM Node
	//
	//	doc: Document?
	//		Document to work in. Defaults to the current value of
	//		dojo.doc.  Can be used to retrieve
	//		node references from other documents.
	//
	//	example:
	//	Look up a node by ID:
	//	|	var n = dojo.byId("foo");
	//
	//	example:
	//	Check if a node exists, and use it.
	//	|	var n = dojo.byId("bar");
	//	|	if(n){ doStuff() ... }
	//
	//	example:
	//	Allow string or DomNode references to be passed to a custom function:
	//	|	var foo = function(nodeOrId){
	//	|		nodeOrId = dojo.byId(nodeOrId);
	//	|		// ... more stuff
	//	|	}
=====*/

if(dojo.isIE){
	dojo.byId = function(id, doc){
		if(typeof id != "string"){
			return id;
		}
		var _d = doc || dojo.doc, te = _d.getElementById(id);
		// attributes.id.value is better than just id in case the
		// user has a name=id inside a form
		if(te && (te.attributes.id.value == id || te.id == id)){
			return te;
		}else{
			var eles = _d.all[id];
			if(!eles || eles.nodeName){
				eles = [eles];
			}
			// if more than 1, choose first with the correct id
			var i=0;
			while((te=eles[i++])){
				if((te.attributes && te.attributes.id && te.attributes.id.value == id)
					|| te.id == id){
					return te;
				}
			}
		}
	};
}else{
	dojo.byId = function(id, doc){
		// inline'd type check.
		// be sure to return null per documentation, to match IE branch.
		return ((typeof id == "string") ? (doc || dojo.doc).getElementById(id) : id) || null; // DomNode
	};
}
/*=====
};
=====*/

(function(){
	var d = dojo;
	var byId = d.byId;

	var _destroyContainer = null,
		_destroyDoc;
		d.addOnWindowUnload(function(){
		_destroyContainer = null; //prevent IE leak
	});
	
/*=====
	dojo._destroyElement = function(node){
		// summary:
		// 		Existing alias for `dojo.destroy`. Deprecated, will be removed
		// 		in 2.0
	}
=====*/
	dojo._destroyElement = dojo.destroy = function(/*String|DomNode*/node){
		//	summary:
		//		Removes a node from its parent, clobbering it and all of its
		//		children.
		//
		//	description:
		//		Removes a node from its parent, clobbering it and all of its
		//		children. Function only works with DomNodes, and returns nothing.
		//
		//	node:
		//		A String ID or DomNode reference of the element to be destroyed
		//
		//	example:
		//	Destroy a node byId:
		//	|	dojo.destroy("someId");
		//
		//	example:
		//	Destroy all nodes in a list by reference:
		//	|	dojo.query(".someNode").forEach(dojo.destroy);

		node = byId(node);
		try{
			var doc = node.ownerDocument;
			// cannot use _destroyContainer.ownerDocument since this can throw an exception on IE
			if(!_destroyContainer || _destroyDoc != doc){
				_destroyContainer = doc.createElement("div");
				_destroyDoc = doc;
			}
			_destroyContainer.appendChild(node.parentNode ? node.parentNode.removeChild(node) : node);
			// NOTE: see http://trac.dojotoolkit.org/ticket/2931. This may be a bug and not a feature
			_destroyContainer.innerHTML = "";
		}catch(e){
			/* squelch */
		}
	};

	dojo.isDescendant = function(/*DomNode|String*/node, /*DomNode|String*/ancestor){
		//	summary:
		//		Returns true if node is a descendant of ancestor
		//	node: string id or node reference to test
		//	ancestor: string id or node reference of potential parent to test against
		//
		// example:
		//	Test is node id="bar" is a descendant of node id="foo"
		//	|	if(dojo.isDescendant("bar", "foo")){ ... }
		try{
			node = byId(node);
			ancestor = byId(ancestor);
			while(node){
				if(node == ancestor){
					return true; // Boolean
				}
				node = node.parentNode;
			}
		}catch(e){ /* squelch, return false */ }
		return false; // Boolean
	};

	dojo.setSelectable = function(/*DomNode|String*/node, /*Boolean*/selectable){
		//	summary:
		//		Enable or disable selection on a node
		//	node:
		//		id or reference to node
		//	selectable:
		//		state to put the node in. false indicates unselectable, true
		//		allows selection.
		//	example:
		//	Make the node id="bar" unselectable
		//	|	dojo.setSelectable("bar");
		//	example:
		//	Make the node id="bar" selectable
		//	|	dojo.setSelectable("bar", true);
		node = byId(node);
				if(d.isMozilla){
			node.style.MozUserSelect = selectable ? "" : "none";
		}else if(d.isKhtml || d.isWebKit){
					node.style.KhtmlUserSelect = selectable ? "auto" : "none";
				}else if(d.isIE){
			var v = (node.unselectable = selectable ? "" : "on");
			d.query("*", node).forEach("item.unselectable = '"+v+"'");
		}
				//FIXME: else?  Opera?
	};

	var _insertBefore = function(/*DomNode*/node, /*DomNode*/ref){
		var parent = ref.parentNode;
		if(parent){
			parent.insertBefore(node, ref);
		}
	};

	var _insertAfter = function(/*DomNode*/node, /*DomNode*/ref){
		//	summary:
		//		Try to insert node after ref
		var parent = ref.parentNode;
		if(parent){
			if(parent.lastChild == ref){
				parent.appendChild(node);
			}else{
				parent.insertBefore(node, ref.nextSibling);
			}
		}
	};

	dojo.place = function(node, refNode, position){
		//	summary:
		//		Attempt to insert node into the DOM, choosing from various positioning options.
		//		Returns the first argument resolved to a DOM node.
		//
		//	node: String|DomNode
		//		id or node reference, or HTML fragment starting with "<" to place relative to refNode
		//
		//	refNode: String|DomNode
		//		id or node reference to use as basis for placement
		//
		//	position: String|Number?
		//		string noting the position of node relative to refNode or a
		//		number indicating the location in the childNodes collection of refNode.
		//		Accepted string values are:
		//	|	* before
		//	|	* after
		//	|	* replace
		//	|	* only
		//	|	* first
		//	|	* last
		//		"first" and "last" indicate positions as children of refNode, "replace" replaces refNode,
		//		"only" replaces all children.  position defaults to "last" if not specified
		//
		//	returns: DomNode
		//		Returned values is the first argument resolved to a DOM node.
		//
		//		.place() is also a method of `dojo.NodeList`, allowing `dojo.query` node lookups.
		//
		// example:
		//		Place a node by string id as the last child of another node by string id:
		//	|	dojo.place("someNode", "anotherNode");
		//
		// example:
		//		Place a node by string id before another node by string id
		//	|	dojo.place("someNode", "anotherNode", "before");
		//
		// example:
		//		Create a Node, and place it in the body element (last child):
		//	|	dojo.place("<div></div>", dojo.body());
		//
		// example:
		//		Put a new LI as the first child of a list by id:
		//	|	dojo.place("<li></li>", "someUl", "first");

		refNode = byId(refNode);
		if(typeof node == "string"){ // inline'd type check
			node = /^\s*</.test(node) ? d._toDom(node, refNode.ownerDocument) : byId(node);
		}
		if(typeof position == "number"){ // inline'd type check
			var cn = refNode.childNodes;
			if(!cn.length || cn.length <= position){
				refNode.appendChild(node);
			}else{
				_insertBefore(node, cn[position < 0 ? 0 : position]);
			}
		}else{
			switch(position){
				case "before":
					_insertBefore(node, refNode);
					break;
				case "after":
					_insertAfter(node, refNode);
					break;
				case "replace":
					refNode.parentNode.replaceChild(node, refNode);
					break;
				case "only":
					d.empty(refNode);
					refNode.appendChild(node);
					break;
				case "first":
					if(refNode.firstChild){
						_insertBefore(node, refNode.firstChild);
						break;
					}
					// else fallthrough...
				default: // aka: last
					refNode.appendChild(node);
			}
		}
		return node; // DomNode
	};

	// Box functions will assume this model.
	// On IE/Opera, BORDER_BOX will be set if the primary document is in quirks mode.
	// Can be set to change behavior of box setters.

	// can be either:
	//	"border-box"
	//	"content-box" (default)
	dojo.boxModel = "content-box";

	// We punt per-node box mode testing completely.
	// If anybody cares, we can provide an additional (optional) unit
	// that overrides existing code to include per-node box sensitivity.

	// Opera documentation claims that Opera 9 uses border-box in BackCompat mode.
	// but experiments (Opera 9.10.8679 on Windows Vista) indicate that it actually continues to use content-box.
	// IIRC, earlier versions of Opera did in fact use border-box.
	// Opera guys, this is really confusing. Opera being broken in quirks mode is not our fault.

		if(d.isIE /*|| dojo.isOpera*/){
		// client code may have to adjust if compatMode varies across iframes
		d.boxModel = document.compatMode == "BackCompat" ? "border-box" : "content-box";
	}
	
	// =============================
	// Style Functions
	// =============================

	// getComputedStyle drives most of the style code.
	// Wherever possible, reuse the returned object.
	//
	// API functions below that need to access computed styles accept an
	// optional computedStyle parameter.
	// If this parameter is omitted, the functions will call getComputedStyle themselves.
	// This way, calling code can access computedStyle once, and then pass the reference to
	// multiple API functions.

/*=====
	dojo.getComputedStyle = function(node){
		//	summary:
		//		Returns a "computed style" object.
		//
		//	description:
		//		Gets a "computed style" object which can be used to gather
		//		information about the current state of the rendered node.
		//
		//		Note that this may behave differently on different browsers.
		//		Values may have different formats and value encodings across
		//		browsers.
		//
		//		Note also that this method is expensive.  Wherever possible,
		//		reuse the returned object.
		//
		//		Use the dojo.style() method for more consistent (pixelized)
		//		return values.
		//
		//	node: DOMNode
		//		A reference to a DOM node. Does NOT support taking an
		//		ID string for speed reasons.
		//	example:
		//	|	dojo.getComputedStyle(dojo.byId('foo')).borderWidth;
		//
		//	example:
		//	Reusing the returned object, avoiding multiple lookups:
		//	|	var cs = dojo.getComputedStyle(dojo.byId("someNode"));
		//	|	var w = cs.width, h = cs.height;
		return; // CSS2Properties
	}
=====*/

	// Although we normally eschew argument validation at this
	// level, here we test argument 'node' for (duck)type,
	// by testing nodeType, ecause 'document' is the 'parentNode' of 'body'
	// it is frequently sent to this function even
	// though it is not Element.
	var gcs;
		if(d.isWebKit){
			gcs = function(/*DomNode*/node){
			var s;
			if(node.nodeType == 1){
				var dv = node.ownerDocument.defaultView;
				s = dv.getComputedStyle(node, null);
				if(!s && node.style){
					node.style.display = "";
					s = dv.getComputedStyle(node, null);
				}
			}
			return s || {};
		};
		}else if(d.isIE){
		gcs = function(node){
			// IE (as of 7) doesn't expose Element like sane browsers
			return node.nodeType == 1 /* ELEMENT_NODE*/ ? node.currentStyle : {};
		};
	}else{
		gcs = function(node){
			return node.nodeType == 1 ?
				node.ownerDocument.defaultView.getComputedStyle(node, null) : {};
		};
	}
		dojo.getComputedStyle = gcs;

		if(!d.isIE){
			d._toPixelValue = function(element, value){
			// style values can be floats, client code may want
			// to round for integer pixels.
			return parseFloat(value) || 0;
		};
		}else{
		d._toPixelValue = function(element, avalue){
			if(!avalue){ return 0; }
			// on IE7, medium is usually 4 pixels
			if(avalue == "medium"){ return 4; }
			// style values can be floats, client code may
			// want to round this value for integer pixels.
			if(avalue.slice && avalue.slice(-2) == 'px'){ return parseFloat(avalue); }
			with(element){
				var sLeft = style.left;
				var rsLeft = runtimeStyle.left;
				runtimeStyle.left = currentStyle.left;
				try{
					// 'avalue' may be incompatible with style.left, which can cause IE to throw
					// this has been observed for border widths using "thin", "medium", "thick" constants
					// those particular constants could be trapped by a lookup
					// but perhaps there are more
					style.left = avalue;
					avalue = style.pixelLeft;
				}catch(e){
					avalue = 0;
				}
				style.left = sLeft;
				runtimeStyle.left = rsLeft;
			}
			return avalue;
		};
	}
		var px = d._toPixelValue;

	// FIXME: there opacity quirks on FF that we haven't ported over. Hrm.
	/*=====
	dojo._getOpacity = function(node){
			//	summary:
			//		Returns the current opacity of the passed node as a
			//		floating-point value between 0 and 1.
			//	node: DomNode
			//		a reference to a DOM node. Does NOT support taking an
			//		ID string for speed reasons.
			//	returns: Number between 0 and 1
			return; // Number
	}
	=====*/

		var astr = "DXImageTransform.Microsoft.Alpha";
	var af = function(n, f){
		try{
			return n.filters.item(astr);
		}catch(e){
			return f ? {} : null;
		}
	};

		dojo._getOpacity =
			d.isIE < 9 ? function(node){
			try{
				return af(node).Opacity / 100; // Number
			}catch(e){
				return 1; // Number
			}
		} :
			function(node){
			return gcs(node).opacity;
		};

	/*=====
	dojo._setOpacity = function(node, opacity){
			//	summary:
			//		set the opacity of the passed node portably. Returns the
			//		new opacity of the node.
			//	node: DOMNode
			//		a reference to a DOM node. Does NOT support taking an
			//		ID string for performance reasons.
			//	opacity: Number
			//		A Number between 0 and 1. 0 specifies transparent.
			//	returns: Number between 0 and 1
			return; // Number
	}
	=====*/

	dojo._setOpacity =
				d.isIE < 9 ? function(/*DomNode*/node, /*Number*/opacity){
			var ov = opacity * 100, opaque = opacity == 1;
			node.style.zoom = opaque ? "" : 1;

			if(!af(node)){
				if(opaque){
					return opacity;
				}
				node.style.filter += " progid:" + astr + "(Opacity=" + ov + ")";
			}else{
				af(node, 1).Opacity = ov;
			}

			// on IE7 Alpha(Filter opacity=100) makes text look fuzzy so disable it altogether (bug #2661),
			//but still update the opacity value so we can get a correct reading if it is read later.
			af(node, 1).Enabled = !opaque;

			if(node.nodeName.toLowerCase() == "tr"){
				d.query("> td", node).forEach(function(i){
					d._setOpacity(i, opacity);
				});
			}
			return opacity;
		} :
				function(node, opacity){
			return node.style.opacity = opacity;
		};

	var _pixelNamesCache = {
		left: true, top: true
	};
	var _pixelRegExp = /margin|padding|width|height|max|min|offset/;  // |border
	var _toStyleValue = function(node, type, value){
		type = type.toLowerCase(); // FIXME: should we really be doing string case conversion here? Should we cache it? Need to profile!
				if(d.isIE){
			if(value == "auto"){
				if(type == "height"){ return node.offsetHeight; }
				if(type == "width"){ return node.offsetWidth; }
			}
			if(type == "fontweight"){
				switch(value){
					case 700: return "bold";
					case 400:
					default: return "normal";
				}
			}
		}
				if(!(type in _pixelNamesCache)){
			_pixelNamesCache[type] = _pixelRegExp.test(type);
		}
		return _pixelNamesCache[type] ? px(node, value) : value;
	};

	var _floatStyle = d.isIE ? "styleFloat" : "cssFloat",
		_floatAliases = { "cssFloat": _floatStyle, "styleFloat": _floatStyle, "float": _floatStyle }
	;

	// public API

	dojo.style = function(	/*DomNode|String*/ node,
							/*String?|Object?*/ style,
							/*String?*/ value){
		//	summary:
		//		Accesses styles on a node. If 2 arguments are
		//		passed, acts as a getter. If 3 arguments are passed, acts
		//		as a setter.
		//	description:
		//		Getting the style value uses the computed style for the node, so the value
		//		will be a calculated value, not just the immediate node.style value.
		//		Also when getting values, use specific style names,
		//		like "borderBottomWidth" instead of "border" since compound values like
		//		"border" are not necessarily reflected as expected.
		//		If you want to get node dimensions, use `dojo.marginBox()`,
		//		`dojo.contentBox()` or `dojo.position()`.
		//	node:
		//		id or reference to node to get/set style for
		//	style:
		//		the style property to set in DOM-accessor format
		//		("borderWidth", not "border-width") or an object with key/value
		//		pairs suitable for setting each property.
		//	value:
		//		If passed, sets value on the node for style, handling
		//		cross-browser concerns.  When setting a pixel value,
		//		be sure to include "px" in the value. For instance, top: "200px".
		//		Otherwise, in some cases, some browsers will not apply the style.
		//	example:
		//		Passing only an ID or node returns the computed style object of
		//		the node:
		//	|	dojo.style("thinger");
		//	example:
		//		Passing a node and a style property returns the current
		//		normalized, computed value for that property:
		//	|	dojo.style("thinger", "opacity"); // 1 by default
		//
		//	example:
		//		Passing a node, a style property, and a value changes the
		//		current display of the node and returns the new computed value
		//	|	dojo.style("thinger", "opacity", 0.5); // == 0.5
		//
		//	example:
		//		Passing a node, an object-style style property sets each of the values in turn and returns the computed style object of the node:
		//	|	dojo.style("thinger", {
		//	|		"opacity": 0.5,
		//	|		"border": "3px solid black",
		//	|		"height": "300px"
		//	|	});
		//
		// 	example:
		//		When the CSS style property is hyphenated, the JavaScript property is camelCased.
		//		font-size becomes fontSize, and so on.
		//	|	dojo.style("thinger",{
		//	|		fontSize:"14pt",
		//	|		letterSpacing:"1.2em"
		//	|	});
		//
		//	example:
		//		dojo.NodeList implements .style() using the same syntax, omitting the "node" parameter, calling
		//		dojo.style() on every element of the list. See: `dojo.query()` and `dojo.NodeList()`
		//	|	dojo.query(".someClassName").style("visibility","hidden");
		//	|	// or
		//	|	dojo.query("#baz > div").style({
		//	|		opacity:0.75,
		//	|		fontSize:"13pt"
		//	|	});

		var n = byId(node), args = arguments.length, op = (style == "opacity");
		style = _floatAliases[style] || style;
		if(args == 3){
			return op ? d._setOpacity(n, value) : n.style[style] = value; /*Number*/
		}
		if(args == 2 && op){
			return d._getOpacity(n);
		}
		var s = gcs(n);
		if(args == 2 && typeof style != "string"){ // inline'd type check
			for(var x in style){
				d.style(node, x, style[x]);
			}
			return s;
		}
		return (args == 1) ? s : _toStyleValue(n, style, s[style] || n.style[style]); /* CSS2Properties||String||Number */
	};

	// =============================
	// Box Functions
	// =============================

	dojo._getPadExtents = function(/*DomNode*/n, /*Object*/computedStyle){
		//	summary:
		// 		Returns object with special values specifically useful for node
		// 		fitting.
		//	description:
		//		Returns an object with `w`, `h`, `l`, `t` properties:
		//	|		l/t = left/top padding (respectively)
		//	|		w = the total of the left and right padding
		//	|		h = the total of the top and bottom padding
		//		If 'node' has position, l/t forms the origin for child nodes.
		//		The w/h are used for calculating boxes.
		//		Normally application code will not need to invoke this
		//		directly, and will use the ...box... functions instead.
		var
			s = computedStyle||gcs(n),
			l = px(n, s.paddingLeft),
			t = px(n, s.paddingTop);
		return {
			l: l,
			t: t,
			w: l+px(n, s.paddingRight),
			h: t+px(n, s.paddingBottom)
		};
	};

	dojo._getBorderExtents = function(/*DomNode*/n, /*Object*/computedStyle){
		//	summary:
		//		returns an object with properties useful for noting the border
		//		dimensions.
		//	description:
		// 		* l/t = the sum of left/top border (respectively)
		//		* w = the sum of the left and right border
		//		* h = the sum of the top and bottom border
		//
		//		The w/h are used for calculating boxes.
		//		Normally application code will not need to invoke this
		//		directly, and will use the ...box... functions instead.
		var
			ne = "none",
			s = computedStyle||gcs(n),
			bl = (s.borderLeftStyle != ne ? px(n, s.borderLeftWidth) : 0),
			bt = (s.borderTopStyle != ne ? px(n, s.borderTopWidth) : 0);
		return {
			l: bl,
			t: bt,
			w: bl + (s.borderRightStyle!=ne ? px(n, s.borderRightWidth) : 0),
			h: bt + (s.borderBottomStyle!=ne ? px(n, s.borderBottomWidth) : 0)
		};
	};

	dojo._getPadBorderExtents = function(/*DomNode*/n, /*Object*/computedStyle){
		//	summary:
		//		Returns object with properties useful for box fitting with
		//		regards to padding.
		// description:
		//		* l/t = the sum of left/top padding and left/top border (respectively)
		//		* w = the sum of the left and right padding and border
		//		* h = the sum of the top and bottom padding and border
		//
		//		The w/h are used for calculating boxes.
		//		Normally application code will not need to invoke this
		//		directly, and will use the ...box... functions instead.
		var
			s = computedStyle||gcs(n),
			p = d._getPadExtents(n, s),
			b = d._getBorderExtents(n, s);
		return {
			l: p.l + b.l,
			t: p.t + b.t,
			w: p.w + b.w,
			h: p.h + b.h
		};
	};

	dojo._getMarginExtents = function(n, computedStyle){
		//	summary:
		//		returns object with properties useful for box fitting with
		//		regards to box margins (i.e., the outer-box).
		//
		//		* l/t = marginLeft, marginTop, respectively
		//		* w = total width, margin inclusive
		//		* h = total height, margin inclusive
		//
		//		The w/h are used for calculating boxes.
		//		Normally application code will not need to invoke this
		//		directly, and will use the ...box... functions instead.
		var
			s = computedStyle||gcs(n),
			l = px(n, s.marginLeft),
			t = px(n, s.marginTop),
			r = px(n, s.marginRight),
			b = px(n, s.marginBottom);
		if(d.isWebKit && (s.position != "absolute")){
			// FIXME: Safari's version of the computed right margin
			// is the space between our right edge and the right edge
			// of our offsetParent.
			// What we are looking for is the actual margin value as
			// determined by CSS.
			// Hack solution is to assume left/right margins are the same.
			r = l;
		}
		return {
			l: l,
			t: t,
			w: l+r,
			h: t+b
		};
	};

	// Box getters work in any box context because offsetWidth/clientWidth
	// are invariant wrt box context
	//
	// They do *not* work for display: inline objects that have padding styles
	// because the user agent ignores padding (it's bogus styling in any case)
	//
	// Be careful with IMGs because they are inline or block depending on
	// browser and browser mode.

	// Although it would be easier to read, there are not separate versions of
	// _getMarginBox for each browser because:
	// 1. the branching is not expensive
	// 2. factoring the shared code wastes cycles (function call overhead)
	// 3. duplicating the shared code wastes bytes

	dojo._getMarginBox = function(/*DomNode*/node, /*Object*/computedStyle){
		// summary:
		//		returns an object that encodes the width, height, left and top
		//		positions of the node's margin box.
		var s = computedStyle || gcs(node), me = d._getMarginExtents(node, s);
		var l = node.offsetLeft - me.l, t = node.offsetTop - me.t, p = node.parentNode;
				if(d.isMoz){
			// Mozilla:
			// If offsetParent has a computed overflow != visible, the offsetLeft is decreased
			// by the parent's border.
			// We don't want to compute the parent's style, so instead we examine node's
			// computed left/top which is more stable.
			var sl = parseFloat(s.left), st = parseFloat(s.top);
			if(!isNaN(sl) && !isNaN(st)){
				l = sl, t = st;
			}else{
				// If child's computed left/top are not parseable as a number (e.g. "auto"), we
				// have no choice but to examine the parent's computed style.
				if(p && p.style){
					var pcs = gcs(p);
					if(pcs.overflow != "visible"){
						var be = d._getBorderExtents(p, pcs);
						l += be.l, t += be.t;
					}
				}
			}
		}else if(d.isOpera || (d.isIE > 7 && !d.isQuirks)){
			// On Opera and IE 8, offsetLeft/Top includes the parent's border
			if(p){
				be = d._getBorderExtents(p);
				l -= be.l;
				t -= be.t;
			}
		}
				return {
			l: l,
			t: t,
			w: node.offsetWidth + me.w,
			h: node.offsetHeight + me.h
		};
	}
	
	dojo._getMarginSize = function(/*DomNode*/node, /*Object*/computedStyle){
		// summary:
		//	returns an object that encodes the width and height of
		//	the node's margin box
		node = byId(node);
		var me = d._getMarginExtents(node, computedStyle || gcs(node));

		var size = node.getBoundingClientRect();
		return {
			w: (size.right - size.left) + me.w,
			h: (size.bottom - size.top) + me.h
		}
	}

	dojo._getContentBox = function(node, computedStyle){
		// summary:
		//		Returns an object that encodes the width, height, left and top
		//		positions of the node's content box, irrespective of the
		//		current box model.

		// clientWidth/Height are important since the automatically account for scrollbars
		// fallback to offsetWidth/Height for special cases (see #3378)
		var s = computedStyle || gcs(node),
			pe = d._getPadExtents(node, s),
			be = d._getBorderExtents(node, s),
			w = node.clientWidth,
			h
		;
		if(!w){
			w = node.offsetWidth, h = node.offsetHeight;
		}else{
			h = node.clientHeight, be.w = be.h = 0;
		}
		// On Opera, offsetLeft includes the parent's border
				if(d.isOpera){ pe.l += be.l; pe.t += be.t; };
				return {
			l: pe.l,
			t: pe.t,
			w: w - pe.w - be.w,
			h: h - pe.h - be.h
		};
	};

	dojo._getBorderBox = function(node, computedStyle){
		var s = computedStyle || gcs(node),
			pe = d._getPadExtents(node, s),
			cb = d._getContentBox(node, s)
		;
		return {
			l: cb.l - pe.l,
			t: cb.t - pe.t,
			w: cb.w + pe.w,
			h: cb.h + pe.h
		};
	};

	// Box setters depend on box context because interpretation of width/height styles
	// vary wrt box context.
	//
	// The value of dojo.boxModel is used to determine box context.
	// dojo.boxModel can be set directly to change behavior.
	//
	// Beware of display: inline objects that have padding styles
	// because the user agent ignores padding (it's a bogus setup anyway)
	//
	// Be careful with IMGs because they are inline or block depending on
	// browser and browser mode.
	//
	// Elements other than DIV may have special quirks, like built-in
	// margins or padding, or values not detectable via computedStyle.
	// In particular, margins on TABLE do not seems to appear
	// at all in computedStyle on Mozilla.

	dojo._setBox = function(/*DomNode*/node, /*Number?*/l, /*Number?*/t, /*Number?*/w, /*Number?*/h, /*String?*/u){
		//	summary:
		//		sets width/height/left/top in the current (native) box-model
		//		dimentions. Uses the unit passed in u.
		//	node:
		//		DOM Node reference. Id string not supported for performance
		//		reasons.
		//	l:
		//		left offset from parent.
		//	t:
		//		top offset from parent.
		//	w:
		//		width in current box model.
		//	h:
		//		width in current box model.
		//	u:
		//		unit measure to use for other measures. Defaults to "px".
		u = u || "px";
		var s = node.style;
		if(!isNaN(l)){ s.left = l + u; }
		if(!isNaN(t)){ s.top = t + u; }
		if(w >= 0){ s.width = w + u; }
		if(h >= 0){ s.height = h + u; }
	};

	dojo._isButtonTag = function(/*DomNode*/node) {
		// summary:
		//		True if the node is BUTTON or INPUT.type="button".
		return node.tagName == "BUTTON"
			|| node.tagName=="INPUT" && (node.getAttribute("type")||'').toUpperCase() == "BUTTON"; // boolean
	};

	dojo._usesBorderBox = function(/*DomNode*/node){
		//	summary:
		//		True if the node uses border-box layout.

		// We could test the computed style of node to see if a particular box
		// has been specified, but there are details and we choose not to bother.

		// TABLE and BUTTON (and INPUT type=button) are always border-box by default.
		// If you have assigned a different box to either one via CSS then
		// box functions will break.

		var n = node.tagName;
		return d.boxModel=="border-box" || n=="TABLE" || d._isButtonTag(node); // boolean
	};

	dojo._setContentSize = function(/*DomNode*/node, /*Number*/widthPx, /*Number*/heightPx, /*Object*/computedStyle){
		//	summary:
		//		Sets the size of the node's contents, irrespective of margins,
		//		padding, or borders.
		if(d._usesBorderBox(node)){
			var pb = d._getPadBorderExtents(node, computedStyle);
			if(widthPx >= 0){ widthPx += pb.w; }
			if(heightPx >= 0){ heightPx += pb.h; }
		}
		d._setBox(node, NaN, NaN, widthPx, heightPx);
	};

	dojo._setMarginBox = function(/*DomNode*/node, 	/*Number?*/leftPx, /*Number?*/topPx,
													/*Number?*/widthPx, /*Number?*/heightPx,
													/*Object*/computedStyle){
		//	summary:
		//		sets the size of the node's margin box and placement
		//		(left/top), irrespective of box model. Think of it as a
		//		passthrough to dojo._setBox that handles box-model vagaries for
		//		you.

		var s = computedStyle || gcs(node),
		// Some elements have special padding, margin, and box-model settings.
		// To use box functions you may need to set padding, margin explicitly.
		// Controlling box-model is harder, in a pinch you might set dojo.boxModel.
			bb = d._usesBorderBox(node),
			pb = bb ? _nilExtents : d._getPadBorderExtents(node, s)
		;
		if(d.isWebKit){
			// on Safari (3.1.2), button nodes with no explicit size have a default margin
			// setting an explicit size eliminates the margin.
			// We have to swizzle the width to get correct margin reading.
			if(d._isButtonTag(node)){
				var ns = node.style;
				if(widthPx >= 0 && !ns.width) { ns.width = "4px"; }
				if(heightPx >= 0 && !ns.height) { ns.height = "4px"; }
			}
		}
		var mb = d._getMarginExtents(node, s);
		if(widthPx >= 0){ widthPx = Math.max(widthPx - pb.w - mb.w, 0); }
		if(heightPx >= 0){ heightPx = Math.max(heightPx - pb.h - mb.h, 0); }
		d._setBox(node, leftPx, topPx, widthPx, heightPx);
	};

	var _nilExtents = { l:0, t:0, w:0, h:0 };

	// public API

	dojo.marginBox = function(/*DomNode|String*/node, /*Object?*/box){
		//	summary:
		//		Getter/setter for the margin-box of node.
		//	description:
		//		Getter/setter for the margin-box of node.
		//		Returns an object in the expected format of box (regardless
		//		if box is passed). The object might look like:
		//			`{ l: 50, t: 200, w: 300: h: 150 }`
		//		for a node offset from its parent 50px to the left, 200px from
		//		the top with a margin width of 300px and a margin-height of
		//		150px.
		//	node:
		//		id or reference to DOM Node to get/set box for
		//	box:
		//		If passed, denotes that dojo.marginBox() should
		//		update/set the margin box for node. Box is an object in the
		//		above format. All properties are optional if passed.
		//	example:
		//	Retrieve the marginbox of a passed node
		//	|	var box = dojo.marginBox("someNodeId");
		//	|	console.dir(box);
		//
		//	example:
		//	Set a node's marginbox to the size of another node
		//	|	var box = dojo.marginBox("someNodeId");
		//	|	dojo.marginBox("someOtherNode", box);
		
		var n = byId(node), s = gcs(n), b = box;
		return !b ? d._getMarginBox(n, s) : d._setMarginBox(n, b.l, b.t, b.w, b.h, s); // Object
	};

	dojo.contentBox = function(/*DomNode|String*/node, /*Object?*/box){
		//	summary:
		//		Getter/setter for the content-box of node.
		//	description:
		//		Returns an object in the expected format of box (regardless if box is passed).
		//		The object might look like:
		//			`{ l: 50, t: 200, w: 300: h: 150 }`
		//		for a node offset from its parent 50px to the left, 200px from
		//		the top with a content width of 300px and a content-height of
		//		150px. Note that the content box may have a much larger border
		//		or margin box, depending on the box model currently in use and
		//		CSS values set/inherited for node.
		//		While the getter will return top and left values, the
		//		setter only accepts setting the width and height.
		//	node:
		//		id or reference to DOM Node to get/set box for
		//	box:
		//		If passed, denotes that dojo.contentBox() should
		//		update/set the content box for node. Box is an object in the
		//		above format, but only w (width) and h (height) are supported.
		//		All properties are optional if passed.
		var n = byId(node), s = gcs(n), b = box;
		return !b ? d._getContentBox(n, s) : d._setContentSize(n, b.w, b.h, s); // Object
	};

	// =============================
	// Positioning
	// =============================

	var _sumAncestorProperties = function(node, prop){
		if(!(node = (node||0).parentNode)){return 0;}
		var val, retVal = 0, _b = d.body();
		while(node && node.style){
			if(gcs(node).position == "fixed"){
				return 0;
			}
			val = node[prop];
			if(val){
				retVal += val - 0;
				// opera and khtml #body & #html has the same values, we only
				// need one value
				if(node == _b){ break; }
			}
			node = node.parentNode;
		}
		return retVal;	//	integer
	};

	dojo._docScroll = function(){
		var n = d.global;
		return "pageXOffset" in n
			? { x:n.pageXOffset, y:n.pageYOffset }
			: (n = d.isQuirks? d.doc.body : d.doc.documentElement, { x:d._fixIeBiDiScrollLeft(n.scrollLeft || 0), y:n.scrollTop || 0 });
	};

	dojo._isBodyLtr = function(){
		return "_bodyLtr" in d? d._bodyLtr :
			d._bodyLtr = (d.body().dir || d.doc.documentElement.dir || "ltr").toLowerCase() == "ltr"; // Boolean
	};

		dojo._getIeDocumentElementOffset = function(){
		//	summary:
		//		returns the offset in x and y from the document body to the
		//		visual edge of the page
		//	description:
		// The following values in IE contain an offset:
		//	|		event.clientX
		//	|		event.clientY
		//	|		node.getBoundingClientRect().left
		//	|		node.getBoundingClientRect().top
		//	 	But other position related values do not contain this offset,
		//	 	such as node.offsetLeft, node.offsetTop, node.style.left and
		//	 	node.style.top. The offset is always (2, 2) in LTR direction.
		//	 	When the body is in RTL direction, the offset counts the width
		//	 	of left scroll bar's width.  This function computes the actual
		//	 	offset.

		//NOTE: assumes we're being called in an IE browser

		var de = d.doc.documentElement; // only deal with HTML element here, _abs handles body/quirks

		if(d.isIE < 8){
			var r = de.getBoundingClientRect(); // works well for IE6+
			//console.debug('rect left,top = ' + r.left+','+r.top + ', html client left/top = ' + de.clientLeft+','+de.clientTop + ', rtl = ' + (!d._isBodyLtr()) + ', quirks = ' + d.isQuirks);
			var l = r.left,
			    t = r.top;
			if(d.isIE < 7){
				l += de.clientLeft;	// scrollbar size in strict/RTL, or,
				t += de.clientTop;	// HTML border size in strict
			}
			return {
				x: l < 0? 0 : l, // FRAME element border size can lead to inaccurate negative values
				y: t < 0? 0 : t
			};
		}else{
			return {
				x: 0,
				y: 0
			};
		}

	};
	
	dojo._fixIeBiDiScrollLeft = function(/*Integer*/ scrollLeft){
		// In RTL direction, scrollLeft should be a negative value, but IE
		// returns a positive one. All codes using documentElement.scrollLeft
		// must call this function to fix this error, otherwise the position
		// will offset to right when there is a horizontal scrollbar.

				var ie = d.isIE;
		if(ie && !d._isBodyLtr()){
			var qk = d.isQuirks,
				de = qk ? d.doc.body : d.doc.documentElement;
			if(ie == 6 && !qk && d.global.frameElement && de.scrollHeight > de.clientHeight){
				scrollLeft += de.clientLeft; // workaround ie6+strict+rtl+iframe+vertical-scrollbar bug where clientWidth is too small by clientLeft pixels
			}
			return (ie < 8 || qk) ? (scrollLeft + de.clientWidth - de.scrollWidth) : -scrollLeft; // Integer
		}
				return scrollLeft; // Integer
	};

	// FIXME: need a setter for coords or a moveTo!!
	dojo._abs = dojo.position = function(/*DomNode*/node, /*Boolean?*/includeScroll){
		//	summary:
		//		Gets the position and size of the passed element relative to
		//		the viewport (if includeScroll==false), or relative to the
		//		document root (if includeScroll==true).
		//
		//	description:
		//		Returns an object of the form:
		//			{ x: 100, y: 300, w: 20, h: 15 }
		//		If includeScroll==true, the x and y values will include any
		//		document offsets that may affect the position relative to the
		//		viewport.
		//		Uses the border-box model (inclusive of border and padding but
		//		not margin).  Does not act as a setter.

		node = byId(node);
		var	db = d.body(),
			dh = db.parentNode,
			ret = node.getBoundingClientRect();
			ret = { x: ret.left, y: ret.top, w: ret.right - ret.left, h: ret.bottom - ret.top };
					if(d.isIE){
				// On IE there's a 2px offset that we need to adjust for, see _getIeDocumentElementOffset()
				var offset = d._getIeDocumentElementOffset();

				// fixes the position in IE, quirks mode
				ret.x -= offset.x + (d.isQuirks ? db.clientLeft+db.offsetLeft : 0);
				ret.y -= offset.y + (d.isQuirks ? db.clientTop+db.offsetTop : 0);
			}else if(d.isFF == 3){
				// In FF3 you have to subtract the document element margins.
				// Fixed in FF3.5 though.
				var cs = gcs(dh);
				ret.x -= px(dh, cs.marginLeft) + px(dh, cs.borderLeftWidth);
				ret.y -= px(dh, cs.marginTop) + px(dh, cs.borderTopWidth);
			}
				// account for document scrolling
		if(includeScroll){
			var scroll = d._docScroll();
			ret.x += scroll.x;
			ret.y += scroll.y;
		}

		return ret; // Object
	};

	dojo.coords = function(/*DomNode|String*/node, /*Boolean?*/includeScroll){
		//	summary:
		//		Deprecated: Use position() for border-box x/y/w/h
		//		or marginBox() for margin-box w/h/l/t.
		//		Returns an object representing a node's size and position.
		//
		//	description:
		//		Returns an object that measures margin-box (w)idth/(h)eight
		//		and absolute position x/y of the border-box. Also returned
		//		is computed (l)eft and (t)op values in pixels from the
		//		node's offsetParent as returned from marginBox().
		//		Return value will be in the form:
		//|			{ l: 50, t: 200, w: 300: h: 150, x: 100, y: 300 }
		//		Does not act as a setter. If includeScroll is passed, the x and
		//		y params are affected as one would expect in dojo.position().
		var n = byId(node), s = gcs(n), mb = d._getMarginBox(n, s);
		var abs = d.position(n, includeScroll);
		mb.x = abs.x;
		mb.y = abs.y;
		return mb;
	};

	// =============================
	// Element attribute Functions
	// =============================

	// dojo.attr() should conform to http://www.w3.org/TR/DOM-Level-2-Core/

	var _propNames = {
			// properties renamed to avoid clashes with reserved words
			"class":   "className",
			"for":     "htmlFor",
			// properties written as camelCase
			tabindex:  "tabIndex",
			readonly:  "readOnly",
			colspan:   "colSpan",
			frameborder: "frameBorder",
			rowspan:   "rowSpan",
			valuetype: "valueType"
		},
		_attrNames = {
			// original attribute names
			classname: "class",
			htmlfor:   "for",
			// for IE
			tabindex:  "tabIndex",
			readonly:  "readOnly"
		},
		_forcePropNames = {
			innerHTML: 1,
			className: 1,
			htmlFor:   d.isIE,
			value:     1
		};

	var _fixAttrName = function(/*String*/ name){
		return _attrNames[name.toLowerCase()] || name;
	};

	var _hasAttr = function(node, name){
		var attr = node.getAttributeNode && node.getAttributeNode(name);
		return attr && attr.specified; // Boolean
	};

	// There is a difference in the presence of certain properties and their default values
	// between browsers. For example, on IE "disabled" is present on all elements,
	// but it is value is "false"; "tabIndex" of <div> returns 0 by default on IE, yet other browsers
	// can return -1.

	dojo.hasAttr = function(/*DomNode|String*/node, /*String*/name){
		//	summary:
		//		Returns true if the requested attribute is specified on the
		//		given element, and false otherwise.
		//	node:
		//		id or reference to the element to check
		//	name:
		//		the name of the attribute
		//	returns:
		//		true if the requested attribute is specified on the
		//		given element, and false otherwise
		var lc = name.toLowerCase();
		return _forcePropNames[_propNames[lc] || name] || _hasAttr(byId(node), _attrNames[lc] || name);	// Boolean
	};

	var _evtHdlrMap = {}, _ctr = 0,
		_attrId = dojo._scopeName + "attrid",
		// the next dictionary lists elements with read-only innerHTML on IE
		_roInnerHtml = {col: 1, colgroup: 1,
			// frameset: 1, head: 1, html: 1, style: 1,
			table: 1, tbody: 1, tfoot: 1, thead: 1, tr: 1, title: 1};

	dojo.attr = function(/*DomNode|String*/node, /*String|Object*/name, /*String?*/value){
		//	summary:
		//		Gets or sets an attribute on an HTML element.
		//	description:
		//		Handles normalized getting and setting of attributes on DOM
		//		Nodes. If 2 arguments are passed, and a the second argumnt is a
		//		string, acts as a getter.
		//
		//		If a third argument is passed, or if the second argument is a
		//		map of attributes, acts as a setter.
		//
		//		When passing functions as values, note that they will not be
		//		directly assigned to slots on the node, but rather the default
		//		behavior will be removed and the new behavior will be added
		//		using `dojo.connect()`, meaning that event handler properties
		//		will be normalized and that some caveats with regards to
		//		non-standard behaviors for onsubmit apply. Namely that you
		//		should cancel form submission using `dojo.stopEvent()` on the
		//		passed event object instead of returning a boolean value from
		//		the handler itself.
		//	node:
		//		id or reference to the element to get or set the attribute on
		//	name:
		//		the name of the attribute to get or set.
		//	value:
		//		The value to set for the attribute
		//	returns:
		//		when used as a getter, the value of the requested attribute
		//		or null if that attribute does not have a specified or
		//		default value;
		//
		//		when used as a setter, the DOM node
		//
		//	example:
		//	|	// get the current value of the "foo" attribute on a node
		//	|	dojo.attr(dojo.byId("nodeId"), "foo");
		//	|	// or we can just pass the id:
		//	|	dojo.attr("nodeId", "foo");
		//
		//	example:
		//	|	// use attr() to set the tab index
		//	|	dojo.attr("nodeId", "tabIndex", 3);
		//	|
		//
		//	example:
		//	Set multiple values at once, including event handlers:
		//	|	dojo.attr("formId", {
		//	|		"foo": "bar",
		//	|		"tabIndex": -1,
		//	|		"method": "POST",
		//	|		"onsubmit": function(e){
		//	|			// stop submitting the form. Note that the IE behavior
		//	|			// of returning true or false will have no effect here
		//	|			// since our handler is connect()ed to the built-in
		//	|			// onsubmit behavior and so we need to use
		//	|			// dojo.stopEvent() to ensure that the submission
		//	|			// doesn't proceed.
		//	|			dojo.stopEvent(e);
		//	|
		//	|			// submit the form with Ajax
		//	|			dojo.xhrPost({ form: "formId" });
		//	|		}
		//	|	});
		//
		//	example:
		//	Style is s special case: Only set with an object hash of styles
		//	|	dojo.attr("someNode",{
		//	|		id:"bar",
		//	|		style:{
		//	|			width:"200px", height:"100px", color:"#000"
		//	|		}
		//	|	});
		//
		//	example:
		//	Again, only set style as an object hash of styles:
		//	|	var obj = { color:"#fff", backgroundColor:"#000" };
		//	|	dojo.attr("someNode", "style", obj);
		//	|
		//	|	// though shorter to use `dojo.style()` in this case:
		//	|	dojo.style("someNode", obj);

		node = byId(node);
		var args = arguments.length, prop;
		if(args == 2 && typeof name != "string"){ // inline'd type check
			// the object form of setter: the 2nd argument is a dictionary
			for(var x in name){
				d.attr(node, x, name[x]);
			}
			return node; // DomNode
		}
		var lc = name.toLowerCase(),
			propName = _propNames[lc] || name,
			forceProp = _forcePropNames[propName],
			attrName = _attrNames[lc] || name;
		if(args == 3){
			// setter
			do{
				if(propName == "style" && typeof value != "string"){ // inline'd type check
					// special case: setting a style
					d.style(node, value);
					break;
				}
				if(propName == "innerHTML"){
					// special case: assigning HTML
										if(d.isIE && node.tagName.toLowerCase() in _roInnerHtml){
						d.empty(node);
						node.appendChild(d._toDom(value, node.ownerDocument));
					}else{
											node[propName] = value;
										}
										break;
				}
				if(d.isFunction(value)){
					// special case: assigning an event handler
					// clobber if we can
					var attrId = d.attr(node, _attrId);
					if(!attrId){
						attrId = _ctr++;
						d.attr(node, _attrId, attrId);
					}
					if(!_evtHdlrMap[attrId]){
						_evtHdlrMap[attrId] = {};
					}
					var h = _evtHdlrMap[attrId][propName];
					if(h){
						d.disconnect(h);
					}else{
						try{
							delete node[propName];
						}catch(e){}
					}
					// ensure that event objects are normalized, etc.
					_evtHdlrMap[attrId][propName] = d.connect(node, propName, value);
					break;
				}
				if(forceProp || typeof value == "boolean"){
					// special case: forcing assignment to the property
					// special case: setting boolean to a property instead of attribute
					node[propName] = value;
					break;
				}
				// node's attribute
				node.setAttribute(attrName, value);
			}while(false);
			return node; // DomNode
		}
		// getter
		// should we access this attribute via a property or
		// via getAttribute()?
		value = node[propName];
		if(forceProp && typeof value != "undefined"){
			// node's property
			return value;	// Anything
		}
		if(propName != "href" && (typeof value == "boolean" || d.isFunction(value))){
			// node's property
			return value;	// Anything
		}
		// node's attribute
		// we need _hasAttr() here to guard against IE returning a default value
		return _hasAttr(node, attrName) ? node.getAttribute(attrName) : null; // Anything
	};

	dojo.removeAttr = function(/*DomNode|String*/ node, /*String*/ name){
		//	summary:
		//		Removes an attribute from an HTML element.
		//	node:
		//		id or reference to the element to remove the attribute from
		//	name:
		//		the name of the attribute to remove
		byId(node).removeAttribute(_fixAttrName(name));
	};

	dojo.getNodeProp = function(/*DomNode|String*/ node, /*String*/ name){
		//	summary:
		//		Returns an effective value of a property or an attribute.
		//	node:
		//		id or reference to the element to remove the attribute from
		//	name:
		//		the name of the attribute
		node = byId(node);
		var lc = name.toLowerCase(),
			propName = _propNames[lc] || name;
		if((propName in node) && propName != "href"){
			// node's property
			return node[propName];	// Anything
		}
		// node's attribute
		var attrName = _attrNames[lc] || name;
		return _hasAttr(node, attrName) ? node.getAttribute(attrName) : null; // Anything
	};

	dojo.create = function(tag, attrs, refNode, pos){
		//	summary:
		//		Create an element, allowing for optional attribute decoration
		//		and placement.
		//
		// description:
		//		A DOM Element creation function. A shorthand method for creating a node or
		//		a fragment, and allowing for a convenient optional attribute setting step,
		//		as well as an optional DOM placement reference.
		//|
		//		Attributes are set by passing the optional object through `dojo.attr`.
		//		See `dojo.attr` for noted caveats and nuances, and API if applicable.
		//|
		//		Placement is done via `dojo.place`, assuming the new node to be the action
		//		node, passing along the optional reference node and position.
		//
		// tag: String|DomNode
		//		A string of the element to create (eg: "div", "a", "p", "li", "script", "br"),
		//		or an existing DOM node to process.
		//
		// attrs: Object
		//		An object-hash of attributes to set on the newly created node.
		//		Can be null, if you don't want to set any attributes/styles.
		//		See: `dojo.attr` for a description of available attributes.
		//
		// refNode: String?|DomNode?
		//		Optional reference node. Used by `dojo.place` to place the newly created
		//		node somewhere in the dom relative to refNode. Can be a DomNode reference
		//		or String ID of a node.
		//
		// pos: String?
		//		Optional positional reference. Defaults to "last" by way of `dojo.place`,
		//		though can be set to "first","after","before","last", "replace" or "only"
		//		to further control the placement of the new node relative to the refNode.
		//		'refNode' is required if a 'pos' is specified.
		//
		// returns: DomNode
		//
		// example:
		//	Create a DIV:
		//	|	var n = dojo.create("div");
		//
		// example:
		//	Create a DIV with content:
		//	|	var n = dojo.create("div", { innerHTML:"<p>hi</p>" });
		//
		// example:
		//	Place a new DIV in the BODY, with no attributes set
		//	|	var n = dojo.create("div", null, dojo.body());
		//
		// example:
		//	Create an UL, and populate it with LI's. Place the list as the first-child of a
		//	node with id="someId":
		//	|	var ul = dojo.create("ul", null, "someId", "first");
		//	|	var items = ["one", "two", "three", "four"];
		//	|	dojo.forEach(items, function(data){
		//	|		dojo.create("li", { innerHTML: data }, ul);
		//	|	});
		//
		// example:
		//	Create an anchor, with an href. Place in BODY:
		//	|	dojo.create("a", { href:"foo.html", title:"Goto FOO!" }, dojo.body());
		//
		// example:
		//	Create a `dojo.NodeList()` from a new element (for syntatic sugar):
		//	|	dojo.query(dojo.create('div'))
		//	|		.addClass("newDiv")
		//	|		.onclick(function(e){ console.log('clicked', e.target) })
		//	|		.place("#someNode"); // redundant, but cleaner.

		var doc = d.doc;
		if(refNode){
			refNode = byId(refNode);
			doc = refNode.ownerDocument;
		}
		if(typeof tag == "string"){ // inline'd type check
			tag = doc.createElement(tag);
		}
		if(attrs){ d.attr(tag, attrs); }
		if(refNode){ d.place(tag, refNode, pos); }
		return tag; // DomNode
	};

	/*=====
	dojo.empty = function(node){
			//	summary:
			//		safely removes all children of the node.
			//	node: DOMNode|String
			//		a reference to a DOM node or an id.
			//	example:
			//	Destroy node's children byId:
			//	|	dojo.empty("someId");
			//
			//	example:
			//	Destroy all nodes' children in a list by reference:
			//	|	dojo.query(".someNode").forEach(dojo.empty);
	}
	=====*/

	d.empty =
				d.isIE ?  function(node){
			node = byId(node);
			for(var c; c = node.lastChild;){ // intentional assignment
				d.destroy(c);
			}
		} :
				function(node){
			byId(node).innerHTML = "";
		};

	/*=====
	dojo._toDom = function(frag, doc){
			//	summary:
			//		instantiates an HTML fragment returning the corresponding DOM.
			//	frag: String
			//		the HTML fragment
			//	doc: DocumentNode?
			//		optional document to use when creating DOM nodes, defaults to
			//		dojo.doc if not specified.
			//	returns: DocumentFragment
			//
			//	example:
			//	Create a table row:
			//	|	var tr = dojo._toDom("<tr><td>First!</td></tr>");
	}
	=====*/

	// support stuff for dojo._toDom
	var tagWrap = {
			option: ["select"],
			tbody: ["table"],
			thead: ["table"],
			tfoot: ["table"],
			tr: ["table", "tbody"],
			td: ["table", "tbody", "tr"],
			th: ["table", "thead", "tr"],
			legend: ["fieldset"],
			caption: ["table"],
			colgroup: ["table"],
			col: ["table", "colgroup"],
			li: ["ul"]
		},
		reTag = /<\s*([\w\:]+)/,
		masterNode = {}, masterNum = 0,
		masterName = "__" + d._scopeName + "ToDomId";

	// generate start/end tag strings to use
	// for the injection for each special tag wrap case.
	for(var param in tagWrap){
		if(tagWrap.hasOwnProperty(param)){
			var tw = tagWrap[param];
			tw.pre  = param == "option" ? '<select multiple="multiple">' : "<" + tw.join("><") + ">";
			tw.post = "</" + tw.reverse().join("></") + ">";
			// the last line is destructive: it reverses the array,
			// but we don't care at this point
		}
	}

	d._toDom = function(frag, doc){
		//	summary:
		// 		converts HTML string into DOM nodes.

		doc = doc || d.doc;
		var masterId = doc[masterName];
		if(!masterId){
			doc[masterName] = masterId = ++masterNum + "";
			masterNode[masterId] = doc.createElement("div");
		}

		// make sure the frag is a string.
		frag += "";

		// find the starting tag, and get node wrapper
		var match = frag.match(reTag),
			tag = match ? match[1].toLowerCase() : "",
			master = masterNode[masterId],
			wrap, i, fc, df;
		if(match && tagWrap[tag]){
			wrap = tagWrap[tag];
			master.innerHTML = wrap.pre + frag + wrap.post;
			for(i = wrap.length; i; --i){
				master = master.firstChild;
			}
		}else{
			master.innerHTML = frag;
		}

		// one node shortcut => return the node itself
		if(master.childNodes.length == 1){
			return master.removeChild(master.firstChild); // DOMNode
		}

		// return multiple nodes as a document fragment
		df = doc.createDocumentFragment();
		while(fc = master.firstChild){ // intentional assignment
			df.appendChild(fc);
		}
		return df; // DOMNode
	};

	// =============================
	// (CSS) Class Functions
	// =============================
	var _className = "className";

	dojo.hasClass = function(/*DomNode|String*/node, /*String*/classStr){
		//	summary:
		//		Returns whether or not the specified classes are a portion of the
		//		class list currently applied to the node.
		//
		//	node:
		//		String ID or DomNode reference to check the class for.
		//
		//	classStr:
		//		A string class name to look for.
		//
		//	example:
		//	Do something if a node with id="someNode" has class="aSillyClassName" present
		//	|	if(dojo.hasClass("someNode","aSillyClassName")){ ... }

		return ((" "+ byId(node)[_className] +" ").indexOf(" " + classStr + " ") >= 0);  // Boolean
	};

	var spaces = /\s+/, a1 = [""],
		fakeNode = {},
		str2array = function(s){
			if(typeof s == "string" || s instanceof String){
				if(s.indexOf(" ") < 0){
					a1[0] = s;
					return a1;
				}else{
					return s.split(spaces);
				}
			}
			// assumed to be an array
			return s || "";
		};

	dojo.addClass = function(/*DomNode|String*/node, /*String|Array*/classStr){
		//	summary:
		//		Adds the specified classes to the end of the class list on the
		//		passed node. Will not re-apply duplicate classes.
		//
		//	node:
		//		String ID or DomNode reference to add a class string too
		//
		//	classStr:
		//		A String class name to add, or several space-separated class names,
		//		or an array of class names.
		//
		// example:
		//	Add a class to some node:
		//	|	dojo.addClass("someNode", "anewClass");
		//
		// example:
		//	Add two classes at once:
		//	|	dojo.addClass("someNode", "firstClass secondClass");
		//
		// example:
		//	Add two classes at once (using array):
		//	|	dojo.addClass("someNode", ["firstClass", "secondClass"]);
		//
		// example:
		//	Available in `dojo.NodeList` for multiple additions
		//	|	dojo.query("ul > li").addClass("firstLevel");

		node = byId(node);
		classStr = str2array(classStr);
		var cls = node[_className], oldLen;
		cls = cls ? " " + cls + " " : " ";
		oldLen = cls.length;
		for(var i = 0, len = classStr.length, c; i < len; ++i){
			c = classStr[i];
			if(c && cls.indexOf(" " + c + " ") < 0){
				cls += c + " ";
			}
		}
		if(oldLen < cls.length){
			node[_className] = cls.substr(1, cls.length - 2);
		}
	};

	dojo.removeClass = function(/*DomNode|String*/node, /*String|Array?*/classStr){
		// summary:
		//		Removes the specified classes from node. No `dojo.hasClass`
		//		check is required.
		//
		// node:
		// 		String ID or DomNode reference to remove the class from.
		//
		// classStr:
		//		An optional String class name to remove, or several space-separated
		//		class names, or an array of class names. If omitted, all class names
		//		will be deleted.
		//
		// example:
		//	Remove a class from some node:
		//	|	dojo.removeClass("someNode", "firstClass");
		//
		// example:
		//	Remove two classes from some node:
		//	|	dojo.removeClass("someNode", "firstClass secondClass");
		//
		// example:
		//	Remove two classes from some node (using array):
		//	|	dojo.removeClass("someNode", ["firstClass", "secondClass"]);
		//
		// example:
		//	Remove all classes from some node:
		//	|	dojo.removeClass("someNode");
		//
		// example:
		//	Available in `dojo.NodeList()` for multiple removal
		//	|	dojo.query(".foo").removeClass("foo");

		node = byId(node);
		var cls;
		if(classStr !== undefined){
			classStr = str2array(classStr);
			cls = " " + node[_className] + " ";
			for(var i = 0, len = classStr.length; i < len; ++i){
				cls = cls.replace(" " + classStr[i] + " ", " ");
			}
			cls = d.trim(cls);
		}else{
			cls = "";
		}
		if(node[_className] != cls){ node[_className] = cls; }
	};

	dojo.replaceClass = function(/*DomNode|String*/node, /*String|Array*/addClassStr, /*String|Array?*/removeClassStr){
		// summary:
		//		Replaces one or more classes on a node if not present.
		//		Operates more quickly than calling dojo.removeClass and dojo.addClass
		// node:
		// 		String ID or DomNode reference to remove the class from.
		// addClassStr:
		//		A String class name to add, or several space-separated class names,
		//		or an array of class names.
		// removeClassStr:
		//		A String class name to remove, or several space-separated class names,
		//		or an array of class names.
		//
		// example:
		//	|	dojo.replaceClass("someNode", "add1 add2", "remove1 remove2");
		//
		// example:
		//	Replace all classes with addMe
		//	|	dojo.replaceClass("someNode", "addMe");
		//
		// example:
		//	Available in `dojo.NodeList()` for multiple toggles
		//	|	dojo.query(".findMe").replaceClass("addMe", "removeMe");

        node = byId(node);
		fakeNode.className = node.className;
		dojo.removeClass(fakeNode, removeClassStr);
		dojo.addClass(fakeNode, addClassStr);
		if(node.className !== fakeNode.className){
			node.className = fakeNode.className;
		}
	};

	dojo.toggleClass = function(/*DomNode|String*/node, /*String|Array*/classStr, /*Boolean?*/condition){
		//	summary:
		//		Adds a class to node if not present, or removes if present.
		//		Pass a boolean condition if you want to explicitly add or remove.
		//	condition:
		//		If passed, true means to add the class, false means to remove.
		//
		// example:
		//	|	dojo.toggleClass("someNode", "hovered");
		//
		// example:
		//	Forcefully add a class
		//	|	dojo.toggleClass("someNode", "hovered", true);
		//
		// example:
		//	Available in `dojo.NodeList()` for multiple toggles
		//	|	dojo.query(".toggleMe").toggleClass("toggleMe");

		if(condition === undefined){
			condition = !d.hasClass(node, classStr);
		}
		d[condition ? "addClass" : "removeClass"](node, classStr);
	};

})();

}

if(!dojo._hasResource["dojo._base.NodeList"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.NodeList"] = true;
dojo.provide("dojo._base.NodeList");






(function(){

	var d = dojo;

	var ap = Array.prototype, aps = ap.slice, apc = ap.concat;

	var tnl = function(/*Array*/ a, /*dojo.NodeList?*/ parent, /*Function?*/ NodeListCtor){
		// summary:
		// 		decorate an array to make it look like a `dojo.NodeList`.
		// a:
		// 		Array of nodes to decorate.
		// parent:
		// 		An optional parent NodeList that generated the current
		// 		list of nodes. Used to call _stash() so the parent NodeList
		// 		can be accessed via end() later.
		// NodeListCtor:
		// 		An optional constructor function to use for any
		// 		new NodeList calls. This allows a certain chain of
		// 		NodeList calls to use a different object than dojo.NodeList.
		if(!a.sort){
			// make sure it's a real array before we pass it on to be wrapped
			a = aps.call(a, 0);
		}
		var ctor = NodeListCtor || this._NodeListCtor || d._NodeListCtor;
		a.constructor = ctor;
		dojo._mixin(a, ctor.prototype);
		a._NodeListCtor = ctor;
		return parent ? a._stash(parent) : a;
	};

	var loopBody = function(f, a, o){
		a = [0].concat(aps.call(a, 0));
		o = o || d.global;
		return function(node){
			a[0] = node;
			return f.apply(o, a);
		};
	};

	// adapters

	var adaptAsForEach = function(f, o){
		//	summary:
		//		adapts a single node function to be used in the forEach-type
		//		actions. The initial object is returned from the specialized
		//		function.
		//	f: Function
		//		a function to adapt
		//	o: Object?
		//		an optional context for f
		return function(){
			this.forEach(loopBody(f, arguments, o));
			return this;	// Object
		};
	};

	var adaptAsMap = function(f, o){
		//	summary:
		//		adapts a single node function to be used in the map-type
		//		actions. The return is a new array of values, as via `dojo.map`
		//	f: Function
		//		a function to adapt
		//	o: Object?
		//		an optional context for f
		return function(){
			return this.map(loopBody(f, arguments, o));
		};
	};

	var adaptAsFilter = function(f, o){
		//	summary:
		//		adapts a single node function to be used in the filter-type actions
		//	f: Function
		//		a function to adapt
		//	o: Object?
		//		an optional context for f
		return function(){
			return this.filter(loopBody(f, arguments, o));
		};
	};

	var adaptWithCondition = function(f, g, o){
		//	summary:
		//		adapts a single node function to be used in the map-type
		//		actions, behaves like forEach() or map() depending on arguments
		//	f: Function
		//		a function to adapt
		//	g: Function
		//		a condition function, if true runs as map(), otherwise runs as forEach()
		//	o: Object?
		//		an optional context for f and g
		return function(){
			var a = arguments, body = loopBody(f, a, o);
			if(g.call(o || d.global, a)){
				return this.map(body);	// self
			}
			this.forEach(body);
			return this;	// self
		};
	};

	var magicGuard = function(a){
		//	summary:
		//		the guard function for dojo.attr() and dojo.style()
		return a.length == 1 && (typeof a[0] == "string"); // inline'd type check
	};

	var orphan = function(node){
		//	summary:
		//		function to orphan nodes
		var p = node.parentNode;
		if(p){
			p.removeChild(node);
		}
	};
	// FIXME: should we move orphan() to dojo.html?

	dojo.NodeList = function(){
		//	summary:
		//		dojo.NodeList is an of Array subclass which adds syntactic
		//		sugar for chaining, common iteration operations, animation, and
		//		node manipulation. NodeLists are most often returned as the
		//		result of dojo.query() calls.
		//	description:
		//		dojo.NodeList instances provide many utilities that reflect
		//		core Dojo APIs for Array iteration and manipulation, DOM
		//		manipulation, and event handling. Instead of needing to dig up
		//		functions in the dojo.* namespace, NodeLists generally make the
		//		full power of Dojo available for DOM manipulation tasks in a
		//		simple, chainable way.
		//	example:
		//		create a node list from a node
		//		|	new dojo.NodeList(dojo.byId("foo"));
		//	example:
		//		get a NodeList from a CSS query and iterate on it
		//		|	var l = dojo.query(".thinger");
		//		|	l.forEach(function(node, index, nodeList){
		//		|		console.log(index, node.innerHTML);
		//		|	});
		//	example:
		//		use native and Dojo-provided array methods to manipulate a
		//		NodeList without needing to use dojo.* functions explicitly:
		//		|	var l = dojo.query(".thinger");
		//		|	// since NodeLists are real arrays, they have a length
		//		|	// property that is both readable and writable and
		//		|	// push/pop/shift/unshift methods
		//		|	console.log(l.length);
		//		|	l.push(dojo.create("span"));
		//		|
		//		|	// dojo's normalized array methods work too:
		//		|	console.log( l.indexOf(dojo.byId("foo")) );
		//		|	// ...including the special "function as string" shorthand
		//		|	console.log( l.every("item.nodeType == 1") );
		//		|
		//		|	// NodeLists can be [..] indexed, or you can use the at()
		//		|	// function to get specific items wrapped in a new NodeList:
		//		|	var node = l[3]; // the 4th element
		//		|	var newList = l.at(1, 3); // the 2nd and 4th elements
		//	example:
		//		the style functions you expect are all there too:
		//		|	// style() as a getter...
		//		|	var borders = dojo.query(".thinger").style("border");
		//		|	// ...and as a setter:
		//		|	dojo.query(".thinger").style("border", "1px solid black");
		//		|	// class manipulation
		//		|	dojo.query("li:nth-child(even)").addClass("even");
		//		|	// even getting the coordinates of all the items
		//		|	var coords = dojo.query(".thinger").coords();
		//	example:
		//		DOM manipulation functions from the dojo.* namespace area also
		//		available:
		//		|	// remove all of the elements in the list from their
		//		|	// parents (akin to "deleting" them from the document)
		//		|	dojo.query(".thinger").orphan();
		//		|	// place all elements in the list at the front of #foo
		//		|	dojo.query(".thinger").place("foo", "first");
		//	example:
		//		Event handling couldn't be easier. `dojo.connect` is mapped in,
		//		and shortcut handlers are provided for most DOM events:
		//		|	// like dojo.connect(), but with implicit scope
		//		|	dojo.query("li").connect("onclick", console, "log");
		//		|
		//		|	// many common event handlers are already available directly:
		//		|	dojo.query("li").onclick(console, "log");
		//		|	var toggleHovered = dojo.hitch(dojo, "toggleClass", "hovered");
		//		|	dojo.query("p")
		//		|		.onmouseenter(toggleHovered)
		//		|		.onmouseleave(toggleHovered);
		//	example:
		//		chainability is a key advantage of NodeLists:
		//		|	dojo.query(".thinger")
		//		|		.onclick(function(e){ /* ... */ })
		//		|		.at(1, 3, 8) // get a subset
		//		|			.style("padding", "5px")
		//		|			.forEach(console.log);

		return tnl(Array.apply(null, arguments));
	};

	//Allow things that new up a NodeList to use a delegated or alternate NodeList implementation.
	d._NodeListCtor = d.NodeList;

	var nl = d.NodeList, nlp = nl.prototype;

	// expose adapters and the wrapper as private functions

	nl._wrap = nlp._wrap = tnl;
	nl._adaptAsMap = adaptAsMap;
	nl._adaptAsForEach = adaptAsForEach;
	nl._adaptAsFilter  = adaptAsFilter;
	nl._adaptWithCondition = adaptWithCondition;

	// mass assignment

	// add array redirectors
	d.forEach(["slice", "splice"], function(name){
		var f = ap[name];
		//Use a copy of the this array via this.slice() to allow .end() to work right in the splice case.
		// CANNOT apply ._stash()/end() to splice since it currently modifies
		// the existing this array -- it would break backward compatibility if we copy the array before
		// the splice so that we can use .end(). So only doing the stash option to this._wrap for slice.
		nlp[name] = function(){ return this._wrap(f.apply(this, arguments), name == "slice" ? this : null); };
	});
	// concat should be here but some browsers with native NodeList have problems with it

	// add array.js redirectors
	d.forEach(["indexOf", "lastIndexOf", "every", "some"], function(name){
		var f = d[name];
		nlp[name] = function(){ return f.apply(d, [this].concat(aps.call(arguments, 0))); };
	});

	// add conditional methods
	d.forEach(["attr", "style"], function(name){
		nlp[name] = adaptWithCondition(d[name], magicGuard);
	});

	// add forEach actions
	d.forEach(["connect", "addClass", "removeClass", "replaceClass", "toggleClass", "empty", "removeAttr"], function(name){
		nlp[name] = adaptAsForEach(d[name]);
	});

	dojo.extend(dojo.NodeList, {
		_normalize: function(/*String||Element||Object||NodeList*/content, /*DOMNode?*/refNode){
			// summary:
			// 		normalizes data to an array of items to insert.
			// description:
			// 		If content is an object, it can have special properties "template" and
			// 		"parse". If "template" is defined, then the template value is run through
			// 		dojo.string.substitute (if dojo.string.substitute has been dojo.required elsewhere),
			// 		or if templateFunc is a function on the content, that function will be used to
			// 		transform the template into a final string to be used for for passing to dojo._toDom.
			// 		If content.parse is true, then it is remembered for later, for when the content
			// 		nodes are inserted into the DOM. At that point, the nodes will be parsed for widgets
			// 		(if dojo.parser has been dojo.required elsewhere).

			//Wanted to just use a DocumentFragment, but for the array/NodeList
			//case that meant  using cloneNode, but we may not want that.
			//Cloning should only happen if the node operations span
			//multiple refNodes. Also, need a real array, not a NodeList from the
			//DOM since the node movements could change those NodeLists.

			var parse = content.parse === true ? true : false;

			//Do we have an object that needs to be run through a template?
			if(typeof content.template == "string"){
				var templateFunc = content.templateFunc || (dojo.string && dojo.string.substitute);
				content = templateFunc ? templateFunc(content.template, content) : content;
			}

			var type = (typeof content);
			if(type == "string" || type == "number"){
				content = dojo._toDom(content, (refNode && refNode.ownerDocument));
				if(content.nodeType == 11){
					//DocumentFragment. It cannot handle cloneNode calls, so pull out the children.
					content = dojo._toArray(content.childNodes);
				}else{
					content = [content];
				}
			}else if(!dojo.isArrayLike(content)){
				content = [content];
			}else if(!dojo.isArray(content)){
				//To get to this point, content is array-like, but
				//not an array, which likely means a DOM NodeList. Convert it now.
				content = dojo._toArray(content);
			}

			//Pass around the parse info
			if(parse){
				content._runParse = true;
			}
			return content; //Array
		},

		_cloneNode: function(/*DOMNode*/ node){
			// summary:
			// 		private utility to clone a node. Not very interesting in the vanilla
			// 		dojo.NodeList case, but delegates could do interesting things like
			// 		clone event handlers if that is derivable from the node.
			return node.cloneNode(true);
		},

		_place: function(/*Array*/ary, /*DOMNode*/refNode, /*String*/position, /*Boolean*/useClone){
			// summary:
			// 		private utility to handle placing an array of nodes relative to another node.
			// description:
			// 		Allows for cloning the nodes in the array, and for
			// 		optionally parsing widgets, if ary._runParse is true.

			//Avoid a disallowed operation if trying to do an innerHTML on a non-element node.
			if(refNode.nodeType != 1 && position == "only"){
				return;
			}
			var rNode = refNode, tempNode;

			//Always cycle backwards in case the array is really a
			//DOM NodeList and the DOM operations take it out of the live collection.
			var length = ary.length;
			for(var i = length - 1; i >= 0; i--){
				var node = (useClone ? this._cloneNode(ary[i]) : ary[i]);

				//If need widget parsing, use a temp node, instead of waiting after inserting into
				//real DOM because we need to start widget parsing at one node up from current node,
				//which could cause some already parsed widgets to be parsed again.
				if(ary._runParse && dojo.parser && dojo.parser.parse){
					if(!tempNode){
						tempNode = rNode.ownerDocument.createElement("div");
					}
					tempNode.appendChild(node);
					dojo.parser.parse(tempNode);
					node = tempNode.firstChild;
					while(tempNode.firstChild){
						tempNode.removeChild(tempNode.firstChild);
					}
				}

				if(i == length - 1){
					dojo.place(node, rNode, position);
				}else{
					rNode.parentNode.insertBefore(node, rNode);
				}
				rNode = node;
			}
		},

		_stash: function(parent){
			// summary:
			// 		private function to hold to a parent NodeList. end() to return the parent NodeList.
			//
			// example:
			// How to make a `dojo.NodeList` method that only returns the third node in
			// the dojo.NodeList but allows access to the original NodeList by using this._stash:
			//	|	dojo.extend(dojo.NodeList, {
			//	|		third: function(){
			//  |			var newNodeList = dojo.NodeList(this[2]);
			//	|			return newNodeList._stash(this);
			//	|		}
			//	|	});
			//	|	// then see how _stash applies a sub-list, to be .end()'ed out of
			//	|	dojo.query(".foo")
			//	|		.third()
			//	|			.addClass("thirdFoo")
			//	|		.end()
			//	|		// access to the orig .foo list
			//	|		.removeClass("foo")
			//	|
			//
			this._parent = parent;
			return this; //dojo.NodeList
		},

		end: function(){
			// summary:
			// 		Ends use of the current `dojo.NodeList` by returning the previous dojo.NodeList
			// 		that generated the current dojo.NodeList.
			// description:
			// 		Returns the `dojo.NodeList` that generated the current `dojo.NodeList`. If there
			// 		is no parent dojo.NodeList, an empty dojo.NodeList is returned.
			// example:
			//	|	dojo.query("a")
			//	|		.filter(".disabled")
			//	|			// operate on the anchors that only have a disabled class
			//	|			.style("color", "grey")
			//	|		.end()
			//	|		// jump back to the list of anchors
			//	|		.style(...)
			//
			if(this._parent){
				return this._parent;
			}else{
				//Just return empty list.
				return new this._NodeListCtor();
			}
		},

		// http://developer.mozilla.org/en/docs/Core_JavaScript_1.5_Reference:Global_Objects:Array#Methods

		// FIXME: handle return values for #3244
		//		http://trac.dojotoolkit.org/ticket/3244

		// FIXME:
		//		need to wrap or implement:
		//			join (perhaps w/ innerHTML/outerHTML overload for toString() of items?)
		//			reduce
		//			reduceRight

		/*=====
		slice: function(begin, end){
			// summary:
			//		Returns a new NodeList, maintaining this one in place
			// description:
			//		This method behaves exactly like the Array.slice method
			//		with the caveat that it returns a dojo.NodeList and not a
			//		raw Array. For more details, see Mozilla's (slice
			//		documentation)[http://developer.mozilla.org/en/docs/Core_JavaScript_1.5_Reference:Global_Objects:Array:slice]
			// begin: Integer
			//		Can be a positive or negative integer, with positive
			//		integers noting the offset to begin at, and negative
			//		integers denoting an offset from the end (i.e., to the left
			//		of the end)
			// end: Integer?
			//		Optional parameter to describe what position relative to
			//		the NodeList's zero index to end the slice at. Like begin,
			//		can be positive or negative.
			return this._wrap(a.slice.apply(this, arguments));
		},

		splice: function(index, howmany, item){
			// summary:
			//		Returns a new NodeList, manipulating this NodeList based on
			//		the arguments passed, potentially splicing in new elements
			//		at an offset, optionally deleting elements
			// description:
			//		This method behaves exactly like the Array.splice method
			//		with the caveat that it returns a dojo.NodeList and not a
			//		raw Array. For more details, see Mozilla's (splice
			//		documentation)[http://developer.mozilla.org/en/docs/Core_JavaScript_1.5_Reference:Global_Objects:Array:splice]
			// 		For backwards compatibility, calling .end() on the spliced NodeList
			// 		does not return the original NodeList -- splice alters the NodeList in place.
			// index: Integer
			//		begin can be a positive or negative integer, with positive
			//		integers noting the offset to begin at, and negative
			//		integers denoting an offset from the end (i.e., to the left
			//		of the end)
			// howmany: Integer?
			//		Optional parameter to describe what position relative to
			//		the NodeList's zero index to end the slice at. Like begin,
			//		can be positive or negative.
			// item: Object...?
			//		Any number of optional parameters may be passed in to be
			//		spliced into the NodeList
			// returns:
			//		dojo.NodeList
			return this._wrap(a.splice.apply(this, arguments));
		},

		indexOf: function(value, fromIndex){
			//	summary:
			//		see dojo.indexOf(). The primary difference is that the acted-on
			//		array is implicitly this NodeList
			// value: Object:
			//		The value to search for.
			// fromIndex: Integer?:
			//		The location to start searching from. Optional. Defaults to 0.
			//	description:
			//		For more details on the behavior of indexOf, see Mozilla's
			//		(indexOf
			//		docs)[http://developer.mozilla.org/en/docs/Core_JavaScript_1.5_Reference:Global_Objects:Array:indexOf]
			//	returns:
			//		Positive Integer or 0 for a match, -1 of not found.
			return d.indexOf(this, value, fromIndex); // Integer
		},

		lastIndexOf: function(value, fromIndex){
			// summary:
			//		see dojo.lastIndexOf(). The primary difference is that the
			//		acted-on array is implicitly this NodeList
			//	description:
			//		For more details on the behavior of lastIndexOf, see
			//		Mozilla's (lastIndexOf
			//		docs)[http://developer.mozilla.org/en/docs/Core_JavaScript_1.5_Reference:Global_Objects:Array:lastIndexOf]
			// value: Object
			//		The value to search for.
			// fromIndex: Integer?
			//		The location to start searching from. Optional. Defaults to 0.
			// returns:
			//		Positive Integer or 0 for a match, -1 of not found.
			return d.lastIndexOf(this, value, fromIndex); // Integer
		},

		every: function(callback, thisObject){
			//	summary:
			//		see `dojo.every()` and the (Array.every
			//		docs)[http://developer.mozilla.org/en/docs/Core_JavaScript_1.5_Reference:Global_Objects:Array:every].
			//		Takes the same structure of arguments and returns as
			//		dojo.every() with the caveat that the passed array is
			//		implicitly this NodeList
			// callback: Function: the callback
			// thisObject: Object?: the context
			return d.every(this, callback, thisObject); // Boolean
		},

		some: function(callback, thisObject){
			//	summary:
			//		Takes the same structure of arguments and returns as
			//		`dojo.some()` with the caveat that the passed array is
			//		implicitly this NodeList.  See `dojo.some()` and Mozilla's
			//		(Array.some
			//		documentation)[http://developer.mozilla.org/en/docs/Core_JavaScript_1.5_Reference:Global_Objects:Array:some].
			// callback: Function: the callback
			// thisObject: Object?: the context
			return d.some(this, callback, thisObject); // Boolean
		},
		=====*/

		concat: function(item){
			// summary:
			//		Returns a new NodeList comprised of items in this NodeList
			//		as well as items passed in as parameters
			// description:
			//		This method behaves exactly like the Array.concat method
			//		with the caveat that it returns a `dojo.NodeList` and not a
			//		raw Array. For more details, see the (Array.concat
			//		docs)[http://developer.mozilla.org/en/docs/Core_JavaScript_1.5_Reference:Global_Objects:Array:concat]
			// item: Object?
			//		Any number of optional parameters may be passed in to be
			//		spliced into the NodeList
			// returns:
			//		dojo.NodeList

			//return this._wrap(apc.apply(this, arguments));
			// the line above won't work for the native NodeList :-(

			// implementation notes:
			// 1) Native NodeList is not an array, and cannot be used directly
			// in concat() --- the latter doesn't recognize it as an array, and
			// does not inline it, but append as a single entity.
			// 2) On some browsers (e.g., Safari) the "constructor" property is
			// read-only and cannot be changed. So we have to test for both
			// native NodeList and dojo.NodeList in this property to recognize
			// the node list.

			var t = d.isArray(this) ? this : aps.call(this, 0),
				m = d.map(arguments, function(a){
					return a && !d.isArray(a) &&
						(typeof NodeList != "undefined" && a.constructor === NodeList || a.constructor === this._NodeListCtor) ?
							aps.call(a, 0) : a;
				});
			return this._wrap(apc.apply(t, m), this);	// dojo.NodeList
		},

		map: function(/*Function*/ func, /*Function?*/ obj){
			//	summary:
			//		see dojo.map(). The primary difference is that the acted-on
			//		array is implicitly this NodeList and the return is a
			//		dojo.NodeList (a subclass of Array)
			///return d.map(this, func, obj, d.NodeList); // dojo.NodeList
			return this._wrap(d.map(this, func, obj), this); // dojo.NodeList
		},

		forEach: function(callback, thisObj){
			//	summary:
			//		see `dojo.forEach()`. The primary difference is that the acted-on
			//		array is implicitly this NodeList. If you want the option to break out
			//		of the forEach loop, use every() or some() instead.
			d.forEach(this, callback, thisObj);
			// non-standard return to allow easier chaining
			return this; // dojo.NodeList
		},

		/*=====
		coords: function(){
			//	summary:
			//		Returns the box objects of all elements in a node list as
			//		an Array (*not* a NodeList). Acts like `dojo.coords`, though assumes
			//		the node passed is each node in this list.

			return d.map(this, d.coords); // Array
		},

		position: function(){
			//	summary:
			//		Returns border-box objects (x/y/w/h) of all elements in a node list
			//		as an Array (*not* a NodeList). Acts like `dojo.position`, though
			//		assumes the node passed is each node in this list.

			return d.map(this, d.position); // Array
		},

		attr: function(property, value){
			//	summary:
			//		gets or sets the DOM attribute for every element in the
			//		NodeList. See also `dojo.attr`
			//	property: String
			//		the attribute to get/set
			//	value: String?
			//		optional. The value to set the property to
			//	returns:
			//		if no value is passed, the result is an array of attribute values
			//		If a value is passed, the return is this NodeList
			//	example:
			//		Make all nodes with a particular class focusable:
			//	|	dojo.query(".focusable").attr("tabIndex", -1);
			//	example:
			//		Disable a group of buttons:
			//	|	dojo.query("button.group").attr("disabled", true);
			//	example:
			//		innerHTML can be assigned or retrieved as well:
			//	|	// get the innerHTML (as an array) for each list item
			//	|	var ih = dojo.query("li.replaceable").attr("innerHTML");
			return; // dojo.NodeList
			return; // Array
		},

		style: function(property, value){
			//	summary:
			//		gets or sets the CSS property for every element in the NodeList
			//	property: String
			//		the CSS property to get/set, in JavaScript notation
			//		("lineHieght" instead of "line-height")
			//	value: String?
			//		optional. The value to set the property to
			//	returns:
			//		if no value is passed, the result is an array of strings.
			//		If a value is passed, the return is this NodeList
			return; // dojo.NodeList
			return; // Array
		},

		addClass: function(className){
			//	summary:
			//		adds the specified class to every node in the list
			//	className: String|Array
			//		A String class name to add, or several space-separated class names,
			//		or an array of class names.
			return; // dojo.NodeList
		},

		removeClass: function(className){
			//	summary:
			//		removes the specified class from every node in the list
			//	className: String|Array?
			//		An optional String class name to remove, or several space-separated
			//		class names, or an array of class names. If omitted, all class names
			//		will be deleted.
			//	returns:
			//		dojo.NodeList, this list
			return; // dojo.NodeList
		},

		toggleClass: function(className, condition){
			//	summary:
			//		Adds a class to node if not present, or removes if present.
			//		Pass a boolean condition if you want to explicitly add or remove.
			//	condition: Boolean?
			//		If passed, true means to add the class, false means to remove.
			//	className: String
			//		the CSS class to add
			return; // dojo.NodeList
		},

		connect: function(methodName, objOrFunc, funcName){
			//	summary:
			//		attach event handlers to every item of the NodeList. Uses dojo.connect()
			//		so event properties are normalized
			//	methodName: String
			//		the name of the method to attach to. For DOM events, this should be
			//		the lower-case name of the event
			//	objOrFunc: Object|Function|String
			//		if 2 arguments are passed (methodName, objOrFunc), objOrFunc should
			//		reference a function or be the name of the function in the global
			//		namespace to attach. If 3 arguments are provided
			//		(methodName, objOrFunc, funcName), objOrFunc must be the scope to
			//		locate the bound function in
			//	funcName: String?
			//		optional. A string naming the function in objOrFunc to bind to the
			//		event. May also be a function reference.
			//	example:
			//		add an onclick handler to every button on the page
			//		|	dojo.query("div:nth-child(odd)").connect("onclick", function(e){
			//		|		console.log("clicked!");
			//		|	});
			// example:
			//		attach foo.bar() to every odd div's onmouseover
			//		|	dojo.query("div:nth-child(odd)").connect("onmouseover", foo, "bar");
		},

		empty: function(){
			//	summary:
			//		clears all content from each node in the list. Effectively
			//		equivalent to removing all child nodes from every item in
			//		the list.
			return this.forEach("item.innerHTML='';"); // dojo.NodeList
			// FIXME: should we be checking for and/or disposing of widgets below these nodes?
		},
		=====*/

		// useful html methods
		coords:	adaptAsMap(d.coords),
		position: adaptAsMap(d.position),

		// FIXME: connectPublisher()? connectRunOnce()?

		/*
		destroy: function(){
			//	summary:
			//		destroys every item in 	the list.
			this.forEach(d.destroy);
			// FIXME: should we be checking for and/or disposing of widgets below these nodes?
		},
		*/

		place: function(/*String||Node*/ queryOrNode, /*String*/ position){
			//	summary:
			//		places elements of this node list relative to the first element matched
			//		by queryOrNode. Returns the original NodeList. See: `dojo.place`
			//	queryOrNode:
			//		may be a string representing any valid CSS3 selector or a DOM node.
			//		In the selector case, only the first matching element will be used
			//		for relative positioning.
			//	position:
			//		can be one of:
			//		|	"last" (default)
			//		|	"first"
			//		|	"before"
			//		|	"after"
			//		|	"only"
			//		|	"replace"
			// 		or an offset in the childNodes property
			var item = d.query(queryOrNode)[0];
			return this.forEach(function(node){ d.place(node, item, position); }); // dojo.NodeList
		},

		orphan: function(/*String?*/ filter){
			//	summary:
			//		removes elements in this list that match the filter
			//		from their parents and returns them as a new NodeList.
			//	filter:
			//		CSS selector like ".foo" or "div > span"
			//	returns:
			//		`dojo.NodeList` containing the orphaned elements
			return (filter ? d._filterQueryResult(this, filter) : this).forEach(orphan); // dojo.NodeList
		},

		adopt: function(/*String||Array||DomNode*/ queryOrListOrNode, /*String?*/ position){
			//	summary:
			//		places any/all elements in queryOrListOrNode at a
			//		position relative to the first element in this list.
			//		Returns a dojo.NodeList of the adopted elements.
			//	queryOrListOrNode:
			//		a DOM node or a query string or a query result.
			//		Represents the nodes to be adopted relative to the
			//		first element of this NodeList.
			//	position:
			//		can be one of:
			//		|	"last" (default)
			//		|	"first"
			//		|	"before"
			//		|	"after"
			//		|	"only"
			//		|	"replace"
			// 		or an offset in the childNodes property
			return d.query(queryOrListOrNode).place(this[0], position)._stash(this);	// dojo.NodeList
		},

		// FIXME: do we need this?
		query: function(/*String*/ queryStr){
			//	summary:
			//		Returns a new list whose members match the passed query,
			//		assuming elements of the current NodeList as the root for
			//		each search.
			//	example:
			//		assume a DOM created by this markup:
			//	|	<div id="foo">
			//	|		<p>
			//	|			bacon is tasty, <span>dontcha think?</span>
			//	|		</p>
			//	|	</div>
			//	|	<div id="bar">
			//	|		<p>great comedians may not be funny <span>in person</span></p>
			//	|	</div>
			//		If we are presented with the following definition for a NodeList:
			//	|	var l = new dojo.NodeList(dojo.byId("foo"), dojo.byId("bar"));
			//		it's possible to find all span elements under paragraphs
			//		contained by these elements with this sub-query:
			//	| 	var spans = l.query("p span");

			// FIXME: probably slow
			if(!queryStr){ return this; }
			var ret = this.map(function(node){
				// FIXME: why would we ever get undefined here?
				return d.query(queryStr, node).filter(function(subNode){ return subNode !== undefined; });
			});
			return this._wrap(apc.apply([], ret), this);	// dojo.NodeList
		},

		filter: function(/*String|Function*/ filter){
			//	summary:
			// 		"masks" the built-in javascript filter() method (supported
			// 		in Dojo via `dojo.filter`) to support passing a simple
			// 		string filter in addition to supporting filtering function
			// 		objects.
			//	filter:
			//		If a string, a CSS rule like ".thinger" or "div > span".
			//	example:
			//		"regular" JS filter syntax as exposed in dojo.filter:
			//		|	dojo.query("*").filter(function(item){
			//		|		// highlight every paragraph
			//		|		return (item.nodeName == "p");
			//		|	}).style("backgroundColor", "yellow");
			// example:
			//		the same filtering using a CSS selector
			//		|	dojo.query("*").filter("p").styles("backgroundColor", "yellow");

			var a = arguments, items = this, start = 0;
			if(typeof filter == "string"){ // inline'd type check
				items = d._filterQueryResult(this, a[0]);
				if(a.length == 1){
					// if we only got a string query, pass back the filtered results
					return items._stash(this); // dojo.NodeList
				}
				// if we got a callback, run it over the filtered items
				start = 1;
			}
			return this._wrap(d.filter(items, a[start], a[start + 1]), this);	// dojo.NodeList
		},

		/*
		// FIXME: should this be "copyTo" and include parenting info?
		clone: function(){
			// summary:
			//		creates node clones of each element of this list
			//		and returns a new list containing the clones
		},
		*/

		addContent: function(/*String||DomNode||Object||dojo.NodeList*/ content, /*String||Integer?*/ position){
			//	summary:
			//		add a node, NodeList or some HTML as a string to every item in the
			//		list.  Returns the original list.
			//	description:
			//		a copy of the HTML content is added to each item in the
			//		list, with an optional position argument. If no position
			//		argument is provided, the content is appended to the end of
			//		each item.
			//	content:
			//		DOM node, HTML in string format, a NodeList or an Object. If a DOM node or
			// 		NodeList, the content will be cloned if the current NodeList has more than one
			// 		element. Only the DOM nodes are cloned, no event handlers. If it is an Object,
			// 		it should be an object with at "template" String property that has the HTML string
			// 		to insert. If dojo.string has already been dojo.required, then dojo.string.substitute
			// 		will be used on the "template" to generate the final HTML string. Other allowed
			// 		properties on the object are: "parse" if the HTML
			// 		string should be parsed for widgets (dojo.require("dojo.parser") to get that
			// 		option to work), and "templateFunc" if a template function besides dojo.string.substitute
			// 		should be used to transform the "template".
			//	position:
			//		can be one of:
			//		|	"last"||"end" (default)
			//		|	"first||"start"
			//		|	"before"
			//		|	"after"
			//		|	"replace" (replaces nodes in this NodeList with new content)
			//		|	"only" (removes other children of the nodes so new content is the only child)
			// 		or an offset in the childNodes property
			//	example:
			//		appends content to the end if the position is omitted
			//	|	dojo.query("h3 > p").addContent("hey there!");
			//	example:
			//		add something to the front of each element that has a
			//		"thinger" property:
			//	|	dojo.query("[thinger]").addContent("...", "first");
			//	example:
			//		adds a header before each element of the list
			//	|	dojo.query(".note").addContent("<h4>NOTE:</h4>", "before");
			//	example:
			//		add a clone of a DOM node to the end of every element in
			//		the list, removing it from its existing parent.
			//	|	dojo.query(".note").addContent(dojo.byId("foo"));
			//  example:
			//  	Append nodes from a templatized string.
			// 		dojo.require("dojo.string");
			// 		dojo.query(".note").addContent({
			//  		template: '<b>${id}: </b><span>${name}</span>',
			// 			id: "user332",
			//  		name: "Mr. Anderson"
			//  	});
			//  example:
			//  	Append nodes from a templatized string that also has widgets parsed.
			//  	dojo.require("dojo.string");
			//  	dojo.require("dojo.parser");
			//  	var notes = dojo.query(".note").addContent({
			//  		template: '<button dojoType="dijit.form.Button">${text}</button>',
			//  		parse: true,
			//  		text: "Send"
			//  	});
			content = this._normalize(content, this[0]);
			for(var i = 0, node; (node = this[i]); i++){
				this._place(content, node, position, i > 0);
			}
			return this; //dojo.NodeList
		},

		instantiate: function(/*String|Object*/ declaredClass, /*Object?*/ properties){
			//	summary:
			//		Create a new instance of a specified class, using the
			//		specified properties and each node in the nodeList as a
			//		srcNodeRef.
			//	example:
			//		Grabs all buttons in the page and converts them to diji.form.Buttons.
			//	|	var buttons = dojo.query("button").instantiate("dijit.form.Button", {showLabel: true});
			var c = d.isFunction(declaredClass) ? declaredClass : d.getObject(declaredClass);
			properties = properties || {};
			return this.forEach(function(node){
				new c(properties, node);
			});	// dojo.NodeList
		},

		at: function(/*===== index =====*/){
			//	summary:
			//		Returns a new NodeList comprised of items in this NodeList
			//		at the given index or indices.
			//
			//	index: Integer...
			//		One or more 0-based indices of items in the current
			//		NodeList. A negative index will start at the end of the
			//		list and go backwards.
			//
			//	example:
			//	Shorten the list to the first, second, and third elements
			//	|	dojo.query("a").at(0, 1, 2).forEach(fn);
			//
			//	example:
			//	Retrieve the first and last elements of a unordered list:
			//	|	dojo.query("ul > li").at(0, -1).forEach(cb);
			//
			//	example:
			//	Do something for the first element only, but end() out back to
			//	the original list and continue chaining:
			//	|	dojo.query("a").at(0).onclick(fn).end().forEach(function(n){
			//	|		console.log(n); // all anchors on the page.
			//	|	})
			//
			//	returns:
			//		dojo.NodeList
			var t = new this._NodeListCtor();
			d.forEach(arguments, function(i){
				if(i < 0){ i = this.length + i }
				if(this[i]){ t.push(this[i]); }
			}, this);
			return t._stash(this); // dojo.NodeList
		}

	});

	nl.events = [
		// summary:
		//		list of all DOM events used in NodeList
		"blur", "focus", "change", "click", "error", "keydown", "keypress",
		"keyup", "load", "mousedown", "mouseenter", "mouseleave", "mousemove",
		"mouseout", "mouseover", "mouseup", "submit"
	];
	
	// FIXME: pseudo-doc the above automatically generated on-event functions

	// syntactic sugar for DOM events
	d.forEach(nl.events, function(evt){
			var _oe = "on" + evt;
			nlp[_oe] = function(a, b){
				return this.connect(_oe, a, b);
			};
				// FIXME: should these events trigger publishes?
				/*
				return (a ? this.connect(_oe, a, b) :
							this.forEach(function(n){
								// FIXME:
								//		listeners get buried by
								//		addEventListener and can't be dug back
								//		out to be triggered externally.
								// see:
								//		http://developer.mozilla.org/en/docs/DOM:element

								console.log(n, evt, _oe);

								// FIXME: need synthetic event support!
								var _e = { target: n, faux: true, type: evt };
								// dojo._event_listener._synthesizeEvent({}, { target: n, faux: true, type: evt });
								try{ n[evt](_e); }catch(e){ console.log(e); }
								try{ n[_oe](_e); }catch(e){ console.log(e); }
							})
				);
				*/
		}
	);

})();

}

if(!dojo._hasResource["dojo._base.query"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.query"] = true;
(function(){

/*
	dojo.query() architectural overview:

		dojo.query is a relatively full-featured CSS3 query library. It is
		designed to take any valid CSS3 selector and return the nodes matching
		the selector. To do this quickly, it processes queries in several
		steps, applying caching where profitable.
		
		The steps (roughly in reverse order of the way they appear in the code):
			1.) check to see if we already have a "query dispatcher"
				- if so, use that with the given parameterization. Skip to step 4.
			2.) attempt to determine which branch to dispatch the query to:
				- JS (optimized DOM iteration)
				- native (FF3.1+, Safari 3.1+, IE 8+)
			3.) tokenize and convert to executable "query dispatcher"
				- this is where the lion's share of the complexity in the
				  system lies. In the DOM version, the query dispatcher is
				  assembled as a chain of "yes/no" test functions pertaining to
				  a section of a simple query statement (".blah:nth-child(odd)"
				  but not "div div", which is 2 simple statements). Individual
				  statement dispatchers are cached (to prevent re-definition)
				  as are entire dispatch chains (to make re-execution of the
				  same query fast)
			4.) the resulting query dispatcher is called in the passed scope
			    (by default the top-level document)
				- for DOM queries, this results in a recursive, top-down
				  evaluation of nodes based on each simple query section
				- for native implementations, this may mean working around spec
				  bugs. So be it.
			5.) matched nodes are pruned to ensure they are unique (if necessary)
*/

var defineQuery= function(d){
	// define everything in a closure for compressability reasons. "d" is an
	// alias to "dojo" (or the toolkit alias object, e.g., "acme").

	////////////////////////////////////////////////////////////////////////
	// Toolkit aliases
	////////////////////////////////////////////////////////////////////////

	// if you are extracting dojo.query for use in your own system, you will
	// need to provide these methods and properties. No other porting should be
	// necessary, save for configuring the system to use a class other than
	// dojo.NodeList as the return instance instantiator
	var trim = 			d.trim;
	var each = 			d.forEach;
	// 					d.isIE; // float
	// 					d.isSafari; // float
	// 					d.isOpera; // float
	// 					d.isWebKit; // float
	// 					d.doc ; // document element
	var qlc = (d._NodeListCtor = 		d.NodeList);

	var getDoc = function(){ return d.doc; };
	// NOTE(alex): the spec is idiotic. CSS queries should ALWAYS be case-sensitive, but nooooooo
	var cssCaseBug = ((d.isWebKit||d.isMozilla) && ((getDoc().compatMode) == "BackCompat"));

	////////////////////////////////////////////////////////////////////////
	// Global utilities
	////////////////////////////////////////////////////////////////////////


	// on browsers that support the "children" collection we can avoid a lot of
	// iteration on chaff (non-element) nodes.
	// why.
	var childNodesName = !!getDoc().firstChild["children"] ? "children" : "childNodes";

	var specials = ">~+";

	// global thunk to determine whether we should treat the current query as
	// case sensitive or not. This switch is flipped by the query evaluator
	// based on the document passed as the context to search.
	var caseSensitive = false;

	// how high?
	var yesman = function(){ return true; };

	////////////////////////////////////////////////////////////////////////
	// Tokenizer
	////////////////////////////////////////////////////////////////////////

	var getQueryParts = function(query){
		//	summary:
		//		state machine for query tokenization
		//	description:
		//		instead of using a brittle and slow regex-based CSS parser,
		//		dojo.query implements an AST-style query representation. This
		//		representation is only generated once per query. For example,
		//		the same query run multiple times or under different root nodes
		//		does not re-parse the selector expression but instead uses the
		//		cached data structure. The state machine implemented here
		//		terminates on the last " " (space) character and returns an
		//		ordered array of query component structures (or "parts"). Each
		//		part represents an operator or a simple CSS filtering
		//		expression. The structure for parts is documented in the code
		//		below.


		// NOTE:
		//		this code is designed to run fast and compress well. Sacrifices
		//		to readability and maintainability have been made.  Your best
		//		bet when hacking the tokenizer is to put The Donnas on *really*
		//		loud (may we recommend their "Spend The Night" release?) and
		//		just assume you're gonna make mistakes. Keep the unit tests
		//		open and run them frequently. Knowing is half the battle ;-)
		if(specials.indexOf(query.slice(-1)) >= 0){
			// if we end with a ">", "+", or "~", that means we're implicitly
			// searching all children, so make it explicit
			query += " * "
		}else{
			// if you have not provided a terminator, one will be provided for
			// you...
			query += " ";
		}

		var ts = function(/*Integer*/ s, /*Integer*/ e){
			// trim and slice.

			// take an index to start a string slice from and an end position
			// and return a trimmed copy of that sub-string
			return trim(query.slice(s, e));
		}

		// the overall data graph of the full query, as represented by queryPart objects
		var queryParts = [];


		// state keeping vars
		var inBrackets = -1, inParens = -1, inMatchFor = -1,
			inPseudo = -1, inClass = -1, inId = -1, inTag = -1,
			lc = "", cc = "", pStart;

		// iteration vars
		var x = 0, // index in the query
			ql = query.length,
			currentPart = null, // data structure representing the entire clause
			_cp = null; // the current pseudo or attr matcher

		// several temporary variables are assigned to this structure during a
		// potential sub-expression match:
		//		attr:
		//			a string representing the current full attribute match in a
		//			bracket expression
		//		type:
		//			if there's an operator in a bracket expression, this is
		//			used to keep track of it
		//		value:
		//			the internals of parenthetical expression for a pseudo. for
		//			:nth-child(2n+1), value might be "2n+1"

		var endTag = function(){
			// called when the tokenizer hits the end of a particular tag name.
			// Re-sets state variables for tag matching and sets up the matcher
			// to handle the next type of token (tag or operator).
			if(inTag >= 0){
				var tv = (inTag == x) ? null : ts(inTag, x); // .toLowerCase();
				currentPart[ (specials.indexOf(tv) < 0) ? "tag" : "oper" ] = tv;
				inTag = -1;
			}
		}

		var endId = function(){
			// called when the tokenizer might be at the end of an ID portion of a match
			if(inId >= 0){
				currentPart.id = ts(inId, x).replace(/\\/g, "");
				inId = -1;
			}
		}

		var endClass = function(){
			// called when the tokenizer might be at the end of a class name
			// match. CSS allows for multiple classes, so we augment the
			// current item with another class in its list
			if(inClass >= 0){
				currentPart.classes.push(ts(inClass+1, x).replace(/\\/g, ""));
				inClass = -1;
			}
		}

		var endAll = function(){
			// at the end of a simple fragment, so wall off the matches
			endId(); endTag(); endClass();
		}

		var endPart = function(){
			endAll();
			if(inPseudo >= 0){
				currentPart.pseudos.push({ name: ts(inPseudo+1, x) });
			}
			// hint to the selector engine to tell it whether or not it
			// needs to do any iteration. Many simple selectors don't, and
			// we can avoid significant construction-time work by advising
			// the system to skip them
			currentPart.loops = (
					currentPart.pseudos.length ||
					currentPart.attrs.length ||
					currentPart.classes.length	);

			currentPart.oquery = currentPart.query = ts(pStart, x); // save the full expression as a string


			// otag/tag are hints to suggest to the system whether or not
			// it's an operator or a tag. We save a copy of otag since the
			// tag name is cast to upper-case in regular HTML matches. The
			// system has a global switch to figure out if the current
			// expression needs to be case sensitive or not and it will use
			// otag or tag accordingly
			currentPart.otag = currentPart.tag = (currentPart["oper"]) ? null : (currentPart.tag || "*");

			if(currentPart.tag){
				// if we're in a case-insensitive HTML doc, we likely want
				// the toUpperCase when matching on element.tagName. If we
				// do it here, we can skip the string op per node
				// comparison
				currentPart.tag = currentPart.tag.toUpperCase();
			}

			// add the part to the list
			if(queryParts.length && (queryParts[queryParts.length-1].oper)){
				// operators are always infix, so we remove them from the
				// list and attach them to the next match. The evaluator is
				// responsible for sorting out how to handle them.
				currentPart.infixOper = queryParts.pop();
				currentPart.query = currentPart.infixOper.query + " " + currentPart.query;
				/*
				console.debug(	"swapping out the infix",
								currentPart.infixOper,
								"and attaching it to",
								currentPart);
				*/
			}
			queryParts.push(currentPart);

			currentPart = null;
		}

		// iterate over the query, character by character, building up a
		// list of query part objects
		for(; lc=cc, cc=query.charAt(x), x < ql; x++){
			//		cc: the current character in the match
			//		lc: the last character (if any)

			// someone is trying to escape something, so don't try to match any
			// fragments. We assume we're inside a literal.
			if(lc == "\\"){ continue; }
			if(!currentPart){ // a part was just ended or none has yet been created
				// NOTE: I hate all this alloc, but it's shorter than writing tons of if's
				pStart = x;
				//	rules describe full CSS sub-expressions, like:
				//		#someId
				//		.className:first-child
				//	but not:
				//		thinger > div.howdy[type=thinger]
				//	the indidual components of the previous query would be
				//	split into 3 parts that would be represented a structure
				//	like:
				//		[
				//			{
				//				query: "thinger",
				//				tag: "thinger",
				//			},
				//			{
				//				query: "div.howdy[type=thinger]",
				//				classes: ["howdy"],
				//				infixOper: {
				//					query: ">",
				//					oper: ">",
				//				}
				//			},
				//		]
				currentPart = {
					query: null, // the full text of the part's rule
					pseudos: [], // CSS supports multiple pseud-class matches in a single rule
					attrs: [], 	// CSS supports multi-attribute match, so we need an array
					classes: [], // class matches may be additive, e.g.: .thinger.blah.howdy
					tag: null, 	// only one tag...
					oper: null, // ...or operator per component. Note that these wind up being exclusive.
					id: null, 	// the id component of a rule
					getTag: function(){
						return (caseSensitive) ? this.otag : this.tag;
					}
				};

				// if we don't have a part, we assume we're going to start at
				// the beginning of a match, which should be a tag name. This
				// might fault a little later on, but we detect that and this
				// iteration will still be fine.
				inTag = x;
			}

			if(inBrackets >= 0){
				// look for a the close first
				if(cc == "]"){ // if we're in a [...] clause and we end, do assignment
					if(!_cp.attr){
						// no attribute match was previously begun, so we
						// assume this is an attribute existence match in the
						// form of [someAttributeName]
						_cp.attr = ts(inBrackets+1, x);
					}else{
						// we had an attribute already, so we know that we're
						// matching some sort of value, as in [attrName=howdy]
						_cp.matchFor = ts((inMatchFor||inBrackets+1), x);
					}
					var cmf = _cp.matchFor;
					if(cmf){
						// try to strip quotes from the matchFor value. We want
						// [attrName=howdy] to match the same
						//	as [attrName = 'howdy' ]
						if(	(cmf.charAt(0) == '"') || (cmf.charAt(0)  == "'") ){
							_cp.matchFor = cmf.slice(1, -1);
						}
					}
					// end the attribute by adding it to the list of attributes.
					currentPart.attrs.push(_cp);
					_cp = null; // necessary?
					inBrackets = inMatchFor = -1;
				}else if(cc == "="){
					// if the last char was an operator prefix, make sure we
					// record it along with the "=" operator.
					var addToCc = ("|~^$*".indexOf(lc) >=0 ) ? lc : "";
					_cp.type = addToCc+cc;
					_cp.attr = ts(inBrackets+1, x-addToCc.length);
					inMatchFor = x+1;
				}
				// now look for other clause parts
			}else if(inParens >= 0){
				// if we're in a parenthetical expression, we need to figure
				// out if it's attached to a pseudo-selector rule like
				// :nth-child(1)
				if(cc == ")"){
					if(inPseudo >= 0){
						_cp.value = ts(inParens+1, x);
					}
					inPseudo = inParens = -1;
				}
			}else if(cc == "#"){
				// start of an ID match
				endAll();
				inId = x+1;
			}else if(cc == "."){
				// start of a class match
				endAll();
				inClass = x;
			}else if(cc == ":"){
				// start of a pseudo-selector match
				endAll();
				inPseudo = x;
			}else if(cc == "["){
				// start of an attribute match.
				endAll();
				inBrackets = x;
				// provide a new structure for the attribute match to fill-in
				_cp = {
					/*=====
					attr: null, type: null, matchFor: null
					=====*/
				};
			}else if(cc == "("){
				// we really only care if we've entered a parenthetical
				// expression if we're already inside a pseudo-selector match
				if(inPseudo >= 0){
					// provide a new structure for the pseudo match to fill-in
					_cp = {
						name: ts(inPseudo+1, x),
						value: null
					}
					currentPart.pseudos.push(_cp);
				}
				inParens = x;
			}else if(
				(cc == " ") &&
				// if it's a space char and the last char is too, consume the
				// current one without doing more work
				(lc != cc)
			){
				endPart();
			}
		}
		return queryParts;
	};
	

	////////////////////////////////////////////////////////////////////////
	// DOM query infrastructure
	////////////////////////////////////////////////////////////////////////

	var agree = function(first, second){
		// the basic building block of the yes/no chaining system. agree(f1,
		// f2) generates a new function which returns the boolean results of
		// both of the passed functions to a single logical-anded result. If
		// either are not passed, the other is used exclusively.
		if(!first){ return second; }
		if(!second){ return first; }

		return function(){
			return first.apply(window, arguments) && second.apply(window, arguments);
		}
	};

	var getArr = function(i, arr){
		// helps us avoid array alloc when we don't need it
		var r = arr||[]; // FIXME: should this be 'new d._NodeListCtor()' ?
		if(i){ r.push(i); }
		return r;
	};

	var _isElement = function(n){ return (1 == n.nodeType); };

	// FIXME: need to coalesce _getAttr with defaultGetter
	var blank = "";
	var _getAttr = function(elem, attr){
		if(!elem){ return blank; }
		if(attr == "class"){
			return elem.className || blank;
		}
		if(attr == "for"){
			return elem.htmlFor || blank;
		}
		if(attr == "style"){
			return elem.style.cssText || blank;
		}
		return (caseSensitive ? elem.getAttribute(attr) : elem.getAttribute(attr, 2)) || blank;
	};

	var attrs = {
		"*=": function(attr, value){
			return function(elem){
				// E[foo*="bar"]
				//		an E element whose "foo" attribute value contains
				//		the substring "bar"
				return (_getAttr(elem, attr).indexOf(value)>=0);
			}
		},
		"^=": function(attr, value){
			// E[foo^="bar"]
			//		an E element whose "foo" attribute value begins exactly
			//		with the string "bar"
			return function(elem){
				return (_getAttr(elem, attr).indexOf(value)==0);
			}
		},
		"$=": function(attr, value){
			// E[foo$="bar"]
			//		an E element whose "foo" attribute value ends exactly
			//		with the string "bar"
			var tval = " "+value;
			return function(elem){
				var ea = " "+_getAttr(elem, attr);
				return (ea.lastIndexOf(value)==(ea.length-value.length));
			}
		},
		"~=": function(attr, value){
			// E[foo~="bar"]
			//		an E element whose "foo" attribute value is a list of
			//		space-separated values, one of which is exactly equal
			//		to "bar"

			// return "[contains(concat(' ',@"+attr+",' '), ' "+ value +" ')]";
			var tval = " "+value+" ";
			return function(elem){
				var ea = " "+_getAttr(elem, attr)+" ";
				return (ea.indexOf(tval)>=0);
			}
		},
		"|=": function(attr, value){
			// E[hreflang|="en"]
			//		an E element whose "hreflang" attribute has a
			//		hyphen-separated list of values beginning (from the
			//		left) with "en"
			var valueDash = " "+value+"-";
			return function(elem){
				var ea = " "+_getAttr(elem, attr);
				return (
					(ea == value) ||
					(ea.indexOf(valueDash)==0)
				);
			}
		},
		"=": function(attr, value){
			return function(elem){
				return (_getAttr(elem, attr) == value);
			}
		}
	};

	// avoid testing for node type if we can. Defining this in the negative
	// here to avoid negation in the fast path.
	var _noNES = (typeof getDoc().firstChild.nextElementSibling == "undefined");
	var _ns = !_noNES ? "nextElementSibling" : "nextSibling";
	var _ps = !_noNES ? "previousElementSibling" : "previousSibling";
	var _simpleNodeTest = (_noNES ? _isElement : yesman);

	var _lookLeft = function(node){
		// look left
		while(node = node[_ps]){
			if(_simpleNodeTest(node)){ return false; }
		}
		return true;
	};

	var _lookRight = function(node){
		// look right
		while(node = node[_ns]){
			if(_simpleNodeTest(node)){ return false; }
		}
		return true;
	};

	var getNodeIndex = function(node){
		var root = node.parentNode;
		var i = 0,
			tret = root[childNodesName],
			ci = (node["_i"]||-1),
			cl = (root["_l"]||-1);

		if(!tret){ return -1; }
		var l = tret.length;

		// we calculate the parent length as a cheap way to invalidate the
		// cache. It's not 100% accurate, but it's much more honest than what
		// other libraries do
		if( cl == l && ci >= 0 && cl >= 0 ){
			// if it's legit, tag and release
			return ci;
		}

		// else re-key things
		root["_l"] = l;
		ci = -1;
		for(var te = root["firstElementChild"]||root["firstChild"]; te; te = te[_ns]){
			if(_simpleNodeTest(te)){
				te["_i"] = ++i;
				if(node === te){
					// NOTE:
					// 	shortcutting the return at this step in indexing works
					// 	very well for benchmarking but we avoid it here since
					// 	it leads to potential O(n^2) behavior in sequential
					// 	getNodexIndex operations on a previously un-indexed
					// 	parent. We may revisit this at a later time, but for
					// 	now we just want to get the right answer more often
					// 	than not.
					ci = i;
				}
			}
		}
		return ci;
	};

	var isEven = function(elem){
		return !((getNodeIndex(elem)) % 2);
	};

	var isOdd = function(elem){
		return ((getNodeIndex(elem)) % 2);
	};

	var pseudos = {
		"checked": function(name, condition){
			return function(elem){
				return !!("checked" in elem ? elem.checked : elem.selected);
			}
		},
		"first-child": function(){ return _lookLeft; },
		"last-child": function(){ return _lookRight; },
		"only-child": function(name, condition){
			return function(node){
				if(!_lookLeft(node)){ return false; }
				if(!_lookRight(node)){ return false; }
				return true;
			};
		},
		"empty": function(name, condition){
			return function(elem){
				// DomQuery and jQuery get this wrong, oddly enough.
				// The CSS 3 selectors spec is pretty explicit about it, too.
				var cn = elem.childNodes;
				var cnl = elem.childNodes.length;
				// if(!cnl){ return true; }
				for(var x=cnl-1; x >= 0; x--){
					var nt = cn[x].nodeType;
					if((nt === 1)||(nt == 3)){ return false; }
				}
				return true;
			}
		},
		"contains": function(name, condition){
			var cz = condition.charAt(0);
			if( cz == '"' || cz == "'" ){ //remove quote
				condition = condition.slice(1, -1);
			}
			return function(elem){
				return (elem.innerHTML.indexOf(condition) >= 0);
			}
		},
		"not": function(name, condition){
			var p = getQueryParts(condition)[0];
			var ignores = { el: 1 };
			if(p.tag != "*"){
				ignores.tag = 1;
			}
			if(!p.classes.length){
				ignores.classes = 1;
			}
			var ntf = getSimpleFilterFunc(p, ignores);
			return function(elem){
				return (!ntf(elem));
			}
		},
		"nth-child": function(name, condition){
			var pi = parseInt;
			// avoid re-defining function objects if we can
			if(condition == "odd"){
				return isOdd;
			}else if(condition == "even"){
				return isEven;
			}
			// FIXME: can we shorten this?
			if(condition.indexOf("n") != -1){
				var tparts = condition.split("n", 2);
				var pred = tparts[0] ? ((tparts[0] == '-') ? -1 : pi(tparts[0])) : 1;
				var idx = tparts[1] ? pi(tparts[1]) : 0;
				var lb = 0, ub = -1;
				if(pred > 0){
					if(idx < 0){
						idx = (idx % pred) && (pred + (idx % pred));
					}else if(idx>0){
						if(idx >= pred){
							lb = idx - idx % pred;
						}
						idx = idx % pred;
					}
				}else if(pred<0){
					pred *= -1;
					// idx has to be greater than 0 when pred is negative;
					// shall we throw an error here?
					if(idx > 0){
						ub = idx;
						idx = idx % pred;
					}
				}
				if(pred > 0){
					return function(elem){
						var i = getNodeIndex(elem);
						return (i>=lb) && (ub<0 || i<=ub) && ((i % pred) == idx);
					}
				}else{
					condition = idx;
				}
			}
			var ncount = pi(condition);
			return function(elem){
				return (getNodeIndex(elem) == ncount);
			}
		}
	};

	var defaultGetter = (d.isIE < 9 || (dojo.isIE && dojo.isQuirks)) ? function(cond){
		var clc = cond.toLowerCase();
		if(clc == "class"){ cond = "className"; }
		return function(elem){
			return (caseSensitive ? elem.getAttribute(cond) : elem[cond]||elem[clc]);
		}
	} : function(cond){
		return function(elem){
			return (elem && elem.getAttribute && elem.hasAttribute(cond));
		}
	};

	var getSimpleFilterFunc = function(query, ignores){
		// generates a node tester function based on the passed query part. The
		// query part is one of the structures generated by the query parser
		// when it creates the query AST. The "ignores" object specifies which
		// (if any) tests to skip, allowing the system to avoid duplicating
		// work where it may have already been taken into account by other
		// factors such as how the nodes to test were fetched in the first
		// place
		if(!query){ return yesman; }
		ignores = ignores||{};

		var ff = null;

		if(!("el" in ignores)){
			ff = agree(ff, _isElement);
		}

		if(!("tag" in ignores)){
			if(query.tag != "*"){
				ff = agree(ff, function(elem){
					return (elem && (elem.tagName == query.getTag()));
				});
			}
		}

		if(!("classes" in ignores)){
			each(query.classes, function(cname, idx, arr){
				// get the class name
				/*
				var isWildcard = cname.charAt(cname.length-1) == "*";
				if(isWildcard){
					cname = cname.substr(0, cname.length-1);
				}
				// I dislike the regex thing, even if memoized in a cache, but it's VERY short
				var re = new RegExp("(?:^|\\s)" + cname + (isWildcard ? ".*" : "") + "(?:\\s|$)");
				*/
				var re = new RegExp("(?:^|\\s)" + cname + "(?:\\s|$)");
				ff = agree(ff, function(elem){
					return re.test(elem.className);
				});
				ff.count = idx;
			});
		}

		if(!("pseudos" in ignores)){
			each(query.pseudos, function(pseudo){
				var pn = pseudo.name;
				if(pseudos[pn]){
					ff = agree(ff, pseudos[pn](pn, pseudo.value));
				}
			});
		}

		if(!("attrs" in ignores)){
			each(query.attrs, function(attr){
				var matcher;
				var a = attr.attr;
				// type, attr, matchFor
				if(attr.type && attrs[attr.type]){
					matcher = attrs[attr.type](a, attr.matchFor);
				}else if(a.length){
					matcher = defaultGetter(a);
				}
				if(matcher){
					ff = agree(ff, matcher);
				}
			});
		}

		if(!("id" in ignores)){
			if(query.id){
				ff = agree(ff, function(elem){
					return (!!elem && (elem.id == query.id));
				});
			}
		}

		if(!ff){
			if(!("default" in ignores)){
				ff = yesman;
			}
		}
		return ff;
	};

	var _nextSibling = function(filterFunc){
		return function(node, ret, bag){
			while(node = node[_ns]){
				if(_noNES && (!_isElement(node))){ continue; }
				if(
					(!bag || _isUnique(node, bag)) &&
					filterFunc(node)
				){
					ret.push(node);
				}
				break;
			}
			return ret;
		}
	};

	var _nextSiblings = function(filterFunc){
		return function(root, ret, bag){
			var te = root[_ns];
			while(te){
				if(_simpleNodeTest(te)){
					if(bag && !_isUnique(te, bag)){
						break;
					}
					if(filterFunc(te)){
						ret.push(te);
					}
				}
				te = te[_ns];
			}
			return ret;
		}
	};

	// get an array of child *elements*, skipping text and comment nodes
	var _childElements = function(filterFunc){
		filterFunc = filterFunc||yesman;
		return function(root, ret, bag){
			// get an array of child elements, skipping text and comment nodes
			var te, x = 0, tret = root[childNodesName];
			while(te = tret[x++]){
				if(
					_simpleNodeTest(te) &&
					(!bag || _isUnique(te, bag)) &&
					(filterFunc(te, x))
				){
					ret.push(te);
				}
			}
			return ret;
		};
	};
	
	/*
	// thanks, Dean!
	var itemIsAfterRoot = d.isIE ? function(item, root){
		return (item.sourceIndex > root.sourceIndex);
	} : function(item, root){
		return (item.compareDocumentPosition(root) == 2);
	};
	*/

	// test to see if node is below root
	var _isDescendant = function(node, root){
		var pn = node.parentNode;
		while(pn){
			if(pn == root){
				break;
			}
			pn = pn.parentNode;
		}
		return !!pn;
	};

	var _getElementsFuncCache = {};

	var getElementsFunc = function(query){
		var retFunc = _getElementsFuncCache[query.query];
		// if we've got a cached dispatcher, just use that
		if(retFunc){ return retFunc; }
		// else, generate a new on

		// NOTE:
		//		this function returns a function that searches for nodes and
		//		filters them.  The search may be specialized by infix operators
		//		(">", "~", or "+") else it will default to searching all
		//		descendants (the " " selector). Once a group of children is
		//		found, a test function is applied to weed out the ones we
		//		don't want. Many common cases can be fast-pathed. We spend a
		//		lot of cycles to create a dispatcher that doesn't do more work
		//		than necessary at any point since, unlike this function, the
		//		dispatchers will be called every time. The logic of generating
		//		efficient dispatchers looks like this in pseudo code:
		//
		//		# if it's a purely descendant query (no ">", "+", or "~" modifiers)
		//		if infixOperator == " ":
		//			if only(id):
		//				return def(root):
		//					return d.byId(id, root);
		//
		//			elif id:
		//				return def(root):
		//					return filter(d.byId(id, root));
		//
		//			elif cssClass && getElementsByClassName:
		//				return def(root):
		//					return filter(root.getElementsByClassName(cssClass));
		//
		//			elif only(tag):
		//				return def(root):
		//					return root.getElementsByTagName(tagName);
		//
		//			else:
		//				# search by tag name, then filter
		//				return def(root):
		//					return filter(root.getElementsByTagName(tagName||"*"));
		//
		//		elif infixOperator == ">":
		//			# search direct children
		//			return def(root):
		//				return filter(root.children);
		//
		//		elif infixOperator == "+":
		//			# search next sibling
		//			return def(root):
		//				return filter(root.nextElementSibling);
		//
		//		elif infixOperator == "~":
		//			# search rightward siblings
		//			return def(root):
		//				return filter(nextSiblings(root));

		var io = query.infixOper;
		var oper = (io ? io.oper : "");
		// the default filter func which tests for all conditions in the query
		// part. This is potentially inefficient, so some optimized paths may
		// re-define it to test fewer things.
		var filterFunc = getSimpleFilterFunc(query, { el: 1 });
		var qt = query.tag;
		var wildcardTag = ("*" == qt);
		var ecs = getDoc()["getElementsByClassName"];

		if(!oper){
			// if there's no infix operator, then it's a descendant query. ID
			// and "elements by class name" variants can be accelerated so we
			// call them out explicitly:
			if(query.id){
				// testing shows that the overhead of yesman() is acceptable
				// and can save us some bytes vs. re-defining the function
				// everywhere.
				filterFunc = (!query.loops && wildcardTag) ?
					yesman :
					getSimpleFilterFunc(query, { el: 1, id: 1 });

				retFunc = function(root, arr){
					var te = d.byId(query.id, (root.ownerDocument||root));
					if(!te || !filterFunc(te)){ return; }
					if(9 == root.nodeType){ // if root's a doc, we just return directly
						return getArr(te, arr);
					}else{ // otherwise check ancestry
						if(_isDescendant(te, root)){
							return getArr(te, arr);
						}
					}
				}
			}else if(
				ecs &&
				// isAlien check. Workaround for Prototype.js being totally evil/dumb.
				/\{\s*\[native code\]\s*\}/.test(String(ecs)) &&
				query.classes.length &&
				!cssCaseBug
			){
				// it's a class-based query and we've got a fast way to run it.

				// ignore class and ID filters since we will have handled both
				filterFunc = getSimpleFilterFunc(query, { el: 1, classes: 1, id: 1 });
				var classesString = query.classes.join(" ");
				retFunc = function(root, arr, bag){
					var ret = getArr(0, arr), te, x=0;
					var tret = root.getElementsByClassName(classesString);
					while((te = tret[x++])){
						if(filterFunc(te, root) && _isUnique(te, bag)){
							ret.push(te);
						}
					}
					return ret;
				};

			}else if(!wildcardTag && !query.loops){
				// it's tag only. Fast-path it.
				retFunc = function(root, arr, bag){
					var ret = getArr(0, arr), te, x=0;
					var tret = root.getElementsByTagName(query.getTag());
					while((te = tret[x++])){
						if(_isUnique(te, bag)){
							ret.push(te);
						}
					}
					return ret;
				};
			}else{
				// the common case:
				//		a descendant selector without a fast path. By now it's got
				//		to have a tag selector, even if it's just "*" so we query
				//		by that and filter
				filterFunc = getSimpleFilterFunc(query, { el: 1, tag: 1, id: 1 });
				retFunc = function(root, arr, bag){
					var ret = getArr(0, arr), te, x=0;
					// we use getTag() to avoid case sensitivity issues
					var tret = root.getElementsByTagName(query.getTag());
					while((te = tret[x++])){
						if(filterFunc(te, root) && _isUnique(te, bag)){
							ret.push(te);
						}
					}
					return ret;
				};
			}
		}else{
			// the query is scoped in some way. Instead of querying by tag we
			// use some other collection to find candidate nodes
			var skipFilters = { el: 1 };
			if(wildcardTag){
				skipFilters.tag = 1;
			}
			filterFunc = getSimpleFilterFunc(query, skipFilters);
			if("+" == oper){
				retFunc = _nextSibling(filterFunc);
			}else if("~" == oper){
				retFunc = _nextSiblings(filterFunc);
			}else if(">" == oper){
				retFunc = _childElements(filterFunc);
			}
		}
		// cache it and return
		return _getElementsFuncCache[query.query] = retFunc;
	};

	var filterDown = function(root, queryParts){
		// NOTE:
		//		this is the guts of the DOM query system. It takes a list of
		//		parsed query parts and a root and finds children which match
		//		the selector represented by the parts
		var candidates = getArr(root), qp, x, te, qpl = queryParts.length, bag, ret;

		for(var i = 0; i < qpl; i++){
			ret = [];
			qp = queryParts[i];
			x = candidates.length - 1;
			if(x > 0){
				// if we have more than one root at this level, provide a new
				// hash to use for checking group membership but tell the
				// system not to post-filter us since we will already have been
				// gauranteed to be unique
				bag = {};
				ret.nozip = true;
			}
			var gef = getElementsFunc(qp);
			for(var j = 0; (te = candidates[j]); j++){
				// for every root, get the elements that match the descendant
				// selector, adding them to the "ret" array and filtering them
				// via membership in this level's bag. If there are more query
				// parts, then this level's return will be used as the next
				// level's candidates
				gef(te, ret, bag);
			}
			if(!ret.length){ break; }
			candidates = ret;
		}
		return ret;
	};

	////////////////////////////////////////////////////////////////////////
	// the query runner
	////////////////////////////////////////////////////////////////////////

	// these are the primary caches for full-query results. The query
	// dispatcher functions are generated then stored here for hash lookup in
	// the future
	var _queryFuncCacheDOM = {},
		_queryFuncCacheQSA = {};

	// this is the second level of spliting, from full-length queries (e.g.,
	// "div.foo .bar") into simple query expressions (e.g., ["div.foo",
	// ".bar"])
	var getStepQueryFunc = function(query){
		var qparts = getQueryParts(trim(query));

		// if it's trivial, avoid iteration and zipping costs
		if(qparts.length == 1){
			// we optimize this case here to prevent dispatch further down the
			// chain, potentially slowing things down. We could more elegantly
			// handle this in filterDown(), but it's slower for simple things
			// that need to be fast (e.g., "#someId").
			var tef = getElementsFunc(qparts[0]);
			return function(root){
				var r = tef(root, new qlc());
				if(r){ r.nozip = true; }
				return r;
			}
		}

		// otherwise, break it up and return a runner that iterates over the parts recursively
		return function(root){
			return filterDown(root, qparts);
		}
	};

	// NOTES:
	//	* we can't trust QSA for anything but document-rooted queries, so
	//	  caching is split into DOM query evaluators and QSA query evaluators
	//	* caching query results is dirty and leak-prone (or, at a minimum,
	//	  prone to unbounded growth). Other toolkits may go this route, but
	//	  they totally destroy their own ability to manage their memory
	//	  footprint. If we implement it, it should only ever be with a fixed
	//	  total element reference # limit and an LRU-style algorithm since JS
	//	  has no weakref support. Caching compiled query evaluators is also
	//	  potentially problematic, but even on large documents the size of the
	//	  query evaluators is often < 100 function objects per evaluator (and
	//	  LRU can be applied if it's ever shown to be an issue).
	//	* since IE's QSA support is currently only for HTML documents and even
	//	  then only in IE 8's "standards mode", we have to detect our dispatch
	//	  route at query time and keep 2 separate caches. Ugg.

	// we need to determine if we think we can run a given query via
	// querySelectorAll or if we'll need to fall back on DOM queries to get
	// there. We need a lot of information about the environment and the query
	// to make the determiniation (e.g. does it support QSA, does the query in
	// question work in the native QSA impl, etc.).
	var nua = navigator.userAgent;
	// some versions of Safari provided QSA, but it was buggy and crash-prone.
	// We need te detect the right "internal" webkit version to make this work.
	var wk = "WebKit/";
	var is525 = (
		d.isWebKit &&
		(nua.indexOf(wk) > 0) &&
		(parseFloat(nua.split(wk)[1]) > 528)
	);

	// IE QSA queries may incorrectly include comment nodes, so we throw the
	// zipping function into "remove" comments mode instead of the normal "skip
	// it" which every other QSA-clued browser enjoys
	var noZip = d.isIE ? "commentStrip" : "nozip";

	var qsa = "querySelectorAll";
	var qsaAvail = (
		!!getDoc()[qsa] &&
		// see #5832
		(!d.isSafari || (d.isSafari > 3.1) || is525 )
	);

	//Don't bother with n+3 type of matches, IE complains if we modify those.
	var infixSpaceRe = /n\+\d|([^ ])?([>~+])([^ =])?/g;
	var infixSpaceFunc = function(match, pre, ch, post) {
		return ch ? (pre ? pre + " " : "") + ch + (post ? " " + post : "") : /*n+3*/ match;
	};

	var getQueryFunc = function(query, forceDOM){
		//Normalize query. The CSS3 selectors spec allows for omitting spaces around
		//infix operators, >, ~ and +
		//Do the work here since detection for spaces is used as a simple "not use QSA"
		//test below.
		query = query.replace(infixSpaceRe, infixSpaceFunc);

		if(qsaAvail){
			// if we've got a cached variant and we think we can do it, run it!
			var qsaCached = _queryFuncCacheQSA[query];
			if(qsaCached && !forceDOM){ return qsaCached; }
		}

		// else if we've got a DOM cached variant, assume that we already know
		// all we need to and use it
		var domCached = _queryFuncCacheDOM[query];
		if(domCached){ return domCached; }

		// TODO:
		//		today we're caching DOM and QSA branches separately so we
		//		recalc useQSA every time. If we had a way to tag root+query
		//		efficiently, we'd be in good shape to do a global cache.

		var qcz = query.charAt(0);
		var nospace = (-1 == query.indexOf(" "));

		// byId searches are wicked fast compared to QSA, even when filtering
		// is required
		if( (query.indexOf("#") >= 0) && (nospace) ){
			forceDOM = true;
		}

		var useQSA = (
			qsaAvail && (!forceDOM) &&
			// as per CSS 3, we can't currently start w/ combinator:
			//		http://www.w3.org/TR/css3-selectors/#w3cselgrammar
			(specials.indexOf(qcz) == -1) &&
			// IE's QSA impl sucks on pseudos
			(!d.isIE || (query.indexOf(":") == -1)) &&

			(!(cssCaseBug && (query.indexOf(".") >= 0))) &&

			// FIXME:
			//		need to tighten up browser rules on ":contains" and "|=" to
			//		figure out which aren't good
			//		Latest webkit (around 531.21.8) does not seem to do well with :checked on option
			//		elements, even though according to spec, selected options should
			//		match :checked. So go nonQSA for it:
			//		http://bugs.dojotoolkit.org/ticket/5179
			(query.indexOf(":contains") == -1) && (query.indexOf(":checked") == -1) &&
			(query.indexOf("|=") == -1) // some browsers don't grok it
		);

		// TODO:
		//		if we've got a descendant query (e.g., "> .thinger" instead of
		//		just ".thinger") in a QSA-able doc, but are passed a child as a
		//		root, it should be possible to give the item a synthetic ID and
		//		trivially rewrite the query to the form "#synid > .thinger" to
		//		use the QSA branch


		if(useQSA){
			var tq = (specials.indexOf(query.charAt(query.length-1)) >= 0) ?
						(query + " *") : query;
			return _queryFuncCacheQSA[query] = function(root){
				try{
					// the QSA system contains an egregious spec bug which
					// limits us, effectively, to only running QSA queries over
					// entire documents.  See:
					//		http://ejohn.org/blog/thoughts-on-queryselectorall/
					//	despite this, we can also handle QSA runs on simple
					//	selectors, but we don't want detection to be expensive
					//	so we're just checking for the presence of a space char
					//	right now. Not elegant, but it's cheaper than running
					//	the query parser when we might not need to
					if(!((9 == root.nodeType) || nospace)){ throw ""; }
					var r = root[qsa](tq);
					// skip expensive duplication checks and just wrap in a NodeList
					r[noZip] = true;
					return r;
				}catch(e){
					// else run the DOM branch on this query, ensuring that we
					// default that way in the future
					return getQueryFunc(query, true)(root);
				}
			}
		}else{
			// DOM branch
			var parts = query.split(/\s*,\s*/);
			return _queryFuncCacheDOM[query] = ((parts.length < 2) ?
				// if not a compound query (e.g., ".foo, .bar"), cache and return a dispatcher
				getStepQueryFunc(query) :
				// if it *is* a complex query, break it up into its
				// constituent parts and return a dispatcher that will
				// merge the parts when run
				function(root){
					var pindex = 0, // avoid array alloc for every invocation
						ret = [],
						tp;
					while((tp = parts[pindex++])){
						ret = ret.concat(getStepQueryFunc(tp)(root));
					}
					return ret;
				}
			);
		}
	};

	var _zipIdx = 0;

	// NOTE:
	//		this function is Moo inspired, but our own impl to deal correctly
	//		with XML in IE
	var _nodeUID = d.isIE ? function(node){
		if(caseSensitive){
			// XML docs don't have uniqueID on their nodes
			return (node.getAttribute("_uid") || node.setAttribute("_uid", ++_zipIdx) || _zipIdx);

		}else{
			return node.uniqueID;
		}
	} :
	function(node){
		return (node._uid || (node._uid = ++_zipIdx));
	};

	// determine if a node in is unique in a "bag". In this case we don't want
	// to flatten a list of unique items, but rather just tell if the item in
	// question is already in the bag. Normally we'd just use hash lookup to do
	// this for us but IE's DOM is busted so we can't really count on that. On
	// the upside, it gives us a built in unique ID function.
	var _isUnique = function(node, bag){
		if(!bag){ return 1; }
		var id = _nodeUID(node);
		if(!bag[id]){ return bag[id] = 1; }
		return 0;
	};

	// attempt to efficiently determine if an item in a list is a dupe,
	// returning a list of "uniques", hopefully in doucment order
	var _zipIdxName = "_zipIdx";
	var _zip = function(arr){
		if(arr && arr.nozip){
			return (qlc._wrap) ? qlc._wrap(arr) : arr;
		}
		// var ret = new d._NodeListCtor();
		var ret = new qlc();
		if(!arr || !arr.length){ return ret; }
		if(arr[0]){
			ret.push(arr[0]);
		}
		if(arr.length < 2){ return ret; }

		_zipIdx++;
		
		// we have to fork here for IE and XML docs because we can't set
		// expandos on their nodes (apparently). *sigh*
		if(d.isIE && caseSensitive){
			var szidx = _zipIdx+"";
			arr[0].setAttribute(_zipIdxName, szidx);
			for(var x = 1, te; te = arr[x]; x++){
				if(arr[x].getAttribute(_zipIdxName) != szidx){
					ret.push(te);
				}
				te.setAttribute(_zipIdxName, szidx);
			}
		}else if(d.isIE && arr.commentStrip){
			try{
				for(var x = 1, te; te = arr[x]; x++){
					if(_isElement(te)){
						ret.push(te);
					}
				}
			}catch(e){ /* squelch */ }
		}else{
			if(arr[0]){ arr[0][_zipIdxName] = _zipIdx; }
			for(var x = 1, te; te = arr[x]; x++){
				if(arr[x][_zipIdxName] != _zipIdx){
					ret.push(te);
				}
				te[_zipIdxName] = _zipIdx;
			}
		}
		return ret;
	};

	// the main executor
	d.query = function(/*String*/ query, /*String|DOMNode?*/ root){
		//	summary:
		//		Returns nodes which match the given CSS3 selector, searching the
		//		entire document by default but optionally taking a node to scope
		//		the search by. Returns an instance of dojo.NodeList.
		//	description:
		//		dojo.query() is the swiss army knife of DOM node manipulation in
		//		Dojo. Much like Prototype's "$$" (bling-bling) function or JQuery's
		//		"$" function, dojo.query provides robust, high-performance
		//		CSS-based node selector support with the option of scoping searches
		//		to a particular sub-tree of a document.
		//
		//		Supported Selectors:
		//		--------------------
		//
		//		dojo.query() supports a rich set of CSS3 selectors, including:
		//
		//			* class selectors (e.g., `.foo`)
		//			* node type selectors like `span`
		//			* ` ` descendant selectors
		//			* `>` child element selectors
		//			* `#foo` style ID selectors
		//			* `*` universal selector
		//			* `~`, the preceded-by sibling selector
		//			* `+`, the immediately preceded-by sibling selector
		//			* attribute queries:
		//			|	* `[foo]` attribute presence selector
		//			|	* `[foo='bar']` attribute value exact match
		//			|	* `[foo~='bar']` attribute value list item match
		//			|	* `[foo^='bar']` attribute start match
		//			|	* `[foo$='bar']` attribute end match
		//			|	* `[foo*='bar']` attribute substring match
		//			* `:first-child`, `:last-child`, and `:only-child` positional selectors
		//			* `:empty` content emtpy selector
		//			* `:checked` pseudo selector
		//			* `:nth-child(n)`, `:nth-child(2n+1)` style positional calculations
		//			* `:nth-child(even)`, `:nth-child(odd)` positional selectors
		//			* `:not(...)` negation pseudo selectors
		//
		//		Any legal combination of these selectors will work with
		//		`dojo.query()`, including compound selectors ("," delimited).
		//		Very complex and useful searches can be constructed with this
		//		palette of selectors and when combined with functions for
		//		manipulation presented by dojo.NodeList, many types of DOM
		//		manipulation operations become very straightforward.
		//
		//		Unsupported Selectors:
		//		----------------------
		//
		//		While dojo.query handles many CSS3 selectors, some fall outside of
		//		what's reasonable for a programmatic node querying engine to
		//		handle. Currently unsupported selectors include:
		//
		//			* namespace-differentiated selectors of any form
		//			* all `::` pseduo-element selectors
		//			* certain pseduo-selectors which don't get a lot of day-to-day use:
		//			|	* `:root`, `:lang()`, `:target`, `:focus`
		//			* all visual and state selectors:
		//			|	* `:root`, `:active`, `:hover`, `:visisted`, `:link`,
		//				  `:enabled`, `:disabled`
		//			* `:*-of-type` pseudo selectors
		//
		//		dojo.query and XML Documents:
		//		-----------------------------
		//
		//		`dojo.query` (as of dojo 1.2) supports searching XML documents
		//		in a case-sensitive manner. If an HTML document is served with
		//		a doctype that forces case-sensitivity (e.g., XHTML 1.1
		//		Strict), dojo.query() will detect this and "do the right
		//		thing". Case sensitivity is dependent upon the document being
		//		searched and not the query used. It is therefore possible to
		//		use case-sensitive queries on strict sub-documents (iframes,
		//		etc.) or XML documents while still assuming case-insensitivity
		//		for a host/root document.
		//
		//		Non-selector Queries:
		//		---------------------
		//
		//		If something other than a String is passed for the query,
		//		`dojo.query` will return a new `dojo.NodeList` instance
		//		constructed from that parameter alone and all further
		//		processing will stop. This means that if you have a reference
		//		to a node or NodeList, you can quickly construct a new NodeList
		//		from the original by calling `dojo.query(node)` or
		//		`dojo.query(list)`.
		//
		//	query:
		//		The CSS3 expression to match against. For details on the syntax of
		//		CSS3 selectors, see <http://www.w3.org/TR/css3-selectors/#selectors>
		//	root:
		//		A DOMNode (or node id) to scope the search from. Optional.
		//	returns: dojo.NodeList
		//		An instance of `dojo.NodeList`. Many methods are available on
		//		NodeLists for searching, iterating, manipulating, and handling
		//		events on the matched nodes in the returned list.
		//	example:
		//		search the entire document for elements with the class "foo":
		//	|	dojo.query(".foo");
		//		these elements will match:
		//	|	<span class="foo"></span>
		//	|	<span class="foo bar"></span>
		//	|	<p class="thud foo"></p>
		//	example:
		//		search the entire document for elements with the classes "foo" *and* "bar":
		//	|	dojo.query(".foo.bar");
		//		these elements will match:
		//	|	<span class="foo bar"></span>
		//		while these will not:
		//	|	<span class="foo"></span>
		//	|	<p class="thud foo"></p>
		//	example:
		//		find `<span>` elements which are descendants of paragraphs and
		//		which have a "highlighted" class:
		//	|	dojo.query("p span.highlighted");
		//		the innermost span in this fragment matches:
		//	|	<p class="foo">
		//	|		<span>...
		//	|			<span class="highlighted foo bar">...</span>
		//	|		</span>
		//	|	</p>
		//	example:
		//		set an "odd" class on all odd table rows inside of the table
		//		`#tabular_data`, using the `>` (direct child) selector to avoid
		//		affecting any nested tables:
		//	|	dojo.query("#tabular_data > tbody > tr:nth-child(odd)").addClass("odd");
		//	example:
		//		remove all elements with the class "error" from the document
		//		and store them in a list:
		//	|	var errors = dojo.query(".error").orphan();
		//	example:
		//		add an onclick handler to every submit button in the document
		//		which causes the form to be sent via Ajax instead:
		//	|	dojo.query("input[type='submit']").onclick(function(e){
		//	|		dojo.stopEvent(e); // prevent sending the form
		//	|		var btn = e.target;
		//	|		dojo.xhrPost({
		//	|			form: btn.form,
		//	|			load: function(data){
		//	|				// replace the form with the response
		//	|				var div = dojo.doc.createElement("div");
		//	|				dojo.place(div, btn.form, "after");
		//	|				div.innerHTML = data;
		//	|				dojo.style(btn.form, "display", "none");
		//	|			}
		//	|		});
		//	|	});

		//Set list constructor to desired value. This can change
		//between calls, so always re-assign here.
		qlc = d._NodeListCtor;

		if(!query){
			return new qlc();
		}

		if(query.constructor == qlc){
			return query;
		}
		if(typeof query != "string"){ // inline'd type check
			return new qlc(query); // dojo.NodeList
		}
		if(typeof root == "string"){ // inline'd type check
			root = d.byId(root);
			if(!root){ return new qlc(); }
		}

		root = root||getDoc();
		var od = root.ownerDocument||root.documentElement;

		// throw the big case sensitivity switch

		// NOTE:
		// 		Opera in XHTML mode doesn't detect case-sensitivity correctly
		// 		and it's not clear that there's any way to test for it
		caseSensitive = (root.contentType && root.contentType=="application/xml") ||
						(d.isOpera && (root.doctype || od.toString() == "[object XMLDocument]")) ||
						(!!od) &&
						(d.isIE ? od.xml : (root.xmlVersion||od.xmlVersion));

		// NOTE:
		//		adding "true" as the 2nd argument to getQueryFunc is useful for
		//		testing the DOM branch without worrying about the
		//		behavior/performance of the QSA branch.
		var r = getQueryFunc(query)(root);

		// FIXME:
		//		need to investigate this branch WRT #8074 and #8075
		if(r && r.nozip && !qlc._wrap){
			return r;
		}
		return _zip(r); // dojo.NodeList
	}

	// FIXME: need to add infrastructure for post-filtering pseudos, ala :last
	d.query.pseudos = pseudos;

	// function for filtering a NodeList based on a selector, optimized for simple selectors
	d._filterQueryResult = function(/*NodeList*/ nodeList, /*String*/ filter, /*String|DOMNode?*/ root){
		var tmpNodeList = new d._NodeListCtor(),
			parts = getQueryParts(filter),
			filterFunc =
				(parts.length == 1 && !/[^\w#\.]/.test(filter)) ?
				getSimpleFilterFunc(parts[0]) :
				function(node) {
					return dojo.query(filter, root).indexOf(node) != -1;
				};
		for(var x = 0, te; te = nodeList[x]; x++){
			if(filterFunc(te)){ tmpNodeList.push(te); }
		}
		return tmpNodeList;
	}
};//end defineQuery

var defineAcme= function(){
	// a self-sufficient query impl
	acme = {
		trim: function(/*String*/ str){
			// summary:
			//		trims whitespaces from both sides of the string
			str = str.replace(/^\s+/, '');
			for(var i = str.length - 1; i >= 0; i--){
				if(/\S/.test(str.charAt(i))){
					str = str.substring(0, i + 1);
					break;
				}
			}
			return str;	// String
		},
		forEach: function(/*String*/ arr, /*Function*/ callback, /*Object?*/ thisObject){
			//	summary:
			// 		an iterator function that passes items, indexes,
			// 		and the array to a callback
			if(!arr || !arr.length){ return; }
			for(var i=0,l=arr.length; i<l; ++i){
				callback.call(thisObject||window, arr[i], i, arr);
			}
		},
		byId: function(id, doc){
			// 	summary:
			//		a function that return an element by ID, but also
			//		accepts nodes safely
			if(typeof id == "string"){
				return (doc||document).getElementById(id); // DomNode
			}else{
				return id; // DomNode
			}
		},
		// the default document to search
		doc: document,
		// the constructor for node list objects returned from query()
		NodeList: Array
	};

	// define acme.isIE, acme.isSafari, acme.isOpera, etc.
	var n = navigator;
	var dua = n.userAgent;
	var dav = n.appVersion;
	var tv = parseFloat(dav);
	acme.isOpera = (dua.indexOf("Opera") >= 0) ? tv: undefined;
	acme.isKhtml = (dav.indexOf("Konqueror") >= 0) ? tv : undefined;
	acme.isWebKit = parseFloat(dua.split("WebKit/")[1]) || undefined;
	acme.isChrome = parseFloat(dua.split("Chrome/")[1]) || undefined;
	var index = Math.max(dav.indexOf("WebKit"), dav.indexOf("Safari"), 0);
	if(index && !acme.isChrome){
		acme.isSafari = parseFloat(dav.split("Version/")[1]);
		if(!acme.isSafari || parseFloat(dav.substr(index + 7)) <= 419.3){
			acme.isSafari = 2;
		}
	}
	if(document.all && !acme.isOpera){
		acme.isIE = parseFloat(dav.split("MSIE ")[1]) || undefined;
	}

	Array._wrap = function(arr){ return arr; };
  return acme;
};

	//prefers queryPortability, then acme, then dojo
	if(this["dojo"]){
		dojo.provide("dojo._base.query");
		
		
		defineQuery(this["queryPortability"]||this["acme"]||dojo);
	}else{
		defineQuery(this["queryPortability"]||this["acme"]||defineAcme());
	}

})();

/*
*/

}

if(!dojo._hasResource["dojo._base.xhr"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.xhr"] = true;
dojo.provide("dojo._base.xhr");






(function(){
	var _d = dojo, cfg = _d.config;

	function setValue(/*Object*/obj, /*String*/name, /*String*/value){
		//summary:
		//		For the named property in object, set the value. If a value
		//		already exists and it is a string, convert the value to be an
		//		array of values.

		//Skip it if there is no value
		if(value === null){
			return;
		}

		var val = obj[name];
		if(typeof val == "string"){ // inline'd type check
			obj[name] = [val, value];
		}else if(_d.isArray(val)){
			val.push(value);
		}else{
			obj[name] = value;
		}
	}

	dojo.fieldToObject = function(/*DOMNode||String*/ inputNode){
		// summary:
		//		Serialize a form field to a JavaScript object.
		//
		// description:
		//		Returns the value encoded in a form field as
		//		as a string or an array of strings. Disabled form elements
		//		and unchecked radio and checkboxes are skipped.	Multi-select
		//		elements are returned as an array of string values.
		var ret = null;
		var item = _d.byId(inputNode);
		if(item){
			var _in = item.name;
			var type = (item.type||"").toLowerCase();
			if(_in && type && !item.disabled){
				if(type == "radio" || type == "checkbox"){
					if(item.checked){ ret = item.value; }
				}else if(item.multiple){
					ret = [];
					_d.query("option", item).forEach(function(opt){
						if(opt.selected){
							ret.push(opt.value);
						}
					});
				}else{
					ret = item.value;
				}
			}
		}
		return ret; // Object
	};

	dojo.formToObject = function(/*DOMNode||String*/ formNode){
		// summary:
		//		Serialize a form node to a JavaScript object.
		// description:
		//		Returns the values encoded in an HTML form as
		//		string properties in an object which it then returns. Disabled form
		//		elements, buttons, and other non-value form elements are skipped.
		//		Multi-select elements are returned as an array of string values.
		//
		// example:
		//		This form:
		//		|	<form id="test_form">
		//		|		<input type="text" name="blah" value="blah">
		//		|		<input type="text" name="no_value" value="blah" disabled>
		//		|		<input type="button" name="no_value2" value="blah">
		//		|		<select type="select" multiple name="multi" size="5">
		//		|			<option value="blah">blah</option>
		//		|			<option value="thud" selected>thud</option>
		//		|			<option value="thonk" selected>thonk</option>
		//		|		</select>
		//		|	</form>
		//
		//		yields this object structure as the result of a call to
		//		formToObject():
		//
		//		|	{
		//		|		blah: "blah",
		//		|		multi: [
		//		|			"thud",
		//		|			"thonk"
		//		|		]
		//		|	};

		var ret = {};
		var exclude = "file|submit|image|reset|button|";
		_d.forEach(dojo.byId(formNode).elements, function(item){
			var _in = item.name;
			var type = (item.type||"").toLowerCase();
			if(_in && type && exclude.indexOf(type) == -1 && !item.disabled){
				setValue(ret, _in, _d.fieldToObject(item));
				if(type == "image"){
					ret[_in+".x"] = ret[_in+".y"] = ret[_in].x = ret[_in].y = 0;
				}
			}
		});
		return ret; // Object
	};

	dojo.objectToQuery = function(/*Object*/ map){
		//	summary:
		//		takes a name/value mapping object and returns a string representing
		//		a URL-encoded version of that object.
		//	example:
		//		this object:
		//
		//		|	{
		//		|		blah: "blah",
		//		|		multi: [
		//		|			"thud",
		//		|			"thonk"
		//		|		]
		//		|	};
		//
		//	yields the following query string:
		//
		//	|	"blah=blah&multi=thud&multi=thonk"

		// FIXME: need to implement encodeAscii!!
		var enc = encodeURIComponent;
		var pairs = [];
		var backstop = {};
		for(var name in map){
			var value = map[name];
			if(value != backstop[name]){
				var assign = enc(name) + "=";
				if(_d.isArray(value)){
					for(var i=0; i < value.length; i++){
						pairs.push(assign + enc(value[i]));
					}
				}else{
					pairs.push(assign + enc(value));
				}
			}
		}
		return pairs.join("&"); // String
	};

	dojo.formToQuery = function(/*DOMNode||String*/ formNode){
		// summary:
		//		Returns a URL-encoded string representing the form passed as either a
		//		node or string ID identifying the form to serialize
		return _d.objectToQuery(_d.formToObject(formNode)); // String
	};

	dojo.formToJson = function(/*DOMNode||String*/ formNode, /*Boolean?*/prettyPrint){
		// summary:
		//		Create a serialized JSON string from a form node or string
		//		ID identifying the form to serialize
		return _d.toJson(_d.formToObject(formNode), prettyPrint); // String
	};

	dojo.queryToObject = function(/*String*/ str){
		// summary:
		//		Create an object representing a de-serialized query section of a
		//		URL. Query keys with multiple values are returned in an array.
		//
		// example:
		//		This string:
		//
		//	|		"foo=bar&foo=baz&thinger=%20spaces%20=blah&zonk=blarg&"
		//
		//		results in this object structure:
		//
		//	|		{
		//	|			foo: [ "bar", "baz" ],
		//	|			thinger: " spaces =blah",
		//	|			zonk: "blarg"
		//	|		}
		//
		//		Note that spaces and other urlencoded entities are correctly
		//		handled.

		// FIXME: should we grab the URL string if we're not passed one?
		var ret = {};
		var qp = str.split("&");
		var dec = decodeURIComponent;
		_d.forEach(qp, function(item){
			if(item.length){
				var parts = item.split("=");
				var name = dec(parts.shift());
				var val = dec(parts.join("="));
				if(typeof ret[name] == "string"){ // inline'd type check
					ret[name] = [ret[name]];
				}

				if(_d.isArray(ret[name])){
					ret[name].push(val);
				}else{
					ret[name] = val;
				}
			}
		});
		return ret; // Object
	};

	// need to block async callbacks from snatching this thread as the result
	// of an async callback might call another sync XHR, this hangs khtml forever
	// must checked by watchInFlight()

	dojo._blockAsync = false;

	// MOW: remove dojo._contentHandlers alias in 2.0
	var handlers = _d._contentHandlers = dojo.contentHandlers = {
		// summary:
		//		A map of availble XHR transport handle types. Name matches the
		//		`handleAs` attribute passed to XHR calls.
		//
		// description:
		//		A map of availble XHR transport handle types. Name matches the
		//		`handleAs` attribute passed to XHR calls. Each contentHandler is
		//		called, passing the xhr object for manipulation. The return value
		//		from the contentHandler will be passed to the `load` or `handle`
		//		functions defined in the original xhr call.
		//
		// example:
		//		Creating a custom content-handler:
		//	|	dojo.contentHandlers.makeCaps = function(xhr){
		//	|		return xhr.responseText.toUpperCase();
		//	|	}
		//	|	// and later:
		//	|	dojo.xhrGet({
		//	|		url:"foo.txt",
		//	|		handleAs:"makeCaps",
		//	|		load: function(data){ /* data is a toUpper version of foo.txt */ }
		//	|	});

		text: function(xhr){
			// summary: A contentHandler which simply returns the plaintext response data
			return xhr.responseText;
		},
		json: function(xhr){
			// summary: A contentHandler which returns a JavaScript object created from the response data
			return _d.fromJson(xhr.responseText || null);
		},
		"json-comment-filtered": function(xhr){
			// summary: A contentHandler which expects comment-filtered JSON.
			// description:
			//		A contentHandler which expects comment-filtered JSON.
			//		the json-comment-filtered option was implemented to prevent
			//		"JavaScript Hijacking", but it is less secure than standard JSON. Use
			//		standard JSON instead. JSON prefixing can be used to subvert hijacking.
			//
			//		Will throw a notice suggesting to use application/json mimetype, as
			//		json-commenting can introduce security issues. To decrease the chances of hijacking,
			//		use the standard `json` contentHandler, and prefix your "JSON" with: {}&&
			//
			//		use djConfig.useCommentedJson = true to turn off the notice
			if(!dojo.config.useCommentedJson){
				console.warn("Consider using the standard mimetype:application/json."
					+ " json-commenting can introduce security issues. To"
					+ " decrease the chances of hijacking, use the standard the 'json' handler and"
					+ " prefix your json with: {}&&\n"
					+ "Use djConfig.useCommentedJson=true to turn off this message.");
			}

			var value = xhr.responseText;
			var cStartIdx = value.indexOf("\/*");
			var cEndIdx = value.lastIndexOf("*\/");
			if(cStartIdx == -1 || cEndIdx == -1){
				throw new Error("JSON was not comment filtered");
			}
			return _d.fromJson(value.substring(cStartIdx+2, cEndIdx));
		},
		javascript: function(xhr){
			// summary: A contentHandler which evaluates the response data, expecting it to be valid JavaScript

			// FIXME: try Moz and IE specific eval variants?
			return _d.eval(xhr.responseText);
		},
		xml: function(xhr){
			// summary: A contentHandler returning an XML Document parsed from the response data
			var result = xhr.responseXML;
						if(_d.isIE && (!result || !result.documentElement)){
				//WARNING: this branch used by the xml handling in dojo.io.iframe,
				//so be sure to test dojo.io.iframe if making changes below.
				var ms = function(n){ return "MSXML" + n + ".DOMDocument"; };
				var dp = ["Microsoft.XMLDOM", ms(6), ms(4), ms(3), ms(2)];
				_d.some(dp, function(p){
					try{
						var dom = new ActiveXObject(p);
						dom.async = false;
						dom.loadXML(xhr.responseText);
						result = dom;
					}catch(e){ return false; }
					return true;
				});
			}
						return result; // DOMDocument
		},
		"json-comment-optional": function(xhr){
			// summary: A contentHandler which checks the presence of comment-filtered JSON and
			//		alternates between the `json` and `json-comment-filtered` contentHandlers.
			if(xhr.responseText && /^[^{\[]*\/\*/.test(xhr.responseText)){
				return handlers["json-comment-filtered"](xhr);
			}else{
				return handlers["json"](xhr);
			}
		}
	};

	/*=====
	dojo.__IoArgs = function(){
		//	url: String
		//		URL to server endpoint.
		//	content: Object?
		//		Contains properties with string values. These
		//		properties will be serialized as name1=value2 and
		//		passed in the request.
		//	timeout: Integer?
		//		Milliseconds to wait for the response. If this time
		//		passes, the then error callbacks are called.
		//	form: DOMNode?
		//		DOM node for a form. Used to extract the form values
		//		and send to the server.
		//	preventCache: Boolean?
		//		Default is false. If true, then a
		//		"dojo.preventCache" parameter is sent in the request
		//		with a value that changes with each request
		//		(timestamp). Useful only with GET-type requests.
		//	handleAs: String?
		//		Acceptable values depend on the type of IO
		//		transport (see specific IO calls for more information).
		//	rawBody: String?
		// 		Sets the raw body for an HTTP request. If this is used, then the content
		// 		property is ignored. This is mostly useful for HTTP methods that have
		// 		a body to their requests, like PUT or POST. This property can be used instead
		// 		of postData and putData for dojo.rawXhrPost and dojo.rawXhrPut respectively.
		//	ioPublish: Boolean?
		//		Set this explicitly to false to prevent publishing of topics related to
		// 		IO operations. Otherwise, if djConfig.ioPublish is set to true, topics
		// 		will be published via dojo.publish for different phases of an IO operation.
		// 		See dojo.__IoPublish for a list of topics that are published.
		//	load: Function?
		//		This function will be
		//		called on a successful HTTP response code.
		//	error: Function?
		//		This function will
		//		be called when the request fails due to a network or server error, the url
		//		is invalid, etc. It will also be called if the load or handle callback throws an
		//		exception, unless djConfig.debugAtAllCosts is true.  This allows deployed applications
		//		to continue to run even when a logic error happens in the callback, while making
		//		it easier to troubleshoot while in debug mode.
		//	handle: Function?
		//		This function will
		//		be called at the end of every request, whether or not an error occurs.
		this.url = url;
		this.content = content;
		this.timeout = timeout;
		this.form = form;
		this.preventCache = preventCache;
		this.handleAs = handleAs;
		this.ioPublish = ioPublish;
		this.load = function(response, ioArgs){
			// ioArgs: dojo.__IoCallbackArgs
			//		Provides additional information about the request.
			// response: Object
			//		The response in the format as defined with handleAs.
		}
		this.error = function(response, ioArgs){
			// ioArgs: dojo.__IoCallbackArgs
			//		Provides additional information about the request.
			// response: Object
			//		The response in the format as defined with handleAs.
		}
		this.handle = function(loadOrError, response, ioArgs){
			// loadOrError: String
			//		Provides a string that tells you whether this function
			//		was called because of success (load) or failure (error).
			// response: Object
			//		The response in the format as defined with handleAs.
			// ioArgs: dojo.__IoCallbackArgs
			//		Provides additional information about the request.
		}
	}
	=====*/

	/*=====
	dojo.__IoCallbackArgs = function(args, xhr, url, query, handleAs, id, canDelete, json){
		//	args: Object
		//		the original object argument to the IO call.
		//	xhr: XMLHttpRequest
		//		For XMLHttpRequest calls only, the
		//		XMLHttpRequest object that was used for the
		//		request.
		//	url: String
		//		The final URL used for the call. Many times it
		//		will be different than the original args.url
		//		value.
		//	query: String
		//		For non-GET requests, the
		//		name1=value1&name2=value2 parameters sent up in
		//		the request.
		//	handleAs: String
		//		The final indicator on how the response will be
		//		handled.
		//	id: String
		//		For dojo.io.script calls only, the internal
		//		script ID used for the request.
		//	canDelete: Boolean
		//		For dojo.io.script calls only, indicates
		//		whether the script tag that represents the
		//		request can be deleted after callbacks have
		//		been called. Used internally to know when
		//		cleanup can happen on JSONP-type requests.
		//	json: Object
		//		For dojo.io.script calls only: holds the JSON
		//		response for JSONP-type requests. Used
		//		internally to hold on to the JSON responses.
		//		You should not need to access it directly --
		//		the same object should be passed to the success
		//		callbacks directly.
		this.args = args;
		this.xhr = xhr;
		this.url = url;
		this.query = query;
		this.handleAs = handleAs;
		this.id = id;
		this.canDelete = canDelete;
		this.json = json;
	}
	=====*/


	/*=====
	dojo.__IoPublish = function(){
		// 	summary:
		// 		This is a list of IO topics that can be published
		// 		if djConfig.ioPublish is set to true. IO topics can be
		// 		published for any Input/Output, network operation. So,
		// 		dojo.xhr, dojo.io.script and dojo.io.iframe can all
		// 		trigger these topics to be published.
		//	start: String
		//		"/dojo/io/start" is sent when there are no outstanding IO
		// 		requests, and a new IO request is started. No arguments
		// 		are passed with this topic.
		//	send: String
		//		"/dojo/io/send" is sent whenever a new IO request is started.
		// 		It passes the dojo.Deferred for the request with the topic.
		//	load: String
		//		"/dojo/io/load" is sent whenever an IO request has loaded
		// 		successfully. It passes the response and the dojo.Deferred
		// 		for the request with the topic.
		//	error: String
		//		"/dojo/io/error" is sent whenever an IO request has errored.
		// 		It passes the error and the dojo.Deferred
		// 		for the request with the topic.
		//	done: String
		//		"/dojo/io/done" is sent whenever an IO request has completed,
		// 		either by loading or by erroring. It passes the error and
		// 		the dojo.Deferred for the request with the topic.
		//	stop: String
		//		"/dojo/io/stop" is sent when all outstanding IO requests have
		// 		finished. No arguments are passed with this topic.
		this.start = "/dojo/io/start";
		this.send = "/dojo/io/send";
		this.load = "/dojo/io/load";
		this.error = "/dojo/io/error";
		this.done = "/dojo/io/done";
		this.stop = "/dojo/io/stop";
	}
	=====*/


	dojo._ioSetArgs = function(/*dojo.__IoArgs*/args,
			/*Function*/canceller,
			/*Function*/okHandler,
			/*Function*/errHandler){
		//	summary:
		//		sets up the Deferred and ioArgs property on the Deferred so it
		//		can be used in an io call.
		//	args:
		//		The args object passed into the public io call. Recognized properties on
		//		the args object are:
		//	canceller:
		//		The canceller function used for the Deferred object. The function
		//		will receive one argument, the Deferred object that is related to the
		//		canceller.
		//	okHandler:
		//		The first OK callback to be registered with Deferred. It has the opportunity
		//		to transform the OK response. It will receive one argument -- the Deferred
		//		object returned from this function.
		//	errHandler:
		//		The first error callback to be registered with Deferred. It has the opportunity
		//		to do cleanup on an error. It will receive two arguments: error (the
		//		Error object) and dfd, the Deferred object returned from this function.

		var ioArgs = {args: args, url: args.url};

		//Get values from form if requestd.
		var formObject = null;
		if(args.form){
			var form = _d.byId(args.form);
			//IE requires going through getAttributeNode instead of just getAttribute in some form cases,
			//so use it for all.  See #2844
			var actnNode = form.getAttributeNode("action");
			ioArgs.url = ioArgs.url || (actnNode ? actnNode.value : null);
			formObject = _d.formToObject(form);
		}

		// set up the query params
		var miArgs = [{}];

		if(formObject){
			// potentially over-ride url-provided params w/ form values
			miArgs.push(formObject);
		}
		if(args.content){
			// stuff in content over-rides what's set by form
			miArgs.push(args.content);
		}
		if(args.preventCache){
			miArgs.push({"dojo.preventCache": new Date().valueOf()});
		}
		ioArgs.query = _d.objectToQuery(_d.mixin.apply(null, miArgs));

		// .. and the real work of getting the deferred in order, etc.
		ioArgs.handleAs = args.handleAs || "text";
		var d = new _d.Deferred(canceller);
		d.addCallbacks(okHandler, function(error){
			return errHandler(error, d);
		});

		//Support specifying load, error and handle callback functions from the args.
		//For those callbacks, the "this" object will be the args object.
		//The callbacks will get the deferred result value as the
		//first argument and the ioArgs object as the second argument.
		var ld = args.load;
		if(ld && _d.isFunction(ld)){
			d.addCallback(function(value){
				return ld.call(args, value, ioArgs);
			});
		}
		var err = args.error;
		if(err && _d.isFunction(err)){
			d.addErrback(function(value){
				return err.call(args, value, ioArgs);
			});
		}
		var handle = args.handle;
		if(handle && _d.isFunction(handle)){
			d.addBoth(function(value){
				return handle.call(args, value, ioArgs);
			});
		}

		//Plug in topic publishing, if dojo.publish is loaded.
		if(cfg.ioPublish && _d.publish && ioArgs.args.ioPublish !== false){
			d.addCallbacks(
				function(res){
					_d.publish("/dojo/io/load", [d, res]);
					return res;
				},
				function(res){
					_d.publish("/dojo/io/error", [d, res]);
					return res;
				}
			);
			d.addBoth(function(res){
				_d.publish("/dojo/io/done", [d, res]);
				return res;
			});
		}

		d.ioArgs = ioArgs;

		// FIXME: need to wire up the xhr object's abort method to something
		// analagous in the Deferred
		return d;
	};

	var _deferredCancel = function(/*Deferred*/dfd){
		// summary: canceller function for dojo._ioSetArgs call.

		dfd.canceled = true;
		var xhr = dfd.ioArgs.xhr;
		var _at = typeof xhr.abort;
		if(_at == "function" || _at == "object" || _at == "unknown"){
			xhr.abort();
		}
		var err = dfd.ioArgs.error;
		if(!err){
			err = new Error("xhr cancelled");
			err.dojoType="cancel";
		}
		return err;
	};
	var _deferredOk = function(/*Deferred*/dfd){
		// summary: okHandler function for dojo._ioSetArgs call.

		var ret = handlers[dfd.ioArgs.handleAs](dfd.ioArgs.xhr);
		return ret === undefined ? null : ret;
	};
	var _deferError = function(/*Error*/error, /*Deferred*/dfd){
		// summary: errHandler function for dojo._ioSetArgs call.

		if(!dfd.ioArgs.args.failOk){
			console.error(error);
		}
		return error;
	};

	// avoid setting a timer per request. It degrades performance on IE
	// something fierece if we don't use unified loops.
	var _inFlightIntvl = null;
	var _inFlight = [];


	//Use a separate count for knowing if we are starting/stopping io calls.
	//Cannot use _inFlight.length since it can change at a different time than
	//when we want to do this kind of test. We only want to decrement the count
	//after a callback/errback has finished, since the callback/errback should be
	//considered as part of finishing a request.
	var _pubCount = 0;
	var _checkPubCount = function(dfd){
		if(_pubCount <= 0){
			_pubCount = 0;
			if(cfg.ioPublish && _d.publish && (!dfd || dfd && dfd.ioArgs.args.ioPublish !== false)){
				_d.publish("/dojo/io/stop");
			}
		}
	};

	var _watchInFlight = function(){
		//summary:
		//		internal method that checks each inflight XMLHttpRequest to see
		//		if it has completed or if the timeout situation applies.

		var now = (new Date()).getTime();
		// make sure sync calls stay thread safe, if this callback is called
		// during a sync call and this results in another sync call before the
		// first sync call ends the browser hangs
		if(!_d._blockAsync){
			// we need manual loop because we often modify _inFlight (and therefore 'i') while iterating
			// note: the second clause is an assigment on purpose, lint may complain
			for(var i = 0, tif; i < _inFlight.length && (tif = _inFlight[i]); i++){
				var dfd = tif.dfd;
				var func = function(){
					if(!dfd || dfd.canceled || !tif.validCheck(dfd)){
						_inFlight.splice(i--, 1);
						_pubCount -= 1;
					}else if(tif.ioCheck(dfd)){
						_inFlight.splice(i--, 1);
						tif.resHandle(dfd);
						_pubCount -= 1;
					}else if(dfd.startTime){
						//did we timeout?
						if(dfd.startTime + (dfd.ioArgs.args.timeout || 0) < now){
							_inFlight.splice(i--, 1);
							var err = new Error("timeout exceeded");
							err.dojoType = "timeout";
							dfd.errback(err);
							//Cancel the request so the io module can do appropriate cleanup.
							dfd.cancel();
							_pubCount -= 1;
						}
					}
				};
				if(dojo.config.debugAtAllCosts){
					func.call(this);
				}else{
					try{
						func.call(this);
					}catch(e){
						dfd.errback(e);
					}
				}
			}
		}

		_checkPubCount(dfd);

		if(!_inFlight.length){
			clearInterval(_inFlightIntvl);
			_inFlightIntvl = null;
			return;
		}
	};

	dojo._ioCancelAll = function(){
		//summary: Cancels all pending IO requests, regardless of IO type
		//(xhr, script, iframe).
		try{
			_d.forEach(_inFlight, function(i){
				try{
					i.dfd.cancel();
				}catch(e){/*squelch*/}
			});
		}catch(e){/*squelch*/}
	};

	//Automatically call cancel all io calls on unload
	//in IE for trac issue #2357.
		if(_d.isIE){
		_d.addOnWindowUnload(_d._ioCancelAll);
	}
	
	_d._ioNotifyStart = function(/*Deferred*/dfd){
		// summary:
		// 		If dojo.publish is available, publish topics
		// 		about the start of a request queue and/or the
		// 		the beginning of request.
		// description:
		// 		Used by IO transports. An IO transport should
		// 		call this method before making the network connection.
		if(cfg.ioPublish && _d.publish && dfd.ioArgs.args.ioPublish !== false){
			if(!_pubCount){
				_d.publish("/dojo/io/start");
			}
			_pubCount += 1;
			_d.publish("/dojo/io/send", [dfd]);
		}
	};

	_d._ioWatch = function(dfd, validCheck, ioCheck, resHandle){
		// summary:
		//		Watches the io request represented by dfd to see if it completes.
		// dfd: Deferred
		//		The Deferred object to watch.
		// validCheck: Function
		//		Function used to check if the IO request is still valid. Gets the dfd
		//		object as its only argument.
		// ioCheck: Function
		//		Function used to check if basic IO call worked. Gets the dfd
		//		object as its only argument.
		// resHandle: Function
		//		Function used to process response. Gets the dfd
		//		object as its only argument.
		var args = dfd.ioArgs.args;
		if(args.timeout){
			dfd.startTime = (new Date()).getTime();
		}

		_inFlight.push({dfd: dfd, validCheck: validCheck, ioCheck: ioCheck, resHandle: resHandle});
		if(!_inFlightIntvl){
			_inFlightIntvl = setInterval(_watchInFlight, 50);
		}
		// handle sync requests
		//A weakness: async calls in flight
		//could have their handlers called as part of the
		//_watchInFlight call, before the sync's callbacks
		// are called.
		if(args.sync){
			_watchInFlight();
		}
	};

	var _defaultContentType = "application/x-www-form-urlencoded";

	var _validCheck = function(/*Deferred*/dfd){
		return dfd.ioArgs.xhr.readyState; //boolean
	};
	var _ioCheck = function(/*Deferred*/dfd){
		return 4 == dfd.ioArgs.xhr.readyState; //boolean
	};
	var _resHandle = function(/*Deferred*/dfd){
		var xhr = dfd.ioArgs.xhr;
		if(_d._isDocumentOk(xhr)){
			dfd.callback(dfd);
		}else{
			var err = new Error("Unable to load " + dfd.ioArgs.url + " status:" + xhr.status);
			err.status = xhr.status;
			err.responseText = xhr.responseText;
			dfd.errback(err);
		}
	};

	dojo._ioAddQueryToUrl = function(/*dojo.__IoCallbackArgs*/ioArgs){
		//summary: Adds query params discovered by the io deferred construction to the URL.
		//Only use this for operations which are fundamentally GET-type operations.
		if(ioArgs.query.length){
			ioArgs.url += (ioArgs.url.indexOf("?") == -1 ? "?" : "&") + ioArgs.query;
			ioArgs.query = null;
		}
	};

	/*=====
	dojo.declare("dojo.__XhrArgs", dojo.__IoArgs, {
		constructor: function(){
			//	summary:
			//		In addition to the properties listed for the dojo._IoArgs type,
			//		the following properties are allowed for dojo.xhr* methods.
			//	handleAs: String?
			//		Acceptable values are: text (default), json, json-comment-optional,
			//		json-comment-filtered, javascript, xml. See `dojo.contentHandlers`
			//	sync: Boolean?
			//		false is default. Indicates whether the request should
			//		be a synchronous (blocking) request.
			//	headers: Object?
			//		Additional HTTP headers to send in the request.
			//	failOk: Boolean?
			//		false is default. Indicates whether a request should be
			//		allowed to fail (and therefore no console error message in
			//		the event of a failure)
			this.handleAs = handleAs;
			this.sync = sync;
			this.headers = headers;
			this.failOk = failOk;
		}
	});
	=====*/

	dojo.xhr = function(/*String*/ method, /*dojo.__XhrArgs*/ args, /*Boolean?*/ hasBody){
		//	summary:
		//		Sends an HTTP request with the given method.
		//	description:
		//		Sends an HTTP request with the given method.
		//		See also dojo.xhrGet(), xhrPost(), xhrPut() and dojo.xhrDelete() for shortcuts
		//		for those HTTP methods. There are also methods for "raw" PUT and POST methods
		//		via dojo.rawXhrPut() and dojo.rawXhrPost() respectively.
		//	method:
		//		HTTP method to be used, such as GET, POST, PUT, DELETE.  Should be uppercase.
		//	hasBody:
		//		If the request has an HTTP body, then pass true for hasBody.

		//Make the Deferred object for this xhr request.
		var dfd = _d._ioSetArgs(args, _deferredCancel, _deferredOk, _deferError);
		var ioArgs = dfd.ioArgs;

		//Pass the args to _xhrObj, to allow alternate XHR calls based specific calls, like
		//the one used for iframe proxies.
		var xhr = ioArgs.xhr = _d._xhrObj(ioArgs.args);
		//If XHR factory fails, cancel the deferred.
		if(!xhr){
			dfd.cancel();
			return dfd;
		}

		//Allow for specifying the HTTP body completely.
		if("postData" in args){
			ioArgs.query = args.postData;
		}else if("putData" in args){
			ioArgs.query = args.putData;
		}else if("rawBody" in args){
			ioArgs.query = args.rawBody;
		}else if((arguments.length > 2 && !hasBody) || "POST|PUT".indexOf(method.toUpperCase()) == -1){
			//Check for hasBody being passed. If no hasBody,
			//then only append query string if not a POST or PUT request.
			_d._ioAddQueryToUrl(ioArgs);
		}

		// IE 6 is a steaming pile. It won't let you call apply() on the native function (xhr.open).
		// workaround for IE6's apply() "issues"
		xhr.open(method, ioArgs.url, args.sync !== true, args.user || undefined, args.password || undefined);
		if(args.headers){
			for(var hdr in args.headers){
				if(hdr.toLowerCase() === "content-type" && !args.contentType){
					args.contentType = args.headers[hdr];
				}else if(args.headers[hdr]){
					//Only add header if it has a value. This allows for instnace, skipping
					//insertion of X-Requested-With by specifying empty value.
					xhr.setRequestHeader(hdr, args.headers[hdr]);
				}
			}
		}
		// FIXME: is this appropriate for all content types?
		xhr.setRequestHeader("Content-Type", args.contentType || _defaultContentType);
		if(!args.headers || !("X-Requested-With" in args.headers)){
			xhr.setRequestHeader("X-Requested-With", "XMLHttpRequest");
		}
		// FIXME: set other headers here!
		_d._ioNotifyStart(dfd);
		if(dojo.config.debugAtAllCosts){
			xhr.send(ioArgs.query);
		}else{
			try{
				xhr.send(ioArgs.query);
			}catch(e){
				ioArgs.error = e;
				dfd.cancel();
			}
		}
		_d._ioWatch(dfd, _validCheck, _ioCheck, _resHandle);
		xhr = null;
		return dfd; // dojo.Deferred
	};

	dojo.xhrGet = function(/*dojo.__XhrArgs*/ args){
		//	summary:
		//		Sends an HTTP GET request to the server.

		if (djConfig && djConfig.allowCORS && djConfig.allowCORS===true) {
			_d.mixin(args, {
			    headers: {
			        'X-Requested-With': null
			    }
			});
		}

		return _d.xhr("GET", args); // dojo.Deferred
	};

	dojo.rawXhrPost = dojo.xhrPost = function(/*dojo.__XhrArgs*/ args){
		//	summary:
		//		Sends an HTTP POST request to the server. In addtion to the properties
		//		listed for the dojo.__XhrArgs type, the following property is allowed:
		//	postData:
		//		String. Send raw data in the body of the POST request.
		return _d.xhr("POST", args, true); // dojo.Deferred
	};

	dojo.rawXhrPut = dojo.xhrPut = function(/*dojo.__XhrArgs*/ args){
		//	summary:
		//		Sends an HTTP PUT request to the server. In addtion to the properties
		//		listed for the dojo.__XhrArgs type, the following property is allowed:
		//	putData:
		//		String. Send raw data in the body of the PUT request.
		return _d.xhr("PUT", args, true); // dojo.Deferred
	};

	dojo.xhrDelete = function(/*dojo.__XhrArgs*/ args){
		//	summary:
		//		Sends an HTTP DELETE request to the server.
		return _d.xhr("DELETE", args); //dojo.Deferred
	};

	/*
	dojo.wrapForm = function(formNode){
		//summary:
		//		A replacement for FormBind, but not implemented yet.

		// FIXME: need to think harder about what extensions to this we might
		// want. What should we allow folks to do w/ this? What events to
		// set/send?
		throw new Error("dojo.wrapForm not yet implemented");
	}
	*/
})();

}

if(!dojo._hasResource["dojo._base.fx"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.fx"] = true;
dojo.provide("dojo._base.fx");






/*
	Animation loosely package based on Dan Pupius' work, contributed under CLA:
		http://pupius.co.uk/js/Toolkit.Drawing.js
*/
(function(){
	var d = dojo;
	var _mixin = d._mixin;

	dojo._Line = function(/*int*/ start, /*int*/ end){
		//	summary:
		//		dojo._Line is the object used to generate values from a start value
		//		to an end value
		//	start: int
		//		Beginning value for range
		//	end: int
		//		Ending value for range
		this.start = start;
		this.end = end;
	};

	dojo._Line.prototype.getValue = function(/*float*/ n){
		//	summary: Returns the point on the line
		//	n: a floating point number greater than 0 and less than 1
		return ((this.end - this.start) * n) + this.start; // Decimal
	};

	dojo.Animation = function(args){
		//	summary:
		//		A generic animation class that fires callbacks into its handlers
		//		object at various states.
		//	description:
		//		A generic animation class that fires callbacks into its handlers
		//		object at various states. Nearly all dojo animation functions
		//		return an instance of this method, usually without calling the
		//		.play() method beforehand. Therefore, you will likely need to
		//		call .play() on instances of `dojo.Animation` when one is
		//		returned.
		// args: Object
		//		The 'magic argument', mixing all the properties into this
		//		animation instance.

		_mixin(this, args);
		if(d.isArray(this.curve)){
			this.curve = new d._Line(this.curve[0], this.curve[1]);
		}

	};

	// Alias to drop come 2.0:
	d._Animation = d.Animation;

	d.extend(dojo.Animation, {
		// duration: Integer
		//		The time in milliseonds the animation will take to run
		duration: 350,

	/*=====
		// curve: dojo._Line|Array
		//		A two element array of start and end values, or a `dojo._Line` instance to be
		//		used in the Animation.
		curve: null,

		// easing: Function?
		//		A Function to adjust the acceleration (or deceleration) of the progress
		//		across a dojo._Line
		easing: null,
	=====*/

		// repeat: Integer?
		//		The number of times to loop the animation
		repeat: 0,

		// rate: Integer?
		//		the time in milliseconds to wait before advancing to next frame
		//		(used as a fps timer: 1000/rate = fps)
		rate: 20 /* 50 fps */,

	/*=====
		// delay: Integer?
		//		The time in milliseconds to wait before starting animation after it
		//		has been .play()'ed
		delay: null,

		// beforeBegin: Event?
		//		Synthetic event fired before a dojo.Animation begins playing (synchronous)
		beforeBegin: null,

		// onBegin: Event?
		//		Synthetic event fired as a dojo.Animation begins playing (useful?)
		onBegin: null,

		// onAnimate: Event?
		//		Synthetic event fired at each interval of a `dojo.Animation`
		onAnimate: null,

		// onEnd: Event?
		//		Synthetic event fired after the final frame of a `dojo.Animation`
		onEnd: null,

		// onPlay: Event?
		//		Synthetic event fired any time a `dojo.Animation` is play()'ed
		onPlay: null,

		// onPause: Event?
		//		Synthetic event fired when a `dojo.Animation` is paused
		onPause: null,

		// onStop: Event
		//		Synthetic event fires when a `dojo.Animation` is stopped
		onStop: null,

	=====*/

		_percent: 0,
		_startRepeatCount: 0,

		_getStep: function(){
			var _p = this._percent,
				_e = this.easing
			;
			return _e ? _e(_p) : _p;
		},
		_fire: function(/*Event*/ evt, /*Array?*/ args){
			//	summary:
			//		Convenience function.  Fire event "evt" and pass it the
			//		arguments specified in "args".
			//	description:
			//		Convenience function.  Fire event "evt" and pass it the
			//		arguments specified in "args".
			//		Fires the callback in the scope of the `dojo.Animation`
			//		instance.
			//	evt:
			//		The event to fire.
			//	args:
			//		The arguments to pass to the event.
			var a = args||[];
			if(this[evt]){
				if(d.config.debugAtAllCosts){
					this[evt].apply(this, a);
				}else{
					try{
						this[evt].apply(this, a);
					}catch(e){
						// squelch and log because we shouldn't allow exceptions in
						// synthetic event handlers to cause the internal timer to run
						// amuck, potentially pegging the CPU. I'm not a fan of this
						// squelch, but hopefully logging will make it clear what's
						// going on
						console.error("exception in animation handler for:", evt);
						console.error(e);
					}
				}
			}
			return this; // dojo.Animation
		},

		play: function(/*int?*/ delay, /*Boolean?*/ gotoStart){
			// summary:
			//		Start the animation.
			// delay:
			//		How many milliseconds to delay before starting.
			// gotoStart:
			//		If true, starts the animation from the beginning; otherwise,
			//		starts it from its current position.
			// returns: dojo.Animation
			//		The instance to allow chaining.

			var _t = this;
			if(_t._delayTimer){ _t._clearTimer(); }
			if(gotoStart){
				_t._stopTimer();
				_t._active = _t._paused = false;
				_t._percent = 0;
			}else if(_t._active && !_t._paused){
				return _t;
			}

			_t._fire("beforeBegin", [_t.node]);

			var de = delay || _t.delay,
				_p = dojo.hitch(_t, "_play", gotoStart);

			if(de > 0){
				_t._delayTimer = setTimeout(_p, de);
				return _t;
			}
			_p();
			return _t;
		},

		_play: function(gotoStart){
			var _t = this;
			if(_t._delayTimer){ _t._clearTimer(); }
			_t._startTime = new Date().valueOf();
			if(_t._paused){
				_t._startTime -= _t.duration * _t._percent;
			}

			_t._active = true;
			_t._paused = false;
			var value = _t.curve.getValue(_t._getStep());
			if(!_t._percent){
				if(!_t._startRepeatCount){
					_t._startRepeatCount = _t.repeat;
				}
				_t._fire("onBegin", [value]);
			}

			_t._fire("onPlay", [value]);

			_t._cycle();
			return _t; // dojo.Animation
		},

		pause: function(){
			// summary: Pauses a running animation.
			var _t = this;
			if(_t._delayTimer){ _t._clearTimer(); }
			_t._stopTimer();
			if(!_t._active){ return _t; /*dojo.Animation*/ }
			_t._paused = true;
			_t._fire("onPause", [_t.curve.getValue(_t._getStep())]);
			return _t; // dojo.Animation
		},

		gotoPercent: function(/*Decimal*/ percent, /*Boolean?*/ andPlay){
			//	summary:
			//		Sets the progress of the animation.
			//	percent:
			//		A percentage in decimal notation (between and including 0.0 and 1.0).
			//	andPlay:
			//		If true, play the animation after setting the progress.
			var _t = this;
			_t._stopTimer();
			_t._active = _t._paused = true;
			_t._percent = percent;
			if(andPlay){ _t.play(); }
			return _t; // dojo.Animation
		},

		stop: function(/*boolean?*/ gotoEnd){
			// summary: Stops a running animation.
			// gotoEnd: If true, the animation will end.
			var _t = this;
			if(_t._delayTimer){ _t._clearTimer(); }
			if(!_t._timer){ return _t; /* dojo.Animation */ }
			_t._stopTimer();
			if(gotoEnd){
				_t._percent = 1;
			}
			_t._fire("onStop", [_t.curve.getValue(_t._getStep())]);
			_t._active = _t._paused = false;
			return _t; // dojo.Animation
		},

		status: function(){
			// summary:
			//		Returns a string token representation of the status of
			//		the animation, one of: "paused", "playing", "stopped"
			if(this._active){
				return this._paused ? "paused" : "playing"; // String
			}
			return "stopped"; // String
		},

		_cycle: function(){
			var _t = this;
			if(_t._active){
				var curr = new Date().valueOf();
				var step = (curr - _t._startTime) / (_t.duration);

				if(step >= 1){
					step = 1;
				}
				_t._percent = step;

				// Perform easing
				if(_t.easing){
					step = _t.easing(step);
				}

				_t._fire("onAnimate", [_t.curve.getValue(step)]);

				if(_t._percent < 1){
					_t._startTimer();
				}else{
					_t._active = false;

					if(_t.repeat > 0){
						_t.repeat--;
						_t.play(null, true);
					}else if(_t.repeat == -1){
						_t.play(null, true);
					}else{
						if(_t._startRepeatCount){
							_t.repeat = _t._startRepeatCount;
							_t._startRepeatCount = 0;
						}
					}
					_t._percent = 0;
					_t._fire("onEnd", [_t.node]);
					!_t.repeat && _t._stopTimer();
				}
			}
			return _t; // dojo.Animation
		},

		_clearTimer: function(){
			// summary: Clear the play delay timer
			clearTimeout(this._delayTimer);
			delete this._delayTimer;
		}

	});

	// the local timer, stubbed into all Animation instances
	var ctr = 0,
		timer = null,
		runner = {
			run: function(){}
		};

	d.extend(d.Animation, {

		_startTimer: function(){
			if(!this._timer){
				this._timer = d.connect(runner, "run", this, "_cycle");
				ctr++;
			}
			if(!timer){
				timer = setInterval(d.hitch(runner, "run"), this.rate);
			}
		},

		_stopTimer: function(){
			if(this._timer){
				d.disconnect(this._timer);
				this._timer = null;
				ctr--;
			}
			if(ctr <= 0){
				clearInterval(timer);
				timer = null;
				ctr = 0;
			}
		}

	});

	var _makeFadeable =
				d.isIE ? function(node){
			// only set the zoom if the "tickle" value would be the same as the
			// default
			var ns = node.style;
			// don't set the width to auto if it didn't already cascade that way.
			// We don't want to f anyones designs
			if(!ns.width.length && d.style(node, "width") == "auto"){
				ns.width = "auto";
			}
		} :
				function(){};

	dojo._fade = function(/*Object*/ args){
		//	summary:
		//		Returns an animation that will fade the node defined by
		//		args.node from the start to end values passed (args.start
		//		args.end) (end is mandatory, start is optional)

		args.node = d.byId(args.node);
		var fArgs = _mixin({ properties: {} }, args),
			props = (fArgs.properties.opacity = {});

		props.start = !("start" in fArgs) ?
			function(){
				return +d.style(fArgs.node, "opacity")||0;
			} : fArgs.start;
		props.end = fArgs.end;

		var anim = d.animateProperty(fArgs);
		d.connect(anim, "beforeBegin", d.partial(_makeFadeable, fArgs.node));

		return anim; // dojo.Animation
	};

	/*=====
	dojo.__FadeArgs = function(node, duration, easing){
		//	node: DOMNode|String
		//		The node referenced in the animation
		//	duration: Integer?
		//		Duration of the animation in milliseconds.
		//	easing: Function?
		//		An easing function.
		this.node = node;
		this.duration = duration;
		this.easing = easing;
	}
	=====*/

	dojo.fadeIn = function(/*dojo.__FadeArgs*/ args){
		// summary:
		//		Returns an animation that will fade node defined in 'args' from
		//		its current opacity to fully opaque.
		return d._fade(_mixin({ end: 1 }, args)); // dojo.Animation
	};

	dojo.fadeOut = function(/*dojo.__FadeArgs*/  args){
		// summary:
		//		Returns an animation that will fade node defined in 'args'
		//		from its current opacity to fully transparent.
		return d._fade(_mixin({ end: 0 }, args)); // dojo.Animation
	};

	dojo._defaultEasing = function(/*Decimal?*/ n){
		// summary: The default easing function for dojo.Animation(s)
		return 0.5 + ((Math.sin((n + 1.5) * Math.PI)) / 2);
	};

	var PropLine = function(properties){
		// PropLine is an internal class which is used to model the values of
		// an a group of CSS properties across an animation lifecycle. In
		// particular, the "getValue" function handles getting interpolated
		// values between start and end for a particular CSS value.
		this._properties = properties;
		for(var p in properties){
			var prop = properties[p];
			if(prop.start instanceof d.Color){
				// create a reusable temp color object to keep intermediate results
				prop.tempColor = new d.Color();
			}
		}
	};

	PropLine.prototype.getValue = function(r){
		var ret = {};
		for(var p in this._properties){
			var prop = this._properties[p],
				start = prop.start;
			if(start instanceof d.Color){
				ret[p] = d.blendColors(start, prop.end, r, prop.tempColor).toCss();
			}else if(!d.isArray(start)){
				ret[p] = ((prop.end - start) * r) + start + (p != "opacity" ? prop.units || "px" : 0);
			}
		}
		return ret;
	};

	/*=====
	dojo.declare("dojo.__AnimArgs", [dojo.__FadeArgs], {
		// Properties: Object?
		//	A hash map of style properties to Objects describing the transition,
		//	such as the properties of dojo._Line with an additional 'units' property
		properties: {}

		//TODOC: add event callbacks
	});
	=====*/

	dojo.animateProperty = function(/*dojo.__AnimArgs*/ args){
		// summary:
		//		Returns an animation that will transition the properties of
		//		node defined in `args` depending how they are defined in
		//		`args.properties`
		//
		// description:
		//		`dojo.animateProperty` is the foundation of most `dojo.fx`
		//		animations. It takes an object of "properties" corresponding to
		//		style properties, and animates them in parallel over a set
		//		duration.
		//
		// example:
		//		A simple animation that changes the width of the specified node.
		//	|	dojo.animateProperty({
		//	|		node: "nodeId",
		//	|		properties: { width: 400 },
		//	|	}).play();
		//		Dojo figures out the start value for the width and converts the
		//		integer specified for the width to the more expressive but
		//		verbose form `{ width: { end: '400', units: 'px' } }` which you
		//		can also specify directly. Defaults to 'px' if ommitted.
		//
		// example:
		//		Animate width, height, and padding over 2 seconds... the
		//		pedantic way:
		//	|	dojo.animateProperty({ node: node, duration:2000,
		//	|		properties: {
		//	|			width: { start: '200', end: '400', units:"px" },
		//	|			height: { start:'200', end: '400', units:"px" },
		//	|			paddingTop: { start:'5', end:'50', units:"px" }
		//	|		}
		//	|	}).play();
		//		Note 'paddingTop' is used over 'padding-top'. Multi-name CSS properties
		//		are written using "mixed case", as the hyphen is illegal as an object key.
		//
		// example:
		//		Plug in a different easing function and register a callback for
		//		when the animation ends. Easing functions accept values between
		//		zero and one and return a value on that basis. In this case, an
		//		exponential-in curve.
		//	|	dojo.animateProperty({
		//	|		node: "nodeId",
		//	|		// dojo figures out the start value
		//	|		properties: { width: { end: 400 } },
		//	|		easing: function(n){
		//	|			return (n==0) ? 0 : Math.pow(2, 10 * (n - 1));
		//	|		},
		//	|		onEnd: function(node){
		//	|			// called when the animation finishes. The animation
		//	|			// target is passed to this function
		//	|		}
		//	|	}).play(500); // delay playing half a second
		//
		// example:
		//		Like all `dojo.Animation`s, animateProperty returns a handle to the
		//		Animation instance, which fires the events common to Dojo FX. Use `dojo.connect`
		//		to access these events outside of the Animation definiton:
		//	|	var anim = dojo.animateProperty({
		//	|		node:"someId",
		//	|		properties:{
		//	|			width:400, height:500
		//	|		}
		//	|	});
		//	|	dojo.connect(anim,"onEnd", function(){
		//	|		console.log("animation ended");
		//	|	});
		//	|	// play the animation now:
		//	|	anim.play();
		//
		// example:
		//		Each property can be a function whose return value is substituted along.
		//		Additionally, each measurement (eg: start, end) can be a function. The node
		//		reference is passed direcly to callbacks.
		//	|	dojo.animateProperty({
		//	|		node:"mine",
		//	|		properties:{
		//	|			height:function(node){
		//	|				// shrink this node by 50%
		//	|				return dojo.position(node).h / 2
		//	|			},
		//	|			width:{
		//	|				start:function(node){ return 100; },
		//	|				end:function(node){ return 200; }
		//	|			}
		//	|		}
		//	|	}).play();
		//

		var n = args.node = d.byId(args.node);
		if(!args.easing){ args.easing = d._defaultEasing; }

		var anim = new d.Animation(args);
		d.connect(anim, "beforeBegin", anim, function(){
			var pm = {};
			for(var p in this.properties){
				// Make shallow copy of properties into pm because we overwrite
				// some values below. In particular if start/end are functions
				// we don't want to overwrite them or the functions won't be
				// called if the animation is reused.
				if(p == "width" || p == "height"){
					this.node.display = "block";
				}
				var prop = this.properties[p];
				if(d.isFunction(prop)){
					prop = prop(n);
				}
				prop = pm[p] = _mixin({}, (d.isObject(prop) ? prop: { end: prop }));

				if(d.isFunction(prop.start)){
					prop.start = prop.start(n);
				}
				if(d.isFunction(prop.end)){
					prop.end = prop.end(n);
				}
				var isColor = (p.toLowerCase().indexOf("color") >= 0);
				function getStyle(node, p){
					// dojo.style(node, "height") can return "auto" or "" on IE; this is more reliable:
					var v = { height: node.offsetHeight, width: node.offsetWidth }[p];
					if(v !== undefined){ return v; }
					v = d.style(node, p);
					return (p == "opacity") ? +v : (isColor ? v : parseFloat(v));
				}
				if(!("end" in prop)){
					prop.end = getStyle(n, p);
				}else if(!("start" in prop)){
					prop.start = getStyle(n, p);
				}

				if(isColor){
					prop.start = new d.Color(prop.start);
					prop.end = new d.Color(prop.end);
				}else{
					prop.start = (p == "opacity") ? +prop.start : parseFloat(prop.start);
				}
			}
			this.curve = new PropLine(pm);
		});
		d.connect(anim, "onAnimate", d.hitch(d, "style", anim.node));
		return anim; // dojo.Animation
	};

	dojo.anim = function(	/*DOMNode|String*/	node,
							/*Object*/			properties,
							/*Integer?*/		duration,
							/*Function?*/		easing,
							/*Function?*/		onEnd,
							/*Integer?*/		delay){
		//	summary:
		//		A simpler interface to `dojo.animateProperty()`, also returns
		//		an instance of `dojo.Animation` but begins the animation
		//		immediately, unlike nearly every other Dojo animation API.
		//	description:
		//		`dojo.anim` is a simpler (but somewhat less powerful) version
		//		of `dojo.animateProperty`.  It uses defaults for many basic properties
		//		and allows for positional parameters to be used in place of the
		//		packed "property bag" which is used for other Dojo animation
		//		methods.
		//
		//		The `dojo.Animation` object returned from `dojo.anim` will be
		//		already playing when it is returned from this function, so
		//		calling play() on it again is (usually) a no-op.
		//	node:
		//		a DOM node or the id of a node to animate CSS properties on
		//	duration:
		//		The number of milliseconds over which the animation
		//		should run. Defaults to the global animation default duration
		//		(350ms).
		//	easing:
		//		An easing function over which to calculate acceleration
		//		and deceleration of the animation through its duration.
		//		A default easing algorithm is provided, but you may
		//		plug in any you wish. A large selection of easing algorithms
		//		are available in `dojo.fx.easing`.
		//	onEnd:
		//		A function to be called when the animation finishes
		//		running.
		//	delay:
		//		The number of milliseconds to delay beginning the
		//		animation by. The default is 0.
		//	example:
		//		Fade out a node
		//	|	dojo.anim("id", { opacity: 0 });
		//	example:
		//		Fade out a node over a full second
		//	|	dojo.anim("id", { opacity: 0 }, 1000);
		return d.animateProperty({ // dojo.Animation
			node: node,
			duration: duration || d.Animation.prototype.duration,
			properties: properties,
			easing: easing,
			onEnd: onEnd
		}).play(delay || 0);
	};
})();

}

if(!dojo._hasResource["dojo._base.browser"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base.browser"] = true;
dojo.provide("dojo._base.browser");









	//Need this to be the last code segment in base, so do not place any
	//dojo/requireIf calls in this file/ Otherwise, due to how the build system
	//puts all requireIf dependencies after the current file, the require calls
	//could be called before all of base is defined/
	dojo.forEach(dojo.config.require, function(i){
		dojo["require"](i);
	});

}

if(!dojo._hasResource["dojo._base"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo._base"] = true;
dojo.provide("dojo._base");











}

	//INSERT dojo.i18n._preloadLocalizations HERE

	//Check if document already complete, and if so, just trigger page load
	//listeners. NOTE: does not work with Firefox before 3.6. To support
	//those browsers, set djConfig.afterOnLoad = true when you know Dojo is added
	//after page load. Using a timeout so the rest of this
	//script gets evaluated properly. This work needs to happen after the
	//dojo.config.require work done in dojo._base.
	if(dojo.isBrowser && (document.readyState === "complete" || dojo.config.afterOnLoad)){
		window.setTimeout(dojo._loadInit, 100);
	}
})();


/* package: ep_base.js.uncompressed */
/*
	Copyright (c) 2004-2011, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/

/*
	This is an optimized version of Dojo, built for deployment and not for
	development. To get sources and documentation, please visit:

		http://dojotoolkit.org
*/

if(!dojo._hasResource["dojo.dnd.common"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.common"] = true;
dojo.provide("dojo.dnd.common");

dojo.getObject("dnd", true, dojo);

dojo.dnd.getCopyKeyState = dojo.isCopyKey;

dojo.dnd._uniqueId = 0;
dojo.dnd.getUniqueId = function(){
	// summary:
	//		returns a unique string for use with any DOM element
	var id;
	do{
		id = dojo._scopeName + "Unique" + (++dojo.dnd._uniqueId);
	}while(dojo.byId(id));
	return id;
};

dojo.dnd._empty = {};

dojo.dnd.isFormElement = function(/*Event*/ e){
	// summary:
	//		returns true if user clicked on a form element
	var t = e.target;
	if(t.nodeType == 3 /*TEXT_NODE*/){
		t = t.parentNode;
	}
	return " button textarea input select option ".indexOf(" " + t.tagName.toLowerCase() + " ") >= 0;	// Boolean
};

}

if(!dojo._hasResource["dojo.window"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.window"] = true;
dojo.provide("dojo.window");

dojo.getObject("window", true, dojo);

dojo.window.getBox = function(){
	// summary:
	//		Returns the dimensions and scroll position of the viewable area of a browser window

	var scrollRoot = (dojo.doc.compatMode == 'BackCompat') ? dojo.body() : dojo.doc.documentElement;

	// get scroll position
	var scroll = dojo._docScroll(); // scrollRoot.scrollTop/Left should work
	return { w: scrollRoot.clientWidth, h: scrollRoot.clientHeight, l: scroll.x, t: scroll.y };
};

dojo.window.get = function(doc){
	// summary:
	// 		Get window object associated with document doc

	// In some IE versions (at least 6.0), document.parentWindow does not return a
	// reference to the real window object (maybe a copy), so we must fix it as well
	// We use IE specific execScript to attach the real window reference to
	// document._parentWindow for later use
	if(dojo.isIE && window !== document.parentWindow){
		/*
		In IE 6, only the variable "window" can be used to connect events (others
		may be only copies).
		*/
		doc.parentWindow.execScript("document._parentWindow = window;", "Javascript");
		//to prevent memory leak, unset it after use
		//another possibility is to add an onUnload handler which seems overkill to me (liucougar)
		var win = doc._parentWindow;
		doc._parentWindow = null;
		return win;	//	Window
	}

	return doc.parentWindow || doc.defaultView;	//	Window
};

dojo.window.scrollIntoView = function(/*DomNode*/ node, /*Object?*/ pos){
	// summary:
	//		Scroll the passed node into view, if it is not already.
	
	// don't rely on node.scrollIntoView working just because the function is there

	try{ // catch unexpected/unrecreatable errors (#7808) since we can recover using a semi-acceptable native method
		node = dojo.byId(node);
		var doc = node.ownerDocument || dojo.doc,
			body = doc.body || dojo.body(),
			html = doc.documentElement || body.parentNode,
			isIE = dojo.isIE, isWK = dojo.isWebKit;
		// if an untested browser, then use the native method
		if((!(dojo.isMoz || isIE || isWK || dojo.isOpera) || node == body || node == html) && (typeof node.scrollIntoView != "undefined")){
			node.scrollIntoView(false); // short-circuit to native if possible
			return;
		}
		var backCompat = doc.compatMode == 'BackCompat',
			clientAreaRoot = (isIE >= 9 && node.ownerDocument.parentWindow.frameElement)
				? ((html.clientHeight > 0 && html.clientWidth > 0 && (body.clientHeight == 0 || body.clientWidth == 0 || body.clientHeight > html.clientHeight || body.clientWidth > html.clientWidth)) ? html : body)
				: (backCompat ? body : html),
			scrollRoot = isWK ? body : clientAreaRoot,
			rootWidth = clientAreaRoot.clientWidth,
			rootHeight = clientAreaRoot.clientHeight,
			rtl = !dojo._isBodyLtr(),
			nodePos = pos || dojo.position(node),
			el = node.parentNode,
			isFixed = function(el){
				return ((isIE <= 6 || (isIE && backCompat))? false : (dojo.style(el, 'position').toLowerCase() == "fixed"));
			};
		if(isFixed(node)){ return; } // nothing to do

		while(el){
			if(el == body){ el = scrollRoot; }
			var elPos = dojo.position(el),
				fixedPos = isFixed(el);
	
			if(el == scrollRoot){
				elPos.w = rootWidth; elPos.h = rootHeight;
				if(scrollRoot == html && isIE && rtl){ elPos.x += scrollRoot.offsetWidth-elPos.w; } // IE workaround where scrollbar causes negative x
				if(elPos.x < 0 || !isIE){ elPos.x = 0; } // IE can have values > 0
				if(elPos.y < 0 || !isIE){ elPos.y = 0; }
			}else{
				var pb = dojo._getPadBorderExtents(el);
				elPos.w -= pb.w; elPos.h -= pb.h; elPos.x += pb.l; elPos.y += pb.t;
				var clientSize = el.clientWidth,
					scrollBarSize = elPos.w - clientSize;
				if(clientSize > 0 && scrollBarSize > 0){
					elPos.w = clientSize;
					elPos.x += (rtl && (isIE || el.clientLeft > pb.l/*Chrome*/)) ? scrollBarSize : 0;
				}
				clientSize = el.clientHeight;
				scrollBarSize = elPos.h - clientSize;
				if(clientSize > 0 && scrollBarSize > 0){
					elPos.h = clientSize;
				}
			}
			if(fixedPos){ // bounded by viewport, not parents
				if(elPos.y < 0){
					elPos.h += elPos.y; elPos.y = 0;
				}
				if(elPos.x < 0){
					elPos.w += elPos.x; elPos.x = 0;
				}
				if(elPos.y + elPos.h > rootHeight){
					elPos.h = rootHeight - elPos.y;
				}
				if(elPos.x + elPos.w > rootWidth){
					elPos.w = rootWidth - elPos.x;
				}
			}
			// calculate overflow in all 4 directions
			var l = nodePos.x - elPos.x, // beyond left: < 0
				t = nodePos.y - Math.max(elPos.y, 0), // beyond top: < 0
				r = l + nodePos.w - elPos.w, // beyond right: > 0
				bot = t + nodePos.h - elPos.h; // beyond bottom: > 0
			if(r * l > 0){
				var s = Math[l < 0? "max" : "min"](l, r);
				if(rtl && ((isIE == 8 && !backCompat) || isIE >= 9)){ s = -s; }
				nodePos.x += el.scrollLeft;
				el.scrollLeft += s;
				nodePos.x -= el.scrollLeft;
			}
			if(bot * t > 0){
				nodePos.y += el.scrollTop;
				el.scrollTop += Math[t < 0? "max" : "min"](t, bot);
				nodePos.y -= el.scrollTop;
			}
			el = (el != scrollRoot) && !fixedPos && el.parentNode;
		}
	}catch(error){
		console.error('scrollIntoView: ' + error);
		node.scrollIntoView(false);
	}
};

}

if(!dojo._hasResource["dojo.dnd.autoscroll"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.autoscroll"] = true;
dojo.provide("dojo.dnd.autoscroll");


dojo.getObject("dnd", true, dojo);

dojo.dnd.getViewport = dojo.window.getBox;

dojo.dnd.V_TRIGGER_AUTOSCROLL = 32;
dojo.dnd.H_TRIGGER_AUTOSCROLL = 32;

dojo.dnd.V_AUTOSCROLL_VALUE = 16;
dojo.dnd.H_AUTOSCROLL_VALUE = 16;

dojo.dnd.autoScroll = function(e){
	// summary:
	//		a handler for onmousemove event, which scrolls the window, if
	//		necesary
	// e: Event
	//		onmousemove event

	// FIXME: needs more docs!
	var v = dojo.window.getBox(), dx = 0, dy = 0;
	if(e.clientX < dojo.dnd.H_TRIGGER_AUTOSCROLL){
		dx = -dojo.dnd.H_AUTOSCROLL_VALUE;
	}else if(e.clientX > v.w - dojo.dnd.H_TRIGGER_AUTOSCROLL){
		dx = dojo.dnd.H_AUTOSCROLL_VALUE;
	}
	if(e.clientY < dojo.dnd.V_TRIGGER_AUTOSCROLL){
		dy = -dojo.dnd.V_AUTOSCROLL_VALUE;
	}else if(e.clientY > v.h - dojo.dnd.V_TRIGGER_AUTOSCROLL){
		dy = dojo.dnd.V_AUTOSCROLL_VALUE;
	}
	window.scrollBy(dx, dy);
};

dojo.dnd._validNodes = {"div": 1, "p": 1, "td": 1};
dojo.dnd._validOverflow = {"auto": 1, "scroll": 1};

dojo.dnd.autoScrollNodes = function(e){
	// summary:
	//		a handler for onmousemove event, which scrolls the first avaialble
	//		Dom element, it falls back to dojo.dnd.autoScroll()
	// e: Event
	//		onmousemove event

	// FIXME: needs more docs!
	for(var n = e.target; n;){
		if(n.nodeType == 1 && (n.tagName.toLowerCase() in dojo.dnd._validNodes)){
			var s = dojo.getComputedStyle(n);
			if(s.overflow.toLowerCase() in dojo.dnd._validOverflow){
				var b = dojo._getContentBox(n, s), t = dojo.position(n, true);
				//console.log(b.l, b.t, t.x, t.y, n.scrollLeft, n.scrollTop);
				var w = Math.min(dojo.dnd.H_TRIGGER_AUTOSCROLL, b.w / 2),
					h = Math.min(dojo.dnd.V_TRIGGER_AUTOSCROLL, b.h / 2),
					rx = e.pageX - t.x, ry = e.pageY - t.y, dx = 0, dy = 0;
				if(dojo.isWebKit || dojo.isOpera){
					// FIXME: this code should not be here, it should be taken into account
					// either by the event fixing code, or the dojo.position()
					// FIXME: this code doesn't work on Opera 9.5 Beta
					rx += dojo.body().scrollLeft;
					ry += dojo.body().scrollTop;
				}
				if(rx > 0 && rx < b.w){
					if(rx < w){
						dx = -w;
					}else if(rx > b.w - w){
						dx = w;
					}
				}
				//console.log("ry =", ry, "b.h =", b.h, "h =", h);
				if(ry > 0 && ry < b.h){
					if(ry < h){
						dy = -h;
					}else if(ry > b.h - h){
						dy = h;
					}
				}
				var oldLeft = n.scrollLeft, oldTop = n.scrollTop;
				n.scrollLeft = n.scrollLeft + dx;
				n.scrollTop  = n.scrollTop  + dy;
				if(oldLeft != n.scrollLeft || oldTop != n.scrollTop){ return; }
			}
		}
		try{
			n = n.parentNode;
		}catch(x){
			n = null;
		}
	}
	dojo.dnd.autoScroll(e);
};

}

if(!dojo._hasResource["dojo.dnd.Mover"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.Mover"] = true;
dojo.provide("dojo.dnd.Mover");




dojo.declare("dojo.dnd.Mover", null, {
	constructor: function(node, e, host){
		// summary:
		//		an object which makes a node follow the mouse, or touch-drag on touch devices.
		//		Used as a default mover, and as a base class for custom movers.
		// node: Node
		//		a node (or node's id) to be moved
		// e: Event
		//		a mouse event, which started the move;
		//		only pageX and pageY properties are used
		// host: Object?
		//		object which implements the functionality of the move,
		//	 	and defines proper events (onMoveStart and onMoveStop)
		this.node = dojo.byId(node);
		var pos = e.touches ? e.touches[0] : e;
		this.marginBox = {l: pos.pageX, t: pos.pageY};
		this.mouseButton = e.button;
		var h = (this.host = host), d = node.ownerDocument;
		this.events = [
			// At the start of a drag, onFirstMove is called, and then the following two
			// connects are disconnected
			dojo.connect(d, "onmousemove", this, "onFirstMove"),
			dojo.connect(d, "ontouchmove", this, "onFirstMove"),

			// These are called continually during the drag
			dojo.connect(d, "onmousemove", this, "onMouseMove"),
			dojo.connect(d, "ontouchmove", this, "onMouseMove"),

			// And these are called at the end of the drag
			dojo.connect(d, "onmouseup",   this, "onMouseUp"),
			dojo.connect(d, "ontouchend", this, "onMouseUp"),

			// cancel text selection and text dragging
			dojo.connect(d, "ondragstart",   dojo.stopEvent),
			dojo.connect(d.body, "onselectstart", dojo.stopEvent)
		];
		// notify that the move has started
		if(h && h.onMoveStart){
			h.onMoveStart(this);
		}
	},
	// mouse event processors
	onMouseMove: function(e){
		// summary:
		//		event processor for onmousemove/ontouchmove
		// e: Event
		//		mouse/touch event
		dojo.dnd.autoScroll(e);
		var m = this.marginBox,
			pos = e.touches ? e.touches[0] : e;
		this.host.onMove(this, {l: m.l + pos.pageX, t: m.t + pos.pageY}, e);
		dojo.stopEvent(e);
	},
	onMouseUp: function(e){
		if(dojo.isWebKit && dojo.isMac && this.mouseButton == 2 ?
				e.button == 0 : this.mouseButton == e.button){ // TODO Should condition be met for touch devices, too?
			this.destroy();
		}
		dojo.stopEvent(e);
	},
	// utilities
	onFirstMove: function(e){
		// summary:
		//		makes the node absolute; it is meant to be called only once.
		// 		relative and absolutely positioned nodes are assumed to use pixel units
		var s = this.node.style, l, t, h = this.host;
		switch(s.position){
			case "relative":
			case "absolute":
				// assume that left and top values are in pixels already
				l = Math.round(parseFloat(s.left)) || 0;
				t = Math.round(parseFloat(s.top)) || 0;
				break;
			default:
				s.position = "absolute";	// enforcing the absolute mode
				var m = dojo.marginBox(this.node);
				// event.pageX/pageY (which we used to generate the initial
				// margin box) includes padding and margin set on the body.
				// However, setting the node's position to absolute and then
				// doing dojo.marginBox on it *doesn't* take that additional
				// space into account - so we need to subtract the combined
				// padding and margin.  We use getComputedStyle and
				// _getMarginBox/_getContentBox to avoid the extra lookup of
				// the computed style.
				var b = dojo.doc.body;
				var bs = dojo.getComputedStyle(b);
				var bm = dojo._getMarginBox(b, bs);
				var bc = dojo._getContentBox(b, bs);
				l = m.l - (bc.l - bm.l);
				t = m.t - (bc.t - bm.t);
				break;
		}
		this.marginBox.l = l - this.marginBox.l;
		this.marginBox.t = t - this.marginBox.t;
		if(h && h.onFirstMove){
			h.onFirstMove(this, e);
		}
		
		// Disconnect onmousemove and ontouchmove events that call this function
		dojo.disconnect(this.events.shift());
		dojo.disconnect(this.events.shift());
	},
	destroy: function(){
		// summary:
		//		stops the move, deletes all references, so the object can be garbage-collected
		dojo.forEach(this.events, dojo.disconnect);
		// undo global settings
		var h = this.host;
		if(h && h.onMoveStop){
			h.onMoveStop(this);
		}
		// destroy objects
		this.events = this.node = this.host = null;
	}
});

}

if(!dojo._hasResource["dojo.dnd.Moveable"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.Moveable"] = true;
dojo.provide("dojo.dnd.Moveable");



/*=====
dojo.declare("dojo.dnd.__MoveableArgs", [], {
	// handle: Node||String
	//		A node (or node's id), which is used as a mouse handle.
	//		If omitted, the node itself is used as a handle.
	handle: null,

	// delay: Number
	//		delay move by this number of pixels
	delay: 0,

	// skip: Boolean
	//		skip move of form elements
	skip: false,

	// mover: Object
	//		a constructor of custom Mover
	mover: dojo.dnd.Mover
});
=====*/

dojo.declare("dojo.dnd.Moveable", null, {
	// object attributes (for markup)
	handle: "",
	delay: 0,
	skip: false,
	
	constructor: function(node, params){
		// summary:
		//		an object, which makes a node moveable
		// node: Node
		//		a node (or node's id) to be moved
		// params: dojo.dnd.__MoveableArgs?
		//		optional parameters
		this.node = dojo.byId(node);
		if(!params){ params = {}; }
		this.handle = params.handle ? dojo.byId(params.handle) : null;
		if(!this.handle){ this.handle = this.node; }
		this.delay = params.delay > 0 ? params.delay : 0;
		this.skip  = params.skip;
		this.mover = params.mover ? params.mover : dojo.dnd.Mover;
		this.events = [
			dojo.connect(this.handle, "onmousedown", this, "onMouseDown"),
			dojo.connect(this.handle, "ontouchstart", this, "onMouseDown"),
			// cancel text selection and text dragging
			dojo.connect(this.handle, "ondragstart",   this, "onSelectStart"),
			dojo.connect(this.handle, "onselectstart", this, "onSelectStart")
		];
	},

	// markup methods
	markupFactory: function(params, node){
		return new dojo.dnd.Moveable(node, params);
	},

	// methods
	destroy: function(){
		// summary:
		//		stops watching for possible move, deletes all references, so the object can be garbage-collected
		dojo.forEach(this.events, dojo.disconnect);
		this.events = this.node = this.handle = null;
	},
	
	// mouse event processors
	onMouseDown: function(e){
		// summary:
		//		event processor for onmousedown/ontouchstart, creates a Mover for the node
		// e: Event
		//		mouse/touch event
		if(this.skip && dojo.dnd.isFormElement(e)){ return; }
		if(this.delay){
			this.events.push(
				dojo.connect(this.handle, "onmousemove", this, "onMouseMove"),
				dojo.connect(this.handle, "ontouchmove", this, "onMouseMove"),
				dojo.connect(this.handle, "onmouseup", this, "onMouseUp"),
				dojo.connect(this.handle, "ontouchend", this, "onMouseUp")
			);
			var pos = e.touches ? e.touches[0] : e;
			this._lastX = pos.pageX;
			this._lastY = pos.pageY;
		}else{
			this.onDragDetected(e);
		}
		dojo.stopEvent(e);
	},
	onMouseMove: function(e){
		// summary:
		//		event processor for onmousemove/ontouchmove, used only for delayed drags
		// e: Event
		//		mouse/touch event
		var pos = e.touches ? e.touches[0] : e;
		if(Math.abs(pos.pageX - this._lastX) > this.delay || Math.abs(pos.pageY - this._lastY) > this.delay){
			this.onMouseUp(e);
			this.onDragDetected(e);
		}
		dojo.stopEvent(e);
	},
	onMouseUp: function(e){
		// summary:
		//		event processor for onmouseup, used only for delayed drags
		// e: Event
		//		mouse event
		for(var i = 0; i < 2; ++i){
			dojo.disconnect(this.events.pop());
		}
		dojo.stopEvent(e);
	},
	onSelectStart: function(e){
		// summary:
		//		event processor for onselectevent and ondragevent
		// e: Event
		//		mouse event
		if(!this.skip || !dojo.dnd.isFormElement(e)){
			dojo.stopEvent(e);
		}
	},
	
	// local events
	onDragDetected: function(/* Event */ e){
		// summary:
		//		called when the drag is detected;
		//		responsible for creation of the mover
		new this.mover(this.node, e, this);
	},
	onMoveStart: function(/* dojo.dnd.Mover */ mover){
		// summary:
		//		called before every move operation
		dojo.publish("/dnd/move/start", [mover]);
		dojo.addClass(dojo.body(), "dojoMove");
		dojo.addClass(this.node, "dojoMoveItem");
	},
	onMoveStop: function(/* dojo.dnd.Mover */ mover){
		// summary:
		//		called after every move operation
		dojo.publish("/dnd/move/stop", [mover]);
		dojo.removeClass(dojo.body(), "dojoMove");
		dojo.removeClass(this.node, "dojoMoveItem");
	},
	onFirstMove: function(/* dojo.dnd.Mover */ mover, /* Event */ e){
		// summary:
		//		called during the very first move notification;
		//		can be used to initialize coordinates, can be overwritten.
		
		// default implementation does nothing
	},
	onMove: function(/* dojo.dnd.Mover */ mover, /* Object */ leftTop, /* Event */ e){
		// summary:
		//		called during every move notification;
		//		should actually move the node; can be overwritten.
		this.onMoving(mover, leftTop);
		var s = mover.node.style;
		s.left = leftTop.l + "px";
		s.top  = leftTop.t + "px";
		this.onMoved(mover, leftTop);
	},
	onMoving: function(/* dojo.dnd.Mover */ mover, /* Object */ leftTop){
		// summary:
		//		called before every incremental move; can be overwritten.
		
		// default implementation does nothing
	},
	onMoved: function(/* dojo.dnd.Mover */ mover, /* Object */ leftTop){
		// summary:
		//		called after every incremental move; can be overwritten.
		
		// default implementation does nothing
	}
});

}

if(!dojo._hasResource["dojo.dnd.move"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.move"] = true;
dojo.provide("dojo.dnd.move");




/*=====
dojo.declare("dojo.dnd.move.__constrainedMoveableArgs", [dojo.dnd.__MoveableArgs], {
	// constraints: Function
	//		Calculates a constraint box.
	//		It is called in a context of the moveable object.
	constraints: function(){},

	// within: Boolean
	//		restrict move within boundaries.
	within: false
});
=====*/

dojo.declare("dojo.dnd.move.constrainedMoveable", dojo.dnd.Moveable, {
	// object attributes (for markup)
	constraints: function(){},
	within: false,
	
	// markup methods
	markupFactory: function(params, node){
		return new dojo.dnd.move.constrainedMoveable(node, params);
	},

	constructor: function(node, params){
		// summary:
		//		an object that makes a node moveable
		// node: Node
		//		a node (or node's id) to be moved
		// params: dojo.dnd.move.__constrainedMoveableArgs?
		//		an optional object with additional parameters;
		//		the rest is passed to the base class
		if(!params){ params = {}; }
		this.constraints = params.constraints;
		this.within = params.within;
	},
	onFirstMove: function(/* dojo.dnd.Mover */ mover){
		// summary:
		//		called during the very first move notification;
		//		can be used to initialize coordinates, can be overwritten.
		var c = this.constraintBox = this.constraints.call(this, mover);
		c.r = c.l + c.w;
		c.b = c.t + c.h;
		if(this.within){
			var mb = dojo._getMarginSize(mover.node);
			c.r -= mb.w;
			c.b -= mb.h;
		}
	},
	onMove: function(/* dojo.dnd.Mover */ mover, /* Object */ leftTop){
		// summary:
		//		called during every move notification;
		//		should actually move the node; can be overwritten.
		var c = this.constraintBox, s = mover.node.style;
		this.onMoving(mover, leftTop);
		leftTop.l = leftTop.l < c.l ? c.l : c.r < leftTop.l ? c.r : leftTop.l;
		leftTop.t = leftTop.t < c.t ? c.t : c.b < leftTop.t ? c.b : leftTop.t;
		s.left = leftTop.l + "px";
		s.top  = leftTop.t + "px";
		this.onMoved(mover, leftTop);
	}
});

/*=====
dojo.declare("dojo.dnd.move.__boxConstrainedMoveableArgs", [dojo.dnd.move.__constrainedMoveableArgs], {
	// box: Object
	//		a constraint box
	box: {}
});
=====*/

dojo.declare("dojo.dnd.move.boxConstrainedMoveable", dojo.dnd.move.constrainedMoveable, {
	// box:
	//		object attributes (for markup)
	box: {},
	
	// markup methods
	markupFactory: function(params, node){
		return new dojo.dnd.move.boxConstrainedMoveable(node, params);
	},

	constructor: function(node, params){
		// summary:
		//		an object, which makes a node moveable
		// node: Node
		//		a node (or node's id) to be moved
		// params: dojo.dnd.move.__boxConstrainedMoveableArgs?
		//		an optional object with parameters
		var box = params && params.box;
		this.constraints = function(){ return box; };
	}
});

/*=====
dojo.declare("dojo.dnd.move.__parentConstrainedMoveableArgs", [dojo.dnd.move.__constrainedMoveableArgs], {
	// area: String
	//		A parent's area to restrict the move.
	//		Can be "margin", "border", "padding", or "content".
	area: ""
});
=====*/

dojo.declare("dojo.dnd.move.parentConstrainedMoveable", dojo.dnd.move.constrainedMoveable, {
	// area:
	//		object attributes (for markup)
	area: "content",

	// markup methods
	markupFactory: function(params, node){
		return new dojo.dnd.move.parentConstrainedMoveable(node, params);
	},

	constructor: function(node, params){
		// summary:
		//		an object, which makes a node moveable
		// node: Node
		//		a node (or node's id) to be moved
		// params: dojo.dnd.move.__parentConstrainedMoveableArgs?
		//		an optional object with parameters
		var area = params && params.area;
		this.constraints = function(){
			var n = this.node.parentNode,
				s = dojo.getComputedStyle(n),
				mb = dojo._getMarginBox(n, s);
			if(area == "margin"){
				return mb;	// Object
			}
			var t = dojo._getMarginExtents(n, s);
			mb.l += t.l, mb.t += t.t, mb.w -= t.w, mb.h -= t.h;
			if(area == "border"){
				return mb;	// Object
			}
			t = dojo._getBorderExtents(n, s);
			mb.l += t.l, mb.t += t.t, mb.w -= t.w, mb.h -= t.h;
			if(area == "padding"){
				return mb;	// Object
			}
			t = dojo._getPadExtents(n, s);
			mb.l += t.l, mb.t += t.t, mb.w -= t.w, mb.h -= t.h;
			return mb;	// Object
		};
	}
});

// patching functions one level up for compatibility

dojo.dnd.constrainedMover = dojo.dnd.move.constrainedMover;
dojo.dnd.boxConstrainedMover = dojo.dnd.move.boxConstrainedMover;
dojo.dnd.parentConstrainedMover = dojo.dnd.move.parentConstrainedMover;

}

if(!dojo._hasResource["dojo.dnd.TimedMoveable"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.TimedMoveable"] = true;
dojo.provide("dojo.dnd.TimedMoveable");



/*=====
dojo.declare("dojo.dnd.__TimedMoveableArgs", [dojo.dnd.__MoveableArgs], {
	// timeout: Number
	//		delay move by this number of ms,
	//		accumulating position changes during the timeout
	timeout: 0
});
=====*/

(function(){
	// precalculate long expressions
	var oldOnMove = dojo.dnd.Moveable.prototype.onMove;
		
	dojo.declare("dojo.dnd.TimedMoveable", dojo.dnd.Moveable, {
		// summary:
		//		A specialized version of Moveable to support an FPS throttling.
		//		This class puts an upper restriction on FPS, which may reduce
		//		the CPU load. The additional parameter "timeout" regulates
		//		the delay before actually moving the moveable object.
		
		// object attributes (for markup)
		timeout: 40,	// in ms, 40ms corresponds to 25 fps
	
		constructor: function(node, params){
			// summary:
			//		an object that makes a node moveable with a timer
			// node: Node||String
			//		a node (or node's id) to be moved
			// params: dojo.dnd.__TimedMoveableArgs
			//		object with additional parameters.
			
			// sanitize parameters
			if(!params){ params = {}; }
			if(params.timeout && typeof params.timeout == "number" && params.timeout >= 0){
				this.timeout = params.timeout;
			}
		},
	
		// markup methods
		markupFactory: function(params, node){
			return new dojo.dnd.TimedMoveable(node, params);
		},
	
		onMoveStop: function(/* dojo.dnd.Mover */ mover){
			if(mover._timer){
				// stop timer
				clearTimeout(mover._timer)
				// reflect the last received position
				oldOnMove.call(this, mover, mover._leftTop)
			}
			dojo.dnd.Moveable.prototype.onMoveStop.apply(this, arguments);
		},
		onMove: function(/* dojo.dnd.Mover */ mover, /* Object */ leftTop){
			mover._leftTop = leftTop;
			if(!mover._timer){
				var _t = this;	// to avoid using dojo.hitch()
				mover._timer = setTimeout(function(){
					// we don't have any pending requests
					mover._timer = null;
					// reflect the last received position
					oldOnMove.call(_t, mover, mover._leftTop);
				}, this.timeout);
			}
		}
	});
})();

}

if(!dojo._hasResource["dojo.i18n"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.i18n"] = true;
dojo.provide("dojo.i18n");

dojo.getObject("i18n", true, dojo);

/*=====
dojo.i18n = {
	// summary: Utility classes to enable loading of resources for internationalization (i18n)
};
=====*/

// when using a real AMD loader, dojo.i18n.getLocalization is already defined by dojo/lib/backCompat
dojo.i18n.getLocalization = dojo.i18n.getLocalization || function(/*String*/packageName, /*String*/bundleName, /*String?*/locale){
	//	summary:
	//		Returns an Object containing the localization for a given resource
	//		bundle in a package, matching the specified locale.
	//	description:
	//		Returns a hash containing name/value pairs in its prototypesuch
	//		that values can be easily overridden.  Throws an exception if the
	//		bundle is not found.  Bundle must have already been loaded by
	//		`dojo.requireLocalization()` or by a build optimization step.  NOTE:
	//		try not to call this method as part of an object property
	//		definition (`var foo = { bar: dojo.i18n.getLocalization() }`).  In
	//		some loading situations, the bundle may not be available in time
	//		for the object definition.  Instead, call this method inside a
	//		function that is run after all modules load or the page loads (like
	//		in `dojo.addOnLoad()`), or in a widget lifecycle method.
	//	packageName:
	//		package which is associated with this resource
	//	bundleName:
	//		the base filename of the resource bundle (without the ".js" suffix)
	//	locale:
	//		the variant to load (optional).  By default, the locale defined by
	//		the host environment: dojo.locale

	locale = dojo.i18n.normalizeLocale(locale);

	// look for nearest locale match
	var elements = locale.split('-');
	var module = [packageName,"nls",bundleName].join('.');
		var bundle = dojo._loadedModules[module];
	if(bundle){
		var localization;
		for(var i = elements.length; i > 0; i--){
			var loc = elements.slice(0, i).join('_');
			if(bundle[loc]){
				localization = bundle[loc];
				break;
			}
		}
		if(!localization){
			localization = bundle.ROOT;
		}

		// make a singleton prototype so that the caller won't accidentally change the values globally
		if(localization){
			var clazz = function(){};
			clazz.prototype = localization;
			return new clazz(); // Object
		}
	}

	throw new Error("Bundle not found: " + bundleName + " in " + packageName+" , locale=" + locale);
};

dojo.i18n.normalizeLocale = function(/*String?*/locale){
	//	summary:
	//		Returns canonical form of locale, as used by Dojo.
	//
	//  description:
	//		All variants are case-insensitive and are separated by '-' as specified in [RFC 3066](http://www.ietf.org/rfc/rfc3066.txt).
	//		If no locale is specified, the dojo.locale is returned.  dojo.locale is defined by
	//		the user agent's locale unless overridden by djConfig.

	var result = locale ? locale.toLowerCase() : dojo.locale;
	if(result == "root"){
		result = "ROOT";
	}
	return result; // String
};

dojo.i18n._requireLocalization = function(/*String*/moduleName, /*String*/bundleName, /*String?*/locale, /*String?*/availableFlatLocales){
	//	summary:
	//		See dojo.requireLocalization()
	//	description:
	// 		Called by the bootstrap, but factored out so that it is only
	// 		included in the build when needed.

	var targetLocale = dojo.i18n.normalizeLocale(locale);
 	var bundlePackage = [moduleName, "nls", bundleName].join(".");
	// NOTE:
	//		When loading these resources, the packaging does not match what is
	//		on disk.  This is an implementation detail, as this is just a
	//		private data structure to hold the loaded resources.  e.g.
	//		`tests/hello/nls/en-us/salutations.js` is loaded as the object
	//		`tests.hello.nls.salutations.en_us={...}` The structure on disk is
	//		intended to be most convenient for developers and translators, but
	//		in memory it is more logical and efficient to store in a different
	//		order.  Locales cannot use dashes, since the resulting path will
	//		not evaluate as valid JS, so we translate them to underscores.

	//Find the best-match locale to load if we have available flat locales.
	var bestLocale = "";
	if(availableFlatLocales){
		var flatLocales = availableFlatLocales.split(",");
		for(var i = 0; i < flatLocales.length; i++){
			//Locale must match from start of string.
			//Using ["indexOf"] so customBase builds do not see
			//this as a dojo._base.array dependency.
			if(targetLocale["indexOf"](flatLocales[i]) == 0){
				if(flatLocales[i].length > bestLocale.length){
					bestLocale = flatLocales[i];
				}
			}
		}
		if(!bestLocale){
			bestLocale = "ROOT";
		}
	}

	//See if the desired locale is already loaded.
	var tempLocale = availableFlatLocales ? bestLocale : targetLocale;
	var bundle = dojo._loadedModules[bundlePackage];
	var localizedBundle = null;
	if(bundle){
		if(dojo.config.localizationComplete && bundle._built){return;}
		var jsLoc = tempLocale.replace(/-/g, '_');
		var translationPackage = bundlePackage+"."+jsLoc;
		localizedBundle = dojo._loadedModules[translationPackage];
	}

	if(!localizedBundle){
		bundle = dojo["provide"](bundlePackage);
		var syms = dojo._getModuleSymbols(moduleName);
		var modpath = syms.concat("nls").join("/");
		var parent;

		dojo.i18n._searchLocalePath(tempLocale, availableFlatLocales, function(loc){
			var jsLoc = loc.replace(/-/g, '_');
			var translationPackage = bundlePackage + "." + jsLoc;
			var loaded = false;
			if(!dojo._loadedModules[translationPackage]){
				// Mark loaded whether it's found or not, so that further load attempts will not be made
				dojo["provide"](translationPackage);
				var module = [modpath];
				if(loc != "ROOT"){module.push(loc);}
				module.push(bundleName);
				var filespec = module.join("/") + '.js';
				loaded = dojo._loadPath(filespec, null, function(hash){
					hash = hash.root || hash;
					// Use singleton with prototype to point to parent bundle, then mix-in result from loadPath
					var clazz = function(){};
					clazz.prototype = parent;
					bundle[jsLoc] = new clazz();
					for(var j in hash){ bundle[jsLoc][j] = hash[j]; }
				});
			}else{
				loaded = true;
			}
			if(loaded && bundle[jsLoc]){
				parent = bundle[jsLoc];
			}else{
				bundle[jsLoc] = parent;
			}

			if(availableFlatLocales){
				//Stop the locale path searching if we know the availableFlatLocales, since
				//the first call to this function will load the only bundle that is needed.
				return true;
			}
		});
	}

	//Save the best locale bundle as the target locale bundle when we know the
	//the available bundles.
	if(availableFlatLocales && targetLocale != bestLocale){
		bundle[targetLocale.replace(/-/g, '_')] = bundle[bestLocale.replace(/-/g, '_')];
	}
};

(function(){
	// If other locales are used, dojo.requireLocalization should load them as
	// well, by default.
	//
	// Override dojo.requireLocalization to do load the default bundle, then
	// iterate through the extraLocale list and load those translations as
	// well, unless a particular locale was requested.

	var extra = dojo.config.extraLocale;
	if(extra){
		if(!extra instanceof Array){
			extra = [extra];
		}

		var req = dojo.i18n._requireLocalization;
		dojo.i18n._requireLocalization = function(m, b, locale, availableFlatLocales){
			req(m,b,locale, availableFlatLocales);
			if(locale){return;}
			for(var i=0; i<extra.length; i++){
				req(m,b,extra[i], availableFlatLocales);
			}
		};
	}
})();

dojo.i18n._searchLocalePath = function(/*String*/locale, /*Boolean*/down, /*Function*/searchFunc){
	//	summary:
	//		A helper method to assist in searching for locale-based resources.
	//		Will iterate through the variants of a particular locale, either up
	//		or down, executing a callback function.  For example, "en-us" and
	//		true will try "en-us" followed by "en" and finally "ROOT".

	locale = dojo.i18n.normalizeLocale(locale);

	var elements = locale.split('-');
	var searchlist = [];
	for(var i = elements.length; i > 0; i--){
		searchlist.push(elements.slice(0, i).join('-'));
	}
	searchlist.push(false);
	if(down){searchlist.reverse();}

	for(var j = searchlist.length - 1; j >= 0; j--){
		var loc = searchlist[j] || "ROOT";
		var stop = searchFunc(loc);
		if(stop){ break; }
	}
};

dojo.i18n._preloadLocalizations = function(/*String*/bundlePrefix, /*Array*/localesGenerated){
	//	summary:
	//		Load built, flattened resource bundles, if available for all
	//		locales used in the page. Only called by built layer files.

	function preload(locale){
		locale = dojo.i18n.normalizeLocale(locale);
		dojo.i18n._searchLocalePath(locale, true, function(loc){
			for(var i=0; i<localesGenerated.length;i++){
				if(localesGenerated[i] == loc){
					dojo["require"](bundlePrefix+"_"+loc);
					return true; // Boolean
				}
			}
			return false; // Boolean
		});
	}
	preload();
	var extra = dojo.config.extraLocale||[];
	for(var i=0; i<extra.length; i++){
		preload(extra[i]);
	}
};

}

if(!dojo._hasResource["epages._workaround"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages._workaround"] = true;
dojo.provide("epages._workaround");

dojo['requireLocalization']("dojo.cldr", "gregorian");

epages._workaround.load = function(module) {
	if( module == 'dojo.parser' ){
		/* on run dojo parser run jQuery metaparse also */
		var parser = dojo.parser.parse;
		dojo.parser.parse = function( rootNode, args ){
			jQuery(document).on('metaparse',function () {
				jQuery(rootNode)
					.find('.ep-js')
					.metaparse();
				});
			return parser.call( dojo.parser, rootNode, args );
		};
		return;
	}

	if (module == 'epages.widget.Calendar' && dojo.version.revision == '0') {

		dijit._placeOnScreenAroundRect = function(
			/* DomNode */		node,
			/* Number */		x,
			/* Number */		y,
			/* Number */		width,
			/* Number */		height,
			/* Object */		aroundCorners,
			/* Function */		layoutNode){

			// summary:
			//		Like dijit.placeOnScreenAroundNode(), except it accepts coordinates
			//		of a rectangle to place node adjacent to.

			// TODO: combine with placeOnScreenAroundRectangle()

			// Generate list of possible positions for node
			var choices = [];
			for(var nodeCorner in aroundCorners){
				choices.push( {
					aroundCorner: nodeCorner,
					corner: aroundCorners[nodeCorner],
					pos: {
						x: x + (nodeCorner.charAt(1) == 'L' ? 0 : width),
						y: y + (nodeCorner.charAt(0) == 'T' ? 0 : height)
					}
				});
			}
		//Start of workaround
			// only correct popups (calendar) with {'BR':'TR','BL':'TL'}
			if (choices.length == 2 &&
				  choices[0].aroundCorner == 'BR' && choices[0].corner == 'TR' &&
					choices[1].aroundCorner == 'BL' && choices[1].corner == 'TL') {
						choices = choices.reverse();
			}
		//End of Workaround
			return dijit._place(node, choices, layoutNode);
		};

		return;
	}

	if (module == 'dijit.Tree' && dojo.version.revision == '20973') {

		//add publish to expand method of tree nodes
		dojo.connect(dijit._TreeNode.prototype, "expand", function() {
			dojo.publish(this.tree.id+'/nodeexpand',[this]);
		});

		return;
	}
	else if (module == 'dojo.cldr.supplemental') {
		dojo.cldr.supplemental.getFirstDayOfWeek = function(/*String?*/locale){
			if (dojo.i18n.normalizeLocale(locale) == djConfig.locale){
				return epages.vars.Locale.firstDayOfWeek;
			}
			// summary: Returns a zero-based index for first day of the week
			// description:
			//		Returns a zero-based index for first day of the week, as used by the local (Gregorian) calendar.
			//		e.g. Sunday (returns 0), or Monday (returns 1)

			// from http://www.unicode.org/cldr/data/common/supplemental/supplementalData.xml:supplementalData/weekData/firstDay
			var firstDay = {/*default is 1=Monday*/
				mv:5,
				ae:6,af:6,bh:6,dj:6,dz:6,eg:6,er:6,et:6,iq:6,ir:6,jo:6,ke:6,kw:6,lb:6,ly:6,ma:6,om:6,qa:6,sa:6,
				sd:6,so:6,tn:6,ye:6,
				as:0,au:0,az:0,bw:0,ca:0,cn:0,fo:0,ge:0,gl:0,gu:0,hk:0,ie:0,il:0,is:0,jm:0,jp:0,kg:0,kr:0,la:0,
				mh:0,mo:0,mp:0,mt:0,nz:0,ph:0,pk:0,sg:0,th:0,tt:0,tw:0,um:0,us:0,uz:0,vi:0,za:0,zw:0,
				et:0,mw:0,ng:0,tj:0,
				// variant. do not use?		gb:0,
				sy:4
			};

			var country = dojo.cldr.supplemental._region(locale);
			var dow = firstDay[country];
			return (dow === undefined) ? 1 : dow; /*Number*/
		};

		return;
	}

	if(module == 'dijit._Widget' && dojo.version.revision == '20973'){
		dijit._Widget.prototype._deferredConnects = {};

		return;
	}
};

dojo.connect(dojo, "require", epages._workaround, "load");




}

if(!dojo._hasResource["epages.epages"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.epages"] = true;
/*  EPages JavaScript module
 *  (c) 2006 ePages GmbH
 *--------------------------------------------------------------------------*/
dojo.provide("epages.epages");

(function() {
	// is this called in an iframe?
	// these vars are set, when epages is loaded in an iframe

	window.parentDojo = undefined;
	window.restrictedParent = undefined;

	try {
		window.parentDojo = parent.dojo ? parent.dojo : undefined;
		if(parent != self && !parent.dojo) {
			window.restrictedParent = true; // IE never throws an error inside of this try-catch statement
			dojo._global_omit_module_check = true; // dojo's module check would fail for IE in that case
		}
	}catch(ex) {
		window.restrictedParent = true;	// page embedded into cross site iframe -> resticted access
	}

	if(parent != self && window.parentDojo !== undefined) {
		parent.epages._windows.push(window);
		for( var i=0,iLength=parent.epages.onIframeStart.length ; i<iLength ; i++ ) {
			parent.epages.onIframeStart[i](parent, window);
		}
		// epages NavBars are globals
		if(epages.NavBars == undefined){
			epages.NavBars = {};
		}
		epages.NavBars = parent.epages.NavBars;
	}
})();

dojo.subscribe('epages/addGlobalSymbol', function(gvn, win) {
	if (win === undefined) {
		console.warn('no target window for addGlobalSymbol');
		return;
	}
	if (win[gvn] != null){
		return;
	}

	if(window.parentDojo){
		win[gvn] = parent[gvn];
	}
});

dojo.mixin( epages, {
	onIframeStart: [],
	onUnloadFunctions: [],
	topDojo: (parent != self && window.parentDojo !== undefined) ? window.parentDojo : dojo,
	topWindow: parent,
	constants: {
		preventCache: false,
		doFlashForward: true
	},
	theme: {
		name: 'epages',
		url:  dojo.moduleUrl('dijit.themes', 'epages')
	},
	// all known windows using epages
	_windows: [ window ],
	// all global vars
	_gvs: {},
	zIndex: 450,

	buildNode: function(attributeArray /* Array */, nodeOrTagRef /* String or DOM node */, content /* String - Optional */, containerNodeName /* String */) {
		// summary:
		//		Injects or expands a node in the current page source.
		// description:
		//		Since we're using attributes that are not valid XHTML syntax we have to cloak
		//		the instantiation of nodes with such attributes attached.
		//
		//		In the future this method could be used to increase the rendering performance.
		//		If the global configuration attribute "djConfig.parseOnLoad" is set to "false"
		//		we could take care of the parsing process in here (and therefore would save
		//		time which is now spent for the global dojo.query("[dojoType]") method).
		// attributeArray:
		//		An array with subarrays of the attributes to be attached to the node.
		// nodeOrTagRef:
		//		Can be a plain tag name > A new node with the specified tag will be created.
		//		Can be a node id as string > The specified node will be extended.
		//		Can be a node reference itself > The specified node will be extended.
		// content:
		//		The new content of the node.
		// example:
		//		epages.buildNode([
		//			["type", "text"],
		//			["dojoType", "epages.widget.NumberSpinner"],
		//			["name", "Quantity"],
		//			["class", "Quantity"],
		//			["value", "#MinOrder[float]"],
		//			["delta", "#IntervalOrder[float]"]
		//		], "input");

		if(attributeArray && attributeArray.length && nodeOrTagRef ) {

			var node;						// main node reference
			var containerNode;	// temporary parent node (never inserted to the DOM)

			if(typeof(nodeOrTagRef) === "string") {
				var nodeRef = $(nodeOrTagRef);
				if(nodeRef) {
					// an id string is passed
					node = nodeRef;
				}else {
					// a tag name is passed
					node = document.createElement(nodeOrTagRef);
					containerNode = document.createElement("div");
				}
			}else {
				// a node reference is passed
				node = nodeOrTagRef;
			}

			if(content) { // rewrites an existing node
				node.innerHTML = content;
			}

			for( var i=0,iLength=attributeArray.length ; i<iLength ; i++ ) {
				if(attributeArray[i][0] === "style") {
					node.style.cssText = attributeArray[i][1];
				}else if(attributeArray[i][0] === "name" && epages.Browser.engine === "MSIE") {
					// somehow the native attribute "name" is written uppercase in the MSIE. Hence we're attaching it separately for this browser.
					node.Name = attributeArray[i][1];
				}else {
					node.setAttribute(attributeArray[i][0], attributeArray[i][1]);
				}
			}

			if(containerNode) {
				if(!containerNodeName) {
					console.warn("error in buildNode method: no containerNodeName string given as container for creating new DOM nodes");
					return;
				}
				containerNode.appendChild(node);
				//document.write(containerNode.innerHTML);
				dojo.create('div', { 'innerHTML' : containerNode.innerHTML, 'style' : 'display:inline' }, containerNodeName, 'before');
			}
		}
	},

	flashForward: function () {
		return epages.constants.doFlashForward;
	},

	setTheme: function (/*String*/theme) {
		var body = dojo.body();
		var old = epages.theme.name;
		if (body){
			dojo.removeClass(body, epages.theme.name);
		} else {
			dojo.addOnLoad(function() {
				var body = dojo.body();
				if (body) {
					dojo.removeClass(body, epages.theme.name);
					dojo.addClass(body, theme);
				}
			});
		}
		epages.theme.name= theme;
		epages.theme.url = dojo.moduleUrl('dijit.themes', theme);
		if (body){
			dojo.addClass(body, theme);
		}
	},

	themeUrl: function (/*String*/path) {
		return epages.vars.IconsRoot;
	},

	reload: function() {
		window.location.hash += "0";
		var url = window.location.href;
		window.location.href = url.substring(0, url.indexOf('#'));
	},

	locationHref: function(uri) {
		window.location.href = uri.substr(0,1) == '?' ? epages.vars.BaseUrl + uri : uri;
	},

	setFormAction: function(formRef, newAction) {
		formRef.action = newAction.substr(0,1) == '?' ? epages.vars.BaseUrl + newAction : newAction;
	},

	locationWebRoot: function(uri) {
		return window.location.protocol + '//' + window.location.host + uri;
	},

	Class: function() {
		return function() {
			this.initialize.apply(this, arguments);
		};
	},

	changeSampleText: function(newdata,group) {
	// this function replaces the data in samp tags (newdata) which are specified
	// by their title attributes (group)
		if(!newdata){
			newdata="";
		}
		var sampletags = document.getElementsByTagName("samp");
		for( var i=0,iLength=sampletags.length ; i<iLength ; i++ ) {
			if(sampletags[i].getAttribute("title") == group) {
				if(sampletags[i].firstChild) {
					sampletags[i].firstChild.data = newdata;
				} else {
					var mydata = document.createTextNode(newdata);
					sampletags[i].appendChild(mydata);
				}
			}
		}
	},

	toggleNodes: function(className /* class of toggled elements */, clearSpace /* true = "display" else "visibility" */, classLimiter /* element that is been scanned for className */) {
		if(typeof className == "string") {
			if(typeof classLimiter == "undefined") {classLimiter = document;}
			if(typeof classLimiter == "string") {classLimiter = document.getElementById(classLimiter);}
			var domElements = classLimiter.getElementsByTagName("*");
			for( var i=0,iLength=domElements.length ; i<iLength ; i++ ) {
				if(domElements[i].attributes && domElements[i].attributes["class"] &&
						domElements[i].attributes["class"].nodeValue.indexOf(className) > -1) {
					if(clearSpace) {
						if(domElements[i].className.match(/HideNode/)) {
								domElements[i].className = domElements[i].className.replace(/HideNode/,'ShowNode');
						}else{
							if(domElements[i].className.match(/ShowNode/)) {
								domElements[i].className = domElements[i].className.replace(/ShowNode/,'HideNode');
							}else {
								if(domElements[i].style.display == "none"){
									domElements[i].style.display = "";
								}else if(domElements[i].style.display != "none"){
									domElements[i].style.display = "none";
								}
							}
						}
						if(domElements[i].className.match(/HideElement/)) {
								domElements[i].className = domElements[i].className.replace(/HideElement/,'ShowElement');
						}
					}else{
						if(domElements[i].style.visibility == "hidden") {
							domElements[i].style.visibility = "visible";
							if(domElements[i].style.display == "none"){
								domElements[i].style.display = "";
							}
							domElements[i].className = domElements[i].className.replace(/HideNode/,'ShowNode');
							domElements[i].className = domElements[i].className.replace(/HideElement/,'ShowElement');
						}else{
							domElements[i].style.visibility = "hidden";
						}
					}
				}
			}
		}
	},

	changeDelimiter: function(DelimiterSymbol, SelectId){
			switch(DelimiterSymbol) {
					case ',' :
					document.getElementById(SelectId).options[0].selected = 'selected';
					break;
					case ';' :
					document.getElementById(SelectId).options[1].selected = 'selected';
					break;
					default :
					document.getElementById(SelectId).options[2].selected = 'selected';
					break;
			}
	},

	toggleLink: function(LinkName){
		if(document.getElementsByName(LinkName)[0].className == 'ShowLink') {
			document.getElementsByName(LinkName)[0].className = 'HideLink';
		}
		else {
			document.getElementsByName(LinkName)[0].className = 'ShowLink';
		}
	},

	/* - MBO Search (Toolbar) -------------------------------------------------------------*/
	toggleExtender: function(object){
		// toggles between the image file names of the extend button
		// object => image node
		var splittedFilename = object.src.split("/");
		var lastItemNo = splittedFilename.length-1;
		var lastItem = splittedFilename[lastItemNo];

		if(lastItem=="toolbar_ico_s_extend.png") {
			splittedFilename[lastItemNo]="toolbar_ico_s_extend_open.png";
		} else {
			splittedFilename[lastItemNo]="toolbar_ico_s_extend.png";
		}
		object.src = splittedFilename.join("/");
	},

	getDocumentWindow: function(doc) {
		return (doc.parentWindow) ? doc.parentWindow : doc.defaultView;
	},

	// returns the url for the iframe wrapper
	// this is useful for external iframes to override/set the charset if it is missing
	getIframeWrapperUrl: function(/*string*/url, /*string?*/charset) {
		var src = '?iframeUrl=' + encodeURIComponent(url);
		if (charset){
			src += '&charset=' + encodeURIComponent(charset);
		}
		return dojo.moduleUrl('epages', 'iframe_wrapper.html') + src;
	},

	require: function(/*string*/packageName,/*modul*/modulName){
		//summary:
		//improve dojo.require to load shrinksafe packages
		//description:
		//check if modul is loaded
		//load package if it is not loaded
		//if package was not loaded correct do normal dojo.require

		// EPG-17181 : just do dojo.require
		if(modulName) {
			return dojo["require"](modulName);
		}
	},

	checkUnit: function(node,unitNode){
		//summary:
		//checks if unitNode has a value if node has a value
		//in error case DialogError class is added
		if(node && unitNode){
			if(unitNode.value === '' && node.value !== ''){
				dojo.addClass(unitNode, 'DialogError');
			}
			else{
				dojo.removeClass(unitNode, 'DialogError');
			}
		}
	}

});

// set default vars if not exists
if( !epages.vars ){
	epages.vars = { Locale: {} };
}

dojo.addOnLoad(function () { epages.setTheme(epages.theme.name); });

// load workarounds
dojo["require"]("epages._workaround");

$ = dojo.byId;

dojo.addOnLoad(function() {
	if(top == self){
		epages.vars.dojoUnloadStuff = window.onbeforeunload;
		window.onbeforeunload = function () {
			var l = false;
			var d = dojo;
			// for each registered epages.onUnloadFunctions element, exec the function and determine whether at least one function returned true
			d.forEach(epages.onUnloadFunctions, function (el) { l |= el(); });

			if (l) {
				d.require('epages.io.translation');
				return epages.io.dictionary.get("LoseChanges");
			}else {
				dojo["require"]("epages.browser");
				if(epages.Browser.engine == "MSIE" && epages.Browser.version > 6) {
					document.getElementsByTagName("body")[0].className += " SuspendUserInteraction";
					setTimeout(function() {
						dojo.removeClass(document.getElementsByTagName("body")[0], "SuspendUserInteraction");
					}, 2000);
					window.onunload = function() {
						if(epages.vars.dojoUnloadStuff) {epages.vars.dojoUnloadStuff();}
					};
				}
			}
			return;
		};
	}
});

epages.parentByTagName = function( node, tagName ){
	while( node.nodeName.toLocaleLowerCase()!=tagName ){
		node = node.parentNode;
		if( node.parentNode==document.body ){
			break;
		}
	}
	return node;
};

// set console (sometimes not set in time and hence throws an error)
try{
window.console = window.console || {};
window.console.debug = window.console.debug || function(){return;};
window.console.warn = window.console.warn || function(){return;};
}
catch(e){}

}

if(!dojo._hasResource['epages.preload']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.preload'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.preload');


epages.Preload = {
	// summary:
	//  preloads the given sources
	// description:
	// |preloads given sources listed in the "files" array
	// |never call the _preloadFiles method directly - simply push the necessary file into the "files" array
	// |there are two required properties: "file" and "priority"
	// |  the "file" property is the path / src to your file
	// |  the "priority" property states the importance of that particular file (e. g. images usually have got a lower priority than js packages)
	// example:
	// | dojo.addOnLoad(function() {
	// |   epages.Preload.add({file:"ep_megapackage.js", priority: 9});
	// | });
	start: function() {
		// summary:
		//  starts / restarts the preloading
		this.stopped = false;
		this._preloadFiles();
	},
	stop: function() {
		// summary:
		//  stops the preload operation on the next queued element
		this.stopped = true;
	},
	add: function(fileObject) {
		// summary:
		//  adds a file to the "files" array
		if(fileObject.file && fileObject.priority) {
			var isAlreadyAdded = false;
			for( var i=0,iLength=this.files.length ; i<iLength ; i++ ) {
				if(this.files[i].file == fileObject.file) {
					isAlreadyAdded = true
					break;
				}
			}
			if(!isAlreadyAdded) {
				this.files.push(fileObject);
			}
		}
	},
	stopped: false,
	_preloadFiles: function() {
		if(!this.stopped && this.files.length > 0) {
			this.nextPreloadFile = this.files[0];
			for( var i=0,iLength=this.files.length ; i<iLength ; i++ ) {
				if(this.files[i].priority >= this.nextPreloadFile.priority) {
					this.nextPreloadFile = this.files[i];
				}
			}
			if(this.nextPreloadFile.priority != -1) {
				this.nextPreloadFile.priority = -1;
				dojo.xhrGet({
					url:  this.nextPreloadFile.file,
					sync: false,
					load: function(){
						epages.Preload._preloadFiles();
						if(djConfig.isDebug){
							console.log('epages.Preload loaded : ',epages.Preload.nextPreloadFile.file);
						}
					},
					error: function(){
						epages.Preload._preloadFiles();
						if(djConfig.isDebug){
							console.warn('epages.Preload could not load : ',epages.Preload.nextPreloadFile.file);
						}
					}
				});
			}
			// Since this is only used once on page load, we do not need to watch for changes in the *files* array,
			// and even if we had to, we should use some sort of event handling instead of timeout monitoring.
			/*else {
				// since we are through we can be a bit lazy - but we surely have to monitor the "files" array for realtime changes
				setTimeout(function() {epages.Preload._preloadFiles()}, 500);
			}*/
		}
	},
	files: [],
	nextPreloadFile: undefined
};

dojo.addOnLoad(function() {
	if(epages.vars.BusyLayerActive){
		dojo.subscribe("uimessage/stopBusy",function(owner, timeout, duration){
			setTimeout(function(){
				epages.Preload.start();
			},timeout);
		});
	}
	else{
		setTimeout(function() {
			epages.Preload.start();
		}, 100);
	}
})

}

if(!dojo._hasResource["dijit._base.manager"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.manager"] = true;
dojo.provide("dijit._base.manager");


dojo.declare("dijit.WidgetSet", null, {
	// summary:
	//		A set of widgets indexed by id. A default instance of this class is
	//		available as `dijit.registry`
	//
	// example:
	//		Create a small list of widgets:
	//		|	var ws = new dijit.WidgetSet();
	//		|	ws.add(dijit.byId("one"));
	//		| 	ws.add(dijit.byId("two"));
	//		|	// destroy both:
	//		|	ws.forEach(function(w){ w.destroy(); });
	//
	// example:
	//		Using dijit.registry:
	//		|	dijit.registry.forEach(function(w){ /* do something */ });

	constructor: function(){
		this._hash = {};
		this.length = 0;
	},

	add: function(/*dijit._Widget*/ widget){
		// summary:
		//		Add a widget to this list. If a duplicate ID is detected, a error is thrown.
		//
		// widget: dijit._Widget
		//		Any dijit._Widget subclass.
		if(this._hash[widget.id]){
			throw new Error("Tried to register widget with id==" + widget.id + " but that id is already registered");
		}
		this._hash[widget.id] = widget;
		this.length++;
	},

	remove: function(/*String*/ id){
		// summary:
		//		Remove a widget from this WidgetSet. Does not destroy the widget; simply
		//		removes the reference.
		if(this._hash[id]){
			delete this._hash[id];
			this.length--;
		}
	},

	forEach: function(/*Function*/ func, /* Object? */thisObj){
		// summary:
		//		Call specified function for each widget in this set.
		//
		// func:
		//		A callback function to run for each item. Is passed the widget, the index
		//		in the iteration, and the full hash, similar to `dojo.forEach`.
		//
		// thisObj:
		//		An optional scope parameter
		//
		// example:
		//		Using the default `dijit.registry` instance:
		//		|	dijit.registry.forEach(function(widget){
		//		|		console.log(widget.declaredClass);
		//		|	});
		//
		// returns:
		//		Returns self, in order to allow for further chaining.

		thisObj = thisObj || dojo.global;
		var i = 0, id;
		for(id in this._hash){
			func.call(thisObj, this._hash[id], i++, this._hash);
		}
		return this;	// dijit.WidgetSet
	},

	filter: function(/*Function*/ filter, /* Object? */thisObj){
		// summary:
		//		Filter down this WidgetSet to a smaller new WidgetSet
		//		Works the same as `dojo.filter` and `dojo.NodeList.filter`
		//
		// filter:
		//		Callback function to test truthiness. Is passed the widget
		//		reference and the pseudo-index in the object.
		//
		// thisObj: Object?
		//		Option scope to use for the filter function.
		//
		// example:
		//		Arbitrary: select the odd widgets in this list
		//		|	dijit.registry.filter(function(w, i){
		//		|		return i % 2 == 0;
		//		|	}).forEach(function(w){ /* odd ones */ });

		thisObj = thisObj || dojo.global;
		var res = new dijit.WidgetSet(), i = 0, id;
		for(id in this._hash){
			var w = this._hash[id];
			if(filter.call(thisObj, w, i++, this._hash)){
				res.add(w);
			}
		}
		return res; // dijit.WidgetSet
	},

	byId: function(/*String*/ id){
		// summary:
		//		Find a widget in this list by it's id.
		// example:
		//		Test if an id is in a particular WidgetSet
		//		| var ws = new dijit.WidgetSet();
		//		| ws.add(dijit.byId("bar"));
		//		| var t = ws.byId("bar") // returns a widget
		//		| var x = ws.byId("foo"); // returns undefined

		return this._hash[id];	// dijit._Widget
	},

	byClass: function(/*String*/ cls){
		// summary:
		//		Reduce this widgetset to a new WidgetSet of a particular `declaredClass`
		//
		// cls: String
		//		The Class to scan for. Full dot-notated string.
		//
		// example:
		//		Find all `dijit.TitlePane`s in a page:
		//		|	dijit.registry.byClass("dijit.TitlePane").forEach(function(tp){ tp.close(); });

		var res = new dijit.WidgetSet(), id, widget;
		for(id in this._hash){
			widget = this._hash[id];
			if(widget.declaredClass == cls){
				res.add(widget);
			}
		 }
		 return res; // dijit.WidgetSet
},

	toArray: function(){
		// summary:
		//		Convert this WidgetSet into a true Array
		//
		// example:
		//		Work with the widget .domNodes in a real Array
		//		|	dojo.map(dijit.registry.toArray(), function(w){ return w.domNode; });

		var ar = [];
		for(var id in this._hash){
			ar.push(this._hash[id]);
		}
		return ar;	// dijit._Widget[]
},

	map: function(/* Function */func, /* Object? */thisObj){
		// summary:
		//		Create a new Array from this WidgetSet, following the same rules as `dojo.map`
		// example:
		//		|	var nodes = dijit.registry.map(function(w){ return w.domNode; });
		//
		// returns:
		//		A new array of the returned values.
		return dojo.map(this.toArray(), func, thisObj); // Array
	},

	every: function(func, thisObj){
		// summary:
		// 		A synthetic clone of `dojo.every` acting explicitly on this WidgetSet
		//
		// func: Function
		//		A callback function run for every widget in this list. Exits loop
		//		when the first false return is encountered.
		//
		// thisObj: Object?
		//		Optional scope parameter to use for the callback

		thisObj = thisObj || dojo.global;
		var x = 0, i;
		for(i in this._hash){
			if(!func.call(thisObj, this._hash[i], x++, this._hash)){
				return false; // Boolean
			}
		}
		return true; // Boolean
	},

	some: function(func, thisObj){
		// summary:
		// 		A synthetic clone of `dojo.some` acting explictly on this WidgetSet
		//
		// func: Function
		//		A callback function run for every widget in this list. Exits loop
		//		when the first true return is encountered.
		//
		// thisObj: Object?
		//		Optional scope parameter to use for the callback

		thisObj = thisObj || dojo.global;
		var x = 0, i;
		for(i in this._hash){
			if(func.call(thisObj, this._hash[i], x++, this._hash)){
				return true; // Boolean
			}
		}
		return false; // Boolean
	}

});

(function(){

	/*=====
	dijit.registry = {
		// summary:
		//		A list of widgets on a page.
		// description:
		//		Is an instance of `dijit.WidgetSet`
	};
	=====*/
	dijit.registry = new dijit.WidgetSet();

	var hash = dijit.registry._hash,
		attr = dojo.attr,
		hasAttr = dojo.hasAttr,
		style = dojo.style;

	dijit.byId = function(/*String|dijit._Widget*/ id){
		// summary:
		//		Returns a widget by it's id, or if passed a widget, no-op (like dojo.byId())
		return typeof id == "string" ? hash[id] : id; // dijit._Widget
	};

	var _widgetTypeCtr = {};
	dijit.getUniqueId = function(/*String*/widgetType){
		// summary:
		//		Generates a unique id for a given widgetType
	
		var id;
		do{
			id = widgetType + "_" +
				(widgetType in _widgetTypeCtr ?
					++_widgetTypeCtr[widgetType] : _widgetTypeCtr[widgetType] = 0);
		}while(hash[id]);
		return dijit._scopeName == "dijit" ? id : dijit._scopeName + "_" + id; // String
	};
	
	dijit.findWidgets = function(/*DomNode*/ root){
		// summary:
		//		Search subtree under root returning widgets found.
		//		Doesn't search for nested widgets (ie, widgets inside other widgets).
	
		var outAry = [];
	
		function getChildrenHelper(root){
			for(var node = root.firstChild; node; node = node.nextSibling){
				if(node.nodeType == 1){
					var widgetId = node.getAttribute("widgetId");
					if(widgetId){
						var widget = hash[widgetId];
						if(widget){	// may be null on page w/multiple dojo's loaded
							outAry.push(widget);
						}
					}else{
						getChildrenHelper(node);
					}
				}
			}
		}
	
		getChildrenHelper(root);
		return outAry;
	};
	
	dijit._destroyAll = function(){
		// summary:
		//		Code to destroy all widgets and do other cleanup on page unload
	
		// Clean up focus manager lingering references to widgets and nodes
		dijit._curFocus = null;
		dijit._prevFocus = null;
		dijit._activeStack = [];
	
		// Destroy all the widgets, top down
		dojo.forEach(dijit.findWidgets(dojo.body()), function(widget){
			// Avoid double destroy of widgets like Menu that are attached to <body>
			// even though they are logically children of other widgets.
			if(!widget._destroyed){
				if(widget.destroyRecursive){
					widget.destroyRecursive();
				}else if(widget.destroy){
					widget.destroy();
				}
			}
		});
	};
	
	if(dojo.isIE){
		// Only run _destroyAll() for IE because we think it's only necessary in that case,
		// and because it causes problems on FF.  See bug #3531 for details.
		dojo.addOnWindowUnload(function(){
			dijit._destroyAll();
		});
	}
	
	dijit.byNode = function(/*DOMNode*/ node){
		// summary:
		//		Returns the widget corresponding to the given DOMNode
		return hash[node.getAttribute("widgetId")]; // dijit._Widget
	};
	
	dijit.getEnclosingWidget = function(/*DOMNode*/ node){
		// summary:
		//		Returns the widget whose DOM tree contains the specified DOMNode, or null if
		//		the node is not contained within the DOM tree of any widget
		while(node){
			var id = node.getAttribute && node.getAttribute("widgetId");
			if(id){
				return hash[id];
			}
			node = node.parentNode;
		}
		return null;
	};

	var shown = (dijit._isElementShown = function(/*Element*/ elem){
		var s = style(elem);
		return (s.visibility != "hidden")
			&& (s.visibility != "collapsed")
			&& (s.display != "none")
			&& (attr(elem, "type") != "hidden");
	});
	
	dijit.hasDefaultTabStop = function(/*Element*/ elem){
		// summary:
		//		Tests if element is tab-navigable even without an explicit tabIndex setting
	
		// No explicit tabIndex setting, need to investigate node type
		switch(elem.nodeName.toLowerCase()){
			case "a":
				// An <a> w/out a tabindex is only navigable if it has an href
				return hasAttr(elem, "href");
			case "area":
			case "button":
			case "input":
			case "object":
			case "select":
			case "textarea":
				// These are navigable by default
				return true;
			case "iframe":
				// If it's an editor <iframe> then it's tab navigable.
				var body;
				try{
					// non-IE
					var contentDocument = elem.contentDocument;
					if("designMode" in contentDocument && contentDocument.designMode == "on"){
						return true;
					}
					body = contentDocument.body;
				}catch(e1){
					// contentWindow.document isn't accessible within IE7/8
					// if the iframe.src points to a foreign url and this
					// page contains an element, that could get focus
					try{
						body = elem.contentWindow.document.body;
					}catch(e2){
						return false;
					}
				}
				return body.contentEditable == 'true' || (body.firstChild && body.firstChild.contentEditable == 'true');
			default:
				return elem.contentEditable == 'true';
		}
	};
	
	var isTabNavigable = (dijit.isTabNavigable = function(/*Element*/ elem){
		// summary:
		//		Tests if an element is tab-navigable
	
		// TODO: convert (and rename method) to return effective tabIndex; will save time in _getTabNavigable()
		if(attr(elem, "disabled")){
			return false;
		}else if(hasAttr(elem, "tabIndex")){
			// Explicit tab index setting
			return attr(elem, "tabIndex") >= 0; // boolean
		}else{
			// No explicit tabIndex setting, so depends on node type
			return dijit.hasDefaultTabStop(elem);
		}
	});

	dijit._getTabNavigable = function(/*DOMNode*/ root){
		// summary:
		//		Finds descendants of the specified root node.
		//
		// description:
		//		Finds the following descendants of the specified root node:
		//		* the first tab-navigable element in document order
		//		  without a tabIndex or with tabIndex="0"
		//		* the last tab-navigable element in document order
		//		  without a tabIndex or with tabIndex="0"
		//		* the first element in document order with the lowest
		//		  positive tabIndex value
		//		* the last element in document order with the highest
		//		  positive tabIndex value
		var first, last, lowest, lowestTabindex, highest, highestTabindex, radioSelected = {};
		function radioName(node) {
			// If this element is part of a radio button group, return the name for that group.
			return node && node.tagName.toLowerCase() == "input" &&
				node.type && node.type.toLowerCase() == "radio" &&
				node.name && node.name.toLowerCase();
		}
		var walkTree = function(/*DOMNode*/parent){
			dojo.query("> *", parent).forEach(function(child){
				// Skip hidden elements, and also non-HTML elements (those in custom namespaces) in IE,
				// since show() invokes getAttribute("type"), which crash on VML nodes in IE.
				if((dojo.isIE && child.scopeName!=="HTML") || !shown(child)){
					return;
				}

				if(isTabNavigable(child)){
					var tabindex = attr(child, "tabIndex");
					if(!hasAttr(child, "tabIndex") || tabindex == 0){
						if(!first){ first = child; }
						last = child;
					}else if(tabindex > 0){
						if(!lowest || tabindex < lowestTabindex){
							lowestTabindex = tabindex;
							lowest = child;
						}
						if(!highest || tabindex >= highestTabindex){
							highestTabindex = tabindex;
							highest = child;
						}
					}
					var rn = radioName(child);
					if(dojo.attr(child, "checked") && rn) {
						radioSelected[rn] = child;
					}
				}
				if(child.nodeName.toUpperCase() != 'SELECT'){
					walkTree(child);
				}
			});
		};
		if(shown(root)){ walkTree(root) }
		function rs(node) {
			// substitute checked radio button for unchecked one, if there is a checked one with the same name.
			return radioSelected[radioName(node)] || node;
		}
		return { first: rs(first), last: rs(last), lowest: rs(lowest), highest: rs(highest) };
	}
	dijit.getFirstInTabbingOrder = function(/*String|DOMNode*/ root){
		// summary:
		//		Finds the descendant of the specified root node
		//		that is first in the tabbing order
		var elems = dijit._getTabNavigable(dojo.byId(root));
		return elems.lowest ? elems.lowest : elems.first; // DomNode
	};
	
	dijit.getLastInTabbingOrder = function(/*String|DOMNode*/ root){
		// summary:
		//		Finds the descendant of the specified root node
		//		that is last in the tabbing order
		var elems = dijit._getTabNavigable(dojo.byId(root));
		return elems.last ? elems.last : elems.highest; // DomNode
	};
	
	/*=====
	dojo.mixin(dijit, {
		// defaultDuration: Integer
		//		The default animation speed (in ms) to use for all Dijit
		//		transitional animations, unless otherwise specified
		//		on a per-instance basis. Defaults to 200, overrided by
		//		`djConfig.defaultDuration`
		defaultDuration: 200
	});
	=====*/
	
	dijit.defaultDuration = dojo.config["defaultDuration"] || 200;

})();

}

if(!dojo._hasResource["dijit._base.focus"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.focus"] = true;
dojo.provide("dijit._base.focus");




// summary:
//		These functions are used to query or set the focus and selection.
//
//		Also, they trace when widgets become activated/deactivated,
//		so that the widget can fire _onFocus/_onBlur events.
//		"Active" here means something similar to "focused", but
//		"focus" isn't quite the right word because we keep track of
//		a whole stack of "active" widgets.  Example: ComboButton --> Menu -->
//		MenuItem.  The onBlur event for ComboButton doesn't fire due to focusing
//		on the Menu or a MenuItem, since they are considered part of the
//		ComboButton widget.  It only happens when focus is shifted
//		somewhere completely different.

dojo.mixin(dijit, {
	// _curFocus: DomNode
	//		Currently focused item on screen
	_curFocus: null,

	// _prevFocus: DomNode
	//		Previously focused item on screen
	_prevFocus: null,

	isCollapsed: function(){
		// summary:
		//		Returns true if there is no text selected
		return dijit.getBookmark().isCollapsed;
	},

	getBookmark: function(){
		// summary:
		//		Retrieves a bookmark that can be used with moveToBookmark to return to the same range
		var bm, rg, tg, sel = dojo.doc.selection, cf = dijit._curFocus;

		if(dojo.global.getSelection){
			//W3C Range API for selections.
			sel = dojo.global.getSelection();
			if(sel){
				if(sel.isCollapsed){
					tg = cf? cf.tagName : "";
					if(tg){
						//Create a fake rangelike item to restore selections.
						tg = tg.toLowerCase();
						if(tg == "textarea" ||
								(tg == "input" && (!cf.type || cf.type.toLowerCase() == "text"))){
							sel = {
								start: cf.selectionStart,
								end: cf.selectionEnd,
								node: cf,
								pRange: true
							};
							return {isCollapsed: (sel.end <= sel.start), mark: sel}; //Object.
						}
					}
					bm = {isCollapsed:true};
					if(sel.rangeCount){
						bm.mark = sel.getRangeAt(0).cloneRange();
					}
				}else{
					rg = sel.getRangeAt(0);
					bm = {isCollapsed: false, mark: rg.cloneRange()};
				}
			}
		}else if(sel){
			// If the current focus was a input of some sort and no selection, don't bother saving
			// a native bookmark.  This is because it causes issues with dialog/page selection restore.
			// So, we need to create psuedo bookmarks to work with.
			tg = cf ? cf.tagName : "";
			tg = tg.toLowerCase();
			if(cf && tg && (tg == "button" || tg == "textarea" || tg == "input")){
				if(sel.type && sel.type.toLowerCase() == "none"){
					return {
						isCollapsed: true,
						mark: null
					}
				}else{
					rg = sel.createRange();
					return {
						isCollapsed: rg.text && rg.text.length?false:true,
						mark: {
							range: rg,
							pRange: true
						}
					};
				}
			}
			bm = {};

			//'IE' way for selections.
			try{
				// createRange() throws exception when dojo in iframe
				//and nothing selected, see #9632
				rg = sel.createRange();
				bm.isCollapsed = !(sel.type == 'Text' ? rg.htmlText.length : rg.length);
			}catch(e){
				bm.isCollapsed = true;
				return bm;
			}
			if(sel.type.toUpperCase() == 'CONTROL'){
				if(rg.length){
					bm.mark=[];
					var i=0,len=rg.length;
					while(i<len){
						bm.mark.push(rg.item(i++));
					}
				}else{
					bm.isCollapsed = true;
					bm.mark = null;
				}
			}else{
				bm.mark = rg.getBookmark();
			}
		}else{
			console.warn("No idea how to store the current selection for this browser!");
		}
		return bm; // Object
	},

	moveToBookmark: function(/*Object*/bookmark){
		// summary:
		//		Moves current selection to a bookmark
		// bookmark:
		//		This should be a returned object from dijit.getBookmark()

		var _doc = dojo.doc,
			mark = bookmark.mark;
		if(mark){
			if(dojo.global.getSelection){
				//W3C Rangi API (FF, WebKit, Opera, etc)
				var sel = dojo.global.getSelection();
				if(sel && sel.removeAllRanges){
					if(mark.pRange){
						var r = mark;
						var n = r.node;
						n.selectionStart = r.start;
						n.selectionEnd = r.end;
					}else{
						sel.removeAllRanges();
						sel.addRange(mark);
					}
				}else{
					console.warn("No idea how to restore selection for this browser!");
				}
			}else if(_doc.selection && mark){
				//'IE' way.
				var rg;
				if(mark.pRange){
					rg = mark.range;
				}else if(dojo.isArray(mark)){
					rg = _doc.body.createControlRange();
					//rg.addElement does not have call/apply method, so can not call it directly
					//rg is not available in "range.addElement(item)", so can't use that either
					dojo.forEach(mark, function(n){
						rg.addElement(n);
					});
				}else{
					rg = _doc.body.createTextRange();
					rg.moveToBookmark(mark);
				}
				rg.select();
			}
		}
	},

	getFocus: function(/*Widget?*/ menu, /*Window?*/ openedForWindow){
		// summary:
		//		Called as getFocus(), this returns an Object showing the current focus
		//		and selected text.
		//
		//		Called as getFocus(widget), where widget is a (widget representing) a button
		//		that was just pressed, it returns where focus was before that button
		//		was pressed.   (Pressing the button may have either shifted focus to the button,
		//		or removed focus altogether.)   In this case the selected text is not returned,
		//		since it can't be accurately determined.
		//
		// menu: dijit._Widget or {domNode: DomNode} structure
		//		The button that was just pressed.  If focus has disappeared or moved
		//		to this button, returns the previous focus.  In this case the bookmark
		//		information is already lost, and null is returned.
		//
		// openedForWindow:
		//		iframe in which menu was opened
		//
		// returns:
		//		A handle to restore focus/selection, to be passed to `dijit.focus`
		var node = !dijit._curFocus || (menu && dojo.isDescendant(dijit._curFocus, menu.domNode)) ? dijit._prevFocus : dijit._curFocus;
		return {
			node: node,
			bookmark: (node == dijit._curFocus) && dojo.withGlobal(openedForWindow || dojo.global, dijit.getBookmark),
			openedForWindow: openedForWindow
		}; // Object
	},

	focus: function(/*Object || DomNode */ handle){
		// summary:
		//		Sets the focused node and the selection according to argument.
		//		To set focus to an iframe's content, pass in the iframe itself.
		// handle:
		//		object returned by get(), or a DomNode

		if(!handle){ return; }

		var node = "node" in handle ? handle.node : handle,		// because handle is either DomNode or a composite object
			bookmark = handle.bookmark,
			openedForWindow = handle.openedForWindow,
			collapsed = bookmark ? bookmark.isCollapsed : false;

		// Set the focus
		// Note that for iframe's we need to use the <iframe> to follow the parentNode chain,
		// but we need to set focus to iframe.contentWindow
		if(node){
			var focusNode = (node.tagName.toLowerCase() == "iframe") ? node.contentWindow : node;
			if(focusNode && focusNode.focus){
				try{
					// Gecko throws sometimes if setting focus is impossible,
					// node not displayed or something like that
					focusNode.focus();
				}catch(e){/*quiet*/}
			}
			dijit._onFocusNode(node);
		}

		// set the selection
		// do not need to restore if current selection is not empty
		// (use keyboard to select a menu item) or if previous selection was collapsed
		// as it may cause focus shift (Esp in IE).
		if(bookmark && dojo.withGlobal(openedForWindow || dojo.global, dijit.isCollapsed) && !collapsed){
			if(openedForWindow){
				openedForWindow.focus();
			}
			try{
				dojo.withGlobal(openedForWindow || dojo.global, dijit.moveToBookmark, null, [bookmark]);
			}catch(e2){
				/*squelch IE internal error, see http://trac.dojotoolkit.org/ticket/1984 */
			}
		}
	},

	// _activeStack: dijit._Widget[]
	//		List of currently active widgets (focused widget and it's ancestors)
	_activeStack: [],

	registerIframe: function(/*DomNode*/ iframe){
		// summary:
		//		Registers listeners on the specified iframe so that any click
		//		or focus event on that iframe (or anything in it) is reported
		//		as a focus/click event on the <iframe> itself.
		// description:
		//		Currently only used by editor.
		// returns:
		//		Handle to pass to unregisterIframe()
		return dijit.registerWin(iframe.contentWindow, iframe);
	},

	unregisterIframe: function(/*Object*/ handle){
		// summary:
		//		Unregisters listeners on the specified iframe created by registerIframe.
		//		After calling be sure to delete or null out the handle itself.
		// handle:
		//		Handle returned by registerIframe()

		dijit.unregisterWin(handle);
	},

	registerWin: function(/*Window?*/targetWindow, /*DomNode?*/ effectiveNode){
		// summary:
		//		Registers listeners on the specified window (either the main
		//		window or an iframe's window) to detect when the user has clicked somewhere
		//		or focused somewhere.
		// description:
		//		Users should call registerIframe() instead of this method.
		// targetWindow:
		//		If specified this is the window associated with the iframe,
		//		i.e. iframe.contentWindow.
		// effectiveNode:
		//		If specified, report any focus events inside targetWindow as
		//		an event on effectiveNode, rather than on evt.target.
		// returns:
		//		Handle to pass to unregisterWin()

		// TODO: make this function private in 2.0; Editor/users should call registerIframe(),

		var mousedownListener = function(evt){
			dijit._justMouseDowned = true;
			setTimeout(function(){ dijit._justMouseDowned = false; }, 0);
			
			// workaround weird IE bug where the click is on an orphaned node
			// (first time clicking a Select/DropDownButton inside a TooltipDialog)
			if(dojo.isIE && evt && evt.srcElement && evt.srcElement.parentNode == null){
				return;
			}

			dijit._onTouchNode(effectiveNode || evt.target || evt.srcElement, "mouse");
		};
		//dojo.connect(targetWindow, "onscroll", ???);

		// Listen for blur and focus events on targetWindow's document.
		// IIRC, I'm using attachEvent() rather than dojo.connect() because focus/blur events don't bubble
		// through dojo.connect(), and also maybe to catch the focus events early, before onfocus handlers
		// fire.
		// Connect to <html> (rather than document) on IE to avoid memory leaks, but document on other browsers because
		// (at least for FF) the focus event doesn't fire on <html> or <body>.
		var doc = dojo.isIE ? targetWindow.document.documentElement : targetWindow.document;
		if(doc){
			if(dojo.isIE){
				targetWindow.document.body.attachEvent('onmousedown', mousedownListener);
				var activateListener = function(evt){
					// IE reports that nodes like <body> have gotten focus, even though they have tabIndex=-1,
					// Should consider those more like a mouse-click than a focus....
					if(evt.srcElement.tagName.toLowerCase() != "#document" &&
						dijit.isTabNavigable(evt.srcElement)){
						dijit._onFocusNode(effectiveNode || evt.srcElement);
					}else{
						dijit._onTouchNode(effectiveNode || evt.srcElement);
					}
				};
				doc.attachEvent('onactivate', activateListener);
				var deactivateListener =  function(evt){
					dijit._onBlurNode(effectiveNode || evt.srcElement);
				};
				doc.attachEvent('ondeactivate', deactivateListener);

				return function(){
					targetWindow.document.detachEvent('onmousedown', mousedownListener);
					doc.detachEvent('onactivate', activateListener);
					doc.detachEvent('ondeactivate', deactivateListener);
					doc = null;	// prevent memory leak (apparent circular reference via closure)
				};
			}else{
				doc.body.addEventListener('mousedown', mousedownListener, true);
				var focusListener = function(evt){
					dijit._onFocusNode(effectiveNode || evt.target);
				};
				doc.addEventListener('focus', focusListener, true);
				var blurListener = function(evt){
					dijit._onBlurNode(effectiveNode || evt.target);
				};
				doc.addEventListener('blur', blurListener, true);

				return function(){
					doc.body.removeEventListener('mousedown', mousedownListener, true);
					doc.removeEventListener('focus', focusListener, true);
					doc.removeEventListener('blur', blurListener, true);
					doc = null;	// prevent memory leak (apparent circular reference via closure)
				};
			}
		}
	},

	unregisterWin: function(/*Handle*/ handle){
		// summary:
		//		Unregisters listeners on the specified window (either the main
		//		window or an iframe's window) according to handle returned from registerWin().
		//		After calling be sure to delete or null out the handle itself.

		// Currently our handle is actually a function
		handle && handle();
	},

	_onBlurNode: function(/*DomNode*/ node){
		// summary:
		// 		Called when focus leaves a node.
		//		Usually ignored, _unless_ it *isn't* follwed by touching another node,
		//		which indicates that we tabbed off the last field on the page,
		//		in which case every widget is marked inactive
		dijit._prevFocus = dijit._curFocus;
		dijit._curFocus = null;

		if(dijit._justMouseDowned){
			// the mouse down caused a new widget to be marked as active; this blur event
			// is coming late, so ignore it.
			return;
		}

		// if the blur event isn't followed by a focus event then mark all widgets as inactive.
		if(dijit._clearActiveWidgetsTimer){
			clearTimeout(dijit._clearActiveWidgetsTimer);
		}
		dijit._clearActiveWidgetsTimer = setTimeout(function(){
			delete dijit._clearActiveWidgetsTimer;
			dijit._setStack([]);
			dijit._prevFocus = null;
		}, 100);
	},

	_onTouchNode: function(/*DomNode*/ node, /*String*/ by){
		// summary:
		//		Callback when node is focused or mouse-downed
		// node:
		//		The node that was touched.
		// by:
		//		"mouse" if the focus/touch was caused by a mouse down event

		// ignore the recent blurNode event
		if(dijit._clearActiveWidgetsTimer){
			clearTimeout(dijit._clearActiveWidgetsTimer);
			delete dijit._clearActiveWidgetsTimer;
		}

		// compute stack of active widgets (ex: ComboButton --> Menu --> MenuItem)
		var newStack=[];
		try{
			while(node){
				var popupParent = dojo.attr(node, "dijitPopupParent");
				if(popupParent){
					node=dijit.byId(popupParent).domNode;
				}else if(node.tagName && node.tagName.toLowerCase() == "body"){
					// is this the root of the document or just the root of an iframe?
					if(node === dojo.body()){
						// node is the root of the main document
						break;
					}
					// otherwise, find the iframe this node refers to (can't access it via parentNode,
					// need to do this trick instead). window.frameElement is supported in IE/FF/Webkit
					node=dojo.window.get(node.ownerDocument).frameElement;
				}else{
					// if this node is the root node of a widget, then add widget id to stack,
					// except ignore clicks on disabled widgets (actually focusing a disabled widget still works,
					// to support MenuItem)
					var id = node.getAttribute && node.getAttribute("widgetId"),
						widget = id && dijit.byId(id);
					if(widget && !(by == "mouse" && widget.get("disabled"))){
						newStack.unshift(id);
					}
					node=node.parentNode;
				}
			}
		}catch(e){ /* squelch */ }

		dijit._setStack(newStack, by);
	},

	_onFocusNode: function(/*DomNode*/ node){
		// summary:
		//		Callback when node is focused

		if(!node){
			return;
		}

		if(node.nodeType == 9){
			// Ignore focus events on the document itself.  This is here so that
			// (for example) clicking the up/down arrows of a spinner
			// (which don't get focus) won't cause that widget to blur. (FF issue)
			return;
		}

		dijit._onTouchNode(node);

		if(node == dijit._curFocus){ return; }
		if(dijit._curFocus){
			dijit._prevFocus = dijit._curFocus;
		}
		dijit._curFocus = node;
		dojo.publish("focusNode", [node]);
	},

	_setStack: function(/*String[]*/ newStack, /*String*/ by){
		// summary:
		//		The stack of active widgets has changed.  Send out appropriate events and records new stack.
		// newStack:
		//		array of widget id's, starting from the top (outermost) widget
		// by:
		//		"mouse" if the focus/touch was caused by a mouse down event

		var oldStack = dijit._activeStack;
		dijit._activeStack = newStack;

		// compare old stack to new stack to see how many elements they have in common
		for(var nCommon=0; nCommon<Math.min(oldStack.length, newStack.length); nCommon++){
			if(oldStack[nCommon] != newStack[nCommon]){
				break;
			}
		}

		var widget;
		// for all elements that have gone out of focus, send blur event
		for(var i=oldStack.length-1; i>=nCommon; i--){
			widget = dijit.byId(oldStack[i]);
			if(widget){
				widget._focused = false;
				widget.set("focused", false);
				widget._hasBeenBlurred = true;
				if(widget._onBlur){
					widget._onBlur(by);
				}
				dojo.publish("widgetBlur", [widget, by]);
			}
		}

		// for all element that have come into focus, send focus event
		for(i=nCommon; i<newStack.length; i++){
			widget = dijit.byId(newStack[i]);
			if(widget){
				widget._focused = true;
				widget.set("focused", true);
				if(widget._onFocus){
					widget._onFocus(by);
				}
				dojo.publish("widgetFocus", [widget, by]);
			}
		}
	}
});

// register top window and all the iframes it contains
dojo.addOnLoad(function(){
	var handle = dijit.registerWin(window);
	if(dojo.isIE){
		dojo.addOnWindowUnload(function(){
			dijit.unregisterWin(handle);
			handle = null;
		})
	}
});

}

if(!dojo._hasResource["dojo.AdapterRegistry"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.AdapterRegistry"] = true;
dojo.provide("dojo.AdapterRegistry");


dojo.AdapterRegistry = function(/*Boolean?*/ returnWrappers){
	//	summary:
	//		A registry to make contextual calling/searching easier.
	//	description:
	//		Objects of this class keep list of arrays in the form [name, check,
	//		wrap, directReturn] that are used to determine what the contextual
	//		result of a set of checked arguments is. All check/wrap functions
	//		in this registry should be of the same arity.
	//	example:
	//	|	// create a new registry
	//	|	var reg = new dojo.AdapterRegistry();
	//	|	reg.register("handleString",
	//	|		dojo.isString,
	//	|		function(str){
	//	|			// do something with the string here
	//	|		}
	//	|	);
	//	|	reg.register("handleArr",
	//	|		dojo.isArray,
	//	|		function(arr){
	//	|			// do something with the array here
	//	|		}
	//	|	);
	//	|
	//	|	// now we can pass reg.match() *either* an array or a string and
	//	|	// the value we pass will get handled by the right function
	//	|	reg.match("someValue"); // will call the first function
	//	|	reg.match(["someValue"]); // will call the second

	this.pairs = [];
	this.returnWrappers = returnWrappers || false; // Boolean
};

dojo.extend(dojo.AdapterRegistry, {
	register: function(/*String*/ name, /*Function*/ check, /*Function*/ wrap, /*Boolean?*/ directReturn, /*Boolean?*/ override){
		//	summary:
		//		register a check function to determine if the wrap function or
		//		object gets selected
		//	name:
		//		a way to identify this matcher.
		//	check:
		//		a function that arguments are passed to from the adapter's
		//		match() function.  The check function should return true if the
		//		given arguments are appropriate for the wrap function.
		//	directReturn:
		//		If directReturn is true, the value passed in for wrap will be
		//		returned instead of being called. Alternately, the
		//		AdapterRegistry can be set globally to "return not call" using
		//		the returnWrappers property. Either way, this behavior allows
		//		the registry to act as a "search" function instead of a
		//		function interception library.
		//	override:
		//		If override is given and true, the check function will be given
		//		highest priority. Otherwise, it will be the lowest priority
		//		adapter.
		this.pairs[((override) ? "unshift" : "push")]([name, check, wrap, directReturn]);
	},

	match: function(/* ... */){
		// summary:
		//		Find an adapter for the given arguments. If no suitable adapter
		//		is found, throws an exception. match() accepts any number of
		//		arguments, all of which are passed to all matching functions
		//		from the registered pairs.
		for(var i = 0; i < this.pairs.length; i++){
			var pair = this.pairs[i];
			if(pair[1].apply(this, arguments)){
				if((pair[3])||(this.returnWrappers)){
					return pair[2];
				}else{
					return pair[2].apply(this, arguments);
				}
			}
		}
		throw new Error("No match found");
	},

	unregister: function(name){
		// summary: Remove a named adapter from the registry

		// FIXME: this is kind of a dumb way to handle this. On a large
		// registry this will be slow-ish and we can use the name as a lookup
		// should we choose to trade memory for speed.
		for(var i = 0; i < this.pairs.length; i++){
			var pair = this.pairs[i];
			if(pair[0] == name){
				this.pairs.splice(i, 1);
				return true;
			}
		}
		return false;
	}
});

}

if(!dojo._hasResource["dijit._base.place"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.place"] = true;
dojo.provide("dijit._base.place");




dijit.getViewport = function(){
	// summary:
	//		Returns the dimensions and scroll position of the viewable area of a browser window

	return dojo.window.getBox();
};

/*=====
dijit.__Position = function(){
	// x: Integer
	//		horizontal coordinate in pixels, relative to document body
	// y: Integer
	//		vertical coordinate in pixels, relative to document body

	thix.x = x;
	this.y = y;
}
=====*/


dijit.placeOnScreen = function(
	/* DomNode */			node,
	/* dijit.__Position */	pos,
	/* String[] */			corners,
	/* dijit.__Position? */	padding){
	// summary:
	//		Positions one of the node's corners at specified position
	//		such that node is fully visible in viewport.
	// description:
	//		NOTE: node is assumed to be absolutely or relatively positioned.
	//	pos:
	//		Object like {x: 10, y: 20}
	//	corners:
	//		Array of Strings representing order to try corners in, like ["TR", "BL"].
	//		Possible values are:
	//			* "BL" - bottom left
	//			* "BR" - bottom right
	//			* "TL" - top left
	//			* "TR" - top right
	//	padding:
	//		set padding to put some buffer around the element you want to position.
	// example:
	//		Try to place node's top right corner at (10,20).
	//		If that makes node go (partially) off screen, then try placing
	//		bottom left corner at (10,20).
	//	|	placeOnScreen(node, {x: 10, y: 20}, ["TR", "BL"])

	var choices = dojo.map(corners, function(corner){
		var c = { corner: corner, pos: {x:pos.x,y:pos.y} };
		if(padding){
			c.pos.x += corner.charAt(1) == 'L' ? padding.x : -padding.x;
			c.pos.y += corner.charAt(0) == 'T' ? padding.y : -padding.y;
		}
		return c;
	});

	return dijit._place(node, choices);
}

dijit._place = function(/*DomNode*/ node, choices, layoutNode, /*Object*/ aroundNodeCoords){
	// summary:
	//		Given a list of spots to put node, put it at the first spot where it fits,
	//		of if it doesn't fit anywhere then the place with the least overflow
	// choices: Array
	//		Array of elements like: {corner: 'TL', pos: {x: 10, y: 20} }
	//		Above example says to put the top-left corner of the node at (10,20)
	// layoutNode: Function(node, aroundNodeCorner, nodeCorner, size)
	//		for things like tooltip, they are displayed differently (and have different dimensions)
	//		based on their orientation relative to the parent.   This adjusts the popup based on orientation.
	//		It also passes in the available size for the popup, which is useful for tooltips to
	//		tell them that their width is limited to a certain amount.   layoutNode() may return a value expressing
	//		how much the popup had to be modified to fit into the available space.   This is used to determine
	//		what the best placement is.
	// aroundNodeCoords: Object
	//		Size of aroundNode, ex: {w: 200, h: 50}

	// get {x: 10, y: 10, w: 100, h:100} type obj representing position of
	// viewport over document
	var view = dojo.window.getBox();

	// This won't work if the node is inside a <div style="position: relative">,
	// so reattach it to dojo.doc.body.   (Otherwise, the positioning will be wrong
	// and also it might get cutoff)
	if(!node.parentNode || String(node.parentNode.tagName).toLowerCase() != "body"){
		dojo.body().appendChild(node);
	}

	var best = null;
	dojo.some(choices, function(choice){
		var corner = choice.corner;
		var pos = choice.pos;
		var overflow = 0;

		// calculate amount of space available given specified position of node
		var spaceAvailable = {
			w: corner.charAt(1) == 'L' ? (view.l + view.w) - pos.x : pos.x - view.l,
			h: corner.charAt(1) == 'T' ? (view.t + view.h) - pos.y : pos.y - view.t
		};

		// configure node to be displayed in given position relative to button
		// (need to do this in order to get an accurate size for the node, because
		// a tooltip's size changes based on position, due to triangle)
		if(layoutNode){
			var res = layoutNode(node, choice.aroundCorner, corner, spaceAvailable, aroundNodeCoords);
			overflow = typeof res == "undefined" ? 0 : res;
		}

		// get node's size
		var style = node.style;
		var oldDisplay = style.display;
		var oldVis = style.visibility;
		style.visibility = "hidden";
		style.display = "";
		var mb = dojo.marginBox(node);
		style.display = oldDisplay;
		style.visibility = oldVis;

		// coordinates and size of node with specified corner placed at pos,
		// and clipped by viewport
		var startX = Math.max(view.l, corner.charAt(1) == 'L' ? pos.x : (pos.x - mb.w)),
			startY = Math.max(view.t, corner.charAt(0) == 'T' ? pos.y : (pos.y - mb.h)),
			endX = Math.min(view.l + view.w, corner.charAt(1) == 'L' ? (startX + mb.w) : pos.x),
			endY = Math.min(view.t + view.h, corner.charAt(0) == 'T' ? (startY + mb.h) : pos.y),
			width = endX - startX,
			height = endY - startY;

		overflow += (mb.w - width) + (mb.h - height);

		if(best == null || overflow < best.overflow){
			best = {
				corner: corner,
				aroundCorner: choice.aroundCorner,
				x: startX,
				y: startY,
				w: width,
				h: height,
				overflow: overflow,
				spaceAvailable: spaceAvailable
			};
		}
		
		return !overflow;
	});

	// In case the best position is not the last one we checked, need to call
	// layoutNode() again.
	if(best.overflow && layoutNode){
		layoutNode(node, best.aroundCorner, best.corner, best.spaceAvailable, aroundNodeCoords);
	}

	// And then position the node.   Do this last, after the layoutNode() above
	// has sized the node, due to browser quirks when the viewport is scrolled
	// (specifically that a Tooltip will shrink to fit as though the window was
	// scrolled to the left).
	//
	// In RTL mode, set style.right rather than style.left so in the common case,
	// window resizes move the popup along with the aroundNode.
	var l = dojo._isBodyLtr(),
		s = node.style;
	s.top = best.y + "px";
	s[l ? "left" : "right"] = (l ? best.x : view.w - best.x - best.w) + "px";
	
	return best;
}

dijit.placeOnScreenAroundNode = function(
	/* DomNode */		node,
	/* DomNode */		aroundNode,
	/* Object */		aroundCorners,
	/* Function? */		layoutNode){

	// summary:
	//		Position node adjacent or kitty-corner to aroundNode
	//		such that it's fully visible in viewport.
	//
	// description:
	//		Place node such that corner of node touches a corner of
	//		aroundNode, and that node is fully visible.
	//
	// aroundCorners:
	//		Ordered list of pairs of corners to try matching up.
	//		Each pair of corners is represented as a key/value in the hash,
	//		where the key corresponds to the aroundNode's corner, and
	//		the value corresponds to the node's corner:
	//
	//	|	{ aroundNodeCorner1: nodeCorner1, aroundNodeCorner2: nodeCorner2, ...}
	//
	//		The following strings are used to represent the four corners:
	//			* "BL" - bottom left
	//			* "BR" - bottom right
	//			* "TL" - top left
	//			* "TR" - top right
	//
	// layoutNode: Function(node, aroundNodeCorner, nodeCorner)
	//		For things like tooltip, they are displayed differently (and have different dimensions)
	//		based on their orientation relative to the parent.   This adjusts the popup based on orientation.
	//
	// example:
	//	|	dijit.placeOnScreenAroundNode(node, aroundNode, {'BL':'TL', 'TR':'BR'});
	//		This will try to position node such that node's top-left corner is at the same position
	//		as the bottom left corner of the aroundNode (ie, put node below
	//		aroundNode, with left edges aligned).  If that fails it will try to put
	// 		the bottom-right corner of node where the top right corner of aroundNode is
	//		(ie, put node above aroundNode, with right edges aligned)
	//

	// get coordinates of aroundNode
	aroundNode = dojo.byId(aroundNode);
	var aroundNodePos = dojo.position(aroundNode, true);

	// place the node around the calculated rectangle
	return dijit._placeOnScreenAroundRect(node,
		aroundNodePos.x, aroundNodePos.y, aroundNodePos.w, aroundNodePos.h,	// rectangle
		aroundCorners, layoutNode);
};

/*=====
dijit.__Rectangle = function(){
	// x: Integer
	//		horizontal offset in pixels, relative to document body
	// y: Integer
	//		vertical offset in pixels, relative to document body
	// width: Integer
	//		width in pixels
	// height: Integer
	//		height in pixels

	this.x = x;
	this.y = y;
	this.width = width;
	this.height = height;
}
=====*/


dijit.placeOnScreenAroundRectangle = function(
	/* DomNode */			node,
	/* dijit.__Rectangle */	aroundRect,
	/* Object */			aroundCorners,
	/* Function */			layoutNode){

	// summary:
	//		Like dijit.placeOnScreenAroundNode(), except that the "around"
	//		parameter is an arbitrary rectangle on the screen (x, y, width, height)
	//		instead of a dom node.

	return dijit._placeOnScreenAroundRect(node,
		aroundRect.x, aroundRect.y, aroundRect.width, aroundRect.height,	// rectangle
		aroundCorners, layoutNode);
};

dijit._placeOnScreenAroundRect = function(
	/* DomNode */		node,
	/* Number */		x,
	/* Number */		y,
	/* Number */		width,
	/* Number */		height,
	/* Object */		aroundCorners,
	/* Function */		layoutNode){

	// summary:
	//		Like dijit.placeOnScreenAroundNode(), except it accepts coordinates
	//		of a rectangle to place node adjacent to.

	// TODO: combine with placeOnScreenAroundRectangle()

	// Generate list of possible positions for node
	var choices = [];
	for(var nodeCorner in aroundCorners){
		choices.push( {
			aroundCorner: nodeCorner,
			corner: aroundCorners[nodeCorner],
			pos: {
				x: x + (nodeCorner.charAt(1) == 'L' ? 0 : width),
				y: y + (nodeCorner.charAt(0) == 'T' ? 0 : height)
			}
		});
	}

	return dijit._place(node, choices, layoutNode, {w: width, h: height});
};

dijit.placementRegistry= new dojo.AdapterRegistry();
dijit.placementRegistry.register("node",
	function(n, x){
		return typeof x == "object" &&
			typeof x.offsetWidth != "undefined" && typeof x.offsetHeight != "undefined";
	},
	dijit.placeOnScreenAroundNode);
dijit.placementRegistry.register("rect",
	function(n, x){
		return typeof x == "object" &&
			"x" in x && "y" in x && "width" in x && "height" in x;
	},
	dijit.placeOnScreenAroundRectangle);

dijit.placeOnScreenAroundElement = function(
	/* DomNode */		node,
	/* Object */		aroundElement,
	/* Object */		aroundCorners,
	/* Function */		layoutNode){

	// summary:
	//		Like dijit.placeOnScreenAroundNode(), except it accepts an arbitrary object
	//		for the "around" argument and finds a proper processor to place a node.

	return dijit.placementRegistry.match.apply(dijit.placementRegistry, arguments);
};

dijit.getPopupAroundAlignment = function(/*Array*/ position, /*Boolean*/ leftToRight){
	// summary:
	//		Transforms the passed array of preferred positions into a format suitable for passing as the aroundCorners argument to dijit.placeOnScreenAroundElement.
	//
	// position: String[]
	//		This variable controls the position of the drop down.
	//		It's an array of strings with the following values:
	//
	//			* before: places drop down to the left of the target node/widget, or to the right in
	//			  the case of RTL scripts like Hebrew and Arabic
	//			* after: places drop down to the right of the target node/widget, or to the left in
	//			  the case of RTL scripts like Hebrew and Arabic
	//			* above: drop down goes above target node
	//			* below: drop down goes below target node
	//
	//		The list is positions is tried, in order, until a position is found where the drop down fits
	//		within the viewport.
	//
	// leftToRight: Boolean
	//		Whether the popup will be displaying in leftToRight mode.
	//
	var align = {};
	dojo.forEach(position, function(pos){
		switch(pos){
			case "after":
				align[leftToRight ? "BR" : "BL"] = leftToRight ? "BL" : "BR";
				break;
			case "before":
				align[leftToRight ? "BL" : "BR"] = leftToRight ? "BR" : "BL";
				break;
			case "below-alt":
				leftToRight = !leftToRight;
				// fall through
			case "below":
				// first try to align left borders, next try to align right borders (or reverse for RTL mode)
				align[leftToRight ? "BL" : "BR"] = leftToRight ? "TL" : "TR";
				align[leftToRight ? "BR" : "BL"] = leftToRight ? "TR" : "TL";
				break;
			case "above-alt":
				leftToRight = !leftToRight;
				// fall through
			case "above":
			default:
				// first try to align left borders, next try to align right borders (or reverse for RTL mode)
				align[leftToRight ? "TL" : "TR"] = leftToRight ? "BL" : "BR";
				align[leftToRight ? "TR" : "TL"] = leftToRight ? "BR" : "BL";
				break;
		}
	});
	return align;
};

}

if(!dojo._hasResource["dijit._base.window"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.window"] = true;
dojo.provide("dijit._base.window");



dijit.getDocumentWindow = function(doc){
	return dojo.window.get(doc);
};

}

if(!dojo._hasResource["dijit._base.popup"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.popup"] = true;
dojo.provide("dijit._base.popup");





/*=====
dijit.popup.__OpenArgs = function(){
	// popup: Widget
	//		widget to display
	// parent: Widget
	//		the button etc. that is displaying this popup
	// around: DomNode
	//		DOM node (typically a button); place popup relative to this node.  (Specify this *or* "x" and "y" parameters.)
	// x: Integer
	//		Absolute horizontal position (in pixels) to place node at.  (Specify this *or* "around" parameter.)
	// y: Integer
	//		Absolute vertical position (in pixels) to place node at.  (Specify this *or* "around" parameter.)
	// orient: Object|String
	//		When the around parameter is specified, orient should be an
	//		ordered list of tuples of the form (around-node-corner, popup-node-corner).
	//		dijit.popup.open() tries to position the popup according to each tuple in the list, in order,
	//		until the popup appears fully within the viewport.
	//
	//		The default value is {BL:'TL', TL:'BL'}, which represents a list of two tuples:
	//			1. (BL, TL)
	//			2. (TL, BL)
	//		where BL means "bottom left" and "TL" means "top left".
	//		So by default, it first tries putting the popup below the around node, left-aligning them,
	//		and then tries to put it above the around node, still left-aligning them.   Note that the
	//		default is horizontally reversed when in RTL mode.
	//
	//		When an (x,y) position is specified rather than an around node, orient is either
	//		"R" or "L".  R (for right) means that it tries to put the popup to the right of the mouse,
	//		specifically positioning the popup's top-right corner at the mouse position, and if that doesn't
	//		fit in the viewport, then it tries, in order, the bottom-right corner, the top left corner,
	//		and the top-right corner.
	// onCancel: Function
	//		callback when user has canceled the popup by
	//			1. hitting ESC or
	//			2. by using the popup widget's proprietary cancel mechanism (like a cancel button in a dialog);
	//			   i.e. whenever popupWidget.onCancel() is called, args.onCancel is called
	// onClose: Function
	//		callback whenever this popup is closed
	// onExecute: Function
	//		callback when user "executed" on the popup/sub-popup by selecting a menu choice, etc. (top menu only)
	// padding: dijit.__Position
	//		adding a buffer around the opening position. This is only useful when around is not set.
	this.popup = popup;
	this.parent = parent;
	this.around = around;
	this.x = x;
	this.y = y;
	this.orient = orient;
	this.onCancel = onCancel;
	this.onClose = onClose;
	this.onExecute = onExecute;
	this.padding = padding;
}
=====*/

dijit.popup = {
	// summary:
	//		This singleton is used to show/hide widgets as popups.

	// _stack: dijit._Widget[]
	//		Stack of currently popped up widgets.
	//		(someone opened _stack[0], and then it opened _stack[1], etc.)
	_stack: [],
	
	// _beginZIndex: Number
	//		Z-index of the first popup.   (If first popup opens other
	//		popups they get a higher z-index.)
	_beginZIndex: 100000,

	_idGen: 1,

	_createWrapper: function(/*Widget || DomNode*/ widget){
		// summary:
		//		Initialization for widgets that will be used as popups.
		//		Puts widget inside a wrapper DIV (if not already in one),
		//		and returns pointer to that wrapper DIV.

		var wrapper = widget.declaredClass ? widget._popupWrapper : (widget.parentNode && dojo.hasClass(widget.parentNode, "dijitPopup")),
			node = widget.domNode || widget;

		if(!wrapper){
			// Create wrapper <div> for when this widget [in the future] will be used as a popup.
			// This is done early because of IE bugs where creating/moving DOM nodes causes focus
			// to go wonky, see tests/robot/Toolbar.html to reproduce
			wrapper = dojo.create("div",{
				"class":"dijitPopup",
				style:{ display: "none"},
				role: "presentation"
			}, dojo.body());
			wrapper.appendChild(node);

			var s = node.style;
			s.display = "";
			s.visibility = "";
			s.position = "";
			s.top = "0px";

			if(widget.declaredClass){		// TODO: in 2.0 change signature to always take widget, then remove if()
				widget._popupWrapper = wrapper;
				dojo.connect(widget, "destroy", function(){
					dojo.destroy(wrapper);
					delete widget._popupWrapper;
				});
			}
		}
		
		return wrapper;
	},

	moveOffScreen: function(/*Widget || DomNode*/ widget){
		// summary:
		//		Moves the popup widget off-screen.
		//		Do not use this method to hide popups when not in use, because
		//		that will create an accessibility issue: the offscreen popup is
		//		still in the tabbing order.

		// Create wrapper if not already there
		var wrapper = this._createWrapper(widget);

		dojo.style(wrapper, {
			visibility: "hidden",
			top: "-9999px",		// prevent transient scrollbar causing misalign (#5776), and initial flash in upper left (#10111)
			display: ""
		});
	},

	hide: function(/*dijit._Widget*/ widget){
		// summary:
		//		Hide this popup widget (until it is ready to be shown).
		//		Initialization for widgets that will be used as popups
		//
		// 		Also puts widget inside a wrapper DIV (if not already in one)
		//
		//		If popup widget needs to layout it should
		//		do so when it is made visible, and popup._onShow() is called.

		// Create wrapper if not already there
		var wrapper = this._createWrapper(widget);

		dojo.style(wrapper, "display", "none");
	},
		
	getTopPopup: function(){
		// summary:
		//		Compute the closest ancestor popup that's *not* a child of another popup.
		//		Ex: For a TooltipDialog with a button that spawns a tree of menus, find the popup of the button.
		var stack = this._stack;
		for(var pi=stack.length-1; pi > 0 && stack[pi].parent === stack[pi-1].widget; pi--){
			/* do nothing, just trying to get right value for pi */
		}
		return stack[pi];
	},

	open: function(/*dijit.popup.__OpenArgs*/ args){
		// summary:
		//		Popup the widget at the specified position
		//
		// example:
		//		opening at the mouse position
		//		|		dijit.popup.open({popup: menuWidget, x: evt.pageX, y: evt.pageY});
		//
		// example:
		//		opening the widget as a dropdown
		//		|		dijit.popup.open({parent: this, popup: menuWidget, around: this.domNode, onClose: function(){...}});
		//
		//		Note that whatever widget called dijit.popup.open() should also listen to its own _onBlur callback
		//		(fired from _base/focus.js) to know that focus has moved somewhere else and thus the popup should be closed.

		var stack = this._stack,
			widget = args.popup,
			orient = args.orient || (
				(args.parent ? args.parent.isLeftToRight() : dojo._isBodyLtr()) ?
				{'BL':'TL', 'BR':'TR', 'TL':'BL', 'TR':'BR'} :
				{'BR':'TR', 'BL':'TL', 'TR':'BR', 'TL':'BL'}
			),
			around = args.around,
			id = (args.around && args.around.id) ? (args.around.id+"_dropdown") : ("popup_"+this._idGen++);

		// If we are opening a new popup that isn't a child of a currently opened popup, then
		// close currently opened popup(s).   This should happen automatically when the old popups
		// gets the _onBlur() event, except that the _onBlur() event isn't reliable on IE, see [22198].
		while(stack.length && (!args.parent || !dojo.isDescendant(args.parent.domNode, stack[stack.length-1].widget.domNode))){
			dijit.popup.close(stack[stack.length-1].widget);
		}

		// Get pointer to popup wrapper, and create wrapper if it doesn't exist
		var wrapper = this._createWrapper(widget);


		dojo.attr(wrapper, {
			id: id,
			style: {
				zIndex: this._beginZIndex + stack.length
			},
			"class": "dijitPopup " + (widget.baseClass || widget["class"] || "").split(" ")[0] +"Popup",
			dijitPopupParent: args.parent ? args.parent.id : ""
		});

		if(dojo.isIE || dojo.isMoz){
			if(!widget.bgIframe){
				// setting widget.bgIframe triggers cleanup in _Widget.destroy()
				widget.bgIframe = new dijit.BackgroundIframe(wrapper);
			}
		}

		// position the wrapper node and make it visible
		var best = around ?
			dijit.placeOnScreenAroundElement(wrapper, around, orient, widget.orient ? dojo.hitch(widget, "orient") : null) :
			dijit.placeOnScreen(wrapper, args, orient == 'R' ? ['TR','BR','TL','BL'] : ['TL','BL','TR','BR'], args.padding);

		wrapper.style.display = "";
		wrapper.style.visibility = "visible";
		widget.domNode.style.visibility = "visible";	// counteract effects from _HasDropDown

		var handlers = [];

		// provide default escape and tab key handling
		// (this will work for any widget, not just menu)
		handlers.push(dojo.connect(wrapper, "onkeypress", this, function(evt){
			if(evt.charOrCode == dojo.keys.ESCAPE && args.onCancel){
				dojo.stopEvent(evt);
				args.onCancel();
			}else if(evt.charOrCode === dojo.keys.TAB){
				dojo.stopEvent(evt);
				var topPopup = this.getTopPopup();
				if(topPopup && topPopup.onCancel){
					topPopup.onCancel();
				}
			}
		}));

		// watch for cancel/execute events on the popup and notify the caller
		// (for a menu, "execute" means clicking an item)
		if(widget.onCancel){
			handlers.push(dojo.connect(widget, "onCancel", args.onCancel));
		}

		handlers.push(dojo.connect(widget, widget.onExecute ? "onExecute" : "onChange", this, function(){
			var topPopup = this.getTopPopup();
			if(topPopup && topPopup.onExecute){
				topPopup.onExecute();
			}
		}));

		stack.push({
			widget: widget,
			parent: args.parent,
			onExecute: args.onExecute,
			onCancel: args.onCancel,
 			onClose: args.onClose,
			handlers: handlers
		});

		if(widget.onOpen){
			// TODO: in 2.0 standardize onShow() (used by StackContainer) and onOpen() (used here)
			widget.onOpen(best);
		}

		return best;
	},

	close: function(/*dijit._Widget?*/ popup){
		// summary:
		//		Close specified popup and any popups that it parented.
		//		If no popup is specified, closes all popups.

		var stack = this._stack;

		// Basically work backwards from the top of the stack closing popups
		// until we hit the specified popup, but IIRC there was some issue where closing
		// a popup would cause others to close too.  Thus if we are trying to close B in [A,B,C]
		// closing C might close B indirectly and then the while() condition will run where stack==[A]...
		// so the while condition is constructed defensively.
		while((popup && dojo.some(stack, function(elem){return elem.widget == popup;})) ||
			(!popup && stack.length)){
			var top = stack.pop(),
				widget = top.widget,
				onClose = top.onClose;

			if(widget.onClose){
				// TODO: in 2.0 standardize onHide() (used by StackContainer) and onClose() (used here)
				widget.onClose();
			}
			dojo.forEach(top.handlers, dojo.disconnect);

			// Hide the widget and it's wrapper unless it has already been destroyed in above onClose() etc.
			if(widget && widget.domNode){
				this.hide(widget);
			}
                        
			if(onClose){
				onClose();
			}
		}
	}
};

// TODO: remove dijit._frames, it isn't being used much, since popups never release their
// iframes (see [22236])
dijit._frames = new function(){
	// summary:
	//		cache of iframes

	var queue = [];

	this.pop = function(){
		var iframe;
		if(queue.length){
			iframe = queue.pop();
			iframe.style.display="";
		}else{
			if(dojo.isIE < 9){
				var burl = dojo.config["dojoBlankHtmlUrl"] || (dojo.moduleUrl("dojo", "resources/blank.html")+"") || "javascript:\"\"";
				var html="<iframe src='" + burl + "'"
					+ " style='position: absolute; left: 0px; top: 0px;"
					+ "z-index: -1; filter:Alpha(Opacity=\"0\");'>";
				iframe = dojo.doc.createElement(html);
			}else{
			 	iframe = dojo.create("iframe");
				iframe.src = 'javascript:""';
				iframe.className = "dijitBackgroundIframe";
				dojo.style(iframe, "opacity", 0.1);
			}
			iframe.tabIndex = -1; // Magic to prevent iframe from getting focus on tab keypress - as style didn't work.
			dijit.setWaiRole(iframe,"presentation");
		}
		return iframe;
	};

	this.push = function(iframe){
		iframe.style.display="none";
		queue.push(iframe);
	}
}();


dijit.BackgroundIframe = function(/*DomNode*/ node){
	// summary:
	//		For IE/FF z-index schenanigans. id attribute is required.
	//
	// description:
	//		new dijit.BackgroundIframe(node)
	//			Makes a background iframe as a child of node, that fills
	//			area (and position) of node

	if(!node.id){ throw new Error("no id"); }
	if(dojo.isIE || dojo.isMoz){
		var iframe = (this.iframe = dijit._frames.pop());
		node.appendChild(iframe);
		if(dojo.isIE<7 || dojo.isQuirks){
			this.resize(node);
			this._conn = dojo.connect(node, 'onresize', this, function(){
				this.resize(node);
			});
		}else{
			dojo.style(iframe, {
				width: '100%',
				height: '100%'
			});
		}
	}
};

dojo.extend(dijit.BackgroundIframe, {
	resize: function(node){
		// summary:
		// 		Resize the iframe so it's the same size as node.
		//		Needed on IE6 and IE/quirks because height:100% doesn't work right.
		if(this.iframe){
			dojo.style(this.iframe, {
				width: node.offsetWidth + 'px',
				height: node.offsetHeight + 'px'
			});
		}
	},
	destroy: function(){
		// summary:
		//		destroy the iframe
		if(this._conn){
			dojo.disconnect(this._conn);
			this._conn = null;
		}
		if(this.iframe){
			dijit._frames.push(this.iframe);
			delete this.iframe;
		}
	}
});

}

if(!dojo._hasResource["dijit._base.scroll"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.scroll"] = true;
dojo.provide("dijit._base.scroll");



dijit.scrollIntoView = function(/*DomNode*/ node, /*Object?*/ pos){
	// summary:
	//		Scroll the passed node into view, if it is not already.
	//		Deprecated, use `dojo.window.scrollIntoView` instead.
	
	dojo.window.scrollIntoView(node, pos);
};

}

if(!dojo._hasResource["dojo.uacss"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.uacss"] = true;
dojo.provide("dojo.uacss");


(function(){
	// summary:
	//		Applies pre-set CSS classes to the top-level HTML node, based on:
	// 			- browser (ex: dj_ie)
	//			- browser version (ex: dj_ie6)
	//			- box model (ex: dj_contentBox)
	//			- text direction (ex: dijitRtl)
	//
	//		In addition, browser, browser version, and box model are
	//		combined with an RTL flag when browser text is RTL.  ex: dj_ie-rtl.

	var d = dojo,
		html = d.doc.documentElement,
		ie = d.isIE,
		opera = d.isOpera,
		maj = Math.floor,
		ff = d.isFF,
		boxModel = d.boxModel.replace(/-/,''),

		classes = {
			dj_ie: ie,
			dj_ie6: maj(ie) == 6,
			dj_ie7: maj(ie) == 7,
			dj_ie8: maj(ie) == 8,
			dj_ie9: maj(ie) == 9,
			dj_quirks: d.isQuirks,
			dj_iequirks: ie && d.isQuirks,

			// NOTE: Opera not supported by dijit
			dj_opera: opera,

			dj_khtml: d.isKhtml,

			dj_webkit: d.isWebKit,
			dj_safari: d.isSafari,
			dj_chrome: d.isChrome,

			dj_gecko: d.isMozilla,
			dj_ff3: maj(ff) == 3
		}; // no dojo unsupported browsers

	classes["dj_" + boxModel] = true;

	// apply browser, browser version, and box model class names
	var classStr = "";
	for(var clz in classes){
		if(classes[clz]){
			classStr += clz + " ";
		}
	}
	html.className = d.trim(html.className + " " + classStr);

	// If RTL mode, then add dj_rtl flag plus repeat existing classes with -rtl extension.
	// We can't run the code below until the <body> tag has loaded (so we can check for dir=rtl).
	// Unshift() is to run sniff code before the parser.
	dojo._loaders.unshift(function(){
		if(!dojo._isBodyLtr()){
			var rtlClassStr = "dj_rtl dijitRtl " + classStr.replace(/ /g, "-rtl ")
			html.className = d.trim(html.className + " " + rtlClassStr);
		}
	});
})();

}

if(!dojo._hasResource["dijit._base.sniff"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.sniff"] = true;
dojo.provide("dijit._base.sniff");



// summary:
//		Applies pre-set CSS classes to the top-level HTML node, see
//		`dojo.uacss` for details.
//
//		Simply doing a require on this module will
//		establish this CSS.  Modified version of Morris' CSS hack.

}

if(!dojo._hasResource["dijit._base.typematic"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.typematic"] = true;
dojo.provide("dijit._base.typematic");


dijit.typematic = {
	// summary:
	//		These functions are used to repetitively call a user specified callback
	//		method when a specific key or mouse click over a specific DOM node is
	//		held down for a specific amount of time.
	//		Only 1 such event is allowed to occur on the browser page at 1 time.

	_fireEventAndReload: function(){
		this._timer = null;
		this._callback(++this._count, this._node, this._evt);
		
		// Schedule next event, timer is at most minDelay (default 10ms) to avoid
		// browser overload (particularly avoiding starving DOH robot so it never gets to send a mouseup)
		this._currentTimeout = Math.max(
			this._currentTimeout < 0 ? this._initialDelay :
				(this._subsequentDelay > 1 ? this._subsequentDelay : Math.round(this._currentTimeout * this._subsequentDelay)),
			this._minDelay);
		this._timer = setTimeout(dojo.hitch(this, "_fireEventAndReload"), this._currentTimeout);
	},

	trigger: function(/*Event*/ evt, /*Object*/ _this, /*DOMNode*/ node, /*Function*/ callback, /*Object*/ obj, /*Number*/ subsequentDelay, /*Number*/ initialDelay, /*Number?*/ minDelay){
		// summary:
		//		Start a timed, repeating callback sequence.
		//		If already started, the function call is ignored.
		//		This method is not normally called by the user but can be
		//		when the normal listener code is insufficient.
		// evt:
		//		key or mouse event object to pass to the user callback
		// _this:
		//		pointer to the user's widget space.
		// node:
		//		the DOM node object to pass the the callback function
		// callback:
		//		function to call until the sequence is stopped called with 3 parameters:
		// count:
		//		integer representing number of repeated calls (0..n) with -1 indicating the iteration has stopped
		// node:
		//		the DOM node object passed in
		// evt:
		//		key or mouse event object
		// obj:
		//		user space object used to uniquely identify each typematic sequence
		// subsequentDelay (optional):
		//		if > 1, the number of milliseconds until the 3->n events occur
		//		or else the fractional time multiplier for the next event's delay, default=0.9
		// initialDelay (optional):
		//		the number of milliseconds until the 2nd event occurs, default=500ms
		// minDelay (optional):
		//		the maximum delay in milliseconds for event to fire, default=10ms
		if(obj != this._obj){
			this.stop();
			this._initialDelay = initialDelay || 500;
			this._subsequentDelay = subsequentDelay || 0.90;
			this._minDelay = minDelay || 10;
			this._obj = obj;
			this._evt = evt;
			this._node = node;
			this._currentTimeout = -1;
			this._count = -1;
			this._callback = dojo.hitch(_this, callback);
			this._fireEventAndReload();
			this._evt = dojo.mixin({faux: true}, evt);
		}
	},

	stop: function(){
		// summary:
		//		Stop an ongoing timed, repeating callback sequence.
		if(this._timer){
			clearTimeout(this._timer);
			this._timer = null;
		}
		if(this._obj){
			this._callback(-1, this._node, this._evt);
			this._obj = null;
		}
	},

	addKeyListener: function(/*DOMNode*/ node, /*Object*/ keyObject, /*Object*/ _this, /*Function*/ callback, /*Number*/ subsequentDelay, /*Number*/ initialDelay, /*Number?*/ minDelay){
		// summary:
		//		Start listening for a specific typematic key.
		//		See also the trigger method for other parameters.
		// keyObject:
		//		an object defining the key to listen for:
		// 		charOrCode:
		//			the printable character (string) or keyCode (number) to listen for.
		// 		keyCode:
		//			(deprecated - use charOrCode) the keyCode (number) to listen for (implies charCode = 0).
		// 		charCode:
		//			(deprecated - use charOrCode) the charCode (number) to listen for.
		// 		ctrlKey:
		//			desired ctrl key state to initiate the callback sequence:
		//			- pressed (true)
		//			- released (false)
		//			- either (unspecified)
		// 		altKey:
		//			same as ctrlKey but for the alt key
		// 		shiftKey:
		//			same as ctrlKey but for the shift key
		// returns:
		//		an array of dojo.connect handles
		if(keyObject.keyCode){
			keyObject.charOrCode = keyObject.keyCode;
			dojo.deprecated("keyCode attribute parameter for dijit.typematic.addKeyListener is deprecated. Use charOrCode instead.", "", "2.0");
		}else if(keyObject.charCode){
			keyObject.charOrCode = String.fromCharCode(keyObject.charCode);
			dojo.deprecated("charCode attribute parameter for dijit.typematic.addKeyListener is deprecated. Use charOrCode instead.", "", "2.0");
		}
		return [
			dojo.connect(node, "onkeypress", this, function(evt){
				if(evt.charOrCode == keyObject.charOrCode &&
				(keyObject.ctrlKey === undefined || keyObject.ctrlKey == evt.ctrlKey) &&
				(keyObject.altKey === undefined || keyObject.altKey == evt.altKey) &&
				(keyObject.metaKey === undefined || keyObject.metaKey == (evt.metaKey || false)) && // IE doesn't even set metaKey
				(keyObject.shiftKey === undefined || keyObject.shiftKey == evt.shiftKey)){
					dojo.stopEvent(evt);
					dijit.typematic.trigger(evt, _this, node, callback, keyObject, subsequentDelay, initialDelay, minDelay);
				}else if(dijit.typematic._obj == keyObject){
					dijit.typematic.stop();
				}
			}),
			dojo.connect(node, "onkeyup", this, function(evt){
				if(dijit.typematic._obj == keyObject){
					dijit.typematic.stop();
				}
			})
		];
	},

	addMouseListener: function(/*DOMNode*/ node, /*Object*/ _this, /*Function*/ callback, /*Number*/ subsequentDelay, /*Number*/ initialDelay, /*Number?*/ minDelay){
		// summary:
		//		Start listening for a typematic mouse click.
		//		See the trigger method for other parameters.
		// returns:
		//		an array of dojo.connect handles
		var dc = dojo.connect;
		return [
			dc(node, "mousedown", this, function(evt){
				dojo.stopEvent(evt);
				dijit.typematic.trigger(evt, _this, node, callback, node, subsequentDelay, initialDelay, minDelay);
			}),
			dc(node, "mouseup", this, function(evt){
				dojo.stopEvent(evt);
				dijit.typematic.stop();
			}),
			dc(node, "mouseout", this, function(evt){
				dojo.stopEvent(evt);
				dijit.typematic.stop();
			}),
			dc(node, "mousemove", this, function(evt){
				evt.preventDefault();
			}),
			dc(node, "dblclick", this, function(evt){
				dojo.stopEvent(evt);
				if(dojo.isIE){
					dijit.typematic.trigger(evt, _this, node, callback, node, subsequentDelay, initialDelay, minDelay);
					setTimeout(dojo.hitch(this, dijit.typematic.stop), 50);
				}
			})
		];
	},

	addListener: function(/*Node*/ mouseNode, /*Node*/ keyNode, /*Object*/ keyObject, /*Object*/ _this, /*Function*/ callback, /*Number*/ subsequentDelay, /*Number*/ initialDelay, /*Number?*/ minDelay){
		// summary:
		//		Start listening for a specific typematic key and mouseclick.
		//		This is a thin wrapper to addKeyListener and addMouseListener.
		//		See the addMouseListener and addKeyListener methods for other parameters.
		// mouseNode:
		//		the DOM node object to listen on for mouse events.
		// keyNode:
		//		the DOM node object to listen on for key events.
		// returns:
		//		an array of dojo.connect handles
		return this.addKeyListener(keyNode, keyObject, _this, callback, subsequentDelay, initialDelay, minDelay).concat(
			this.addMouseListener(mouseNode, _this, callback, subsequentDelay, initialDelay, minDelay));
	}
};

}

if(!dojo._hasResource["dijit._base.wai"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.wai"] = true;
dojo.provide("dijit._base.wai");


dijit.wai = {
	onload: function(){
		// summary:
		//		Detects if we are in high-contrast mode or not

		// This must be a named function and not an anonymous
		// function, so that the widget parsing code can make sure it
		// registers its onload function after this function.
		// DO NOT USE "this" within this function.

		// create div for testing if high contrast mode is on or images are turned off
		var div = dojo.create("div",{
			id: "a11yTestNode",
			style:{
				cssText:'border: 1px solid;'
					+ 'border-color:red green;'
					+ 'position: absolute;'
					+ 'height: 5px;'
					+ 'top: -999px;'
					+ 'background-image: url("' + (dojo.config.blankGif || dojo.moduleUrl("dojo", "resources/blank.gif")) + '");'
			}
		}, dojo.body());

		// test it
		var cs = dojo.getComputedStyle(div);
		if(cs){
			var bkImg = cs.backgroundImage;
			var needsA11y = (cs.borderTopColor == cs.borderRightColor) || (bkImg != null && (bkImg == "none" || bkImg == "url(invalid-url:)" ));
			dojo[needsA11y ? "addClass" : "removeClass"](dojo.body(), "dijit_a11y");
			if(dojo.isIE){
				div.outerHTML = "";		// prevent mixed-content warning, see http://support.microsoft.com/kb/925014
			}else{
				dojo.body().removeChild(div);
			}
		}
	}
};

// Test if computer is in high contrast mode.
// Make sure the a11y test runs first, before widgets are instantiated.
if(dojo.isIE || dojo.isMoz){	// NOTE: checking in Safari messes things up
	dojo._loaders.unshift(dijit.wai.onload);
}

dojo.mixin(dijit, {
	hasWaiRole: function(/*Element*/ elem, /*String?*/ role){
		// summary:
		//		Determines if an element has a particular role.
		// returns:
		//		True if elem has the specific role attribute and false if not.
		// 		For backwards compatibility if role parameter not provided,
		// 		returns true if has a role
		var waiRole = this.getWaiRole(elem);
		return role ? (waiRole.indexOf(role) > -1) : (waiRole.length > 0);
	},

	getWaiRole: function(/*Element*/ elem){
		// summary:
		//		Gets the role for an element (which should be a wai role).
		// returns:
		//		The role of elem or an empty string if elem
		//		does not have a role.
		 return dojo.trim((dojo.attr(elem, "role") || "").replace("wairole:",""));
	},

	setWaiRole: function(/*Element*/ elem, /*String*/ role){
		// summary:
		//		Sets the role on an element.
		// description:
		//		Replace existing role attribute with new role.

			dojo.attr(elem, "role", role);
	},

	removeWaiRole: function(/*Element*/ elem, /*String*/ role){
		// summary:
		//		Removes the specified role from an element.
		// 		Removes role attribute if no specific role provided (for backwards compat.)

		var roleValue = dojo.attr(elem, "role");
		if(!roleValue){ return; }
		if(role){
			var t = dojo.trim((" " + roleValue + " ").replace(" " + role + " ", " "));
			dojo.attr(elem, "role", t);
		}else{
			elem.removeAttribute("role");
		}
	},

	hasWaiState: function(/*Element*/ elem, /*String*/ state){
		// summary:
		//		Determines if an element has a given state.
		// description:
		//		Checks for an attribute called "aria-"+state.
		// returns:
		//		true if elem has a value for the given state and
		//		false if it does not.

		return elem.hasAttribute ? elem.hasAttribute("aria-"+state) : !!elem.getAttribute("aria-"+state);
	},

	getWaiState: function(/*Element*/ elem, /*String*/ state){
		// summary:
		//		Gets the value of a state on an element.
		// description:
		//		Checks for an attribute called "aria-"+state.
		// returns:
		//		The value of the requested state on elem
		//		or an empty string if elem has no value for state.

		return elem.getAttribute("aria-"+state) || "";
	},

	setWaiState: function(/*Element*/ elem, /*String*/ state, /*String*/ value){
		// summary:
		//		Sets a state on an element.
		// description:
		//		Sets an attribute called "aria-"+state.

		elem.setAttribute("aria-"+state, value);
	},

	removeWaiState: function(/*Element*/ elem, /*String*/ state){
		// summary:
		//		Removes a state from an element.
		// description:
		//		Sets an attribute called "aria-"+state.

		elem.removeAttribute("aria-"+state);
	}
});

}

if(!dojo._hasResource["dijit._base"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base"] = true;
dojo.provide("dijit._base");












}

if(!dojo._hasResource["dojo.date.stamp"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.date.stamp"] = true;
dojo.provide("dojo.date.stamp");

dojo.getObject("date.stamp", true, dojo);

// Methods to convert dates to or from a wire (string) format using well-known conventions

dojo.date.stamp.fromISOString = function(/*String*/formattedString, /*Number?*/defaultTime){
	//	summary:
	//		Returns a Date object given a string formatted according to a subset of the ISO-8601 standard.
	//
	//	description:
	//		Accepts a string formatted according to a profile of ISO8601 as defined by
	//		[RFC3339](http://www.ietf.org/rfc/rfc3339.txt), except that partial input is allowed.
	//		Can also process dates as specified [by the W3C](http://www.w3.org/TR/NOTE-datetime)
	//		The following combinations are valid:
	//
	//			* dates only
	//			|	* yyyy
	//			|	* yyyy-MM
	//			|	* yyyy-MM-dd
	// 			* times only, with an optional time zone appended
	//			|	* THH:mm
	//			|	* THH:mm:ss
	//			|	* THH:mm:ss.SSS
	// 			* and "datetimes" which could be any combination of the above
	//
	//		timezones may be specified as Z (for UTC) or +/- followed by a time expression HH:mm
	//		Assumes the local time zone if not specified.  Does not validate.  Improperly formatted
	//		input may return null.  Arguments which are out of bounds will be handled
	// 		by the Date constructor (e.g. January 32nd typically gets resolved to February 1st)
	//		Only years between 100 and 9999 are supported.
	//
  	//	formattedString:
	//		A string such as 2005-06-30T08:05:00-07:00 or 2005-06-30 or T08:05:00
	//
	//	defaultTime:
	//		Used for defaults for fields omitted in the formattedString.
	//		Uses 1970-01-01T00:00:00.0Z by default.

	if(!dojo.date.stamp._isoRegExp){
		dojo.date.stamp._isoRegExp =
//TODO: could be more restrictive and check for 00-59, etc.
			/^(?:(\d{4})(?:-(\d{2})(?:-(\d{2}))?)?)?(?:T(\d{2}):(\d{2})(?::(\d{2})(.\d+)?)?((?:[+-](\d{2}):(\d{2}))|Z)?)?$/;
	}

	var match = dojo.date.stamp._isoRegExp.exec(formattedString),
		result = null;

	if(match){
		match.shift();
		if(match[1]){match[1]--;} // Javascript Date months are 0-based
		if(match[6]){match[6] *= 1000;} // Javascript Date expects fractional seconds as milliseconds

		if(defaultTime){
			// mix in defaultTime.  Relatively expensive, so use || operators for the fast path of defaultTime === 0
			defaultTime = new Date(defaultTime);
			dojo.forEach(dojo.map(["FullYear", "Month", "Date", "Hours", "Minutes", "Seconds", "Milliseconds"], function(prop){
				return defaultTime["get" + prop]();
			}), function(value, index){
				match[index] = match[index] || value;
			});
		}
		result = new Date(match[0]||1970, match[1]||0, match[2]||1, match[3]||0, match[4]||0, match[5]||0, match[6]||0); //TODO: UTC defaults
		if(match[0] < 100){
			result.setFullYear(match[0] || 1970);
		}

		var offset = 0,
			zoneSign = match[7] && match[7].charAt(0);
		if(zoneSign != 'Z'){
			offset = ((match[8] || 0) * 60) + (Number(match[9]) || 0);
			if(zoneSign != '-'){ offset *= -1; }
		}
		if(zoneSign){
			offset -= result.getTimezoneOffset();
		}
		if(offset){
			result.setTime(result.getTime() + offset * 60000);
		}
	}

	return result; // Date or null
};

/*=====
	dojo.date.stamp.__Options = function(){
		//	selector: String
		//		"date" or "time" for partial formatting of the Date object.
		//		Both date and time will be formatted by default.
		//	zulu: Boolean
		//		if true, UTC/GMT is used for a timezone
		//	milliseconds: Boolean
		//		if true, output milliseconds
		this.selector = selector;
		this.zulu = zulu;
		this.milliseconds = milliseconds;
	}
=====*/

dojo.date.stamp.toISOString = function(/*Date*/dateObject, /*dojo.date.stamp.__Options?*/options){
	//	summary:
	//		Format a Date object as a string according a subset of the ISO-8601 standard
	//
	//	description:
	//		When options.selector is omitted, output follows [RFC3339](http://www.ietf.org/rfc/rfc3339.txt)
	//		The local time zone is included as an offset from GMT, except when selector=='time' (time without a date)
	//		Does not check bounds.  Only years between 100 and 9999 are supported.
	//
	//	dateObject:
	//		A Date object

	var _ = function(n){ return (n < 10) ? "0" + n : n; };
	options = options || {};
	var formattedDate = [],
		getter = options.zulu ? "getUTC" : "get",
		date = "";
	if(options.selector != "time"){
		var year = dateObject[getter+"FullYear"]();
		date = ["0000".substr((year+"").length)+year, _(dateObject[getter+"Month"]()+1), _(dateObject[getter+"Date"]())].join('-');
	}
	formattedDate.push(date);
	if(options.selector != "date"){
		var time = [_(dateObject[getter+"Hours"]()), _(dateObject[getter+"Minutes"]()), _(dateObject[getter+"Seconds"]())].join(':');
		var millis = dateObject[getter+"Milliseconds"]();
		if(options.milliseconds){
			time += "."+ (millis < 100 ? "0" : "") + _(millis);
		}
		if(options.zulu){
			time += "Z";
		}else if(options.selector != "time"){
			var timezoneOffset = dateObject.getTimezoneOffset();
			var absOffset = Math.abs(timezoneOffset);
			time += (timezoneOffset > 0 ? "-" : "+") +
				_(Math.floor(absOffset/60)) + ":" + _(absOffset%60);
		}
		formattedDate.push(time);
	}
	return formattedDate.join('T'); // String
};

}

if(!dojo._hasResource["dojo.parser"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.parser"] = true;
dojo.provide("dojo.parser");



new Date("X"); // workaround for #11279, new Date("") == NaN

dojo.parser = new function(){
	// summary:
	//		The Dom/Widget parsing package

	var d = dojo;

	function val2type(/*Object*/ value){
		// summary:
		//		Returns name of type of given value.

		if(d.isString(value)){ return "string"; }
		if(typeof value == "number"){ return "number"; }
		if(typeof value == "boolean"){ return "boolean"; }
		if(d.isFunction(value)){ return "function"; }
		if(d.isArray(value)){ return "array"; } // typeof [] == "object"
		if(value instanceof Date) { return "date"; } // assume timestamp
		if(value instanceof d._Url){ return "url"; }
		return "object";
	}

	function str2obj(/*String*/ value, /*String*/ type){
		// summary:
		//		Convert given string value to given type
		switch(type){
			case "string":
				return value;
			case "number":
				return value.length ? Number(value) : NaN;
			case "boolean":
				// for checked/disabled value might be "" or "checked".	 interpret as true.
				return typeof value == "boolean" ? value : !(value.toLowerCase()=="false");
			case "function":
				if(d.isFunction(value)){
					// IE gives us a function, even when we say something like onClick="foo"
					// (in which case it gives us an invalid function "function(){ foo }").
					//	Therefore, convert to string
					value=value.toString();
					value=d.trim(value.substring(value.indexOf('{')+1, value.length-1));
				}
				try{
					if(value === "" || value.search(/[^\w\.]+/i) != -1){
						// The user has specified some text for a function like "return x+5"
						return new Function(value);
					}else{
						// The user has specified the name of a function like "myOnClick"
						// or a single word function "return"
						return d.getObject(value, false) || new Function(value);
					}
				}catch(e){ return new Function(); }
			case "array":
				return value ? value.split(/\s*,\s*/) : [];
			case "date":
				switch(value){
					case "": return new Date("");	// the NaN of dates
					case "now": return new Date();	// current date
					default: return d.date.stamp.fromISOString(value);
				}
			case "url":
				return d.baseUrl + value;
			default:
				return d.fromJson(value);
		}
	}

	var dummyClass = {}, instanceClasses = {
		// map from fully qualified name (like "dijit.Button") to structure like
		// { cls: dijit.Button, params: {label: "string", disabled: "boolean"} }
	};

	// Widgets like BorderContainer add properties to _Widget via dojo.extend().
	// If BorderContainer is loaded after _Widget's parameter list has been cached,
	// we need to refresh that parameter list (for _Widget and all widgets that extend _Widget).
	// TODO: remove this in 2.0, when we stop caching parameters.
	d.connect(d, "extend", function(){
		instanceClasses = {};
	});

	function getProtoInfo(cls, params){
		// cls: A prototype
		//		The prototype of the class to check props on
		// params: Object
		//		The parameters object to mix found parameters onto.
		for(var name in cls){
			if(name.charAt(0)=="_"){ continue; }	// skip internal properties
			if(name in dummyClass){ continue; }		// skip "constructor" and "toString"
			params[name] = val2type(cls[name]);
		}
		return params;
	}

	function getClassInfo(/*String*/ className, /*Boolean*/ skipParamsLookup){
		// summary:
		//		Maps a widget name string like "dijit.form.Button" to the widget constructor itself,
		//		and a list of that widget's parameters and their types
		// className:
		//		fully qualified name (like "dijit.form.Button")
		// returns:
		//		structure like
		//			{
		//				cls: dijit.Button,
		//				params: { label: "string", disabled: "boolean"}
		//			}

		var c = instanceClasses[className];
		if(!c){
			// get pointer to widget class
			var cls = d.getObject(className), params = null;
			if(!cls){ return null; }		// class not defined [yet]
			if(!skipParamsLookup){ // from fastpath, we don't need to lookup the attrs on the proto because they are explicit
				params = getProtoInfo(cls.prototype, {})
			}
			c = { cls: cls, params: params };
			
		}else if(!skipParamsLookup && !c.params){
			// if we're calling getClassInfo and have a cls proto, but no params info, scan that cls for params now
			// and update the pointer in instanceClasses[className]. This happens when a widget appears in another
			// widget's template which still uses dojoType, but an instance of the widget appears prior with a data-dojo-type,
			// skipping this lookup the first time.
			c.params = getProtoInfo(c.cls.prototype, {});
		}
		
		return c;
	}

	this._functionFromScript = function(script, attrData){
		// summary:
		//		Convert a <script type="dojo/method" args="a, b, c"> ... </script>
		//		into a function
		// script: DOMNode
		//		The <script> DOMNode
		// attrData: String
		//		For HTML5 compliance, searches for attrData + "args" (typically
		//		"data-dojo-args") instead of "args"
		var preamble = "";
		var suffix = "";
		var argsStr = (script.getAttribute(attrData + "args") || script.getAttribute("args"));
		if(argsStr){
			d.forEach(argsStr.split(/\s*,\s*/), function(part, idx){
				preamble += "var "+part+" = arguments["+idx+"]; ";
			});
		}
		var withStr = script.getAttribute("with");
		if(withStr && withStr.length){
			d.forEach(withStr.split(/\s*,\s*/), function(part){
				preamble += "with("+part+"){";
				suffix += "}";
			});
		}
		return new Function(preamble+script.innerHTML+suffix);
	};

	this.instantiate = function(/* Array */nodes, /* Object? */mixin, /* Object? */args){
		// summary:
		//		Takes array of nodes, and turns them into class instances and
		//		potentially calls a startup method to allow them to connect with
		//		any children.
		// nodes: Array
		//		Array of nodes or objects like
		//	|		{
		//	|			type: "dijit.form.Button",
		//	|			node: DOMNode,
		//	|			scripts: [ ... ],	// array of <script type="dojo/..."> children of node
		//	|			inherited: { ... }	// settings inherited from ancestors like dir, theme, etc.
		//	|		}
		// mixin: Object?
		//		An object that will be mixed in with each node in the array.
		//		Values in the mixin will override values in the node, if they
		//		exist.
		// args: Object?
		//		An object used to hold kwArgs for instantiation.
		//		See parse.args argument for details.

		var thelist = [],
		mixin = mixin||{};
		args = args||{};

		// TODO: for 2.0 default to data-dojo- regardless of scopeName (or maybe scopeName won't exist in 2.0)
		var attrName = (args.scope || d._scopeName) + "Type",	// typically "dojoType"
			attrData = "data-" + (args.scope || d._scopeName) + "-";	// typically "data-dojo-"

		d.forEach(nodes, function(obj){
			if(!obj){ return; }

			// Get pointers to DOMNode, dojoType string, and clsInfo (metadata about the dojoType), etc.
			var node, type, clsInfo, clazz, scripts, fastpath;
			if(obj.node){
				// new format of nodes[] array, object w/lots of properties pre-computed for me
				node = obj.node;
				type = obj.type;
				fastpath = obj.fastpath;
				clsInfo = obj.clsInfo || (type && getClassInfo(type, fastpath));
				clazz = clsInfo && clsInfo.cls;
				scripts = obj.scripts;
			}else{
				// old (backwards compatible) format of nodes[] array, simple array of DOMNodes. no fastpath/data-dojo-type support here.
				node = obj;
				type = attrName in mixin ? mixin[attrName] : node.getAttribute(attrName);
				clsInfo = type && getClassInfo(type);
				clazz = clsInfo && clsInfo.cls;
				scripts = (clazz && (clazz._noScript || clazz.prototype._noScript) ? [] :
							d.query("> script[type^='dojo/']", node));
			}
			if(!clsInfo){
				throw new Error("Could not load class '" + type);
			}

			// Setup hash to hold parameter settings for this widget.	Start with the parameter
			// settings inherited from ancestors ("dir" and "lang").
			// Inherited setting may later be overridden by explicit settings on node itself.
			var params = {};
				
			if(args.defaults){
				// settings for the document itself (or whatever subtree is being parsed)
				d._mixin(params, args.defaults);
			}
			if(obj.inherited){
				// settings from dir=rtl or lang=... on a node above this node
				d._mixin(params, obj.inherited);
			}
			
			// mix things found in data-dojo-props into the params
			if(fastpath){
				var extra = node.getAttribute(attrData + "props");
				if(extra && extra.length){
					try{
						extra = d.fromJson.call(args.propsThis, "{" + extra + "}");
						d._mixin(params, extra);
					}catch(e){
						// give the user a pointer to their invalid parameters. FIXME: can we kill this in production?
						throw new Error(e.toString() + " in data-dojo-props='" + extra + "'");
					}
				}

				// For the benefit of _Templated, check if node has data-dojo-attach-point/data-dojo-attach-event
				// and mix those in as though they were parameters
				var attachPoint = node.getAttribute(attrData + "attach-point");
				if(attachPoint){
					params.dojoAttachPoint = attachPoint;
				}
				var attachEvent = node.getAttribute(attrData + "attach-event");
				if(attachEvent){
					params.dojoAttachEvent = attachEvent;
				}
				dojo.mixin(params, mixin);
			}else{
				// FIXME: we need something like "deprecateOnce()" to throw dojo.deprecation for something.
				// remove this logic in 2.0
				// read parameters (ie, attributes) specified on DOMNode

				var attributes = node.attributes;

				// clsInfo.params lists expected params like {"checked": "boolean", "n": "number"}
				for(var name in clsInfo.params){
					var item = name in mixin ? { value:mixin[name], specified:true } : attributes.getNamedItem(name);
					if(!item || (!item.specified && (!dojo.isIE || name.toLowerCase()!="value"))){ continue; }
					var value = item.value;
					// Deal with IE quirks for 'class' and 'style'
					switch(name){
					case "class":
						value = "className" in mixin ? mixin.className : node.className;
						break;
					case "style":
						value = "style" in mixin ? mixin.style : (node.style && node.style.cssText); // FIXME: Opera?
					}
					var _type = clsInfo.params[name];
					if(typeof value == "string"){
						params[name] = str2obj(value, _type);
					}else{
						params[name] = value;
					}
				}
			}

			// Process <script type="dojo/*"> script tags
			// <script type="dojo/method" event="foo"> tags are added to params, and passed to
			// the widget on instantiation.
			// <script type="dojo/method"> tags (with no event) are executed after instantiation
			// <script type="dojo/connect" event="foo"> tags are dojo.connected after instantiation
			// note: dojo/* script tags cannot exist in self closing widgets, like <input />
			var connects = [],	// functions to connect after instantiation
				calls = [];		// functions to call after instantiation

			d.forEach(scripts, function(script){
				node.removeChild(script);
				// FIXME: drop event="" support in 2.0. use data-dojo-event="" instead
				var event = (script.getAttribute(attrData + "event") || script.getAttribute("event")),
					type = script.getAttribute("type"),
					nf = d.parser._functionFromScript(script, attrData);
				if(event){
					if(type == "dojo/connect"){
						connects.push({event: event, func: nf});
					}else{
						params[event] = nf;
					}
				}else{
					calls.push(nf);
				}
			});

			var markupFactory = clazz.markupFactory || clazz.prototype && clazz.prototype.markupFactory;
			// create the instance
			var instance = markupFactory ? markupFactory(params, node, clazz) : new clazz(params, node);
			thelist.push(instance);

			// map it to the JS namespace if that makes sense
			// FIXME: in 2.0, drop jsId support. use data-dojo-id instead
			var jsname = (node.getAttribute(attrData + "id") || node.getAttribute("jsId"));
			if(jsname){
				d.setObject(jsname, instance);
			}

			// process connections and startup functions
			d.forEach(connects, function(connect){
				d.connect(instance, connect.event, null, connect.func);
			});
			d.forEach(calls, function(func){
				func.call(instance);
			});
		});

		// Call startup on each top level instance if it makes sense (as for
		// widgets).  Parent widgets will recursively call startup on their
		// (non-top level) children
		if(!mixin._started){
			// TODO: for 2.0, when old instantiate() API is desupported, store parent-child
			// relationships in the nodes[] array so that no getParent() call is needed.
			// Note that will  require a parse() call from ContentPane setting a param that the
			// ContentPane is the parent widget (so that the parse doesn't call startup() on the
			// ContentPane's children)
			d.forEach(thelist, function(instance){
				if( !args.noStart && instance  &&
					dojo.isFunction(instance.startup) &&
					!instance._started &&
					(!instance.getParent || !instance.getParent())
				){
					instance.startup();
				}
			});
		}
		return thelist;
	};

	this.parse = function(rootNode, args){
		// summary:
		//		Scan the DOM for class instances, and instantiate them.
		//
		// description:
		//		Search specified node (or root node) recursively for class instances,
		//		and instantiate them. Searches for either data-dojo-type="Class" or
		//		dojoType="Class" where "Class" is a a fully qualified class name,
		//		like `dijit.form.Button`
		//
		//		Using `data-dojo-type`:
		//		Attributes using can be mixed into the parameters used to instantitate the
		//		Class by using a `data-dojo-props` attribute on the node being converted.
		//		`data-dojo-props` should be a string attribute to be converted from JSON.
		//
		//		Using `dojoType`:
		//		Attributes are read from the original domNode and converted to appropriate
		//		types by looking up the Class prototype values. This is the default behavior
		//		from Dojo 1.0 to Dojo 1.5. `dojoType` support is deprecated, and will
		//		go away in Dojo 2.0.
		//
		// rootNode: DomNode?
		//		A default starting root node from which to start the parsing. Can be
		//		omitted, defaulting to the entire document. If omitted, the `args`
		//		object can be passed in this place. If the `args` object has a
		//		`rootNode` member, that is used.
		//
		// args: Object
		//		a kwArgs object passed along to instantiate()
		//
		//			* noStart: Boolean?
		//				when set will prevent the parser from calling .startup()
		//				when locating the nodes.
		//			* rootNode: DomNode?
		//				identical to the function's `rootNode` argument, though
		//				allowed to be passed in via this `args object.
		//			* template: Boolean
		//				If true, ignores ContentPane's stopParser flag and parses contents inside of
		//				a ContentPane inside of a template.   This allows dojoAttachPoint on widgets/nodes
		//				nested inside the ContentPane to work.
		//			* inherited: Object
		//				Hash possibly containing dir and lang settings to be applied to
		//				parsed widgets, unless there's another setting on a sub-node that overrides
		//			* scope: String
		//				Root for attribute names to search for.   If scopeName is dojo,
		//				will search for data-dojo-type (or dojoType).   For backwards compatibility
		//				reasons defaults to dojo._scopeName (which is "dojo" except when
		//				multi-version support is used, when it will be something like dojo16, dojo20, etc.)
		//			* propsThis: Object
		//				If specified, "this" referenced from data-dojo-props will refer to propsThis.
		//				Intended for use from the widgets-in-template feature of `dijit._Templated`
		//
		// example:
		//		Parse all widgets on a page:
		//	|		dojo.parser.parse();
		//
		// example:
		//		Parse all classes within the node with id="foo"
		//	|		dojo.parser.parse(dojo.byId('foo'));
		//
		// example:
		//		Parse all classes in a page, but do not call .startup() on any
		//		child
		//	|		dojo.parser.parse({ noStart: true })
		//
		// example:
		//		Parse all classes in a node, but do not call .startup()
		//	|		dojo.parser.parse(someNode, { noStart:true });
		//	|		// or
		//	|		dojo.parser.parse({ noStart:true, rootNode: someNode });

		// determine the root node based on the passed arguments.
		var root;
		if(!args && rootNode && rootNode.rootNode){
			args = rootNode;
			root = args.rootNode;
		}else{
			root = rootNode;
		}
		root = root ? dojo.byId(root) : dojo.body();
		args = args || {};

		var attrName = (args.scope || d._scopeName) + "Type",		// typically "dojoType"
			attrData = "data-" + (args.scope || d._scopeName) + "-";	// typically "data-dojo-"

		function scan(parent, list){
			// summary:
			//		Parent is an Object representing a DOMNode, with or without a dojoType specified.
			//		Scan parent's children looking for nodes with dojoType specified, storing in list[].
			//		If parent has a dojoType, also collects <script type=dojo/*> children and stores in parent.scripts[].
			// parent: Object
			//		Object representing the parent node, like
			//	|	{
			//	|		node: DomNode,			// scan children of this node
			//	|		inherited: {dir: "rtl"},	// dir/lang setting inherited from above node
			//	|
			//	|		// attributes only set if node has dojoType specified
			//	|		scripts: [],			// empty array, put <script type=dojo/*> in here
			//	|		clsInfo: { cls: dijit.form.Button, ...}
			//	|	}
			// list: DomNode[]
			//		Output array of objects (same format as parent) representing nodes to be turned into widgets

			// Effective dir and lang settings on parent node, either set directly or inherited from grandparent
			var inherited = dojo.clone(parent.inherited);
			dojo.forEach(["dir", "lang"], function(name){
				// TODO: what if this is a widget and dir/lang are declared in data-dojo-props?
				var val = parent.node.getAttribute(name);
				if(val){
					inherited[name] = val;
				}
			});

			// if parent is a widget, then search for <script type=dojo/*> tags and put them in scripts[].
			var scripts = parent.clsInfo && !parent.clsInfo.cls.prototype._noScript ? parent.scripts : null;

			// unless parent is a widget with the stopParser flag set, continue search for dojoType, recursively
			var recurse = (!parent.clsInfo || !parent.clsInfo.cls.prototype.stopParser) || (args && args.template);

			// scan parent's children looking for dojoType and <script type=dojo/*>
			for(var child = parent.node.firstChild; child; child = child.nextSibling){
				if(child.nodeType == 1){
					// FIXME: desupport dojoType in 2.0. use data-dojo-type instead
					var type, html5 = recurse && child.getAttribute(attrData + "type");
					if(html5){
						type = html5;
					}else{
						// fallback to backward compatible mode, using dojoType. remove in 2.0
						type = recurse && child.getAttribute(attrName);
					}
					
					var fastpath = html5 == type;

					if(type){
						// if dojoType/data-dojo-type specified, add to output array of nodes to instantiate
						var params = {
							"type": type,
							fastpath: fastpath,
							clsInfo: getClassInfo(type, fastpath), // note: won't find classes declared via dojo.Declaration
							node: child,
							scripts: [], // <script> nodes that are parent's children
							inherited: inherited // dir & lang attributes inherited from parent
						};
						list.push(params);

						// Recurse, collecting <script type="dojo/..."> children, and also looking for
						// descendant nodes with dojoType specified (unless the widget has the stopParser flag),
						scan(params, list);
					}else if(scripts && child.nodeName.toLowerCase() == "script"){
						// if <script type="dojo/...">, save in scripts[]
						type = child.getAttribute("type");
						if (type && /^dojo\/\w/i.test(type)) {
							scripts.push(child);
						}
					}else if(recurse){
						// Recurse, looking for grandchild nodes with dojoType specified
						scan({
							node: child,
							inherited: inherited
						}, list);
					}
				}
			}
		}

		// Ignore bogus entries in inherited hash like {dir: ""}
		var inherited = {};
		if(args && args.inherited){
			for(var key in args.inherited){
				if(args.inherited[key]){ inherited[key] = args.inherited[key]; }
			}
		}

		// Make list of all nodes on page w/dojoType specified
		var list = [];
		scan({
			node: root,
			inherited: inherited
		}, list);

		// go build the object instances
		var mixin = args && args.template ? {template: true} : null;
		return this.instantiate(list, mixin, args); // Array
	};
}();

//Register the parser callback. It should be the first callback
//after the a11y test.

(function(){
	var parseRunner = function(){
		if(dojo.config.parseOnLoad){
			dojo.parser.parse();
		}
	};

	// FIXME: need to clobber cross-dependency!!
	if(dojo.getObject("dijit.wai.onload") === dojo._loaders[0]){
		dojo._loaders.splice(1, 0, parseRunner);
	}else{
		dojo._loaders.unshift(parseRunner);
	}
})();

}

if(!dojo._hasResource["dojo.string"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.string"] = true;
dojo.provide("dojo.string");

dojo.getObject("string", true, dojo);

/*=====
dojo.string = {
	// summary: String utilities for Dojo
};
=====*/

dojo.string.rep = function(/*String*/str, /*Integer*/num){
	//	summary:
	//		Efficiently replicate a string `n` times.
	//	str:
	//		the string to replicate
	//	num:
	//		number of times to replicate the string
	
	if(num <= 0 || !str){ return ""; }
	
	var buf = [];
	for(;;){
		if(num & 1){
			buf.push(str);
		}
		if(!(num >>= 1)){ break; }
		str += str;
	}
	return buf.join("");	// String
};

dojo.string.pad = function(/*String*/text, /*Integer*/size, /*String?*/ch, /*Boolean?*/end){
	//	summary:
	//		Pad a string to guarantee that it is at least `size` length by
	//		filling with the character `ch` at either the start or end of the
	//		string. Pads at the start, by default.
	//	text:
	//		the string to pad
	//	size:
	//		length to provide padding
	//	ch:
	//		character to pad, defaults to '0'
	//	end:
	//		adds padding at the end if true, otherwise pads at start
	//	example:
	//	|	// Fill the string to length 10 with "+" characters on the right.  Yields "Dojo++++++".
	//	|	dojo.string.pad("Dojo", 10, "+", true);

	if(!ch){
		ch = '0';
	}
	var out = String(text),
		pad = dojo.string.rep(ch, Math.ceil((size - out.length) / ch.length));
	return end ? out + pad : pad + out;	// String
};

dojo.string.substitute = function(	/*String*/		template,
									/*Object|Array*/map,
									/*Function?*/	transform,
									/*Object?*/		thisObject){
	//	summary:
	//		Performs parameterized substitutions on a string. Throws an
	//		exception if any parameter is unmatched.
	//	template:
	//		a string with expressions in the form `${key}` to be replaced or
	//		`${key:format}` which specifies a format function. keys are case-sensitive.
	//	map:
	//		hash to search for substitutions
	//	transform:
	//		a function to process all parameters before substitution takes
	//		place, e.g. mylib.encodeXML
	//	thisObject:
	//		where to look for optional format function; default to the global
	//		namespace
	//	example:
	//		Substitutes two expressions in a string from an Array or Object
	//	|	// returns "File 'foo.html' is not found in directory '/temp'."
	//	|	// by providing substitution data in an Array
	//	|	dojo.string.substitute(
	//	|		"File '${0}' is not found in directory '${1}'.",
	//	|		["foo.html","/temp"]
	//	|	);
	//	|
	//	|	// also returns "File 'foo.html' is not found in directory '/temp'."
	//	|	// but provides substitution data in an Object structure.  Dotted
	//	|	// notation may be used to traverse the structure.
	//	|	dojo.string.substitute(
	//	|		"File '${name}' is not found in directory '${info.dir}'.",
	//	|		{ name: "foo.html", info: { dir: "/temp" } }
	//	|	);
	//	example:
	//		Use a transform function to modify the values:
	//	|	// returns "file 'foo.html' is not found in directory '/temp'."
	//	|	dojo.string.substitute(
	//	|		"${0} is not found in ${1}.",
	//	|		["foo.html","/temp"],
	//	|		function(str){
	//	|			// try to figure out the type
	//	|			var prefix = (str.charAt(0) == "/") ? "directory": "file";
	//	|			return prefix + " '" + str + "'";
	//	|		}
	//	|	);
	//	example:
	//		Use a formatter
	//	|	// returns "thinger -- howdy"
	//	|	dojo.string.substitute(
	//	|		"${0:postfix}", ["thinger"], null, {
	//	|			postfix: function(value, key){
	//	|				return value + " -- howdy";
	//	|			}
	//	|		}
	//	|	);

	thisObject = thisObject || dojo.global;
	transform = transform ?
		dojo.hitch(thisObject, transform) : function(v){ return v; };

	return template.replace(/\$\{([^\s\:\}]+)(?:\:([^\s\:\}]+))?\}/g,
		function(match, key, format){
			var value = dojo.getObject(key, false, map);
			if(format){
				value = dojo.getObject(format, false, thisObject).call(thisObject, value, key);
			}
			return transform(value, key).toString();
		}); // String
};

/*=====
dojo.string.trim = function(str){
	//	summary:
	//		Trims whitespace from both sides of the string
	//	str: String
	//		String to be trimmed
	//	returns: String
	//		Returns the trimmed string
	//	description:
	//		This version of trim() was taken from [Steven Levithan's blog](http://blog.stevenlevithan.com/archives/faster-trim-javascript).
	//		The short yet performant version of this function is dojo.trim(),
	//		which is part of Dojo base.  Uses String.prototype.trim instead, if available.
	return "";	// String
}
=====*/

dojo.string.trim = String.prototype.trim ?
	dojo.trim : // aliasing to the native function
	function(str){
		str = str.replace(/^\s+/, '');
		for(var i = str.length - 1; i >= 0; i--){
			if(/\S/.test(str.charAt(i))){
				str = str.substring(0, i + 1);
				break;
			}
		}
		return str;
	};

}

if(!dojo._hasResource["dojo.Stateful"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.Stateful"] = true;
dojo.provide("dojo.Stateful");


dojo.declare("dojo.Stateful", null, {
	// summary:
	//		Base class for objects that provide named properties with optional getter/setter
	//		control and the ability to watch for property changes
	// example:
	//	|	var obj = new dojo.Stateful();
	//	|	obj.watch("foo", function(){
	//	|		console.log("foo changed to " + this.get("foo"));
	//	|	});
	//	|	obj.set("foo","bar");
	postscript: function(mixin){
		if(mixin){
			dojo.mixin(this, mixin);
		}
	},
	
	get: function(/*String*/name){
		// summary:
		//		Get a property on a Stateful instance.
		//	name:
		//		The property to get.
		// description:
		//		Get a named property on a Stateful object. The property may
		//		potentially be retrieved via a getter method in subclasses. In the base class
		// 		this just retrieves the object's property.
		// 		For example:
		//	|	stateful = new dojo.Stateful({foo: 3});
		//	|	stateful.get("foo") // returns 3
		//	|	stateful.foo // returns 3
		
		return this[name];
	},
	set: function(/*String*/name, /*Object*/value){
		// summary:
		//		Set a property on a Stateful instance
		//	name:
		//		The property to set.
		//	value:
		//		The value to set in the property.
		// description:
		//		Sets named properties on a stateful object and notifies any watchers of
		// 		the property. A programmatic setter may be defined in subclasses.
		// 		For example:
		//	|	stateful = new dojo.Stateful();
		//	|	stateful.watch(function(name, oldValue, value){
		//	|		// this will be called on the set below
		//	|	}
		//	|	stateful.set(foo, 5);
		//
		//	set() may also be called with a hash of name/value pairs, ex:
		//	|	myObj.set({
		//	|		foo: "Howdy",
		//	|		bar: 3
		//	|	})
		//	This is equivalent to calling set(foo, "Howdy") and set(bar, 3)
		if(typeof name === "object"){
			for(var x in name){
				this.set(x, name[x]);
			}
			return this;
		}
		var oldValue = this[name];
		this[name] = value;
		if(this._watchCallbacks){
			this._watchCallbacks(name, oldValue, value);
		}
		return this;
	},
	watch: function(/*String?*/name, /*Function*/callback){
		// summary:
		//		Watches a property for changes
		//	name:
		//		Indicates the property to watch. This is optional (the callback may be the
		// 		only parameter), and if omitted, all the properties will be watched
		// returns:
		//		An object handle for the watch. The unwatch method of this object
		// 		can be used to discontinue watching this property:
		//		|	var watchHandle = obj.watch("foo", callback);
		//		|	watchHandle.unwatch(); // callback won't be called now
		//	callback:
		//		The function to execute when the property changes. This will be called after
		//		the property has been changed. The callback will be called with the |this|
		//		set to the instance, the first argument as the name of the property, the
		// 		second argument as the old value and the third argument as the new value.
		
		var callbacks = this._watchCallbacks;
		if(!callbacks){
			var self = this;
			callbacks = this._watchCallbacks = function(name, oldValue, value, ignoreCatchall){
				var notify = function(propertyCallbacks){
					if(propertyCallbacks){
                        propertyCallbacks = propertyCallbacks.slice();
						for(var i = 0, l = propertyCallbacks.length; i < l; i++){
							try{
								propertyCallbacks[i].call(self, name, oldValue, value);
							}catch(e){
								console.error(e);
							}
						}
					}
				};
				notify(callbacks['_' + name]);
				if(!ignoreCatchall){
					notify(callbacks["*"]); // the catch-all
				}
			}; // we use a function instead of an object so it will be ignored by JSON conversion
		}
		if(!callback && typeof name === "function"){
			callback = name;
			name = "*";
		}else{
			// prepend with dash to prevent name conflicts with function (like "name" property)
			name = '_' + name;
		}
		var propertyCallbacks = callbacks[name];
		if(typeof propertyCallbacks !== "object"){
			propertyCallbacks = callbacks[name] = [];
		}
		propertyCallbacks.push(callback);
		return {
			unwatch: function(){
				propertyCallbacks.splice(dojo.indexOf(propertyCallbacks, callback), 1);
			}
		};
	}
	
});

}

if(!dojo._hasResource["dijit._WidgetBase"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._WidgetBase"] = true;
dojo.provide("dijit._WidgetBase");




(function(){

dojo.declare("dijit._WidgetBase", dojo.Stateful, {
	// summary:
	//		Future base class for all Dijit widgets.
	//		_Widget extends this class adding support for various features needed by desktop.

	// id: [const] String
	//		A unique, opaque ID string that can be assigned by users or by the
	//		system. If the developer passes an ID which is known not to be
	//		unique, the specified ID is ignored and the system-generated ID is
	//		used instead.
	id: "",

	// lang: [const] String
	//		Rarely used.  Overrides the default Dojo locale used to render this widget,
	//		as defined by the [HTML LANG](http://www.w3.org/TR/html401/struct/dirlang.html#adef-lang) attribute.
	//		Value must be among the list of locales specified during by the Dojo bootstrap,
	//		formatted according to [RFC 3066](http://www.ietf.org/rfc/rfc3066.txt) (like en-us).
	lang: "",

	// dir: [const] String
	//		Bi-directional support, as defined by the [HTML DIR](http://www.w3.org/TR/html401/struct/dirlang.html#adef-dir)
	//		attribute. Either left-to-right "ltr" or right-to-left "rtl".  If undefined, widgets renders in page's
	//		default direction.
	dir: "",

	// class: String
	//		HTML class attribute
	"class": "",

	// style: String||Object
	//		HTML style attributes as cssText string or name/value hash
	style: "",

	// title: String
	//		HTML title attribute.
	//
	//		For form widgets this specifies a tooltip to display when hovering over
	//		the widget (just like the native HTML title attribute).
	//
	//		For TitlePane or for when this widget is a child of a TabContainer, AccordionContainer,
	//		etc., it's used to specify the tab label, accordion pane title, etc.
	title: "",

	// tooltip: String
	//		When this widget's title attribute is used to for a tab label, accordion pane title, etc.,
	//		this specifies the tooltip to appear when the mouse is hovered over that text.
	tooltip: "",

	// baseClass: [protected] String
	//		Root CSS class of the widget (ex: dijitTextBox), used to construct CSS classes to indicate
	//		widget state.
	baseClass: "",

	// srcNodeRef: [readonly] DomNode
	//		pointer to original DOM node
	srcNodeRef: null,

	// domNode: [readonly] DomNode
	//		This is our visible representation of the widget! Other DOM
	//		Nodes may by assigned to other properties, usually through the
	//		template system's dojoAttachPoint syntax, but the domNode
	//		property is the canonical "top level" node in widget UI.
	domNode: null,

	// containerNode: [readonly] DomNode
	//		Designates where children of the source DOM node will be placed.
	//		"Children" in this case refers to both DOM nodes and widgets.
	//		For example, for myWidget:
	//
	//		|	<div dojoType=myWidget>
	//		|		<b> here's a plain DOM node
	//		|		<span dojoType=subWidget>and a widget</span>
	//		|		<i> and another plain DOM node </i>
	//		|	</div>
	//
	//		containerNode would point to:
	//
	//		|		<b> here's a plain DOM node
	//		|		<span dojoType=subWidget>and a widget</span>
	//		|		<i> and another plain DOM node </i>
	//
	//		In templated widgets, "containerNode" is set via a
	//		dojoAttachPoint assignment.
	//
	//		containerNode must be defined for any widget that accepts innerHTML
	//		(like ContentPane or BorderContainer or even Button), and conversely
	//		is null for widgets that don't, like TextBox.
	containerNode: null,

/*=====
	// _started: Boolean
	//		startup() has completed.
	_started: false,
=====*/

	// attributeMap: [protected] Object
	//		attributeMap sets up a "binding" between attributes (aka properties)
	//		of the widget and the widget's DOM.
	//		Changes to widget attributes listed in attributeMap will be
	//		reflected into the DOM.
	//
	//		For example, calling set('title', 'hello')
	//		on a TitlePane will automatically cause the TitlePane's DOM to update
	//		with the new title.
	//
	//		attributeMap is a hash where the key is an attribute of the widget,
	//		and the value reflects a binding to a:
	//
	//		- DOM node attribute
	// |		focus: {node: "focusNode", type: "attribute"}
	// 		Maps this.focus to this.focusNode.focus
	//
	//		- DOM node innerHTML
	//	|		title: { node: "titleNode", type: "innerHTML" }
	//		Maps this.title to this.titleNode.innerHTML
	//
	//		- DOM node innerText
	//	|		title: { node: "titleNode", type: "innerText" }
	//		Maps this.title to this.titleNode.innerText
	//
	//		- DOM node CSS class
	// |		myClass: { node: "domNode", type: "class" }
	//		Maps this.myClass to this.domNode.className
	//
	//		If the value is an array, then each element in the array matches one of the
	//		formats of the above list.
	//
	//		There are also some shorthands for backwards compatibility:
	//		- string --> { node: string, type: "attribute" }, for example:
	//	|	"focusNode" ---> { node: "focusNode", type: "attribute" }
	//		- "" --> { node: "domNode", type: "attribute" }
	attributeMap: {id:"", dir:"", lang:"", "class":"", style:"", title:""},

	// _blankGif: [protected] String
	//		Path to a blank 1x1 image.
	//		Used by <img> nodes in templates that really get their image via CSS background-image.
	_blankGif: (dojo.config.blankGif || dojo.moduleUrl("dojo", "resources/blank.gif")).toString(),

	//////////// INITIALIZATION METHODS ///////////////////////////////////////

	postscript: function(/*Object?*/params, /*DomNode|String*/srcNodeRef){
		// summary:
		//		Kicks off widget instantiation.  See create() for details.
		// tags:
		//		private
		this.create(params, srcNodeRef);
	},

	create: function(/*Object?*/params, /*DomNode|String?*/srcNodeRef){
		// summary:
		//		Kick off the life-cycle of a widget
		// params:
		//		Hash of initialization parameters for widget, including
		//		scalar values (like title, duration etc.) and functions,
		//		typically callbacks like onClick.
		// srcNodeRef:
		//		If a srcNodeRef (DOM node) is specified:
		//			- use srcNodeRef.innerHTML as my contents
		//			- if this is a behavioral widget then apply behavior
		//			  to that srcNodeRef
		//			- otherwise, replace srcNodeRef with my generated DOM
		//			  tree
		// description:
		//		Create calls a number of widget methods (postMixInProperties, buildRendering, postCreate,
		//		etc.), some of which of you'll want to override. See http://docs.dojocampus.org/dijit/_Widget
		//		for a discussion of the widget creation lifecycle.
		//
		//		Of course, adventurous developers could override create entirely, but this should
		//		only be done as a last resort.
		// tags:
		//		private

		// store pointer to original DOM tree
		this.srcNodeRef = dojo.byId(srcNodeRef);

		// For garbage collection.  An array of handles returned by Widget.connect()
		// Each handle returned from Widget.connect() is an array of handles from dojo.connect()
		this._connects = [];

		// For garbage collection.  An array of handles returned by Widget.subscribe()
		// The handle returned from Widget.subscribe() is the handle returned from dojo.subscribe()
		this._subscribes = [];

		// mix in our passed parameters
		if(this.srcNodeRef && (typeof this.srcNodeRef.id == "string")){ this.id = this.srcNodeRef.id; }
		if(params){
			this.params = params;
			dojo._mixin(this, params);
		}
		this.postMixInProperties();

		// generate an id for the widget if one wasn't specified
		// (be sure to do this before buildRendering() because that function might
		// expect the id to be there.)
		if(!this.id){
			this.id = dijit.getUniqueId(this.declaredClass.replace(/\./g,"_"));
		}
		dijit.registry.add(this);

		this.buildRendering();

		if(this.domNode){
			// Copy attributes listed in attributeMap into the [newly created] DOM for the widget.
			// Also calls custom setters for all attributes with custom setters.
			this._applyAttributes();

			// If srcNodeRef was specified, then swap out original srcNode for this widget's DOM tree.
			// For 2.0, move this after postCreate().  postCreate() shouldn't depend on the
			// widget being attached to the DOM since it isn't when a widget is created programmatically like
			// new MyWidget({}).   See #11635.
			var source = this.srcNodeRef;
			if(source && source.parentNode && this.domNode !== source){
				source.parentNode.replaceChild(this.domNode, source);
			}
		}

		if(this.domNode){
			// Note: for 2.0 may want to rename widgetId to dojo._scopeName + "_widgetId",
			// assuming that dojo._scopeName even exists in 2.0
			this.domNode.setAttribute("widgetId", this.id);
		}
		this.postCreate();

		// If srcNodeRef has been processed and removed from the DOM (e.g. TemplatedWidget) then delete it to allow GC.
		if(this.srcNodeRef && !this.srcNodeRef.parentNode){
			delete this.srcNodeRef;
		}

		this._created = true;
	},

	_applyAttributes: function(){
		// summary:
		//		Step during widget creation to copy all widget attributes to the
		//		DOM as per attributeMap and _setXXXAttr functions.
		// description:
		//		Skips over blank/false attribute values, unless they were explicitly specified
		//		as parameters to the widget, since those are the default anyway,
		//		and setting tabIndex="" is different than not setting tabIndex at all.
		//
		//		It processes the attributes in the attribute map first, and then
		//		it goes through and processes the attributes for the _setXXXAttr
		//		functions that have been specified
		// tags:
		//		private
		var condAttrApply = function(attr, scope){
			if((scope.params && attr in scope.params) || scope[attr]){
				scope.set(attr, scope[attr]);
			}
		};

		// Do the attributes in attributeMap
		for(var attr in this.attributeMap){
			condAttrApply(attr, this);
		}

		// And also any attributes with custom setters
		dojo.forEach(this._getSetterAttributes(), function(a){
			if(!(a in this.attributeMap)){
				condAttrApply(a, this);
			}
		}, this);
	},

	_getSetterAttributes: function(){
		// summary:
		//		Returns list of attributes with custom setters for this widget
		var ctor = this.constructor;
		if(!ctor._setterAttrs){
			var r = (ctor._setterAttrs = []),
				attrs,
				proto = ctor.prototype;
			for(var fxName in proto){
				if(dojo.isFunction(proto[fxName]) && (attrs = fxName.match(/^_set([a-zA-Z]*)Attr$/)) && attrs[1]){
					r.push(attrs[1].charAt(0).toLowerCase() + attrs[1].substr(1));
				}
			}
		}
		return ctor._setterAttrs;	// String[]
	},

	postMixInProperties: function(){
		// summary:
		//		Called after the parameters to the widget have been read-in,
		//		but before the widget template is instantiated. Especially
		//		useful to set properties that are referenced in the widget
		//		template.
		// tags:
		//		protected
	},

	buildRendering: function(){
		// summary:
		//		Construct the UI for this widget, setting this.domNode
		// description:
		//		Most widgets will mixin `dijit._Templated`, which implements this
		//		method.
		// tags:
		//		protected

		if(!this.domNode){
			// Create root node if it wasn't created by _Templated
			this.domNode = this.srcNodeRef || dojo.create('div');
		}

		// baseClass is a single class name or occasionally a space-separated list of names.
		// Add those classes to the DOMNode.  If RTL mode then also add with Rtl suffix.
		// TODO: make baseClass custom setter
		if(this.baseClass){
			var classes = this.baseClass.split(" ");
			if(!this.isLeftToRight()){
				classes = classes.concat( dojo.map(classes, function(name){ return name+"Rtl"; }));
			}
			dojo.addClass(this.domNode, classes);
		}
	},

	postCreate: function(){
		// summary:
		//		Processing after the DOM fragment is created
		// description:
		//		Called after the DOM fragment has been created, but not necessarily
		//		added to the document.  Do not include any operations which rely on
		//		node dimensions or placement.
		// tags:
		//		protected
	},

	startup: function(){
		// summary:
		//		Processing after the DOM fragment is added to the document
		// description:
		//		Called after a widget and its children have been created and added to the page,
		//		and all related widgets have finished their create() cycle, up through postCreate().
		//		This is useful for composite widgets that need to control or layout sub-widgets.
		//		Many layout widgets can use this as a wiring phase.
		this._started = true;
	},

	//////////// DESTROY FUNCTIONS ////////////////////////////////

	destroyRecursive: function(/*Boolean?*/ preserveDom){
		// summary:
		// 		Destroy this widget and its descendants
		// description:
		//		This is the generic "destructor" function that all widget users
		// 		should call to cleanly discard with a widget. Once a widget is
		// 		destroyed, it is removed from the manager object.
		// preserveDom:
		//		If true, this method will leave the original DOM structure
		//		alone of descendant Widgets. Note: This will NOT work with
		//		dijit._Templated widgets.

		this._beingDestroyed = true;
		this.destroyDescendants(preserveDom);
		this.destroy(preserveDom);
	},

	destroy: function(/*Boolean*/ preserveDom){
		// summary:
		// 		Destroy this widget, but not its descendants.
		//		This method will, however, destroy internal widgets such as those used within a template.
		// preserveDom: Boolean
		//		If true, this method will leave the original DOM structure alone.
		//		Note: This will not yet work with _Templated widgets

		this._beingDestroyed = true;
		this.uninitialize();
		var d = dojo,
			dfe = d.forEach,
			dun = d.unsubscribe;
		dfe(this._connects, function(array){
			dfe(array, d.disconnect);
		});
		dfe(this._subscribes, function(handle){
			dun(handle);
		});

		// destroy widgets created as part of template, etc.
		dfe(this._supportingWidgets || [], function(w){
			if(w.destroyRecursive){
				w.destroyRecursive();
			}else if(w.destroy){
				w.destroy();
			}
		});

		this.destroyRendering(preserveDom);
		dijit.registry.remove(this.id);
		this._destroyed = true;
	},

	destroyRendering: function(/*Boolean?*/ preserveDom){
		// summary:
		//		Destroys the DOM nodes associated with this widget
		// preserveDom:
		//		If true, this method will leave the original DOM structure alone
		//		during tear-down. Note: this will not work with _Templated
		//		widgets yet.
		// tags:
		//		protected

		if(this.bgIframe){
			this.bgIframe.destroy(preserveDom);
			delete this.bgIframe;
		}

		if(this.domNode){
			if(preserveDom){
				dojo.removeAttr(this.domNode, "widgetId");
			}else{
				dojo.destroy(this.domNode);
			}
			delete this.domNode;
		}

		if(this.srcNodeRef){
			if(!preserveDom){
				dojo.destroy(this.srcNodeRef);
			}
			delete this.srcNodeRef;
		}
	},

	destroyDescendants: function(/*Boolean?*/ preserveDom){
		// summary:
		//		Recursively destroy the children of this widget and their
		//		descendants.
		// preserveDom:
		//		If true, the preserveDom attribute is passed to all descendant
		//		widget's .destroy() method. Not for use with _Templated
		//		widgets.

		// get all direct descendants and destroy them recursively
		dojo.forEach(this.getChildren(), function(widget){
			if(widget.destroyRecursive){
				widget.destroyRecursive(preserveDom);
			}
		});
	},

	uninitialize: function(){
		// summary:
		//		Stub function. Override to implement custom widget tear-down
		//		behavior.
		// tags:
		//		protected
		return false;
	},

	////////////////// GET/SET, CUSTOM SETTERS, ETC. ///////////////////

	_setClassAttr: function(/*String*/ value){
		// summary:
		//		Custom setter for the CSS "class" attribute
		// tags:
		//		protected
		var mapNode = this[this.attributeMap["class"] || 'domNode'];
		dojo.replaceClass(mapNode, value, this["class"]);
		this._set("class", value);
	},

	_setStyleAttr: function(/*String||Object*/ value){
		// summary:
		//		Sets the style attribute of the widget according to value,
		//		which is either a hash like {height: "5px", width: "3px"}
		//		or a plain string
		// description:
		//		Determines which node to set the style on based on style setting
		//		in attributeMap.
		// tags:
		//		protected

		var mapNode = this[this.attributeMap.style || 'domNode'];

		// Note: technically we should revert any style setting made in a previous call
		// to his method, but that's difficult to keep track of.

		if(dojo.isObject(value)){
			dojo.style(mapNode, value);
		}else{
			if(mapNode.style.cssText){
				mapNode.style.cssText += "; " + value;
			}else{
				mapNode.style.cssText = value;
			}
		}

		this._set("style", value);
	},

	_attrToDom: function(/*String*/ attr, /*String*/ value){
		// summary:
		//		Reflect a widget attribute (title, tabIndex, duration etc.) to
		//		the widget DOM, as specified in attributeMap.
		//		Note some attributes like "type"
		//		cannot be processed this way as they are not mutable.
		//
		// tags:
		//		private

		var commands = this.attributeMap[attr];
		dojo.forEach(dojo.isArray(commands) ? commands : [commands], function(command){

			// Get target node and what we are doing to that node
			var mapNode = this[command.node || command || "domNode"];	// DOM node
			var type = command.type || "attribute";	// class, innerHTML, innerText, or attribute

			switch(type){
				case "attribute":
					if(dojo.isFunction(value)){ // functions execute in the context of the widget
						value = dojo.hitch(this, value);
					}

					// Get the name of the DOM node attribute; usually it's the same
					// as the name of the attribute in the widget (attr), but can be overridden.
					// Also maps handler names to lowercase, like onSubmit --> onsubmit
					var attrName = command.attribute ? command.attribute :
						(/^on[A-Z][a-zA-Z]*$/.test(attr) ? attr.toLowerCase() : attr);

					dojo.attr(mapNode, attrName, value);
					break;
				case "innerText":
					mapNode.innerHTML = "";
					mapNode.appendChild(dojo.doc.createTextNode(value));
					break;
				case "innerHTML":
					mapNode.innerHTML = value;
					break;
				case "class":
					dojo.replaceClass(mapNode, value, this[attr]);
					break;
			}
		}, this);
	},

	get: function(name){
		// summary:
		//		Get a property from a widget.
		//	name:
		//		The property to get.
		// description:
		//		Get a named property from a widget. The property may
		//		potentially be retrieved via a getter method. If no getter is defined, this
		// 		just retrieves the object's property.
		// 		For example, if the widget has a properties "foo"
		//		and "bar" and a method named "_getFooAttr", calling:
		//	|	myWidget.get("foo");
		//		would be equivalent to writing:
		//	|	widget._getFooAttr();
		//		and:
		//	|	myWidget.get("bar");
		//		would be equivalent to writing:
		//	|	widget.bar;
		var names = this._getAttrNames(name);
		return this[names.g] ? this[names.g]() : this[name];
	},
	
	set: function(name, value){
		// summary:
		//		Set a property on a widget
		//	name:
		//		The property to set.
		//	value:
		//		The value to set in the property.
		// description:
		//		Sets named properties on a widget which may potentially be handled by a
		// 		setter in the widget.
		// 		For example, if the widget has a properties "foo"
		//		and "bar" and a method named "_setFooAttr", calling:
		//	|	myWidget.set("foo", "Howdy!");
		//		would be equivalent to writing:
		//	|	widget._setFooAttr("Howdy!");
		//		and:
		//	|	myWidget.set("bar", 3);
		//		would be equivalent to writing:
		//	|	widget.bar = 3;
		//
		//	set() may also be called with a hash of name/value pairs, ex:
		//	|	myWidget.set({
		//	|		foo: "Howdy",
		//	|		bar: 3
		//	|	})
		//	This is equivalent to calling set(foo, "Howdy") and set(bar, 3)

		if(typeof name === "object"){
			for(var x in name){
				this.set(x, name[x]);
			}
			return this;
		}
		var names = this._getAttrNames(name);
		if(this[names.s]){
			// use the explicit setter
			var result = this[names.s].apply(this, Array.prototype.slice.call(arguments, 1));
		}else{
			// if param is specified as DOM node attribute, copy it
			if(name in this.attributeMap){
				this._attrToDom(name, value);
			}
			this._set(name, value);
		}
		return result || this;
	},
	
	_attrPairNames: {},		// shared between all widgets
	_getAttrNames: function(name){
		// summary:
		//		Helper function for get() and set().
		//		Caches attribute name values so we don't do the string ops every time.
		// tags:
		//		private

		var apn = this._attrPairNames;
		if(apn[name]){ return apn[name]; }
		var uc = name.charAt(0).toUpperCase() + name.substr(1);
		return (apn[name] = {
			n: name+"Node",
			s: "_set"+uc+"Attr",
			g: "_get"+uc+"Attr"
		});
	},

	_set: function(/*String*/ name, /*anything*/ value){
		// summary:
		//		Helper function to set new value for specified attribute, and call handlers
		//		registered with watch() if the value has changed.
		var oldValue = this[name];
		this[name] = value;
		if(this._watchCallbacks && this._created && value !== oldValue){
			this._watchCallbacks(name, oldValue, value);
		}
	},

	toString: function(){
		// summary:
		//		Returns a string that represents the widget
		// description:
		//		When a widget is cast to a string, this method will be used to generate the
		//		output. Currently, it does not implement any sort of reversible
		//		serialization.
		return '[Widget ' + this.declaredClass + ', ' + (this.id || 'NO ID') + ']'; // String
	},

	getDescendants: function(){
		// summary:
		//		Returns all the widgets contained by this, i.e., all widgets underneath this.containerNode.
		//		This method should generally be avoided as it returns widgets declared in templates, which are
		//		supposed to be internal/hidden, but it's left here for back-compat reasons.

		return this.containerNode ? dojo.query('[widgetId]', this.containerNode).map(dijit.byNode) : []; // dijit._Widget[]
	},

	getChildren: function(){
		// summary:
		//		Returns all the widgets contained by this, i.e., all widgets underneath this.containerNode.
		//		Does not return nested widgets, nor widgets that are part of this widget's template.
		return this.containerNode ? dijit.findWidgets(this.containerNode) : []; // dijit._Widget[]
	},

	connect: function(
			/*Object|null*/ obj,
			/*String|Function*/ event,
			/*String|Function*/ method){
		// summary:
		//		Connects specified obj/event to specified method of this object
		//		and registers for disconnect() on widget destroy.
		// description:
		//		Provide widget-specific analog to dojo.connect, except with the
		//		implicit use of this widget as the target object.
		//		Events connected with `this.connect` are disconnected upon
		//		destruction.
		// returns:
		//		A handle that can be passed to `disconnect` in order to disconnect before
		//		the widget is destroyed.
		// example:
		//	|	var btn = new dijit.form.Button();
		//	|	// when foo.bar() is called, call the listener we're going to
		//	|	// provide in the scope of btn
		//	|	btn.connect(foo, "bar", function(){
		//	|		console.debug(this.toString());
		//	|	});
		// tags:
		//		protected

		var handles = [dojo._connect(obj, event, this, method)];
		this._connects.push(handles);
		return handles;		// _Widget.Handle
	},

	disconnect: function(/* _Widget.Handle */ handles){
		// summary:
		//		Disconnects handle created by `connect`.
		//		Also removes handle from this widget's list of connects.
		// tags:
		//		protected
		for(var i=0; i<this._connects.length; i++){
			if(this._connects[i] == handles){
				dojo.forEach(handles, dojo.disconnect);
				this._connects.splice(i, 1);
				return;
			}
		}
	},

	subscribe: function(
			/*String*/ topic,
			/*String|Function*/ method){
		// summary:
		//		Subscribes to the specified topic and calls the specified method
		//		of this object and registers for unsubscribe() on widget destroy.
		// description:
		//		Provide widget-specific analog to dojo.subscribe, except with the
		//		implicit use of this widget as the target object.
		// example:
		//	|	var btn = new dijit.form.Button();
		//	|	// when /my/topic is published, this button changes its label to
		//	|   // be the parameter of the topic.
		//	|	btn.subscribe("/my/topic", function(v){
		//	|		this.set("label", v);
		//	|	});
		var handle = dojo.subscribe(topic, this, method);

		// return handles for Any widget that may need them
		this._subscribes.push(handle);
		return handle;
	},

	unsubscribe: function(/*Object*/ handle){
		// summary:
		//		Unsubscribes handle created by this.subscribe.
		//		Also removes handle from this widget's list of subscriptions
		for(var i=0; i<this._subscribes.length; i++){
			if(this._subscribes[i] == handle){
				dojo.unsubscribe(handle);
				this._subscribes.splice(i, 1);
				return;
			}
		}
	},

	isLeftToRight: function(){
		// summary:
		//		Return this widget's explicit or implicit orientation (true for LTR, false for RTL)
		// tags:
		//		protected
		return this.dir ? (this.dir == "ltr") : dojo._isBodyLtr(); //Boolean
	},

	placeAt: function(/* String|DomNode|_Widget */reference, /* String?|Int? */position){
		// summary:
		//		Place this widget's domNode reference somewhere in the DOM based
		//		on standard dojo.place conventions, or passing a Widget reference that
		//		contains and addChild member.
		//
		// description:
		//		A convenience function provided in all _Widgets, providing a simple
		//		shorthand mechanism to put an existing (or newly created) Widget
		//		somewhere in the dom, and allow chaining.
		//
		// reference:
		//		The String id of a domNode, a domNode reference, or a reference to a Widget posessing
		//		an addChild method.
		//
		// position:
		//		If passed a string or domNode reference, the position argument
		//		accepts a string just as dojo.place does, one of: "first", "last",
		//		"before", or "after".
		//
		//		If passed a _Widget reference, and that widget reference has an ".addChild" method,
		//		it will be called passing this widget instance into that method, supplying the optional
		//		position index passed.
		//
		// returns:
		//		dijit._Widget
		//		Provides a useful return of the newly created dijit._Widget instance so you
		//		can "chain" this function by instantiating, placing, then saving the return value
		//		to a variable.
		//
		// example:
		// | 	// create a Button with no srcNodeRef, and place it in the body:
		// | 	var button = new dijit.form.Button({ label:"click" }).placeAt(dojo.body());
		// | 	// now, 'button' is still the widget reference to the newly created button
		// | 	dojo.connect(button, "onClick", function(e){ console.log('click'); });
		//
		// example:
		// |	// create a button out of a node with id="src" and append it to id="wrapper":
		// | 	var button = new dijit.form.Button({},"src").placeAt("wrapper");
		//
		// example:
		// |	// place a new button as the first element of some div
		// |	var button = new dijit.form.Button({ label:"click" }).placeAt("wrapper","first");
		//
		// example:
		// |	// create a contentpane and add it to a TabContainer
		// |	var tc = dijit.byId("myTabs");
		// |	new dijit.layout.ContentPane({ href:"foo.html", title:"Wow!" }).placeAt(tc)

		if(reference.declaredClass && reference.addChild){
			reference.addChild(this, position);
		}else{
			dojo.place(this.domNode, reference, position);
		}
		return this;
	}
});

})();

}

if(!dojo._hasResource["dijit._Widget"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._Widget"] = true;
dojo.provide("dijit._Widget");





////////////////// DEFERRED CONNECTS ///////////////////

// This code is to assist deferring dojo.connect() calls in widgets (connecting to events on the widgets'
// DOM nodes) until someone actually needs to monitor that event.
dojo.connect(dojo, "_connect",
	function(/*dijit._Widget*/ widget, /*String*/ event){
		if(widget && dojo.isFunction(widget._onConnect)){
			widget._onConnect(event);
		}
	});

dijit._connectOnUseEventHandler = function(/*Event*/ event){};

////////////////// ONDIJITCLICK SUPPORT ///////////////////

// Keep track of where the last keydown event was, to help avoid generating
// spurious ondijitclick events when:
// 1. focus is on a <button> or <a>
// 2. user presses then releases the ENTER key
// 3. onclick handler fires and shifts focus to another node, with an ondijitclick handler
// 4. onkeyup event fires, causing the ondijitclick handler to fire
dijit._lastKeyDownNode = null;
if(dojo.isIE){
	(function(){
		var keydownCallback = function(evt){
			dijit._lastKeyDownNode = evt.srcElement;
		};
		dojo.doc.attachEvent('onkeydown', keydownCallback);
		dojo.addOnWindowUnload(function(){
			dojo.doc.detachEvent('onkeydown', keydownCallback);
		});
	})();
}else{
	dojo.doc.addEventListener('keydown', function(evt){
		dijit._lastKeyDownNode = evt.target;
	}, true);
}

(function(){

dojo.declare("dijit._Widget", dijit._WidgetBase, {
	// summary:
	//		Base class for all Dijit widgets.
	//
	//		Extends _WidgetBase, adding support for:
	//			- deferred connections
	//				A call like dojo.connect(myWidget, "onMouseMove", func)
	//				will essentially do a dojo.connect(myWidget.domNode, "onMouseMove", func)
	//			- ondijitclick
	//				Support new dojoAttachEvent="ondijitclick: ..." that is triggered by a mouse click or a SPACE/ENTER keypress
	//			- focus related functions
	//				In particular, the onFocus()/onBlur() callbacks.   Driven internally by
	//				dijit/_base/focus.js.
	//			- deprecated methods
	//			- onShow(), onHide(), onClose()
	//
	//		Also, by loading code in dijit/_base, turns on:
	//			- browser sniffing (putting browser id like .dj_ie on <html> node)
	//			- high contrast mode sniffing (add .dijit_a11y class to <body> if machine is in high contrast mode)
	

	////////////////// DEFERRED CONNECTS ///////////////////

	// _deferredConnects: [protected] Object
	//		attributeMap addendum for event handlers that should be connected only on first use
	_deferredConnects: {
		onClick: "",
		onDblClick: "",
		onKeyDown: "",
		onKeyPress: "",
		onKeyUp: "",
		onMouseMove: "",
		onMouseDown: "",
		onMouseOut: "",
		onMouseOver: "",
		onMouseLeave: "",
		onMouseEnter: "",
		onMouseUp: ""
	},

	onClick: dijit._connectOnUseEventHandler,
	/*=====
	onClick: function(event){
		// summary:
		//		Connect to this function to receive notifications of mouse click events.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onDblClick: dijit._connectOnUseEventHandler,
	/*=====
	onDblClick: function(event){
		// summary:
		//		Connect to this function to receive notifications of mouse double click events.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onKeyDown: dijit._connectOnUseEventHandler,
	/*=====
	onKeyDown: function(event){
		// summary:
		//		Connect to this function to receive notifications of keys being pressed down.
		// event:
		//		key Event
		// tags:
		//		callback
	},
	=====*/
	onKeyPress: dijit._connectOnUseEventHandler,
	/*=====
	onKeyPress: function(event){
		// summary:
		//		Connect to this function to receive notifications of printable keys being typed.
		// event:
		//		key Event
		// tags:
		//		callback
	},
	=====*/
	onKeyUp: dijit._connectOnUseEventHandler,
	/*=====
	onKeyUp: function(event){
		// summary:
		//		Connect to this function to receive notifications of keys being released.
		// event:
		//		key Event
		// tags:
		//		callback
	},
	=====*/
	onMouseDown: dijit._connectOnUseEventHandler,
	/*=====
	onMouseDown: function(event){
		// summary:
		//		Connect to this function to receive notifications of when the mouse button is pressed down.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onMouseMove: dijit._connectOnUseEventHandler,
	/*=====
	onMouseMove: function(event){
		// summary:
		//		Connect to this function to receive notifications of when the mouse moves over nodes contained within this widget.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onMouseOut: dijit._connectOnUseEventHandler,
	/*=====
	onMouseOut: function(event){
		// summary:
		//		Connect to this function to receive notifications of when the mouse moves off of nodes contained within this widget.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onMouseOver: dijit._connectOnUseEventHandler,
	/*=====
	onMouseOver: function(event){
		// summary:
		//		Connect to this function to receive notifications of when the mouse moves onto nodes contained within this widget.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onMouseLeave: dijit._connectOnUseEventHandler,
	/*=====
	onMouseLeave: function(event){
		// summary:
		//		Connect to this function to receive notifications of when the mouse moves off of this widget.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onMouseEnter: dijit._connectOnUseEventHandler,
	/*=====
	onMouseEnter: function(event){
		// summary:
		//		Connect to this function to receive notifications of when the mouse moves onto this widget.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onMouseUp: dijit._connectOnUseEventHandler,
	/*=====
	onMouseUp: function(event){
		// summary:
		//		Connect to this function to receive notifications of when the mouse button is released.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/

	create: function(/*Object?*/params, /*DomNode|String?*/srcNodeRef){
		// To avoid double-connects, remove entries from _deferredConnects
		// that have been setup manually by a subclass (ex, by dojoAttachEvent).
		// If a subclass has redefined a callback (ex: onClick) then assume it's being
		// connected to manually.
		this._deferredConnects = dojo.clone(this._deferredConnects);
		for(var attr in this.attributeMap){
			delete this._deferredConnects[attr]; // can't be in both attributeMap and _deferredConnects
		}
		for(attr in this._deferredConnects){
			if(this[attr] !== dijit._connectOnUseEventHandler){
				delete this._deferredConnects[attr];	// redefined, probably dojoAttachEvent exists
			}
		}

		this.inherited(arguments);

		if(this.domNode){
			// If the developer has specified a handler as a widget parameter
			// (ex: new Button({onClick: ...})
			// then naturally need to connect from DOM node to that handler immediately,
			for(attr in this.params){
				this._onConnect(attr);
			}
		}
	},

	_onConnect: function(/*String*/ event){
		// summary:
		//		Called when someone connects to one of my handlers.
		//		"Turn on" that handler if it isn't active yet.
		//
		//		This is also called for every single initialization parameter
		//		so need to do nothing for parameters like "id".
		// tags:
		//		private
		if(event in this._deferredConnects){
			var mapNode = this[this._deferredConnects[event] || 'domNode'];
			this.connect(mapNode, event.toLowerCase(), event);
			delete this._deferredConnects[event];
		}
	},

	////////////////// FOCUS RELATED ///////////////////
	// _onFocus() and _onBlur() are called by the focus manager

	// focused: [readonly] Boolean
	//		This widget or a widget it contains has focus, or is "active" because
	//		it was recently clicked.
	focused: false,

	isFocusable: function(){
		// summary:
		//		Return true if this widget can currently be focused
		//		and false if not
		return this.focus && (dojo.style(this.domNode, "display") != "none");
	},

	onFocus: function(){
		// summary:
		//		Called when the widget becomes "active" because
		//		it or a widget inside of it either has focus, or has recently
		//		been clicked.
		// tags:
		//		callback
	},

	onBlur: function(){
		// summary:
		//		Called when the widget stops being "active" because
		//		focus moved to something outside of it, or the user
		//		clicked somewhere outside of it, or the widget was
		//		hidden.
		// tags:
		//		callback
	},

	_onFocus: function(e){
		// summary:
		//		This is where widgets do processing for when they are active,
		//		such as changing CSS classes.  See onFocus() for more details.
		// tags:
		//		protected
		this.onFocus();
	},

	_onBlur: function(){
		// summary:
		//		This is where widgets do processing for when they stop being active,
		//		such as changing CSS classes.  See onBlur() for more details.
		// tags:
		//		protected
		this.onBlur();
	},

	////////////////// DEPRECATED METHODS ///////////////////

	setAttribute: function(/*String*/ attr, /*anything*/ value){
		// summary:
		//		Deprecated.  Use set() instead.
		// tags:
		//		deprecated
		dojo.deprecated(this.declaredClass+"::setAttribute(attr, value) is deprecated. Use set() instead.", "", "2.0");
		this.set(attr, value);
	},

	attr: function(/*String|Object*/name, /*Object?*/value){
		// summary:
		//		Set or get properties on a widget instance.
		//	name:
		//		The property to get or set. If an object is passed here and not
		//		a string, its keys are used as names of attributes to be set
		//		and the value of the object as values to set in the widget.
		//	value:
		//		Optional. If provided, attr() operates as a setter. If omitted,
		//		the current value of the named property is returned.
		// description:
		//		This method is deprecated, use get() or set() directly.

		// Print deprecation warning but only once per calling function
		if(dojo.config.isDebug){
			var alreadyCalledHash = arguments.callee._ach || (arguments.callee._ach = {}),
				caller = (arguments.callee.caller || "unknown caller").toString();
			if(!alreadyCalledHash[caller]){
				dojo.deprecated(this.declaredClass + "::attr() is deprecated. Use get() or set() instead, called from " +
				caller, "", "2.0");
				alreadyCalledHash[caller] = true;
			}
		}

		var args = arguments.length;
		if(args >= 2 || typeof name === "object"){ // setter
			return this.set.apply(this, arguments);
		}else{ // getter
			return this.get(name);
		}
	},
	
	////////////////// ONDIJITCLICK SUPPORT ///////////////////

	// nodesWithKeyClick: [private] String[]
	//		List of nodes that correctly handle click events via native browser support,
	//		and don't need dijit's help
	nodesWithKeyClick: ["input", "button"],

	connect: function(
			/*Object|null*/ obj,
			/*String|Function*/ event,
			/*String|Function*/ method){
		// summary:
		//		Connects specified obj/event to specified method of this object
		//		and registers for disconnect() on widget destroy.
		// description:
		//		Provide widget-specific analog to dojo.connect, except with the
		//		implicit use of this widget as the target object.
		//		This version of connect also provides a special "ondijitclick"
		//		event which triggers on a click or space or enter keyup.
		//		Events connected with `this.connect` are disconnected upon
		//		destruction.
		// returns:
		//		A handle that can be passed to `disconnect` in order to disconnect before
		//		the widget is destroyed.
		// example:
		//	|	var btn = new dijit.form.Button();
		//	|	// when foo.bar() is called, call the listener we're going to
		//	|	// provide in the scope of btn
		//	|	btn.connect(foo, "bar", function(){
		//	|		console.debug(this.toString());
		//	|	});
		// tags:
		//		protected

		var d = dojo,
			dc = d._connect,
			handles = this.inherited(arguments, [obj, event == "ondijitclick" ? "onclick" : event, method]);

		if(event == "ondijitclick"){
			// add key based click activation for unsupported nodes.
			// do all processing onkey up to prevent spurious clicks
			// for details see comments at top of this file where _lastKeyDownNode is defined
			if(d.indexOf(this.nodesWithKeyClick, obj.nodeName.toLowerCase()) == -1){ // is NOT input or button
				var m = d.hitch(this, method);
				handles.push(
					dc(obj, "onkeydown", this, function(e){
						//console.log(this.id + ": onkeydown, e.target = ", e.target, ", lastKeyDownNode was ", dijit._lastKeyDownNode, ", equality is ", (e.target === dijit._lastKeyDownNode));
						if((e.keyCode == d.keys.ENTER || e.keyCode == d.keys.SPACE) &&
							!e.ctrlKey && !e.shiftKey && !e.altKey && !e.metaKey){
							// needed on IE for when focus changes between keydown and keyup - otherwise dropdown menus do not work
							dijit._lastKeyDownNode = e.target;
							
							// Stop event to prevent scrolling on space key in IE.
							// But don't do this for _HasDropDown because it surpresses the onkeypress
							// event needed to open the drop down when the user presses the SPACE key.
							if(!("openDropDown" in this && obj == this._buttonNode)){
								e.preventDefault();
							}
						}
			 		}),
					dc(obj, "onkeyup", this, function(e){
						//console.log(this.id + ": onkeyup, e.target = ", e.target, ", lastKeyDownNode was ", dijit._lastKeyDownNode, ", equality is ", (e.target === dijit._lastKeyDownNode));
						if( (e.keyCode == d.keys.ENTER || e.keyCode == d.keys.SPACE) &&
							e.target == dijit._lastKeyDownNode &&	// === breaks greasemonkey
							!e.ctrlKey && !e.shiftKey && !e.altKey && !e.metaKey){
								//need reset here or have problems in FF when focus returns to trigger element after closing popup/alert
								dijit._lastKeyDownNode = null;
								return m(e);
						}
					})
				);
			}
		}

		return handles;		// _Widget.Handle
	},

	////////////////// MISCELLANEOUS METHODS ///////////////////

	_onShow: function(){
		// summary:
		//		Internal method called when this widget is made visible.
		//		See `onShow` for details.
		this.onShow();
	},

	onShow: function(){
		// summary:
		//		Called when this widget becomes the selected pane in a
		//		`dijit.layout.TabContainer`, `dijit.layout.StackContainer`,
		//		`dijit.layout.AccordionContainer`, etc.
		//
		//		Also called to indicate display of a `dijit.Dialog`, `dijit.TooltipDialog`, or `dijit.TitlePane`.
		// tags:
		//		callback
	},

	onHide: function(){
		// summary:
			//		Called when another widget becomes the selected pane in a
			//		`dijit.layout.TabContainer`, `dijit.layout.StackContainer`,
			//		`dijit.layout.AccordionContainer`, etc.
			//
			//		Also called to indicate hide of a `dijit.Dialog`, `dijit.TooltipDialog`, or `dijit.TitlePane`.
			// tags:
			//		callback
	},

	onClose: function(){
		// summary:
		//		Called when this widget is being displayed as a popup (ex: a Calendar popped
		//		up from a DateTextBox), and it is hidden.
		//		This is called from the dijit.popup code, and should not be called directly.
		//
		//		Also used as a parameter for children of `dijit.layout.StackContainer` or subclasses.
		//		Callback if a user tries to close the child.   Child will be closed if this function returns true.
		// tags:
		//		extension

		return true;		// Boolean
	}
});

})();

}

if(!dojo._hasResource["dojo.cache"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.cache"] = true;
dojo.provide("dojo.cache");


/*=====
dojo.cache = {
	// summary:
	// 		A way to cache string content that is fetchable via `dojo.moduleUrl`.
};
=====*/

	var cache = {};
	dojo.cache = function(/*String||Object*/module, /*String*/url, /*String||Object?*/value){
		// summary:
		// 		A getter and setter for storing the string content associated with the
		// 		module and url arguments.
		// description:
		// 		module and url are used to call `dojo.moduleUrl()` to generate a module URL.
		// 		If value is specified, the cache value for the moduleUrl will be set to
		// 		that value. Otherwise, dojo.cache will fetch the moduleUrl and store it
		// 		in its internal cache and return that cached value for the URL. To clear
		// 		a cache value pass null for value. Since XMLHttpRequest (XHR) is used to fetch the
		// 		the URL contents, only modules on the same domain of the page can use this capability.
		// 		The build system can inline the cache values though, to allow for xdomain hosting.
		// module: String||Object
		// 		If a String, the module name to use for the base part of the URL, similar to module argument
		// 		to `dojo.moduleUrl`. If an Object, something that has a .toString() method that
		// 		generates a valid path for the cache item. For example, a dojo._Url object.
		// url: String
		// 		The rest of the path to append to the path derived from the module argument. If
		// 		module is an object, then this second argument should be the "value" argument instead.
		// value: String||Object?
		// 		If a String, the value to use in the cache for the module/url combination.
		// 		If an Object, it can have two properties: value and sanitize. The value property
		// 		should be the value to use in the cache, and sanitize can be set to true or false,
		// 		to indicate if XML declarations should be removed from the value and if the HTML
		// 		inside a body tag in the value should be extracted as the real value. The value argument
		// 		or the value property on the value argument are usually only used by the build system
		// 		as it inlines cache content.
		//	example:
		//		To ask dojo.cache to fetch content and store it in the cache (the dojo["cache"] style
		// 		of call is used to avoid an issue with the build system erroneously trying to intern
		// 		this example. To get the build system to intern your dojo.cache calls, use the
		// 		"dojo.cache" style of call):
		// 		|	//If template.html contains "<h1>Hello</h1>" that will be
		// 		|	//the value for the text variable.
		//		|	var text = dojo["cache"]("my.module", "template.html");
		//	example:
		//		To ask dojo.cache to fetch content and store it in the cache, and sanitize the input
		// 		 (the dojo["cache"] style of call is used to avoid an issue with the build system
		// 		erroneously trying to intern this example. To get the build system to intern your
		// 		dojo.cache calls, use the "dojo.cache" style of call):
		// 		|	//If template.html contains "<html><body><h1>Hello</h1></body></html>", the
		// 		|	//text variable will contain just "<h1>Hello</h1>".
		//		|	var text = dojo["cache"]("my.module", "template.html", {sanitize: true});
		//	example:
		//		Same example as previous, but demostrates how an object can be passed in as
		//		the first argument, then the value argument can then be the second argument.
		// 		|	//If template.html contains "<html><body><h1>Hello</h1></body></html>", the
		// 		|	//text variable will contain just "<h1>Hello</h1>".
		//		|	var text = dojo["cache"](new dojo._Url("my/module/template.html"), {sanitize: true});

		//Module could be a string, or an object that has a toString() method
		//that will return a useful path. If it is an object, then the "url" argument
		//will actually be the value argument.
		if(typeof module == "string"){
			var pathObj = dojo.moduleUrl(module, url);
		}else{
			pathObj = module;
			value = url;
		}
		var key = pathObj.toString();

		var val = value;
		if(value != undefined && !dojo.isString(value)){
			val = ("value" in value ? value.value : undefined);
		}

		var sanitize = value && value.sanitize ? true : false;

		if(typeof val == "string"){
			//We have a string, set cache value
			val = cache[key] = sanitize ? dojo.cache._sanitize(val) : val;
		}else if(val === null){
			//Remove cached value
			delete cache[key];
		}else{
			//Allow cache values to be empty strings. If key property does
			//not exist, fetch it.
			if(!(key in cache)){
				val = dojo._getText(key);
				cache[key] = sanitize ? dojo.cache._sanitize(val) : val;
			}
			val = cache[key];
		}
		return val; //String
	};

	dojo.cache._sanitize = function(/*String*/val){
		// summary:
		//		Strips <?xml ...?> declarations so that external SVG and XML
		// 		documents can be added to a document without worry. Also, if the string
		//		is an HTML document, only the part inside the body tag is returned.
		// description:
		// 		Copied from dijit._Templated._sanitizeTemplateString.
		if(val){
			val = val.replace(/^\s*<\?xml(\s)+version=[\'\"](\d)*.(\d)*[\'\"](\s)*\?>/im, "");
			var matches = val.match(/<body[^>]*>\s*([\s\S]+)\s*<\/body>/im);
			if(matches){
				val = matches[1];
			}
		}else{
			val = "";
		}
		return val; //String
	};

}

if(!dojo._hasResource["dijit._Templated"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._Templated"] = true;
dojo.provide("dijit._Templated");






dojo.declare("dijit._Templated",
	null,
	{
		// summary:
		//		Mixin for widgets that are instantiated from a template

		// templateString: [protected] String
		//		A string that represents the widget template. Pre-empts the
		//		templatePath. In builds that have their strings "interned", the
		//		templatePath is converted to an inline templateString, thereby
		//		preventing a synchronous network call.
		//
		//		Use in conjunction with dojo.cache() to load from a file.
		templateString: null,

		// templatePath: [protected deprecated] String
		//		Path to template (HTML file) for this widget relative to dojo.baseUrl.
		//		Deprecated: use templateString with dojo.cache() instead.
		templatePath: null,

		// widgetsInTemplate: [protected] Boolean
		//		Should we parse the template to find widgets that might be
		//		declared in markup inside it?  False by default.
		widgetsInTemplate: false,

		// skipNodeCache: [protected] Boolean
		//		If using a cached widget template node poses issues for a
		//		particular widget class, it can set this property to ensure
		//		that its template is always re-built from a string
		_skipNodeCache: false,

		// _earlyTemplatedStartup: Boolean
		//		A fallback to preserve the 1.0 - 1.3 behavior of children in
		//		templates having their startup called before the parent widget
		//		fires postCreate. Defaults to 'false', causing child widgets to
		//		have their .startup() called immediately before a parent widget
		//		.startup(), but always after the parent .postCreate(). Set to
		//		'true' to re-enable to previous, arguably broken, behavior.
		_earlyTemplatedStartup: false,

/*=====
		// _attachPoints: [private] String[]
		//		List of widget attribute names associated with dojoAttachPoint=... in the
		//		template, ex: ["containerNode", "labelNode"]
 		_attachPoints: [],
 =====*/

/*=====
		// _attachEvents: [private] Handle[]
		//		List of connections associated with dojoAttachEvent=... in the
		//		template
 		_attachEvents: [],
 =====*/

		constructor: function(){
			this._attachPoints = [];
			this._attachEvents = [];
		},

		_stringRepl: function(tmpl){
			// summary:
			//		Does substitution of ${foo} type properties in template string
			// tags:
			//		private
			var className = this.declaredClass, _this = this;
			// Cache contains a string because we need to do property replacement
			// do the property replacement
			return dojo.string.substitute(tmpl, this, function(value, key){
				if(key.charAt(0) == '!'){ value = dojo.getObject(key.substr(1), false, _this); }
				if(typeof value == "undefined"){ throw new Error(className+" template:"+key); } // a debugging aide
				if(value == null){ return ""; }

				// Substitution keys beginning with ! will skip the transform step,
				// in case a user wishes to insert unescaped markup, e.g. ${!foo}
				return key.charAt(0) == "!" ? value :
					// Safer substitution, see heading "Attribute values" in
					// http://www.w3.org/TR/REC-html40/appendix/notes.html#h-B.3.2
					value.toString().replace(/"/g,"&quot;"); //TODO: add &amp? use encodeXML method?
			}, this);
		},

		buildRendering: function(){
			// summary:
			//		Construct the UI for this widget from a template, setting this.domNode.
			// tags:
			//		protected

			// Lookup cached version of template, and download to cache if it
			// isn't there already.  Returns either a DomNode or a string, depending on
			// whether or not the template contains ${foo} replacement parameters.
			var cached = dijit._Templated.getCachedTemplate(this.templatePath, this.templateString, this._skipNodeCache);

			var node;
			if(dojo.isString(cached)){
				node = dojo._toDom(this._stringRepl(cached));
				if(node.nodeType != 1){
					// Flag common problems such as templates with multiple top level nodes (nodeType == 11)
					throw new Error("Invalid template: " + cached);
				}
			}else{
				// if it's a node, all we have to do is clone it
				node = cached.cloneNode(true);
			}

			this.domNode = node;

			// Call down to _Widget.buildRendering() to get base classes assigned
			// TODO: change the baseClass assignment to attributeMap
			this.inherited(arguments);

			// recurse through the node, looking for, and attaching to, our
			// attachment points and events, which should be defined on the template node.
			this._attachTemplateNodes(node);

			if(this.widgetsInTemplate){
				// Store widgets that we need to start at a later point in time
				var cw = (this._startupWidgets = dojo.parser.parse(node, {
					noStart: !this._earlyTemplatedStartup,
					template: true,
					inherited: {dir: this.dir, lang: this.lang},
					propsThis: this,	// so data-dojo-props of widgets in the template can reference "this" to refer to me
					scope: "dojo"	// even in multi-version mode templates use dojoType/data-dojo-type
				}));

				this._supportingWidgets = dijit.findWidgets(node);

				this._attachTemplateNodes(cw, function(n,p){
					return n[p];
				});
			}

			this._fillContent(this.srcNodeRef);
		},

		_fillContent: function(/*DomNode*/ source){
			// summary:
			//		Relocate source contents to templated container node.
			//		this.containerNode must be able to receive children, or exceptions will be thrown.
			// tags:
			//		protected
			var dest = this.containerNode;
			if(source && dest){
				while(source.hasChildNodes()){
					dest.appendChild(source.firstChild);
				}
			}
		},

		_attachTemplateNodes: function(rootNode, getAttrFunc){
			// summary:
			//		Iterate through the template and attach functions and nodes accordingly.
			//		Alternately, if rootNode is an array of widgets, then will process dojoAttachPoint
			//		etc. for those widgets.
			// description:
			//		Map widget properties and functions to the handlers specified in
			//		the dom node and it's descendants. This function iterates over all
			//		nodes and looks for these properties:
			//			* dojoAttachPoint
			//			* dojoAttachEvent
			//			* waiRole
			//			* waiState
			// rootNode: DomNode|Array[Widgets]
			//		the node to search for properties. All children will be searched.
			// getAttrFunc: Function?
			//		a function which will be used to obtain property for a given
			//		DomNode/Widget
			// tags:
			//		private

			getAttrFunc = getAttrFunc || function(n,p){ return n.getAttribute(p); };

			var nodes = dojo.isArray(rootNode) ? rootNode : (rootNode.all || rootNode.getElementsByTagName("*"));
			var x = dojo.isArray(rootNode) ? 0 : -1;
			for(; x<nodes.length; x++){
				var baseNode = (x == -1) ? rootNode : nodes[x];
				if(this.widgetsInTemplate && (getAttrFunc(baseNode, "dojoType") || getAttrFunc(baseNode, "data-dojo-type"))){
					continue;
				}
				// Process dojoAttachPoint
				var attachPoint = getAttrFunc(baseNode, "dojoAttachPoint") || getAttrFunc(baseNode, "data-dojo-attach-point");
				if(attachPoint){
					var point, points = attachPoint.split(/\s*,\s*/);
					while((point = points.shift())){
						if(dojo.isArray(this[point])){
							this[point].push(baseNode);
						}else{
							this[point]=baseNode;
						}
						this._attachPoints.push(point);
					}
				}

				// Process dojoAttachEvent
				var attachEvent = getAttrFunc(baseNode, "dojoAttachEvent") || getAttrFunc(baseNode, "data-dojo-attach-event");;
				if(attachEvent){
					// NOTE: we want to support attributes that have the form
					// "domEvent: nativeEvent; ..."
					var event, events = attachEvent.split(/\s*,\s*/);
					var trim = dojo.trim;
					while((event = events.shift())){
						if(event){
							var thisFunc = null;
							if(event.indexOf(":") != -1){
								// oh, if only JS had tuple assignment
								var funcNameArr = event.split(":");
								event = trim(funcNameArr[0]);
								thisFunc = trim(funcNameArr[1]);
							}else{
								event = trim(event);
							}
							if(!thisFunc){
								thisFunc = event;
							}
							this._attachEvents.push(this.connect(baseNode, event, thisFunc));
						}
					}
				}

				// waiRole, waiState
				// TODO: remove this in 2.0, templates are now using role=... and aria-XXX=... attributes directicly
				var role = getAttrFunc(baseNode, "waiRole");
				if(role){
					dijit.setWaiRole(baseNode, role);
				}
				var values = getAttrFunc(baseNode, "waiState");
				if(values){
					dojo.forEach(values.split(/\s*,\s*/), function(stateValue){
						if(stateValue.indexOf('-') != -1){
							var pair = stateValue.split('-');
							dijit.setWaiState(baseNode, pair[0], pair[1]);
						}
					});
				}
			}
		},

		startup: function(){
			dojo.forEach(this._startupWidgets, function(w){
				if(w && !w._started && w.startup){
					w.startup();
				}
			});
			this.inherited(arguments);
		},

		destroyRendering: function(){
			// Delete all attach points to prevent IE6 memory leaks.
			dojo.forEach(this._attachPoints, function(point){
				delete this[point];
			}, this);
			this._attachPoints = [];

			// And same for event handlers
			dojo.forEach(this._attachEvents, this.disconnect, this);
			this._attachEvents = [];
			
			this.inherited(arguments);
		}
	}
);

// key is either templatePath or templateString; object is either string or DOM tree
dijit._Templated._templateCache = {};

dijit._Templated.getCachedTemplate = function(templatePath, templateString, alwaysUseString){
	// summary:
	//		Static method to get a template based on the templatePath or
	//		templateString key
	// templatePath: String||dojo.uri.Uri
	//		The URL to get the template from.
	// templateString: String?
	//		a string to use in lieu of fetching the template from a URL. Takes precedence
	//		over templatePath
	// returns: Mixed
	//		Either string (if there are ${} variables that need to be replaced) or just
	//		a DOM tree (if the node can be cloned directly)

	// is it already cached?
	var tmplts = dijit._Templated._templateCache;
	var key = templateString || templatePath;
	var cached = tmplts[key];
	if(cached){
		try{
			// if the cached value is an innerHTML string (no ownerDocument) or a DOM tree created within the current document, then use the current cached value
			if(!cached.ownerDocument || cached.ownerDocument == dojo.doc){
				// string or node of the same document
				return cached;
			}
		}catch(e){ /* squelch */ } // IE can throw an exception if cached.ownerDocument was reloaded
		dojo.destroy(cached);
	}

	// If necessary, load template string from template path
	if(!templateString){
		templateString = dojo.cache(templatePath, {sanitize: true});
	}
	templateString = dojo.string.trim(templateString);

	if(alwaysUseString || templateString.match(/\$\{([^\}]+)\}/g)){
		// there are variables in the template so all we can do is cache the string
		return (tmplts[key] = templateString); //String
	}else{
		// there are no variables in the template so we can cache the DOM tree
		var node = dojo._toDom(templateString);
		if(node.nodeType != 1){
			throw new Error("Invalid template: " + templateString);
		}
		return (tmplts[key] = node); //Node
	}
};

if(dojo.isIE){
	dojo.addOnWindowUnload(function(){
		var cache = dijit._Templated._templateCache;
		for(var key in cache){
			var value = cache[key];
			if(typeof value == "object"){ // value is either a string or a DOM node template
				dojo.destroy(value);
			}
			delete cache[key];
		}
	});
}

// These arguments can be specified for widgets which are used in templates.
// Since any widget can be specified as sub widgets in template, mix it
// into the base widget class.  (This is a hack, but it's effective.)
dojo.extend(dijit._Widget,{
	dojoAttachEvent: "",
	dojoAttachPoint: "",
	waiRole: "",
	waiState:""
});

}

if(!dojo._hasResource["dijit._Container"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._Container"] = true;
dojo.provide("dijit._Container");


dojo.declare("dijit._Container",
	null,
	{
		// summary:
		//		Mixin for widgets that contain a set of widget children.
		// description:
		//		Use this mixin for widgets that needs to know about and
		//		keep track of their widget children. Suitable for widgets like BorderContainer
		//		and TabContainer which contain (only) a set of child widgets.
		//
		//		It's not suitable for widgets like ContentPane
		//		which contains mixed HTML (plain DOM nodes in addition to widgets),
		//		and where contained widgets are not necessarily directly below
		//		this.containerNode.   In that case calls like addChild(node, position)
		//		wouldn't make sense.

		// isContainer: [protected] Boolean
		//		Indicates that this widget acts as a "parent" to the descendant widgets.
		//		When the parent is started it will call startup() on the child widgets.
		//		See also `isLayoutContainer`.
		isContainer: true,

		buildRendering: function(){
			this.inherited(arguments);
			if(!this.containerNode){
				// all widgets with descendants must set containerNode
	 				this.containerNode = this.domNode;
			}
		},

		addChild: function(/*dijit._Widget*/ widget, /*int?*/ insertIndex){
			// summary:
			//		Makes the given widget a child of this widget.
			// description:
			//		Inserts specified child widget's dom node as a child of this widget's
			//		container node, and possibly does other processing (such as layout).

			var refNode = this.containerNode;
			if(insertIndex && typeof insertIndex == "number"){
				var children = this.getChildren();
				if(children && children.length >= insertIndex){
					refNode = children[insertIndex-1].domNode;
					insertIndex = "after";
				}
			}
			dojo.place(widget.domNode, refNode, insertIndex);

			// If I've been started but the child widget hasn't been started,
			// start it now.  Make sure to do this after widget has been
			// inserted into the DOM tree, so it can see that it's being controlled by me,
			// so it doesn't try to size itself.
			if(this._started && !widget._started){
				widget.startup();
			}
		},

		removeChild: function(/*Widget or int*/ widget){
			// summary:
			//		Removes the passed widget instance from this widget but does
			//		not destroy it.  You can also pass in an integer indicating
			//		the index within the container to remove

			if(typeof widget == "number"){
				widget = this.getChildren()[widget];
			}

			if(widget){
				var node = widget.domNode;
				if(node && node.parentNode){
					node.parentNode.removeChild(node); // detach but don't destroy
				}
			}
		},

		hasChildren: function(){
			// summary:
			//		Returns true if widget has children, i.e. if this.containerNode contains something.
			return this.getChildren().length > 0;	// Boolean
		},

		destroyDescendants: function(/*Boolean*/ preserveDom){
			// summary:
			//      Destroys all the widgets inside this.containerNode,
			//      but not this widget itself
			dojo.forEach(this.getChildren(), function(child){ child.destroyRecursive(preserveDom); });
		},

		_getSiblingOfChild: function(/*dijit._Widget*/ child, /*int*/ dir){
			// summary:
			//		Get the next or previous widget sibling of child
			// dir:
			//		if 1, get the next sibling
			//		if -1, get the previous sibling
			// tags:
			//      private
			var node = child.domNode,
				which = (dir>0 ? "nextSibling" : "previousSibling");
			do{
				node = node[which];
			}while(node && (node.nodeType != 1 || !dijit.byNode(node)));
			return node && dijit.byNode(node);	// dijit._Widget
		},

		getIndexOfChild: function(/*dijit._Widget*/ child){
			// summary:
			//		Gets the index of the child in this container or -1 if not found
			return dojo.indexOf(this.getChildren(), child);	// int
		},

		startup: function(){
			// summary:
			//		Called after all the widgets have been instantiated and their
			//		dom nodes have been inserted somewhere under dojo.doc.body.
			//
			//		Widgets should override this method to do any initialization
			//		dependent on other widgets existing, and then call
			//		this superclass method to finish things off.
			//
			//		startup() in subclasses shouldn't do anything
			//		size related because the size of the widget hasn't been set yet.

			if(this._started){ return; }

			// Startup all children of this widget
			dojo.forEach(this.getChildren(), function(child){ child.startup(); });

			this.inherited(arguments);
		}
	}
);

}

if(!dojo._hasResource["dijit._Contained"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._Contained"] = true;
dojo.provide("dijit._Contained");


dojo.declare("dijit._Contained",
		null,
		{
			// summary:
			//		Mixin for widgets that are children of a container widget
			//
			// example:
			// | 	// make a basic custom widget that knows about it's parents
			// |	dojo.declare("my.customClass",[dijit._Widget,dijit._Contained],{});

			getParent: function(){
				// summary:
				//		Returns the parent widget of this widget, assuming the parent
				//		specifies isContainer
				var parent = dijit.getEnclosingWidget(this.domNode.parentNode);
				return parent && parent.isContainer ? parent : null;
			},

			_getSibling: function(/*String*/ which){
				// summary:
				//      Returns next or previous sibling
				// which:
				//      Either "next" or "previous"
				// tags:
				//      private
				var node = this.domNode;
				do{
					node = node[which+"Sibling"];
				}while(node && node.nodeType != 1);
				return node && dijit.byNode(node);	// dijit._Widget
			},

			getPreviousSibling: function(){
				// summary:
				//		Returns null if this is the first child of the parent,
				//		otherwise returns the next element sibling to the "left".

				return this._getSibling("previous"); // dijit._Widget
			},

			getNextSibling: function(){
				// summary:
				//		Returns null if this is the last child of the parent,
				//		otherwise returns the next element sibling to the "right".

				return this._getSibling("next"); // dijit._Widget
			},

			getIndexInParent: function(){
				// summary:
				//		Returns the index of this widget within its container parent.
				//		It returns -1 if the parent does not exist, or if the parent
				//		is not a dijit._Container

				var p = this.getParent();
				if(!p || !p.getIndexOfChild){
					return -1; // int
				}
				return p.getIndexOfChild(this); // int
			}
		}
	);

}

if(!dojo._hasResource["dijit.layout._LayoutWidget"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.layout._LayoutWidget"] = true;
dojo.provide("dijit.layout._LayoutWidget");





dojo.declare("dijit.layout._LayoutWidget",
	[dijit._Widget, dijit._Container, dijit._Contained],
	{
		// summary:
		//		Base class for a _Container widget which is responsible for laying out its children.
		//		Widgets which mixin this code must define layout() to manage placement and sizing of the children.

		// baseClass: [protected extension] String
		//		This class name is applied to the widget's domNode
		//		and also may be used to generate names for sub nodes,
		//		for example dijitTabContainer-content.
		baseClass: "dijitLayoutContainer",

		// isLayoutContainer: [protected] Boolean
		//		Indicates that this widget is going to call resize() on its
		//		children widgets, setting their size, when they become visible.
		isLayoutContainer: true,

		buildRendering: function(){
			this.inherited(arguments);
			dojo.addClass(this.domNode, "dijitContainer");
		},

		startup: function(){
			// summary:
			//		Called after all the widgets have been instantiated and their
			//		dom nodes have been inserted somewhere under dojo.doc.body.
			//
			//		Widgets should override this method to do any initialization
			//		dependent on other widgets existing, and then call
			//		this superclass method to finish things off.
			//
			//		startup() in subclasses shouldn't do anything
			//		size related because the size of the widget hasn't been set yet.

			if(this._started){ return; }

			// Need to call inherited first - so that child widgets get started
			// up correctly
			this.inherited(arguments);

			// If I am a not being controlled by a parent layout widget...
			var parent = this.getParent && this.getParent()
			if(!(parent && parent.isLayoutContainer)){
				// Do recursive sizing and layout of all my descendants
				// (passing in no argument to resize means that it has to glean the size itself)
				this.resize();

				// Since my parent isn't a layout container, and my style *may be* width=height=100%
				// or something similar (either set directly or via a CSS class),
				// monitor when my size changes so that I can re-layout.
				// For browsers where I can't directly monitor when my size changes,
				// monitor when the viewport changes size, which *may* indicate a size change for me.
				this.connect(dojo.isIE ? this.domNode : dojo.global, 'onresize', function(){
					// Using function(){} closure to ensure no arguments to resize.
					this.resize();
				});
			}
		},

		resize: function(changeSize, resultSize){
			// summary:
			//		Call this to resize a widget, or after its size has changed.
			// description:
			//		Change size mode:
			//			When changeSize is specified, changes the marginBox of this widget
			//			and forces it to relayout its contents accordingly.
			//			changeSize may specify height, width, or both.
			//
			//			If resultSize is specified it indicates the size the widget will
			//			become after changeSize has been applied.
			//
			//		Notification mode:
			//			When changeSize is null, indicates that the caller has already changed
			//			the size of the widget, or perhaps it changed because the browser
			//			window was resized.  Tells widget to relayout its contents accordingly.
			//
			//			If resultSize is also specified it indicates the size the widget has
			//			become.
			//
			//		In either mode, this method also:
			//			1. Sets this._borderBox and this._contentBox to the new size of
			//				the widget.  Queries the current domNode size if necessary.
			//			2. Calls layout() to resize contents (and maybe adjust child widgets).
			//
			// changeSize: Object?
			//		Sets the widget to this margin-box size and position.
			//		May include any/all of the following properties:
			//	|	{w: int, h: int, l: int, t: int}
			//
			// resultSize: Object?
			//		The margin-box size of this widget after applying changeSize (if
			//		changeSize is specified).  If caller knows this size and
			//		passes it in, we don't need to query the browser to get the size.
			//	|	{w: int, h: int}

			var node = this.domNode;

			// set margin box size, unless it wasn't specified, in which case use current size
			if(changeSize){
				dojo.marginBox(node, changeSize);

				// set offset of the node
				if(changeSize.t){ node.style.top = changeSize.t + "px"; }
				if(changeSize.l){ node.style.left = changeSize.l + "px"; }
			}

			// If either height or width wasn't specified by the user, then query node for it.
			// But note that setting the margin box and then immediately querying dimensions may return
			// inaccurate results, so try not to depend on it.
			var mb = resultSize || {};
			dojo.mixin(mb, changeSize || {});	// changeSize overrides resultSize
			if( !("h" in mb) || !("w" in mb) ){
				mb = dojo.mixin(dojo.marginBox(node), mb);	// just use dojo.marginBox() to fill in missing values
			}

			// Compute and save the size of my border box and content box
			// (w/out calling dojo.contentBox() since that may fail if size was recently set)
			var cs = dojo.getComputedStyle(node);
			var me = dojo._getMarginExtents(node, cs);
			var be = dojo._getBorderExtents(node, cs);
			var bb = (this._borderBox = {
				w: mb.w - (me.w + be.w),
				h: mb.h - (me.h + be.h)
			});
			var pe = dojo._getPadExtents(node, cs);
			this._contentBox = {
				l: dojo._toPixelValue(node, cs.paddingLeft),
				t: dojo._toPixelValue(node, cs.paddingTop),
				w: bb.w - pe.w,
				h: bb.h - pe.h
			};

			// Callback for widget to adjust size of its children
			this.layout();
		},

		layout: function(){
			// summary:
			//		Widgets override this method to size and position their contents/children.
			//		When this is called this._contentBox is guaranteed to be set (see resize()).
			//
			//		This is called after startup(), and also when the widget's size has been
			//		changed.
			// tags:
			//		protected extension
		},

		_setupChild: function(/*dijit._Widget*/child){
			// summary:
			//		Common setup for initial children and children which are added after startup
			// tags:
			//		protected extension

			var cls = this.baseClass + "-child "
				+ (child.baseClass ? this.baseClass + "-" + child.baseClass : "");
			dojo.addClass(child.domNode, cls);
		},

		addChild: function(/*dijit._Widget*/ child, /*Integer?*/ insertIndex){
			// Overrides _Container.addChild() to call _setupChild()
			this.inherited(arguments);
			if(this._started){
				this._setupChild(child);
			}
		},

		removeChild: function(/*dijit._Widget*/ child){
			// Overrides _Container.removeChild() to remove class added by _setupChild()
			var cls = this.baseClass + "-child"
					+ (child.baseClass ?
						" " + this.baseClass + "-" + child.baseClass : "");
			dojo.removeClass(child.domNode, cls);
			
			this.inherited(arguments);
		}
	}
);

dijit.layout.marginBox2contentBox = function(/*DomNode*/ node, /*Object*/ mb){
	// summary:
	//		Given the margin-box size of a node, return its content box size.
	//		Functions like dojo.contentBox() but is more reliable since it doesn't have
	//		to wait for the browser to compute sizes.
	var cs = dojo.getComputedStyle(node);
	var me = dojo._getMarginExtents(node, cs);
	var pb = dojo._getPadBorderExtents(node, cs);
	return {
		l: dojo._toPixelValue(node, cs.paddingLeft),
		t: dojo._toPixelValue(node, cs.paddingTop),
		w: mb.w - (me.w + pb.w),
		h: mb.h - (me.h + pb.h)
	};
};

(function(){
	var capitalize = function(word){
		return word.substring(0,1).toUpperCase() + word.substring(1);
	};

	var size = function(widget, dim){
		// size the child
		var newSize = widget.resize ? widget.resize(dim) : dojo.marginBox(widget.domNode, dim);

		// record child's size
		if(newSize){
			// if the child returned it's new size then use that
			dojo.mixin(widget, newSize);
		}else{
			// otherwise, call marginBox(), but favor our own numbers when we have them.
			// the browser lies sometimes
			dojo.mixin(widget, dojo.marginBox(widget.domNode));
			dojo.mixin(widget, dim);
		}
	};

	dijit.layout.layoutChildren = function(/*DomNode*/ container, /*Object*/ dim, /*Widget[]*/ children,
			/*String?*/ changedRegionId, /*Number?*/ changedRegionSize){
		// summary
		//		Layout a bunch of child dom nodes within a parent dom node
		// container:
		//		parent node
		// dim:
		//		{l, t, w, h} object specifying dimensions of container into which to place children
		// children:
		//		an array of Widgets or at least objects containing:
		//			* domNode: pointer to DOM node to position
		//			* region or layoutAlign: position to place DOM node
		//			* resize(): (optional) method to set size of node
		//			* id: (optional) Id of widgets, referenced from resize object, below.
		// changedRegionId:
		//		If specified, the slider for the region with the specified id has been dragged, and thus
		//		the region's height or width should be adjusted according to changedRegionSize
		// changedRegionSize:
		//		See changedRegionId.

		// copy dim because we are going to modify it
		dim = dojo.mixin({}, dim);

		dojo.addClass(container, "dijitLayoutContainer");

		// Move "client" elements to the end of the array for layout.  a11y dictates that the author
		// needs to be able to put them in the document in tab-order, but this algorithm requires that
		// client be last.    TODO: move these lines to LayoutContainer?   Unneeded other places I think.
		children = dojo.filter(children, function(item){ return item.region != "center" && item.layoutAlign != "client"; })
			.concat(dojo.filter(children, function(item){ return item.region == "center" || item.layoutAlign == "client"; }));

		// set positions/sizes
		dojo.forEach(children, function(child){
			var elm = child.domNode,
				pos = (child.region || child.layoutAlign);

			// set elem to upper left corner of unused space; may move it later
			var elmStyle = elm.style;
			elmStyle.left = dim.l+"px";
			elmStyle.top = dim.t+"px";
			elmStyle.position = "absolute";

			dojo.addClass(elm, "dijitAlign" + capitalize(pos));

			// Size adjustments to make to this child widget
			var sizeSetting = {};

			// Check for optional size adjustment due to splitter drag (height adjustment for top/bottom align
			// panes and width adjustment for left/right align panes.
			if(changedRegionId && changedRegionId == child.id){
				sizeSetting[child.region == "top" || child.region == "bottom" ? "h" : "w"] = changedRegionSize;
			}

			// set size && adjust record of remaining space.
			// note that setting the width of a <div> may affect its height.
			if(pos == "top" || pos == "bottom"){
				sizeSetting.w = dim.w;
				size(child, sizeSetting);
				dim.h -= child.h;
				if(pos == "top"){
					dim.t += child.h;
				}else{
					elmStyle.top = dim.t + dim.h + "px";
				}
			}else if(pos == "left" || pos == "right"){
				sizeSetting.h = dim.h;
				size(child, sizeSetting);
				dim.w -= child.w;
				if(pos == "left"){
					dim.l += child.w;
				}else{
					elmStyle.left = dim.l + dim.w + "px";
				}
			}else if(pos == "client" || pos == "center"){
				size(child, dim);
			}
		});
	};

})();

}

if(!dojo._hasResource["dijit._CssStateMixin"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._CssStateMixin"] = true;
dojo.provide("dijit._CssStateMixin");


dojo.declare("dijit._CssStateMixin", [], {
	// summary:
	//		Mixin for widgets to set CSS classes on the widget DOM nodes depending on hover/mouse press/focus
	//		state changes, and also higher-level state changes such becoming disabled or selected.
	//
	// description:
	//		By mixing this class into your widget, and setting the this.baseClass attribute, it will automatically
	//		maintain CSS classes on the widget root node (this.domNode) depending on hover,
	//		active, focus, etc. state.   Ex: with a baseClass of dijitButton, it will apply the classes
	//		dijitButtonHovered and dijitButtonActive, as the user moves the mouse over the widget and clicks it.
	//
	//		It also sets CSS like dijitButtonDisabled based on widget semantic state.
	//
	//		By setting the cssStateNodes attribute, a widget can also track events on subnodes (like buttons
	//		within the widget).

	// cssStateNodes: [protected] Object
	//		List of sub-nodes within the widget that need CSS classes applied on mouse hover/press and focus
	//.
	//		Each entry in the hash is a an attachpoint names (like "upArrowButton") mapped to a CSS class names
	//		(like "dijitUpArrowButton"). Example:
	//	|		{
	//	|			"upArrowButton": "dijitUpArrowButton",
	//	|			"downArrowButton": "dijitDownArrowButton"
	//	|		}
	//		The above will set the CSS class dijitUpArrowButton to the this.upArrowButton DOMNode when it
	//		is hovered, etc.
	cssStateNodes: {},

	// hovering: [readonly] Boolean
	//		True if cursor is over this widget
	hovering: false,
	
	// active: [readonly] Boolean
	//		True if mouse was pressed while over this widget, and hasn't been released yet
	active: false,

	_applyAttributes: function(){
		// This code would typically be in postCreate(), but putting in _applyAttributes() for
		// performance: so the class changes happen before DOM is inserted into the document.
		// Change back to postCreate() in 2.0.  See #11635.

		this.inherited(arguments);

		// Automatically monitor mouse events (essentially :hover and :active) on this.domNode
		dojo.forEach(["onmouseenter", "onmouseleave", "onmousedown"], function(e){
			this.connect(this.domNode, e, "_cssMouseEvent");
		}, this);
		
		// Monitoring changes to disabled, readonly, etc. state, and update CSS class of root node
		dojo.forEach(["disabled", "readOnly", "checked", "selected", "focused", "state", "hovering", "active"], function(attr){
			this.watch(attr, dojo.hitch(this, "_setStateClass"));
		}, this);

		// Events on sub nodes within the widget
		for(var ap in this.cssStateNodes){
			this._trackMouseState(this[ap], this.cssStateNodes[ap]);
		}
		// Set state initially; there's probably no hover/active/focus state but widget might be
		// disabled/readonly/checked/selected so we want to set CSS classes for those conditions.
		this._setStateClass();
	},

	_cssMouseEvent: function(/*Event*/ event){
		// summary:
		//	Sets hovering and active properties depending on mouse state,
		//	which triggers _setStateClass() to set appropriate CSS classes for this.domNode.

		if(!this.disabled){
			switch(event.type){
				case "mouseenter":
				case "mouseover":	// generated on non-IE browsers even though we connected to mouseenter
					this._set("hovering", true);
					this._set("active", this._mouseDown);
					break;

				case "mouseleave":
				case "mouseout":	// generated on non-IE browsers even though we connected to mouseleave
					this._set("hovering", false);
					this._set("active", false);
					break;

				case "mousedown" :
					this._set("active", true);
					this._mouseDown = true;
					// Set a global event to handle mouseup, so it fires properly
					// even if the cursor leaves this.domNode before the mouse up event.
					// Alternately could set active=false on mouseout.
					var mouseUpConnector = this.connect(dojo.body(), "onmouseup", function(){
						this._mouseDown = false;
						this._set("active", false);
						this.disconnect(mouseUpConnector);
					});
					break;
			}
		}
	},

	_setStateClass: function(){
		// summary:
		//		Update the visual state of the widget by setting the css classes on this.domNode
		//		(or this.stateNode if defined) by combining this.baseClass with
		//		various suffixes that represent the current widget state(s).
		//
		// description:
		//		In the case where a widget has multiple
		//		states, it sets the class based on all possible
		//	 	combinations.  For example, an invalid form widget that is being hovered
		//		will be "dijitInput dijitInputInvalid dijitInputHover dijitInputInvalidHover".
		//
		//		The widget may have one or more of the following states, determined
		//		by this.state, this.checked, this.valid, and this.selected:
		//			- Error - ValidationTextBox sets this.state to "Error" if the current input value is invalid
		//			- Incomplete - ValidationTextBox sets this.state to "Incomplete" if the current input value is not finished yet
		//			- Checked - ex: a checkmark or a ToggleButton in a checked state, will have this.checked==true
		//			- Selected - ex: currently selected tab will have this.selected==true
		//
		//		In addition, it may have one or more of the following states,
		//		based on this.disabled and flags set in _onMouse (this.active, this.hovering) and from focus manager (this.focused):
		//			- Disabled	- if the widget is disabled
		//			- Active		- if the mouse (or space/enter key?) is being pressed down
		//			- Focused		- if the widget has focus
		//			- Hover		- if the mouse is over the widget

		// Compute new set of classes
		var newStateClasses = this.baseClass.split(" ");

		function multiply(modifier){
			newStateClasses = newStateClasses.concat(dojo.map(newStateClasses, function(c){ return c+modifier; }), "dijit"+modifier);
		}

		if(!this.isLeftToRight()){
			// For RTL mode we need to set an addition class like dijitTextBoxRtl.
			multiply("Rtl");
		}

		if(this.checked){
			multiply("Checked");
		}
		if(this.state){
			multiply(this.state);
		}
		if(this.selected){
			multiply("Selected");
		}

		if(this.disabled){
			multiply("Disabled");
		}else if(this.readOnly){
			multiply("ReadOnly");
		}else{
			if(this.active){
				multiply("Active");
			}else if(this.hovering){
				multiply("Hover");
			}
		}

		if(this._focused){
			multiply("Focused");
		}

		// Remove old state classes and add new ones.
		// For performance concerns we only write into domNode.className once.
		var tn = this.stateNode || this.domNode,
			classHash = {};	// set of all classes (state and otherwise) for node

		dojo.forEach(tn.className.split(" "), function(c){ classHash[c] = true; });

		if("_stateClasses" in this){
			dojo.forEach(this._stateClasses, function(c){ delete classHash[c]; });
		}

		dojo.forEach(newStateClasses, function(c){ classHash[c] = true; });

		var newClasses = [];
		for(var c in classHash){
			newClasses.push(c);
		}
		tn.className = newClasses.join(" ");

		this._stateClasses = newStateClasses;
	},

	_trackMouseState: function(/*DomNode*/ node, /*String*/ clazz){
		// summary:
		//		Track mouse/focus events on specified node and set CSS class on that node to indicate
		//		current state.   Usually not called directly, but via cssStateNodes attribute.
		// description:
		//		Given class=foo, will set the following CSS class on the node
		//			- fooActive: if the user is currently pressing down the mouse button while over the node
		//			- fooHover: if the user is hovering the mouse over the node, but not pressing down a button
		//			- fooFocus: if the node is focused
		//
		//		Note that it won't set any classes if the widget is disabled.
		// node: DomNode
		//		Should be a sub-node of the widget, not the top node (this.domNode), since the top node
		//		is handled specially and automatically just by mixing in this class.
		// clazz: String
		//		CSS class name (ex: dijitSliderUpArrow).

		// Current state of node (initially false)
		// NB: setting specifically to false because dojo.toggleClass() needs true boolean as third arg
		var hovering=false, active=false, focused=false;

		var self = this,
			cn = dojo.hitch(this, "connect", node);

		function setClass(){
			var disabled = ("disabled" in self && self.disabled) || ("readonly" in self && self.readonly);
			dojo.toggleClass(node, clazz+"Hover", hovering && !active && !disabled);
			dojo.toggleClass(node, clazz+"Active", active && !disabled);
			dojo.toggleClass(node, clazz+"Focused", focused && !disabled);
		}

		// Mouse
		cn("onmouseenter", function(){
			hovering = true;
			setClass();
		});
		cn("onmouseleave", function(){
			hovering = false;
			active = false;
			setClass();
		});
		cn("onmousedown", function(){
			active = true;
			setClass();
		});
		cn("onmouseup", function(){
			active = false;
			setClass();
		});

		// Focus
		cn("onfocus", function(){
			focused = true;
			setClass();
		});
		cn("onblur", function(){
			focused = false;
			setClass();
		});

		// Just in case widget is enabled/disabled while it has focus/hover/active state.
		// Maybe this is overkill.
		this.watch("disabled", setClass);
		this.watch("readOnly", setClass);
	}
});

}

if(!dojo._hasResource["dijit.form._FormWidget"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form._FormWidget"] = true;
dojo.provide("dijit.form._FormWidget");






dojo.declare("dijit.form._FormWidget", [dijit._Widget, dijit._Templated, dijit._CssStateMixin],
	{
	// summary:
	//		Base class for widgets corresponding to native HTML elements such as <checkbox> or <button>,
	//		which can be children of a <form> node or a `dijit.form.Form` widget.
	//
	// description:
	//		Represents a single HTML element.
	//		All these widgets should have these attributes just like native HTML input elements.
	//		You can set them during widget construction or afterwards, via `dijit._Widget.attr`.
	//
	//		They also share some common methods.

	// name: [const] String
	//		Name used when submitting form; same as "name" attribute or plain HTML elements
	name: "",

	// alt: String
	//		Corresponds to the native HTML <input> element's attribute.
	alt: "",

	// value: String
	//		Corresponds to the native HTML <input> element's attribute.
	value: "",

	// type: String
	//		Corresponds to the native HTML <input> element's attribute.
	type: "text",

	// tabIndex: Integer
	//		Order fields are traversed when user hits the tab key
	tabIndex: "0",

	// disabled: Boolean
	//		Should this widget respond to user input?
	//		In markup, this is specified as "disabled='disabled'", or just "disabled".
	disabled: false,

	// intermediateChanges: Boolean
	//		Fires onChange for each value change or only on demand
	intermediateChanges: false,

	// scrollOnFocus: Boolean
	//		On focus, should this widget scroll into view?
	scrollOnFocus: true,

	// These mixins assume that the focus node is an INPUT, as many but not all _FormWidgets are.
	attributeMap: dojo.delegate(dijit._Widget.prototype.attributeMap, {
		value: "focusNode",
		id: "focusNode",
		tabIndex: "focusNode",
		alt: "focusNode",
		title: "focusNode"
	}),

	postMixInProperties: function(){
		// Setup name=foo string to be referenced from the template (but only if a name has been specified)
		// Unfortunately we can't use attributeMap to set the name due to IE limitations, see #8660
		// Regarding escaping, see heading "Attribute values" in
		// http://www.w3.org/TR/REC-html40/appendix/notes.html#h-B.3.2
		this.nameAttrSetting = this.name ? ('name="' + this.name.replace(/'/g, "&quot;") + '"') : '';
		this.inherited(arguments);
	},

	postCreate: function(){
		this.inherited(arguments);
		this.connect(this.domNode, "onmousedown", "_onMouseDown");
	},

	_setDisabledAttr: function(/*Boolean*/ value){
		this._set("disabled", value);
		dojo.attr(this.focusNode, 'disabled', value);
		if(this.valueNode){
			dojo.attr(this.valueNode, 'disabled', value);
		}
		dijit.setWaiState(this.focusNode, "disabled", value);

		if(value){
			// reset these, because after the domNode is disabled, we can no longer receive
			// mouse related events, see #4200
			this._set("hovering", false);
			this._set("active", false);

			// clear tab stop(s) on this widget's focusable node(s)  (ComboBox has two focusable nodes)
			var attachPointNames = "tabIndex" in this.attributeMap ? this.attributeMap.tabIndex : "focusNode";
			dojo.forEach(dojo.isArray(attachPointNames) ? attachPointNames : [attachPointNames], function(attachPointName){
				var node = this[attachPointName];
				// complex code because tabIndex=-1 on a <div> doesn't work on FF
				if(dojo.isWebKit || dijit.hasDefaultTabStop(node)){	// see #11064 about webkit bug
					node.setAttribute('tabIndex', "-1");
				}else{
					node.removeAttribute('tabIndex');
				}
			}, this);
		}else{
			if(this.tabIndex != ""){
				this.focusNode.setAttribute('tabIndex', this.tabIndex);
			}
		}
	},

	setDisabled: function(/*Boolean*/ disabled){
		// summary:
		//		Deprecated.  Use set('disabled', ...) instead.
		dojo.deprecated("setDisabled("+disabled+") is deprecated. Use set('disabled',"+disabled+") instead.", "", "2.0");
		this.set('disabled', disabled);
	},

	_onFocus: function(e){
		if(this.scrollOnFocus){
			dojo.window.scrollIntoView(this.domNode);
		}
		this.inherited(arguments);
	},

	isFocusable: function(){
		// summary:
		//		Tells if this widget is focusable or not.  Used internally by dijit.
		// tags:
		//		protected
		return !this.disabled && this.focusNode && (dojo.style(this.domNode, "display") != "none");
	},

	focus: function(){
		// summary:
		//		Put focus on this widget
		if(!this.disabled){
			dijit.focus(this.focusNode);
		}
	},

	compare: function(/*anything*/ val1, /*anything*/ val2){
		// summary:
		//		Compare 2 values (as returned by get('value') for this widget).
		// tags:
		//		protected
		if(typeof val1 == "number" && typeof val2 == "number"){
			return (isNaN(val1) && isNaN(val2)) ? 0 : val1 - val2;
		}else if(val1 > val2){
			return 1;
		}else if(val1 < val2){
			return -1;
		}else{
			return 0;
		}
	},

	onChange: function(newValue){
		// summary:
		//		Callback when this widget's value is changed.
		// tags:
		//		callback
	},

	// _onChangeActive: [private] Boolean
	//		Indicates that changes to the value should call onChange() callback.
	//		This is false during widget initialization, to avoid calling onChange()
	//		when the initial value is set.
	_onChangeActive: false,

	_handleOnChange: function(/*anything*/ newValue, /*Boolean?*/ priorityChange){
		// summary:
		//		Called when the value of the widget is set.  Calls onChange() if appropriate
		// newValue:
		//		the new value
		// priorityChange:
		//		For a slider, for example, dragging the slider is priorityChange==false,
		//		but on mouse up, it's priorityChange==true.  If intermediateChanges==false,
		//		onChange is only called form priorityChange=true events.
		// tags:
		//		private
		if(this._lastValueReported == undefined && (priorityChange === null || !this._onChangeActive)){
			// this block executes not for a change, but during initialization,
			// and is used to store away the original value (or for ToggleButton, the original checked state)
			this._resetValue = this._lastValueReported = newValue;
		}
		this._pendingOnChange = this._pendingOnChange
			|| (typeof newValue != typeof this._lastValueReported)
			|| (this.compare(newValue, this._lastValueReported) != 0);
		if((this.intermediateChanges || priorityChange || priorityChange === undefined) && this._pendingOnChange){
			this._lastValueReported = newValue;
			this._pendingOnChange = false;
			if(this._onChangeActive){
				if(this._onChangeHandle){
					clearTimeout(this._onChangeHandle);
				}
				// setTimout allows hidden value processing to run and
				// also the onChange handler can safely adjust focus, etc
				this._onChangeHandle = setTimeout(dojo.hitch(this,
					function(){
						this._onChangeHandle = null;
						this.onChange(newValue);
					}), 0); // try to collapse multiple onChange's fired faster than can be processed
			}
		}
	},

	create: function(){
		// Overrides _Widget.create()
		this.inherited(arguments);
		this._onChangeActive = true;
	},

	destroy: function(){
		if(this._onChangeHandle){ // destroy called before last onChange has fired
			clearTimeout(this._onChangeHandle);
			this.onChange(this._lastValueReported);
		}
		this.inherited(arguments);
	},

	setValue: function(/*String*/ value){
		// summary:
		//		Deprecated.  Use set('value', ...) instead.
		dojo.deprecated("dijit.form._FormWidget:setValue("+value+") is deprecated.  Use set('value',"+value+") instead.", "", "2.0");
		this.set('value', value);
	},

	getValue: function(){
		// summary:
		//		Deprecated.  Use get('value') instead.
		dojo.deprecated(this.declaredClass+"::getValue() is deprecated. Use get('value') instead.", "", "2.0");
		return this.get('value');
	},
	
	_onMouseDown: function(e){
		// If user clicks on the button, even if the mouse is released outside of it,
		// this button should get focus (to mimics native browser buttons).
		// This is also needed on chrome because otherwise buttons won't get focus at all,
		// which leads to bizarre focus restore on Dialog close etc.
		if(!e.ctrlKey && dojo.mouseButtons.isLeft(e) && this.isFocusable()){ // !e.ctrlKey to ignore right-click on mac
			// Set a global event to handle mouseup, so it fires properly
			// even if the cursor leaves this.domNode before the mouse up event.
			var mouseUpConnector = this.connect(dojo.body(), "onmouseup", function(){
				if (this.isFocusable()) {
					this.focus();
				}
				this.disconnect(mouseUpConnector);
			});
		}
	}
});

dojo.declare("dijit.form._FormValueWidget", dijit.form._FormWidget,
{
	// summary:
	//		Base class for widgets corresponding to native HTML elements such as <input> or <select> that have user changeable values.
	// description:
	//		Each _FormValueWidget represents a single input value, and has a (possibly hidden) <input> element,
	//		to which it serializes it's input value, so that form submission (either normal submission or via FormBind?)
	//		works as expected.

	// Don't attempt to mixin the 'type', 'name' attributes here programatically -- they must be declared
	// directly in the template as read by the parser in order to function. IE is known to specifically
	// require the 'name' attribute at element creation time.  See #8484, #8660.
	// TODO: unclear what that {value: ""} is for; FormWidget.attributeMap copies value to focusNode,
	// so maybe {value: ""} is so the value *doesn't* get copied to focusNode?
	// Seems like we really want value removed from attributeMap altogether
	// (although there's no easy way to do that now)

	// readOnly: Boolean
	//		Should this widget respond to user input?
	//		In markup, this is specified as "readOnly".
	//		Similar to disabled except readOnly form values are submitted.
	readOnly: false,

	attributeMap: dojo.delegate(dijit.form._FormWidget.prototype.attributeMap, {
		value: "",
		readOnly: "focusNode"
	}),

	_setReadOnlyAttr: function(/*Boolean*/ value){
		dojo.attr(this.focusNode, 'readOnly', value);
		dijit.setWaiState(this.focusNode, "readonly", value);
		this._set("readOnly", value);
	},

	postCreate: function(){
		this.inherited(arguments);

		if(dojo.isIE < 9 || (dojo.isIE && dojo.isQuirks)){ // IE won't stop the event with keypress
			this.connect(this.focusNode || this.domNode, "onkeydown", this._onKeyDown);
		}
		// Update our reset value if it hasn't yet been set (because this.set()
		// is only called when there *is* a value)
		if(this._resetValue === undefined){
			this._lastValueReported = this._resetValue = this.value;
		}
	},

	_setValueAttr: function(/*anything*/ newValue, /*Boolean?*/ priorityChange){
		// summary:
		//		Hook so set('value', value) works.
		// description:
		//		Sets the value of the widget.
		//		If the value has changed, then fire onChange event, unless priorityChange
		//		is specified as null (or false?)
		this._handleOnChange(newValue, priorityChange);
	},

	_handleOnChange: function(/*anything*/ newValue, /*Boolean?*/ priorityChange){
		// summary:
		//		Called when the value of the widget has changed.  Saves the new value in this.value,
		//		and calls onChange() if appropriate.   See _FormWidget._handleOnChange() for details.
		this._set("value", newValue);
		this.inherited(arguments);
	},

	undo: function(){
		// summary:
		//		Restore the value to the last value passed to onChange
		this._setValueAttr(this._lastValueReported, false);
	},

	reset: function(){
		// summary:
		//		Reset the widget's value to what it was at initialization time
		this._hasBeenBlurred = false;
		this._setValueAttr(this._resetValue, true);
	},

	_onKeyDown: function(e){
		if(e.keyCode == dojo.keys.ESCAPE && !(e.ctrlKey || e.altKey || e.metaKey)){
			var te;
			if(dojo.isIE){
				e.preventDefault(); // default behavior needs to be stopped here since keypress is too late
				te = document.createEventObject();
				te.keyCode = dojo.keys.ESCAPE;
				te.shiftKey = e.shiftKey;
				e.srcElement.fireEvent('onkeypress', te);
			}
		}
	},

	_layoutHackIE7: function(){
		// summary:
		//		Work around table sizing bugs on IE7 by forcing redraw

		if(dojo.isIE == 7){ // fix IE7 layout bug when the widget is scrolled out of sight
			var domNode = this.domNode;
			var parent = domNode.parentNode;
			var pingNode = domNode.firstChild || domNode; // target node most unlikely to have a custom filter
			var origFilter = pingNode.style.filter; // save custom filter, most likely nothing
			var _this = this;
			while(parent && parent.clientHeight == 0){ // search for parents that haven't rendered yet
				(function ping(){
					var disconnectHandle = _this.connect(parent, "onscroll",
						function(e){
							_this.disconnect(disconnectHandle); // only call once
							pingNode.style.filter = (new Date()).getMilliseconds(); // set to anything that's unique
							setTimeout(function(){ pingNode.style.filter = origFilter }, 0); // restore custom filter, if any
						}
					);
				})();
				parent = parent.parentNode;
			}
		}
	}
});

}

if(!dojo._hasResource["dijit.dijit"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.dijit"] = true;
dojo.provide("dijit.dijit");









/*=====
dijit.dijit = {
	// summary:
	//		A roll-up for common dijit methods
	// description:
	//	A rollup file for the build system including the core and common
	//	dijit files.
	//
	// example:
	// | <script type="text/javascript" src="js/dojo/dijit/dijit.js"></script>
	//
};
=====*/

// All the stuff in _base (these are the function that are guaranteed available without an explicit dojo.require)

// And some other stuff that we tend to pull in all the time anyway

}

if(!dojo._hasResource["dojo.fx.Toggler"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.fx.Toggler"] = true;
dojo.provide("dojo.fx.Toggler");


dojo.declare("dojo.fx.Toggler", null, {
	// summary:
	//		A simple `dojo.Animation` toggler API.
	//
	// description:
	//		class constructor for an animation toggler. It accepts a packed
	//		set of arguments about what type of animation to use in each
	//		direction, duration, etc. All available members are mixed into
	//		these animations from the constructor (for example, `node`,
	//		`showDuration`, `hideDuration`).
	//
	// example:
	//	|	var t = new dojo.fx.Toggler({
	//	|		node: "nodeId",
	//	|		showDuration: 500,
	//	|		// hideDuration will default to "200"
	//	|		showFunc: dojo.fx.wipeIn,
	//	|		// hideFunc will default to "fadeOut"
	//	|	});
	//	|	t.show(100); // delay showing for 100ms
	//	|	// ...time passes...
	//	|	t.hide();

	// node: DomNode
	//		the node to target for the showing and hiding animations
	node: null,

	// showFunc: Function
	//		The function that returns the `dojo.Animation` to show the node
	showFunc: dojo.fadeIn,

	// hideFunc: Function
	//		The function that returns the `dojo.Animation` to hide the node
	hideFunc: dojo.fadeOut,

	// showDuration:
	//		Time in milliseconds to run the show Animation
	showDuration: 200,

	// hideDuration:
	//		Time in milliseconds to run the hide Animation
	hideDuration: 200,

	// FIXME: need a policy for where the toggler should "be" the next
	// time show/hide are called if we're stopped somewhere in the
	// middle.
	// FIXME: also would be nice to specify individual showArgs/hideArgs mixed into
	// each animation individually.
	// FIXME: also would be nice to have events from the animations exposed/bridged

	/*=====
	_showArgs: null,
	_showAnim: null,

	_hideArgs: null,
	_hideAnim: null,

	_isShowing: false,
	_isHiding: false,
	=====*/

	constructor: function(args){
		var _t = this;

		dojo.mixin(_t, args);
		_t.node = args.node;
		_t._showArgs = dojo.mixin({}, args);
		_t._showArgs.node = _t.node;
		_t._showArgs.duration = _t.showDuration;
		_t.showAnim = _t.showFunc(_t._showArgs);

		_t._hideArgs = dojo.mixin({}, args);
		_t._hideArgs.node = _t.node;
		_t._hideArgs.duration = _t.hideDuration;
		_t.hideAnim = _t.hideFunc(_t._hideArgs);

		dojo.connect(_t.showAnim, "beforeBegin", dojo.hitch(_t.hideAnim, "stop", true));
		dojo.connect(_t.hideAnim, "beforeBegin", dojo.hitch(_t.showAnim, "stop", true));
	},

	show: function(delay){
		// summary: Toggle the node to showing
		// delay: Integer?
		//		Ammount of time to stall playing the show animation
		return this.showAnim.play(delay || 0);
	},

	hide: function(delay){
		// summary: Toggle the node to hidden
		// delay: Integer?
		//		Ammount of time to stall playing the hide animation
		return this.hideAnim.play(delay || 0);
	}
});

}

if(!dojo._hasResource["dojo.fx"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.fx"] = true;
dojo.provide("dojo.fx");



/*=====
dojo.fx = {
	// summary: Effects library on top of Base animations
};
=====*/
(function(){
	
	var d = dojo,
		_baseObj = {
			_fire: function(evt, args){
				if(this[evt]){
					this[evt].apply(this, args||[]);
				}
				return this;
			}
		};

	var _chain = function(animations){
		this._index = -1;
		this._animations = animations||[];
		this._current = this._onAnimateCtx = this._onEndCtx = null;

		this.duration = 0;
		d.forEach(this._animations, function(a){
			this.duration += a.duration;
			if(a.delay){ this.duration += a.delay; }
		}, this);
	};
	d.extend(_chain, {
		_onAnimate: function(){
			this._fire("onAnimate", arguments);
		},
		_onEnd: function(){
			d.disconnect(this._onAnimateCtx);
			d.disconnect(this._onEndCtx);
			this._onAnimateCtx = this._onEndCtx = null;
			if(this._index + 1 == this._animations.length){
				this._fire("onEnd");
			}else{
				// switch animations
				this._current = this._animations[++this._index];
				this._onAnimateCtx = d.connect(this._current, "onAnimate", this, "_onAnimate");
				this._onEndCtx = d.connect(this._current, "onEnd", this, "_onEnd");
				this._current.play(0, true);
			}
		},
		play: function(/*int?*/ delay, /*Boolean?*/ gotoStart){
			if(!this._current){ this._current = this._animations[this._index = 0]; }
			if(!gotoStart && this._current.status() == "playing"){ return this; }
			var beforeBegin = d.connect(this._current, "beforeBegin", this, function(){
					this._fire("beforeBegin");
				}),
				onBegin = d.connect(this._current, "onBegin", this, function(arg){
					this._fire("onBegin", arguments);
				}),
				onPlay = d.connect(this._current, "onPlay", this, function(arg){
					this._fire("onPlay", arguments);
					d.disconnect(beforeBegin);
					d.disconnect(onBegin);
					d.disconnect(onPlay);
				});
			if(this._onAnimateCtx){
				d.disconnect(this._onAnimateCtx);
			}
			this._onAnimateCtx = d.connect(this._current, "onAnimate", this, "_onAnimate");
			if(this._onEndCtx){
				d.disconnect(this._onEndCtx);
			}
			this._onEndCtx = d.connect(this._current, "onEnd", this, "_onEnd");
			this._current.play.apply(this._current, arguments);
			return this;
		},
		pause: function(){
			if(this._current){
				var e = d.connect(this._current, "onPause", this, function(arg){
						this._fire("onPause", arguments);
						d.disconnect(e);
					});
				this._current.pause();
			}
			return this;
		},
		gotoPercent: function(/*Decimal*/percent, /*Boolean?*/ andPlay){
			this.pause();
			var offset = this.duration * percent;
			this._current = null;
			d.some(this._animations, function(a){
				if(a.duration <= offset){
					this._current = a;
					return true;
				}
				offset -= a.duration;
				return false;
			});
			if(this._current){
				this._current.gotoPercent(offset / this._current.duration, andPlay);
			}
			return this;
		},
		stop: function(/*boolean?*/ gotoEnd){
			if(this._current){
				if(gotoEnd){
					for(; this._index + 1 < this._animations.length; ++this._index){
						this._animations[this._index].stop(true);
					}
					this._current = this._animations[this._index];
				}
				var e = d.connect(this._current, "onStop", this, function(arg){
						this._fire("onStop", arguments);
						d.disconnect(e);
					});
				this._current.stop();
			}
			return this;
		},
		status: function(){
			return this._current ? this._current.status() : "stopped";
		},
		destroy: function(){
			if(this._onAnimateCtx){ d.disconnect(this._onAnimateCtx); }
			if(this._onEndCtx){ d.disconnect(this._onEndCtx); }
		}
	});
	d.extend(_chain, _baseObj);

	dojo.fx.chain = function(/*dojo.Animation[]*/ animations){
		// summary:
		//		Chain a list of `dojo.Animation`s to run in sequence
		//
		// description:
		//		Return a `dojo.Animation` which will play all passed
		//		`dojo.Animation` instances in sequence, firing its own
		//		synthesized events simulating a single animation. (eg:
		//		onEnd of this animation means the end of the chain,
		//		not the individual animations within)
		//
		// example:
		//	Once `node` is faded out, fade in `otherNode`
		//	|	dojo.fx.chain([
		//	|		dojo.fadeIn({ node:node }),
		//	|		dojo.fadeOut({ node:otherNode })
		//	|	]).play();
		//
		return new _chain(animations) // dojo.Animation
	};

	var _combine = function(animations){
		this._animations = animations||[];
		this._connects = [];
		this._finished = 0;

		this.duration = 0;
		d.forEach(animations, function(a){
			var duration = a.duration;
			if(a.delay){ duration += a.delay; }
			if(this.duration < duration){ this.duration = duration; }
			this._connects.push(d.connect(a, "onEnd", this, "_onEnd"));
		}, this);
		
		this._pseudoAnimation = new d.Animation({curve: [0, 1], duration: this.duration});
		var self = this;
		d.forEach(["beforeBegin", "onBegin", "onPlay", "onAnimate", "onPause", "onStop", "onEnd"],
			function(evt){
				self._connects.push(d.connect(self._pseudoAnimation, evt,
					function(){ self._fire(evt, arguments); }
				));
			}
		);
	};
	d.extend(_combine, {
		_doAction: function(action, args){
			d.forEach(this._animations, function(a){
				a[action].apply(a, args);
			});
			return this;
		},
		_onEnd: function(){
			if(++this._finished > this._animations.length){
				this._fire("onEnd");
			}
		},
		_call: function(action, args){
			var t = this._pseudoAnimation;
			t[action].apply(t, args);
		},
		play: function(/*int?*/ delay, /*Boolean?*/ gotoStart){
			this._finished = 0;
			this._doAction("play", arguments);
			this._call("play", arguments);
			return this;
		},
		pause: function(){
			this._doAction("pause", arguments);
			this._call("pause", arguments);
			return this;
		},
		gotoPercent: function(/*Decimal*/percent, /*Boolean?*/ andPlay){
			var ms = this.duration * percent;
			d.forEach(this._animations, function(a){
				a.gotoPercent(a.duration < ms ? 1 : (ms / a.duration), andPlay);
			});
			this._call("gotoPercent", arguments);
			return this;
		},
		stop: function(/*boolean?*/ gotoEnd){
			this._doAction("stop", arguments);
			this._call("stop", arguments);
			return this;
		},
		status: function(){
			return this._pseudoAnimation.status();
		},
		destroy: function(){
			d.forEach(this._connects, dojo.disconnect);
		}
	});
	d.extend(_combine, _baseObj);

	dojo.fx.combine = function(/*dojo.Animation[]*/ animations){
		// summary:
		//		Combine a list of `dojo.Animation`s to run in parallel
		//
		// description:
		//		Combine an array of `dojo.Animation`s to run in parallel,
		//		providing a new `dojo.Animation` instance encompasing each
		//		animation, firing standard animation events.
		//
		// example:
		//	Fade out `node` while fading in `otherNode` simultaneously
		//	|	dojo.fx.combine([
		//	|		dojo.fadeIn({ node:node }),
		//	|		dojo.fadeOut({ node:otherNode })
		//	|	]).play();
		//
		// example:
		//	When the longest animation ends, execute a function:
		//	|	var anim = dojo.fx.combine([
		//	|		dojo.fadeIn({ node: n, duration:700 }),
		//	|		dojo.fadeOut({ node: otherNode, duration: 300 })
		//	|	]);
		//	|	dojo.connect(anim, "onEnd", function(){
		//	|		// overall animation is done.
		//	|	});
		//	|	anim.play(); // play the animation
		//
		return new _combine(animations); // dojo.Animation
	};

	dojo.fx.wipeIn = function(/*Object*/ args){
		// summary:
		//		Expand a node to it's natural height.
		//
		// description:
		//		Returns an animation that will expand the
		//		node defined in 'args' object from it's current height to
		//		it's natural height (with no scrollbar).
		//		Node must have no margin/border/padding.
		//
		// args: Object
		//		A hash-map of standard `dojo.Animation` constructor properties
		//		(such as easing: node: duration: and so on)
		//
		// example:
		//	|	dojo.fx.wipeIn({
		//	|		node:"someId"
		//	|	}).play()
		var node = args.node = d.byId(args.node), s = node.style, o;

		var anim = d.animateProperty(d.mixin({
			properties: {
				height: {
					// wrapped in functions so we wait till the last second to query (in case value has changed)
					start: function(){
						// start at current [computed] height, but use 1px rather than 0
						// because 0 causes IE to display the whole panel
						o = s.overflow;
						s.overflow = "hidden";
						if(s.visibility == "hidden" || s.display == "none"){
							s.height = "1px";
							s.display = "";
							s.visibility = "";
							return 1;
						}else{
							var height = d.style(node, "height");
							return Math.max(height, 1);
						}
					},
					end: function(){
						return node.scrollHeight;
					}
				}
			}
		}, args));

		d.connect(anim, "onEnd", function(){
			s.height = "auto";
			s.overflow = o;
		});

		return anim; // dojo.Animation
	};

	dojo.fx.wipeOut = function(/*Object*/ args){
		// summary:
		//		Shrink a node to nothing and hide it.
		//
		// description:
		//		Returns an animation that will shrink node defined in "args"
		//		from it's current height to 1px, and then hide it.
		//
		// args: Object
		//		A hash-map of standard `dojo.Animation` constructor properties
		//		(such as easing: node: duration: and so on)
		//
		// example:
		//	|	dojo.fx.wipeOut({ node:"someId" }).play()
		
		var node = args.node = d.byId(args.node), s = node.style, o;
		
		var anim = d.animateProperty(d.mixin({
			properties: {
				height: {
					end: 1 // 0 causes IE to display the whole panel
				}
			}
		}, args));

		d.connect(anim, "beforeBegin", function(){
			o = s.overflow;
			s.overflow = "hidden";
			s.display = "";
		});
		d.connect(anim, "onEnd", function(){
			s.overflow = o;
			s.height = "auto";
			s.display = "none";
		});

		return anim; // dojo.Animation
	};

	dojo.fx.slideTo = function(/*Object*/ args){
		// summary:
		//		Slide a node to a new top/left position
		//
		// description:
		//		Returns an animation that will slide "node"
		//		defined in args Object from its current position to
		//		the position defined by (args.left, args.top).
		//
		// args: Object
		//		A hash-map of standard `dojo.Animation` constructor properties
		//		(such as easing: node: duration: and so on). Special args members
		//		are `top` and `left`, which indicate the new position to slide to.
		//
		// example:
		//	|	dojo.fx.slideTo({ node: node, left:"40", top:"50", units:"px" }).play()

		var node = args.node = d.byId(args.node),
			top = null, left = null;

		var init = (function(n){
			return function(){
				var cs = d.getComputedStyle(n);
				var pos = cs.position;
				top = (pos == 'absolute' ? n.offsetTop : parseInt(cs.top) || 0);
				left = (pos == 'absolute' ? n.offsetLeft : parseInt(cs.left) || 0);
				if(pos != 'absolute' && pos != 'relative'){
					var ret = d.position(n, true);
					top = ret.y;
					left = ret.x;
					n.style.position="absolute";
					n.style.top=top+"px";
					n.style.left=left+"px";
				}
			};
		})(node);
		init();

		var anim = d.animateProperty(d.mixin({
			properties: {
				top: args.top || 0,
				left: args.left || 0
			}
		}, args));
		d.connect(anim, "beforeBegin", anim, init);

		return anim; // dojo.Animation
	};

})();

}

if(!dojo._hasResource["dojo.fx.easing"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.fx.easing"] = true;
dojo.provide("dojo.fx.easing");

dojo.getObject("fx.easing", true, dojo);

dojo.fx.easing = {
	// summary:
	//		Collection of easing functions to use beyond the default
	//		`dojo._defaultEasing` function.
	//
	// description:
	//
	//		Easing functions are used to manipulate the iteration through
	//		an `dojo.Animation`s _Line. _Line being the properties of an Animation,
	//		and the easing function progresses through that Line determing
	//		how quickly (or slowly) it should go. Or more accurately: modify
	//		the value of the _Line based on the percentage of animation completed.
	//
	//		All functions follow a simple naming convention of "ease type" + "when".
	//		If the name of the function ends in Out, the easing described appears
	//		towards the end of the animation. "In" means during the beginning,
	//		and InOut means both ranges of the Animation will applied, both
	//		beginning and end.
	//
	//		One does not call the easing function directly, it must be passed to
	//		the `easing` property of an animation.
	//
	//	example:
	//	|	
	//	|	var anim = dojo.fadeOut({
	//	|		node: 'node',
	//	|		duration: 2000,
	//	|		//	note there is no ()
	//	|		easing: dojo.fx.easing.quadIn
	//	|	}).play();
	//
	
	linear: function(/* Decimal? */n){
		// summary: A linear easing function
		return n;
	},

	quadIn: function(/* Decimal? */n){
		return Math.pow(n, 2);
	},

	quadOut: function(/* Decimal? */n){
		return n * (n - 2) * -1;
	},

	quadInOut: function(/* Decimal? */n){
		n = n * 2;
		if(n < 1){ return Math.pow(n, 2) / 2; }
		return -1 * ((--n) * (n - 2) - 1) / 2;
	},

	cubicIn: function(/* Decimal? */n){
		return Math.pow(n, 3);
	},

	cubicOut: function(/* Decimal? */n){
		return Math.pow(n - 1, 3) + 1;
	},

	cubicInOut: function(/* Decimal? */n){
		n = n * 2;
		if(n < 1){ return Math.pow(n, 3) / 2; }
		n -= 2;
		return (Math.pow(n, 3) + 2) / 2;
	},

	quartIn: function(/* Decimal? */n){
		return Math.pow(n, 4);
	},

	quartOut: function(/* Decimal? */n){
		return -1 * (Math.pow(n - 1, 4) - 1);
	},

	quartInOut: function(/* Decimal? */n){
		n = n * 2;
		if(n < 1){ return Math.pow(n, 4) / 2; }
		n -= 2;
		return -1 / 2 * (Math.pow(n, 4) - 2);
	},

	quintIn: function(/* Decimal? */n){
		return Math.pow(n, 5);
	},

	quintOut: function(/* Decimal? */n){
		return Math.pow(n - 1, 5) + 1;
	},

	quintInOut: function(/* Decimal? */n){
		n = n * 2;
		if(n < 1){ return Math.pow(n, 5) / 2; };
		n -= 2;
		return (Math.pow(n, 5) + 2) / 2;
	},

	sineIn: function(/* Decimal? */n){
		return -1 * Math.cos(n * (Math.PI / 2)) + 1;
	},

	sineOut: function(/* Decimal? */n){
		return Math.sin(n * (Math.PI / 2));
	},

	sineInOut: function(/* Decimal? */n){
		return -1 * (Math.cos(Math.PI * n) - 1) / 2;
	},

	expoIn: function(/* Decimal? */n){
		return (n == 0) ? 0 : Math.pow(2, 10 * (n - 1));
	},

	expoOut: function(/* Decimal? */n){
		return (n == 1) ? 1 : (-1 * Math.pow(2, -10 * n) + 1);
	},

	expoInOut: function(/* Decimal? */n){
		if(n == 0){ return 0; }
		if(n == 1){ return 1; }
		n = n * 2;
		if(n < 1){ return Math.pow(2, 10 * (n - 1)) / 2; }
		--n;
		return (-1 * Math.pow(2, -10 * n) + 2) / 2;
	},

	circIn: function(/* Decimal? */n){
		return -1 * (Math.sqrt(1 - Math.pow(n, 2)) - 1);
	},

	circOut: function(/* Decimal? */n){
		n = n - 1;
		return Math.sqrt(1 - Math.pow(n, 2));
	},

	circInOut: function(/* Decimal? */n){
		n = n * 2;
		if(n < 1){ return -1 / 2 * (Math.sqrt(1 - Math.pow(n, 2)) - 1); }
		n -= 2;
		return 1 / 2 * (Math.sqrt(1 - Math.pow(n, 2)) + 1);
	},

	backIn: function(/* Decimal? */n){
		// summary:
		//		An easing function that starts away from the target,
		//		and quickly accelerates towards the end value.
		//
		//		Use caution when the easing will cause values to become
		//		negative as some properties cannot be set to negative values.
		var s = 1.70158;
		return Math.pow(n, 2) * ((s + 1) * n - s);
	},

	backOut: function(/* Decimal? */n){
		// summary:
		//		An easing function that pops past the range briefly, and slowly comes back.
		//
		// description:
		//		An easing function that pops past the range briefly, and slowly comes back.
		//
		//		Use caution when the easing will cause values to become negative as some
		//		properties cannot be set to negative values.
		
		n = n - 1;
		var s = 1.70158;
		return Math.pow(n, 2) * ((s + 1) * n + s) + 1;
	},

	backInOut: function(/* Decimal? */n){
		// summary:
		//		An easing function combining the effects of `backIn` and `backOut`
		//
		// description:
		//		An easing function combining the effects of `backIn` and `backOut`.
		//		Use caution when the easing will cause values to become negative
		//		as some properties cannot be set to negative values.
		var s = 1.70158 * 1.525;
		n = n * 2;
		if(n < 1){ return (Math.pow(n, 2) * ((s + 1) * n - s)) / 2; }
		n-=2;
		return (Math.pow(n, 2) * ((s + 1) * n + s) + 2) / 2;
	},

	elasticIn: function(/* Decimal? */n){
		// summary:
		//		An easing function the elastically snaps from the start value
		//
		// description:
		//		An easing function the elastically snaps from the start value
		//
		//		Use caution when the elasticity will cause values to become negative
		//		as some properties cannot be set to negative values.
		if(n == 0 || n == 1){ return n; }
		var p = .3;
		var s = p / 4;
		n = n - 1;
		return -1 * Math.pow(2, 10 * n) * Math.sin((n - s) * (2 * Math.PI) / p);
	},

	elasticOut: function(/* Decimal? */n){
		// summary:
		//		An easing function that elasticly snaps around the target value,
		//		near the end of the Animation
		//
		// description:
		//		An easing function that elasticly snaps around the target value,
		//		near the end of the Animation
		//
		//		Use caution when the elasticity will cause values to become
		//		negative as some properties cannot be set to negative values.
		if(n==0 || n == 1){ return n; }
		var p = .3;
		var s = p / 4;
		return Math.pow(2, -10 * n) * Math.sin((n - s) * (2 * Math.PI) / p) + 1;
	},

	elasticInOut: function(/* Decimal? */n){
		// summary:
		//		An easing function that elasticly snaps around the value, near
		//		the beginning and end of the Animation.
		//
		// description:
		//		An easing function that elasticly snaps around the value, near
		//		the beginning and end of the Animation.
		//
		//		Use caution when the elasticity will cause values to become
		//		negative as some properties cannot be set to negative values.
		if(n == 0) return 0;
		n = n * 2;
		if(n == 2) return 1;
		var p = .3 * 1.5;
		var s = p / 4;
		if(n < 1){
			n -= 1;
			return -.5 * (Math.pow(2, 10 * n) * Math.sin((n - s) * (2 * Math.PI) / p));
		}
		n -= 1;
		return .5 * (Math.pow(2, -10 * n) * Math.sin((n - s) * (2 * Math.PI) / p)) + 1;
	},

	bounceIn: function(/* Decimal? */n){
		// summary:
		//		An easing function that 'bounces' near the beginning of an Animation
		return (1 - dojo.fx.easing.bounceOut(1 - n)); // Decimal
	},

	bounceOut: function(/* Decimal? */n){
		// summary:
		//		An easing function that 'bounces' near the end of an Animation
		var s = 7.5625;
		var p = 2.75;
		var l;
		if(n < (1 / p)){
			l = s * Math.pow(n, 2);
		}else if(n < (2 / p)){
			n -= (1.5 / p);
			l = s * Math.pow(n, 2) + .75;
		}else if(n < (2.5 / p)){
			n -= (2.25 / p);
			l = s * Math.pow(n, 2) + .9375;
		}else{
			n -= (2.625 / p);
			l = s * Math.pow(n, 2) + .984375;
		}
		return l;
	},

	bounceInOut: function(/* Decimal? */n){
		// summary:
		//		An easing function that 'bounces' at the beginning and end of the Animation
		if(n < 0.5){ return dojo.fx.easing.bounceIn(n * 2) / 2; }
		return (dojo.fx.easing.bounceOut(n * 2 - 1) / 2) + 0.5; // Decimal
	}
};

}

if(!dojo._hasResource['epages.browser']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.browser'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.browser');


epages.Browser = {};

(function() {
	var browser = epages.Browser;
	browser.engine = "Unknown";
	browser.version = "Unknown";
	if(window.opera) {
		browser.engine = "Presto";
		browser.version = window.opera.version();
	}else {
		var versionString = (navigator.appVersion + navigator.userAgent).toLowerCase();
		if(versionString.match("iemobile") || versionString.match("windows ce")) {
			// ie on smartphone
			browser.engine = "MSIE";
			browser.version = 6;
		}else if(versionString.match("msie")) {
			browser.engine = "MSIE";
			browser.version = (window.XDomainRequest && dojo.isIE == 7) ? 8 : dojo.isIE;
			// ...and finally some testing for IE6 with faked IE7 appVersion & userAgent
			var testNode = document.createElement("b");
			testNode.style.cssText = "max-height:1";
			if(testNode.style.cssText.match("max-height")) {browser.version = 6}
		}else if(versionString.match("webkit")) {
			browser.engine = "WebKit";
			browser.version = parseFloat(versionString.split("/")[2]) || dojo.isSafari;
			var versionMatches = versionString.match(/applewebkit\/(\d+)\.(\d+)/);
			browser.webkitversion = {};
			browser.webkitversion.major = parseInt(versionMatches[1]);
			browser.webkitversion.minor = parseInt(versionMatches[2]);
		}else if(versionString.match("gecko")) {
			browser.engine = "Gecko";
			browser.version = dojo.isFx || dojo.isFF || parseFloat(versionString.split("/").pop()) /* handling firefox versions with alternate ua */;
		}else if(versionString.match("khtml")) {
			browser.engine = "KHTML";
		}
	}
	browser.version = browser.version ? browser.version.toString().replace(/\./g, "_") : "";
	(document.documentElement || document.body.parentNode).className += " " + browser.engine + " " + browser.engine + browser.version;
})();

}

if(!dojo._hasResource["epages.event"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.event"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.event");


epages.event.fire = function(/*Object*/DomObject,/*String*/eventType) {
	// summary: Cross browser function to throw events to dom objects.
	// description: Throws an event of the given event type to the given dom object.
	// DomObject: dom node
	// eventType: type of the event. eg. "click" or "mouseover"

		if (epages.Browser.engine == 'MSIE') {
			try {
				DomObject.fireEvent('on'+eventType);
			}catch(e) {}
		} else {
			if(eventType == 'click' ||
				eventType == 'dblclick' ||
				eventType == 'mousedown' ||
				eventType == 'mousemove' ||
				eventType == 'mouseout' ||
				eventType == 'mouseover' ||
				eventType == 'mouseup') { // create mouse events
				var newevt = document.createEvent('MouseEvents');
				newevt.initMouseEvent(eventType, true, true, window, 0, 0, 0, 0, 0, false, false, false, false, 0, null);
			} else  {										// create html events
				var newevt = document.createEvent('HTMLEvents');
				newevt.initEvent(eventType, true, true);
			}
			DomObject.dispatchEvent(newevt);
		}
};

}

if(!dojo._hasResource["epages.string"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.string"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.string");


epages.string = {

	escapeJavaScript: function (str) {
		return str.replace(/(["'\f\b\n\t\r])/gm, "\\$1");
	},

	escapeXml: function (str, noSingleQuotes) {
		str = str.replace(/&/gm, "&amp;").replace(/</gm, "&lt;").replace(/>/gm, "&gt;").replace(/"/gm, "&quot;");
		if (!noSingleQuotes) {
			str = str.replace(/'/gm, "&#39;");
		}
		return str;
	},

	toBoolean: function(/*String*/value) {
		if (value === undefined){
			return false;
		}
		if (typeof value == "boolean"){
			return value;
		}
		if (typeof value != "string"){
			throw new Error("Not a string value, got " + typeof(value) + "!");
		}
		return value.toLowerCase() === "true" || value == '1' ? true : false;
	},

	toInteger: function(/*String*/value,/*Boolean*/removeThousandDelimiter) {
	// summary: parse string to integer, optional remove thousandDelimiter
		if(removeThousandDelimiter) {
			value = value.replace(/\./g,'');
		}
		return parseInt( value.replace(/[^0-9\,\.]/g, "") );
	},

	toTime: function(/*String*/value, /*String*/epagesPattern) {
		if (value == ''){
			return null;
		}
		if (epagesPattern == null || epagesPattern.length == 0){
			epagesPattern = epages.vars.Locale.timeFormat;
		}
		var pattern = epages.localize.getDojoDateTimePattern(epagesPattern);
		var date = dojo.date.locale.parse(value, { selector: 'date', datePattern: pattern, timePattern: '' });
		if (date === null){
			 date = dojo.date.locale.parse(value, { selector: 'date', datePattern: 'HH:mm a', timePattern: '' });
		}
		if (date === null){
			date = dojo.date.locale.parse(value, { selector: 'date', datePattern: 'HH a', timePattern: '' });
		}
		if (date === null){
			date = dojo.date.locale.parse(value, { selector: 'date', datePattern: 'HH', timePattern: '' });
		}
		// allow entries like "24:00" which means "00:00"
		if (date === null) {
			date = dojo.date.locale.parse(value, { selector: 'date', datePattern: 'KK:mm', timePattern: '' });
		}
		if (date === null){
			 date = dojo.date.locale.parse(value, { selector: 'date', datePattern: 'KK', timePattern: '' });
		}
		return date;
	},

	cssSizeToNumber : function(/* string */ value) {
	// summary: convert css size to a number (float or integer)
		if(typeof value == "string") {
			if (value.match(/^(-?[0-9]+)(px|pt)$/i)) {
				var n = parseInt(RegExp.$1);
				return n;
			}

			if (value.match(/^(-?[0-9]*\.?[0-9]+)(pc|%|mm|cm|em|in|ex)$/i)) {
				var n = parseFloat(RegExp.$1);
				return n;
			}

			if (value.match(/^[0]+$/)) {
				return 0;
			}
		}
		return NaN;
	},

	// corrects a bug in IE's String.split, where IE discards all empty elements
	split: function(string, rx) {
		if (epages.Browser.engine != 'MSIE'){
			 return string.split(rx);
		}
		var unique = '';
		do {
			unique += Date.toString();
		} while(string.match(unique));
		string = string.replace(rx, '|' + unique + '|');
		var splits = string.split(unique);
		for( var i=0,iLength=splits.length ; i<iLength ; i++ ) {
			splits[i] = splits[i].replace(/^(?:\|)?(.*?)(?:\|)?$/g, function(tmp, match) { return match; } );
		}
		return splits;
	}
};

epages.string.Base64 = function () {
};

epages.string.Base64.prototype = {
	// private property
	_keyStr : "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=",

	// public method for encoding
	encode : function (input) {
		var output = "";
		var chr1, chr2, chr3, enc1, enc2, enc3, enc4;
		var i = 0;

		input = this._utf8_encode(input);

		if (typeof(window.btoa) == 'function') {
			return window.btoa(input);
		}

		while (i < input.length) {

			chr1 = input.charCodeAt(i++);
			chr2 = input.charCodeAt(i++);
			chr3 = input.charCodeAt(i++);

			enc1 = chr1 >> 2;
			enc2 = ((chr1 & 3) << 4) | (chr2 >> 4);
			enc3 = ((chr2 & 15) << 2) | (chr3 >> 6);
			enc4 = chr3 & 63;

			if (isNaN(chr2)) {
				enc3 = enc4 = 64;
			} else if (isNaN(chr3)) {
				enc4 = 64;
			}

			output = output +
			this._keyStr.charAt(enc1) + this._keyStr.charAt(enc2) +
			this._keyStr.charAt(enc3) + this._keyStr.charAt(enc4);

		}

		return output;
	},

	// public method for decoding
	decode : function (input) {
		var output = "";
		var chr1, chr2, chr3;
		var enc1, enc2, enc3, enc4;
		var i = 0;

		input = input.replace(/[^A-Za-z0-9\+\/\=]/g, "");

		if (typeof(window.atob) == 'function') {
			output = window.atob(input);
		} else {

			while (i < input.length) {

				enc1 = this._keyStr.indexOf(input.charAt(i++));
				enc2 = this._keyStr.indexOf(input.charAt(i++));
				enc3 = this._keyStr.indexOf(input.charAt(i++));
				enc4 = this._keyStr.indexOf(input.charAt(i++));

				chr1 = (enc1 << 2) | (enc2 >> 4);
				chr2 = ((enc2 & 15) << 4) | (enc3 >> 2);
				chr3 = ((enc3 & 3) << 6) | enc4;

				output = output + String.fromCharCode(chr1);

				if (enc3 != 64) {
					output = output + String.fromCharCode(chr2);
				}
				if (enc4 != 64) {
					output = output + String.fromCharCode(chr3);
				}

			}
		}

		output = this._utf8_decode(output);

		return output;

	},

	// private method for UTF-8 encoding
	_utf8_encode : function (string) {
		string = string.replace(/\r\n/g,"\n");
		var utftext = "";

		for (var n = 0,l=string.length; n < l; n++) {

			var c = string.charCodeAt(n);

			if (c < 128) {
				utftext += String.fromCharCode(c);
			}
			else if((c > 127) && (c < 2048)) {
				utftext += String.fromCharCode((c >> 6) | 192);
				utftext += String.fromCharCode((c & 63) | 128);
			}
			else {
				utftext += String.fromCharCode((c >> 12) | 224);
				utftext += String.fromCharCode(((c >> 6) & 63) | 128);
				utftext += String.fromCharCode((c & 63) | 128);
			}

		}

		return utftext;
	},

	// private method for UTF-8 decoding
	_utf8_decode : function (utftext) {
		var string = "";
		var i = 0;
		var c = c1 = c2 = 0;

		while ( i < utftext.length ) {

			c = utftext.charCodeAt(i);

			if (c < 128) {
				string += String.fromCharCode(c);
				i++;
			}
			else if((c > 191) && (c < 224)) {
				c2 = utftext.charCodeAt(i+1);
				string += String.fromCharCode(((c & 31) << 6) | (c2 & 63));
				i += 2;
			}
			else {
				c2 = utftext.charCodeAt(i+1);
				c3 = utftext.charCodeAt(i+2);
				string += String.fromCharCode(((c & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
				i += 3;
			}
		}
		return string;
	}
};

}

if(!dojo._hasResource['epages.lang.array']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.lang.array'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.lang.array');


$A = function (/*Object?*/arrayLike, /*Boolean?*/asCopy) {
	// summary:
	//    returns a new array, same like new epages.lang.Array
	// example:
	//  | hash = $A(['value1', 'value2']);
	//  | // returns epages.lang.Array
	return new epages.lang.Array(arrayLike, asCopy);
};

epages.lang.Array = /*epages.lang.Array*/ function (/*Object?*/arrayLike, /*Boolean?*/asCopy) {
	// summary:
	//    returns a new array
	// example:
	//  | array = epages.lang.Array(['value1', 'value2']);
	//  | // returns epages.lang.Array
	if (asCopy === undefined){
		asCopy = false;
	}
	var results = [];
	if (arrayLike !== undefined) {
		if (arrayLike._data !== undefined) {
			arrayLike = arrayLike._data;
		}
		if (asCopy) {
			for (var i = 0, length = arrayLike.length; i < length; i++){
				results.push(arrayLike[i]);
			}
		} else {
			results = arrayLike;
		}
	}
	this._data  = results;
	this.length = results.length;
};

epages.lang.Array.prototype = {
	_data: undefined,
	length: 0,

	get: function (/*int*/index) {
		return this._data[index];
	},

	set: function (/*int*/index, /*mixed*/value) {
		this._data[index] = value;
	},

	insertAt: function (/*int*/index, /*mixed*/value) {
		if (!index) {
			this.unshift(value);
		} else if (index == this.length) {
			this.push(value);
		} else {
			var c = this._data;
			for(var i=this.length; i > index; i--){
				c[i] = c[i-1];
			}
			c[index] = value;
			this.length = c.length;
		}
	},

	push: function (/*arguments*/) {
		// summary:
		//    adds elements to this array
		// example:
		//  | array = new epages.lang.Array(['value1', 'value2']);
		//  | array.push('value3', 'value4');
		//  | array.push('value5');
		for (var i = 0, length = arguments.length; i < length; i++) {
			this._data.push(arguments[i]);
		}
		this.length = this._data.length;
	},

	pop: function (/*arguments*/) {
		// summary:
		//    pops the last element from this array
		// returns: 
		//    removed element
		// example:
		//  | array = new epages.lang.Array(['value1', 'value2']);
		//  | array.pop();
		//  | //returns 'value2'
		var el = this._data.pop();
		this.length = this._data.length;
		return el;
	},

	unshift: function (/*arguments*/) {
		// summary:
		//    adds elements to this array at the first position
		// example:
		//  | array = new epages.lang.Array(['value1', 'value2']);
		//  | array.unshift('value3', 'value4');
		//  | // returns ['value4', 'value3','value1', 'value2']
		for (var i = 0, length = arguments.length; i < length; i++) {
			this._data.unshift(arguments[i]);
		}
		this.length=this._data.length;
	},

	shift: function () {
		// summary:
		//    removes an elements from the beginning of this array
		// returns: 
		//    removed element
		var el = this._data.shift();
		this.length = this._data.length;
		return el;
	},

	grep: function (/*Function*/callback, /*Object?*/thisObject) {
		// summary:
		//    returns a new Array with those items from arr that match the
		//    condition implemented by callback.thisObject may be used to
		//    scope the call to callback.
		// example:
		//  | array = new epages.lang.Array([1, 2, 3, 4]);
		//  | array2 = array.grep( function(item){ return item>1; });
		//  | // returns [2, 3, 4]
		if (thisObject === undefined){
			return dojo.filter(this._data, callback); // Array
		}
		return dojo.filter(this._data, callback, thisObject); // Array
	},

	map: function (/*Function*/callback, /*Object?*/thisObject) {
		// summary:
		//    returns calls for each item of this Array the given callback function and collect the return values.
		// example:
		//  | array = new epages.lang.Array([1, 2, 3, 4]);
		//  | var newArray = array.map( function(item){ return item + 1; });
		//  | // newArray = [2,3,4,5]
		return dojo.map(this._data, callback, thisObject); //Array
	},

	each: function (/*Function*/callback, /*Object?*/thisObject) {
		// summary:
		//    returns calls for each item of this Array the given callback function.
		// example:
		//  | array = new epages.lang.Array([1, 2, 3, 4]);
		//  | var sum = 0;
		//  | array.each( function(item){ sum += item; });
		//  | // sum = 10
		dojo.map(this._data, callback, thisObject);
		return; //void
	},

	match: function (/*RegExpr*/ pattern) {
		// summary:
		//    returns a new Array with those items from arr that match the
		//    condition (matches with the given pattern).
		// example:
		//  | array = new epages.lang.Array(['Test', 'Array', 'Hash', 'epages']);
		//  | array2 = array.match(/e/);
		//  | // returns ['Test', 'epages']
		var result = [];
		for (var i = 0, length = this._data.length; i < length; i++) {
			var element = this._data[i];
			if (typeof element.match == 'function' && element.match(pattern)){
				result.push(element);
			}
		}
		return result; //Array
	},

	exists: function (/*Object*/element) {
		// summary:
		//    returns true if an item exists in the array,
		//    otherwise false.
		// example:
		//  | array = new epages.lang.Array(['Test', 'Array', 'Hash', 'epages']);
		//  | isElement = array.exists('e');
		//  | // returns false
		return (this.find(element) !== null); //boolean
	},

	find: function (/*Object*/element) {
		// summary:
		//    returns the index of the element, if it exists in the array
		// example:
		//  | array = new epages.lang.Array(['Test', 'Array', 'Hash', 'epages']);
		//  | isElement = array.find('Array');
		//  | // returns 1
		for (var i = 0, length = this._data.length; i < length; i++) {
			if (element === this._data[i]){
				return i; // integer or null
			}
		}
		return null; // integer or null
	},

	remove: function (/*integer*/index) {
		// summary:
		//    removes the element on position >index
		// example:
		//  | array = new epages.lang.Array(['Test', 'Array', 'Hash', 'epages']);
		//  | isElement = array.find('Array');
		//  | // returns 1
		this._data.splice(index, 1);
		this.length = this._data.length;
	},

	unique: function () {
		// summary:
		//    returns an (JS) array containing every element only once
		// example:
		//  | array = new epages.lang.Array(['a', 'b', 'c', 'c']);
		//  | uniqueArray = array.unique();
		//  | // returns ['a', 'b', 'c']
		var uniqueData = new epages.lang.Array();
		var i = 0;
		while (i < this._data.length) {
			if (uniqueData.find(this._data[i]) == null) {
				uniqueData.push(this._data[i]);
				i++;
			} else {
				this._data.splice(i,1);
			}
		}
		this.length = this._data.length;
	},

	equals: function(/*array|epages.lang.array*/compareArray) {
		// summary:
		//    returns true, if the given array contains the same element in the same order
		//    than this array, otherwise false.
		//    the parameter can be either a JS array or a epages.lang.Array.
		// example:
		//  | array = new epages.lang.Array(['a', 'b', 'c']);
		//  | return array.equals(['a', 'b', 'c']);
		//  | // returns true
		if (compareArray.length == this.length) {
			if (typeof compareArray._data != "undefined") {
				// compareArray seems to be a epages.lang.Array
				for( var i=0,iLength=this.length ; i<iLength ; i++ ) {
					if (this._data[i] !== compareArray._data[i]){
						return false;
					}
				}
			} else {
				// compareArray is a JS array
				for( var i=0,iLength=this.length ; i<iLength ; i++ ) {
					if (this._data[i] !== compareArray[i]){
						return false;
					}
				}
			}
			return true; //Boolean
		} else {
			// lengths differ
			return false; //Boolean
		}
	},

	merge: function(/*array|epages.lang.Array*/anotherArray) {
		var c = [];
		if (dojo.isArray(anotherArray)) {
			c = anotherArray;
		} else if(anotherArray._data !== undefined) {
			c = anotherArray._data;
		}
		for( var i=0,iLength=c.length ; i<iLength ; i++ ) {
			this._data.push(c[i]);
		}
		this.length = this._data.length;
	},

	join: function(delimiter) {
		return this._data.join(delimiter);
	},

	toString: function() {
		var a = this.map(function (v) {
			if (v === undefined){
				return 'undefined';
			}else if (v == null){
				return 'null';
			}else if (dojo.isArray(v)){
				return $A(v).toString();
			}else if (dojo.isObject(v)){
				return v.toString();
			}else{
				return '"' + epages.string.escapeJavaScript('' + v) + '"';
			}
		});
		return '[' + a.join(',') + ']';
	},

	sort: function(sortFunc) {
	  return this._data.sort(sortFunc);
	}
};

}

if(!dojo._hasResource['epages.lang.hash']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.lang.hash'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.lang.hash');



$H = function (/*Object*/object) {
	// summary:
	//		returns a new hash, same like new epages.lang.Hash
	// example:
	//	| hash = $H({ key1: 'value1', key2: 'value2'});
	//	| // returns epages.lang.Hash
	return new epages.lang.Hash(object);
};

epages.lang.Hash = /*epages.lang.Hash*/ function (/*Object?*/existingHash) {
	// summary:
	//		returns a new hash, makes a copy of the existing hash
	// example:
	//	|	hash1 = new epages.lang.Hash();
	//	|	// returns an empty epages.lang.Hash
	//	|	hash2 = new epages.lang.Hash({ key1: 'value1', key2: 'value2'});
	// 	|  hash3 = new epages.lang.Hash({
	// 	|		image       : 'test.png',
	// 	|		header      : 'Test',
	// 	|		description : 'long description, long description'
	// 	|	});
	//	|	hash4 = new epages.lang.Hash(hash2);
	//	|	// returns epages.lang.Hash
	this._data = new Object();
	var data = this._data;
	if (existingHash !== undefined) {
		if (typeof existingHash.each == 'function') {
			existingHash.each(function (pair) {
				data[pair.key] = pair.value;
			});
		} else {
			for (var key in existingHash){
				data[key] = existingHash[key];
			}
		}
	}
};

epages.lang.Hash.prototype = {
	_data: undefined,

	data : function () {
		return this._data;
	},

	each : function(iterator) {
		for (var key in this._data) {
			var value = this._data[key];
			var pair = [key, value];
			pair.key = key;
			pair.value = value;
			iterator(pair);
		}
	},

	flatten: function() {
		// summary:
		//		returns xml representation of this hash
		// example:
		// 	|  var hash = new epages.lang.Hash({
		// 	|		image       : 'test.png',
		// 	|		header      : 'Test'
		// 	|	});
		//	|	string = hash.flatten();
		//	|	// returns
		//	|	// <epages.lang.Hash>
		//	|	//  <element><key>image</key><value>test.png</value></element>
		//	|	//  <element><key>header</key><value>Test</value></element>
		//	|	// </epages.lang.Hash>
		var returnvalue = '';
		this.each( function(pair) {
			returnvalue += '<element><key>' + pair.key + '</key><value>' + pair.value + '</value></element>\n';
		});
		return '<epages.lang.Hash>\n' + returnvalue + '</epages.lang.Hash>\n'; //String
	},

	keys: function() {
		// summary:
		//		returns all keys of this hash
		// example:
		// 	|  var hash = new epages.lang.Hash({
		// 	|		image       : 'test.png',
		// 	|		header      : 'Test',
		// 	|		description : 'long description, long description'
		// 	|	});
		//	|	array = hash.keys();
		//	|	// returns ['image','header','description']
		var returnvalue = [];
		this.each( function(pair) {
			returnvalue.push(pair.key);
		});
		return returnvalue; //Array
	},

	values: function() {
		// summary:
		//		returns all values of this hash
		// example:
		// 	|  var hash = new epages.lang.Hash({
		// 	|		image       : 'test.png',
		// 	|		header      : 'Test',
		// 	|		description : 'long description, long description'
		// 	|	});
		//	|	array = hash.keys();
		//	|	// returns ['test.png','Test','long description, long description']
		var returnvalue = [];
		this.each( function(pair) {
			returnvalue.push(pair.value);
		});
		return returnvalue; //Array
	},

	set: function(/*String*/key, /*Object*/value) {
		// summary:
		//		adds a new element to the hash
		// example:
		// 	|  var hash = new epages.lang.Hash({
		// 	|		image       : 'test.png',
		// 	|		description : 'long description, long description'
		// 	|	});
		//	|	hash.set('header','Test');
		//	|	// same as
		// 	|  var hash2 = new epages.lang.Hash({
		// 	|		image       : 'test.png',
		// 	|		description : 'long description, long description',
		// 	|		header      : 'Test'
		// 	|	});
		this._data[key] = value;
	},

	get: function(/*String*/key) {
		// summary:
		//		returns the value of an specified element
		// example:
		// 	|  var hash = new epages.lang.Hash({
		// 	|		image       : 'test.png',
		// 	|		description : 'long description, long description'
		// 	|	});
		//	|	string = hash.get('image');
		//	|	// returns 'test.png'
		return this._data[key];
	},

	remove: function(/*String*/key) {
		// summary:
		//		removes the node with the given key
		// example:
		// 	|  var hash = new epages.lang.Hash({
		// 	|		image       : 'test.png',
		// 	|		description : 'long description, long description'
		// 	|	});
		//	|	bool = hash.remove('image');
		//	|	// returns true
		delete this._data[key];
	},

	existsKey: function(/*String*/key) {
		// summary:
		//		determines, if the given key exists
		// example:
		// 	|  var hash = new epages.lang.Hash({
		// 	|		image       : 'test.png',
		// 	|		description : 'long description, long description'
		// 	|	});
		//	|	bool = hash.existsKey('image');
		//	|	// returns true
		if(this._data[key] !== undefined){
			return true; //Boolean
		}
		// possible key exists but is undefined
		for (var existingKey in this._data) {
			if (existingKey == key){
				return true; //Boolean
			}
		}
		return false; //Boolean
	},

	existsValue: function(/*Object*/value) {
		// summary:
		//		returns, if the given value exists
		// example:
		// 	|  var hash = new epages.lang.Hash({
		// 	|		image       : 'test.png',
		// 	|		description : 'long description, long description'
		// 	|	});
		//	|	bool = hash.existsValue('test.png');
		//	|	// returns true
		return this.find(value) !== undefined;
	},

	find: function(/*Object*/value) {
		// summary:
		//		returns the key to the given value or undefined, when not found
		// example:
		// 	|  var hash = new epages.lang.Hash({
		// 	|		a: 'aa',
		// 	|		b: 'bb'
		// 	|	});
		//	|	bool = hash.find('aa');
		//	|	// returns 'a'
		for (var key in this._data) {
			if (this._data[key] === value){
				return key; //String
			}
		}
		return undefined; //undefined
	},

	toQueryString: function () {
		// summary:
		//		returns uri query string for a hash
		// example:
		//  | var hash = new epages.lang.Hash({ 'schluessel': 'value', 'enc&Schluessel':'enc&Value'});
		//	| var string = hash.toQueryString();
		//	| // returns 'schluessel=value&enc%26Schluessel=enc%26Value'
		var returnvalue = [];
		this.each( function(pair) {
			if (pair.value !== undefined && pair.value != null) {
				var encKey = encodeURIComponent(pair.key);
				if (dojo.isArray(pair.value)) {
					for( var i=0,iLength=pair.value.length ; i<iLength ; i++ ) {
						returnvalue.push(encKey + '=' + encodeURIComponent(pair.value[i]));
					}
				} else {
					returnvalue.push(encKey + '=' + encodeURIComponent(pair.value));
				}
			}
		});
		return returnvalue.join('&'); //String
	},

	toString: function () {
		// summary:
		//		returns uri query string for a hash
		// example:
		//  | var hash = new epages.lang.Hash({ 'schluessel': 'value', 'enc&Schluessel':'enc&Value'});
		//	| var string = hash.toQueryString();
		//	| // returns 'schluessel=value&enc%26Schluessel=enc%26Value'
		var returnvalue = [];
		this.each( function(pair) {
			var v = pair.value;
			if (v === undefined){
				v = 'undefined';
			}else if (v === null){
				v = 'null';
			}else if (dojo.isArrayLike(v)){
				v = $A(v).toString();
			}else if (dojo.isObject(v)){
				v = v.toString();
			}else{
				v = '"' + epages.string.escapeJavaScript('' + v) + '"';
			}

			returnvalue.push('"' + epages.string.escapeJavaScript(pair.key) + '":' + v);
		});
		return '{' + returnvalue.join(',') + '}'; //String
	}
};

}

if(!dojo._hasResource["epages.widget"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/

dojo.provide("epages.widget");



 // load all on one



//dojo.require('epages.profile'); // use this to measure time for creating widgets

epages.topDojo.publish('epages/addGlobalSymbol', ['$$', window]);

if (window.restrictedParent || $$ === undefined) {
	$$ = function(widgetId) {
		for( var i=0,iLength=epages._windows.length ; i<iLength ; i++ ) {
			if (epages._windows[i].dijit != null && typeof epages._windows[i].dijit.byId == "function") {
				var widget = epages._windows[i].dijit.byId(widgetId);
				if (widget){
					return widget;
				}
			}
		}
	};
}

epages.widget.parserClasses = $H();
/*dojo.parser.instantiateOrg = dojo.parser.instantiate;
dojo.parser.instantiate = function(nodes) {
	var w = epages.widget.parserClasses;
	if(epages.Browser.engine != "Presto") {
		var d = dojo;
		d.forEach(nodes, function(node){
			if(!node){ return; }
			var type = node.getAttribute("dojoType");
			if((!type)||(!type.length)||w.existsKey(type)){ return; }
			w.set(type,1);
			if (!dojo.isFunction(dojo.getObject(type))) {
				console.warn('add this to you script: dojo.%s("%s");', 'require', type);
				d.require(type);
			}
		});
	}
	return this.instantiateOrg(nodes);
};*/

dojo.declare("epages.widget.Popup",
	[dijit._Widget],
	{
		parent: '',					// the button etc. that is displaying this popup
		around: '',					// DOM node (typically a button); place popup relative to this node.
		hideOnBlur: false,	// flag - hide popup on blur
		o: {orient: {'BR':'TR','BL':'TL'}},	// orientation parameters
		_visible:   false,	// current visibility status of popup

		show: function() {
			// summary: show popup
			var h = {
				popup: this,
				parent: this.parent,
				around: this.around
			};

			dojo.mixin(h,this.o);
			dijit.popup.open(h);
			this._visible=true;
			dijit.focus(this.domNode);
			if(epages.zIndex) {
				this.domNode.parentNode.style.zIndex=epages.zIndex;	// set z-index of wrapper div
				epages.zIndex+=1;
			}
		},

		hide: function() {
			// summary: hide popup
			dijit.popup.close(this);
		},

		toggle: function () {
			// summary: toggle visibility of popup
			if (this._visible) {
				this.hide();
			} else {
				this.show();
			}
		},

		onClose: function () {
			// summary: event function close popup
			this._visible=false;
		},

		_onBlur: function () {
			// summary: blur event function
			if (this.hideOnBlur){
				this.hide();
			}
		}
	}
);

// register window for global widget registry
epages.onIframeStart.push(function() {
	dijit.registerWin(window);
});

//remove comment if you want to measure widget creating time
/*
dijit._Widget.prototype.create_profile = dijit._Widget.prototype.create;
dijit._Widget.prototype.create = function(){
	var me = this;
	var args = arguments;
	epages.profile.takeStatistik(me.declaredClass,function(){
		me.create_profile.apply(me,args);
	});
};

window.setTimeout(function(){
	epages.profile.showStatistik();
},25000);
*/


}

if(!dojo._hasResource["epages.widget.TypedWidget"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.TypedWidget"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.widget.TypedWidget");




dojo.declare("epages.widget.TypedWidget", [dijit._Widget, dijit._Templated], {
	// summary : Base class for all widgets which can select template via templateType
	_templateDirectory: undefined,
	postMixInProperties: function() {
		this.inherited("postMixInProperties", arguments);
		if (this._templateMapping !== undefined &&  this.templateType !== undefined &&  this._templateDirectory !== undefined) {
			if(this._templateMapping[this.templateType]!==undefined) {
				// check if set to widget's default using its prototype value
				if(this.templateType != this.defaultTemplateType) {
					var tempPath = '';

					// load templates from json object..
					if(typeof this._templateMapping[this.templateType] == 'object'){
						var TempObj = this._templateMapping[this.templateType];

						// ..from shrinksafed packages
						if(TempObj.templateString){
								this.templatePath   = null;
								this.templateString = TempObj.templateString;
						}

						// ..from sources
						else if(TempObj.templatePath){
							var TempTemplateString;
							dojo.xhrGet({
								url: TempObj.templatePath,
								sync: true,
								load: function(data){
									TempTemplateString = data;
								}
							});
							this.templatePath   = null;
							this.templateString = TempTemplateString;
						} else {
								console.warn('Template type: "'+ this.templateType +'" could not be loaded from json object! Use properties templatePath or templateString to declare its template file!');
						}
					}

					// backward compatibility mode: load templates from old non object format
					else {
							tempPath = this._templateDirectory;
							tempPath.path       += '/'+this._templateMapping[this.templateType];
							tempPath.uri        += '/'+this._templateMapping[this.templateType];
							this.templatePath   = tempPath;
							this.templateString = null;
					}
				}
			} else {
				console.warn('Template type: "'+ this.templateType +'" does not exist in this widget - use default. ('+this.declaredClass+')');
			}
		}
	}

});


}

if(!dojo._hasResource['epages.io.xml']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.io.xml'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.io.xml');

epages.io.Xml = function () {}

epages.io.Xml.prototype = {

	loadSync: function (/*String*/url, /*object?*/formData) {
		// summary:
		//		returns a xml document, which was loaded via http from given url.
		// 		additional parameters will be added in the post.
		// example:
		//	|	xmlLoader = new epages.io.Xml();
		//	|	xmlDoc = xmlLoader.loadSync('http://www.mydomain.de/test.xml', { filename: "test.xml" });
		//	|	// returns XMLDocument object
		var returnData;

		// no parameters => GET
		var requestMethod = formData !== undefined ? dojo.xhrPost : dojo.xhrGet;
		requestMethod({
			url: 					url,
			handleAs:			"xml",
			sync:					true,
			preventCache: epages.constants.preventCache,
			load: 				function(data){
											returnData = data;
										},
			content:			formData
		});
		return returnData; // XMLDocument
	},

	loadAsync: function (/*String*/url, /*Function*/callback, /*object?*/formData) {
		// summary:
		//		returns a xml document, which was loaded via http from given url.
		// 		additional parameters will be added in the post.
		// example:
		//	|	xmlLoader = new epages.io.Xml();
		//	|	xmlDoc = xmlLoader.loadSync('http://www.mydomain.de/test.xml', { filename: "test.xml" });
		//	|	// returns XMLDocument object
		var requestMethod = formData !== undefined ? dojo.xhrPost : dojo.xhrGet;
		requestMethod({
			url: 					url,
			handleAs:			"xml",
			preventCache: epages.constants.preventCache,
			load: 				callback,
			content:			formData
		});
		return;
	}
}

}

if(!dojo._hasResource['epages.io.translation']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.io.translation'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.io.translation');




epages.io.Translation = function (/*String?*/ url, /*String?*/ locale) {
		this.translation = new epages.lang.Hash();
		this.loadedFiles = new epages.lang.Array();
		if( url !== undefined){
			if(locale===undefined){
				this.load(url);
			}else{
				this.loadLocale(url, (locale!="auto") ? locale : undefined);
			}
		}
};

dojo.extend(epages.io.Translation, epages.io.Xml.prototype);
dojo.extend(epages.io.Translation, {
	translation: null,
	loadedFiles: null,
	useLocale:	false,

	load: function (/*String*/ url, /*Boolean?*/ skipError) {
		if (this.loadedFiles.exists(url)){
			return true; // Boolean
		}
		if (skipError === undefined){
			skipError = false;
		}
		var urlData = this.loadSync(url);
		this.loadedFiles.push(url);
		if (urlData === undefined) {
			if (! skipError){
				throw new Error('translation undefined');
			}
			return false; //Boolean
		}
		var tags = urlData.getElementsByTagName('Translation');
		for( var i=0,iLength=tags.length ; i<iLength ; i++ ) {
			var thisElement = tags[i];
			// is translation
			if (thisElement.nodeType == 1) {
				// ignore <notrans>
				var data = '';
				for( var j=0,jLength=thisElement.childNodes.length ; j<jLength ; j++ ) {
					var child = thisElement.childNodes[j];
					data += child.nodeName.match(/notrans/i) ? child.firstChild.data : child.data;
				}
				this.translation.set(thisElement.getAttribute('Keyword'), data);
			}
		}
		return true; //Boolean
	},

	loadLocale: function (/*String*/ url, /*String?*/ locale) {
    // summary: load translation data (of language and locale), the locale will be trans
		// url: file name without locale and extension (.xml)
		// locale: locale string (RFC 3066; eg en-us)
		if (locale === undefined){
			locale = dojo.locale;
		}

		var locParts = locale.split('-');
		var loadLanguage = this.load(url + '.' + locParts[0] + '.xml', true);
		// load locale dependend translation, later
		if (this.useLocale && locParts.length > 1){
		  this.load(url + '.' + locParts[0] + '_' + locParts[1].toUpperCase() + '.xml', true);
		}
		return loadLanguage; //Boolean
	},

	exists: function (/*String*/key) {
		return this.translation.existsKey(key) || (this != epages.io.dictionary && epages.io.dictionary.translation.existsKey(key));
	},

	get: function (/*String*/ key, /*Object?*/vars) {
		// summary:
		//		returns the value of an specified language tag.
		//		returns {key} if the language tag doesnt exist.
		// example:
		//   | var translation = new epages.io.Translation();
		//   | translation.load('translation.de.xml');
		//   |   image       : 'test.png',
		//   |   description : 'long description, long description'
		//   | });
		//   | string = translation.get('Image');
		//   | // returns 'Bild'
		var locName = this.translation.get(key);
		if(locName === undefined && this != epages.io.dictionary){
			return epages.io.dictionary.get(key, vars);
		}
		return (locName === undefined) ? '{' + key + '}' : this.replaceVars(locName, vars); // String
	},

	replaceLanguageTags: function (/*String*/ txt) {
		// summary:
		//		replace all language tags in a string
		//		returns the "translated" string
		// example:
		// 	  var translation = new epages.io.Translation(translation.de.xml');
		// 		var mystring = "<div>{Image}</div>";
		// 		mystring=this.Translation.replaceLanguageTags(mystring);
		var templateRegExp = new RegExp('{(.*?)}', 'g');
		return txt.replace( templateRegExp, dojo.hitch(this, function(match, tag) {
			return this.get(tag);
		})); // String
	},

	replaceVars: function(/*String*/ txt, /*Object?*/ vars) {
	  var varsRegExp = new RegExp('#([a-zA-Z_][a-zA-Z0-9_]*)', 'g');
		return txt.replace( varsRegExp, dojo.hitch(vars, function(match, varName) {
		  return this[varName] !== undefined ? this[varName] : match;
		})); // String
	}

});

epages.io.dictionary = new epages.io.Translation(dojo.moduleUrl('epages', "translation"),"auto");

}

if(!dojo._hasResource["epages.html"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.html"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.html");


dojo.mixin(epages.html, {
	getChildNodesByTagName: function(/*XMLNode*/parentNode, /*String*/childTagName) {
		// summary:
		//  Returns an array of direct children matching the childTagName tag name.
		// description:
		//  Only direct children will be returned, so this differs from getElementsByTagName().
		// example:
		//  |/*
		//  |<ul>
		//  |  <li>node 1</li>
		//  |  <li>node 2</li>
		//  |</ul>
		//  |*/
		//  |listItems = epages.com.getChildNodesByTagName(listNode, "li");
		//  |// listItems has now two children
		var returnValue = [];
		for( var i=0,iLength=parentNode.childNodes.length ; i<iLength ; i++ ) {
			var e = parentNode.childNodes[i];
			if (e.nodeName == childTagName) {
				returnValue.push(e);
			}
		}
		return returnValue; // Array
	},

	getElementsByClassName: function (/*String*/className, /*DomNode*/domNode) {
		if(domNode == null){
			domNode = dojo.body();
		}
		return dojo.query("." + className, domNode);
	},

	replaceClass: function(/*DomNode|String*/node, /*String*/newClassStr, /*String*/ oldClassStr) {
	  var regEx = new RegExp("(^|\\s+)" + oldClassStr + "($|\\s+)", "g");
	  node.className = node.className.replace(regEx, "$1" + newClassStr + "$2");
	},

	removeChildren: function(/*DomNode|String*/node) {
		while(node.firstChild){ node.removeChild(node.firstChild); }
	},

	disableHrefsAndActions: function (/* DomNode */containerNode) {
		if(containerNode == null){
			containerNode = dojo.body();
		}

		// disable links
		var aTags = containerNode.getElementsByTagName('a');
		for( var i=0,iLength=aTags.length ; i<iLength ; i++ ) {
			var tag = aTags[i];
			if(tag.getAttribute("data-ep-preview") == "show") {break;}
			tag.style.cursor='default';
			if(typeof tag.getAttribute("onclick")=="string" && (tag.getAttribute("onclick") || "").match("openWindow")) {
				tag.onclick = function(){ return false; };
			}
			dojo.connect(tag, "onclick", function(evt) {
				dojo.stopEvent(evt);
				return;
			});
			// change href
			if(tag.getAttribute("href")){
				tag.removeAttribute("href");
			}
			// change target
			if(tag.getAttribute("target")){
				tag.removeAttribute("target");
			}
		}
		// disable all forms
		var formTags = containerNode.getElementsByTagName('form');
		for( var i=0,iLength=formTags.length ; i<iLength ; i++ ) {
			formTags[i].onsubmit = function() { return false; };
		}
		// disable all form elements
		var elementList = ['input', 'button', 'select', 'option', 'a'];
		var deleteAttributes = ['onchange','onclick','onselect','onkeyup','onkeypress','onmouseup'];
		for( var j=0,jLength=elementList.length ; j<jLength ; j++ ) {
			var inputTags = containerNode.getElementsByTagName(elementList[j]);
			for( var i=0,iLength=inputTags.length ; i<iLength ; i++ ) {
				var e = inputTags[i];
				if(e.getAttribute("data-ep-preview") == "show") {break;}
				//if (e.type == 'submit') e.type = 'button';
				for( var k=0,kLength=deleteAttributes.length ; k<kLength ; k++ ) {
					var attrib = e.getAttribute(deleteAttributes[k]);

					if(attrib) {
						if((typeof attrib == "string") || (typeof attrib == "function")) {
							dojo.connect(e, deleteAttributes[k], dojo, "stopEvent");
							e.setAttribute(deleteAttributes[k], 'return false;');
						}
					}
				}
			}
		}
	},

	getHref: function (/* DomNode<a>*/linkNode) {
		// returns: real (not transformed absolutely) href content of an A-tag-domNode
		if (linkNode.outerHTML) {
			// IE
			var html = linkNode.outerHTML;
			var href = html.match(/\s*href\s*\=\s*["'](.*?)["']/i);
			if(href && href[1]){
				return href[1];
			}
			return null;
		}
		// others
		return linkNode.getAttribute("href");
	},

	isInnerEvent: function(/* Event */evt, /* DOMNode | array.DOMNode */allowedNodes) {
		// summary: usefull for blur events, that could be triggered by clicking on another dom node
		// returns: whether the given event happened outside of the allowed nodes
		if (!dojo.isArray(allowedNodes)){
			allowedNodes = [ allowedNodes ];
		}
		var target = evt.explicitOriginalTarget;
		for( var i=0,iLength=allowedNodes.length ; i<iLength ; i++ ) {
			if (dojo.isDescendant(target, allowedNodes[i])){
				return true;
			}
		}
		return false;
	},

	encodeEntity: function(string, fixBreaks) {
		if (fixBreaks == null){
			fixBreaks = false;
		}
		var rx = new RegExp("\r?\n", "g");
		var lines = epages.string.split(string, rx);
		var textnode = document.createTextNode('');
		var node = document.createElement('span');
		node.appendChild(textnode);
		for( var i=0,iLength=lines.length ; i<iLength ; i++ ) {
			textnode.nodeValue = lines[i];
			lines[i] = node.innerHTML;
		}
		return lines.join(fixBreaks ? "<br/>\n" : "\n");
	},

	decodeEntity: function(string, fixBreaks) {
		if (fixBreaks == null){
			fixBreaks = false;
		}
		var node = document.createElement('span');
		node.innerHTML = string;
		var value = node.firstChild.nodeValue;
		if (fixBreaks){
			value = value.replace(/\<br\s*\/?\>\r?\n/gi, "\n");
		}
		return value;
	},

	insertAtCursor: function(myValue, fieldId, doc) {
		if (doc === undefined){
			doc = window.document;
		}
		var myField = $(fieldId, doc);
		//IE support
		if (doc.selection) {
			myField.focus();
			sel = doc.selection.createRange();
			sel.text = myValue;
		}
		//MOZILLA/NETSCAPE support
		else if (myField.selectionStart || myField.selectionStart == '0') {
			var startPos = myField.selectionStart;
			var endPos = myField.selectionEnd;
			myField.value = myField.value.substring(0, startPos)
				+ myValue
				+ myField.value.substring(endPos, myField.value.length);
			myField.selectionStart = startPos + myValue.length;
			myField.selectionEnd = startPos + myValue.length;
		} else {
			myField.value += myValue;
		}
		
		epages.event.fire(myField,'change');
	}
});


}

if(!dojo._hasResource['epages.html.element']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.html.element'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.html.element');



epages.html.Element = function (object) {
	//summary: epages.html.Element extends standard object with missing functions
	if (object === undefined) {
		throw new Error("epages.html.Element: initialize without object");
	} else if (typeof object == "string") {
		object = $(object);
		if (object === undefined){
			throw new Error("epages.html.Element: initialize without object, unknown element id");
		}
	}
	this.object = object;
};

dojo.extend(epages.html.Element, {
	object: undefined,

	get: function () {
		//summary: getter function for value of element with special treatment for radiobox & checkbox
		if((dojo.hasClass(this.object,"Radio")|| dojo.hasClass(this.object,"Checkbox"))  && !this.object.checked){
			return '';
		}
		return this.object.value || '';
	},

	set: function(value) {
		//summary: setter function for value of element with speacial treatment for radiobox & checkbox
		var type = this.object.type;
		switch (type) {
			case 'checkbox':
				this.object.value = value;
				if(value){
					this.object.checked = true;
				}
				else{
					this.object.checked = false;
				}
			case 'radio':
				if(this.object.form){
					var items = this.object.form.elements;
					var name = this.object.name;
					dojo.forEach(items, function(object) {
						if (object.type == type && object.name == name && object.value == value){
						object.checked = true;
						}
					});
				}
				break;
			default:
				this.object.value = value;
				break;
		}
	},

	connectChangeEvent: function (callback) {
		//summary: connect onchange event to element but in case of element is radio use click event
		dojo.connect(this.object, (this.object.type == 'radio' ? "onclick" : "onchange"), callback);
	},

	callOnChange: function () {
		//summary: fire onchange event for the element
		epages.event.fire(this.object,'change');
	},

	firstElement: function (nodeType, nodeName) {
		var element = undefined;
		var data = this.object.childNodes;
		for(var counter = 0,l=data.length; counter < l && element === undefined; counter++) {
			// find element, if nodeType == 1 then nodeName has to be equal
			if (nodeType != 1               && data[counter].nodeType == nodeType ||
					data[counter].nodeType == 1 && data[counter].nodeName == nodeName) {
				element = data[counter];
			}
		}
		return (element);
	},

	firstComment: function () {
		var commentElement = this.firstElement(8, 'COMMENT');
		return (commentElement === undefined ? undefined : commentElement.data);
	},

	getIframeDocument: function (iframe) {
		if (iframe === undefined && this.object.tagName.toLowerCase() == 'iframe'){
			 iframe = this.object;
		}
		if (iframe === undefined){
			return iframe;
		}
		return (iframe.contentDocument === undefined) ? iframe.contentWindow.document : iframe.contentDocument;
	},

	addClassName: function (/*string*/className) {
		dojo.addClass(this.object, className);
	},

	removeClassName: function (/*string*/className) {
		dojo.removeClass(this.object, className);
	},

	changeClassName: function (/*string*/fromClassName, /*string*/toClassName) {
	  epages.html.replaceClass(this.object, toClassName, fromClassName);
	},

	getAbsolutePosition: function(baseNode) {
	// summary: get absolute position to base node
		var doc = this.object.documentOwner || document,
			ret = dojo.coords(this.object);
		if( baseNode ){
			var base = dojo.coords(baseNode);
			ret.x -= base.x;
			ret.y -= base.y;
		}

		// EPG-18400
		//if(epages.Browser.engine != "WebKit"){
			ret.x += doc.body.scrollLeft;
			ret.y += doc.body.scrollTop;
		//}
		return ret;
	},

	getPositionToParent: function(parentNode) {
		// summary: calcualte position to the specified parent node
		// parentNode: should be an offsetParent (position: absolute or relative)
		var node = this.object;
		var x = 0, y = 0;
		var position = dojo.getComputedStyle(parentNode).position;
		if(position != "relative" && position != "absolute") {
			console.warn("parentNode should be an offsetParent (position: absolute or relative) in "+ this.delcaredClass);
		}
		var lastOffsetParent = undefined;
		while (node != undefined && parentNode !== node) {
			if(lastOffsetParent !== node.offsetParent) {			// skip offset values which are already added (jump from offsetparent to offsetparent)
				if (node.offsetLeft !== undefined && node.offsetTop !== undefined) {
					x += node.offsetLeft;
					y += node.offsetTop;
				}
				lastOffsetParent = node.offsetParent;
			}
			node = node.parentNode;
		}
		return {'x': x, 'y': y};
	},

	getRelativePosition: function() {
		// summary: calcualte position to the next parentnode with position relative|absolute
		var node = this.object;
		var x = 0, y = 0;
		var position = dojo.getComputedStyle(node).position;
		while (node != undefined && position != "relative" && position != "absolute") {
			if (node.offsetLeft !== undefined && node.offsetTop !== undefined) {
				x += node.offsetLeft;
				y += node.offsetTop;
			}
			node = node.offsetParent;
			position = dojo.getComputedStyle(node).position;
		}
		return {'x': x, 'y': y};
	},

	setCss: function(/*Object*/attributes) {
		for (var attributeName in attributes) {
			this.object.style[attributeName] = attributes[attributeName];
		}
	},

	makeWidgets: function() {
		dojo.parser.parse(this.object);
	},

	toQueryString: function() {
		return encodeURIComponent(this.object.name) + '=' + encodeURIComponent(this.get());
	},

	addEventListener: function(/*String*/eventName, /*function*/callBack, /*boolean?false*/bubbleUp) {
		// summary: cross-browser implementation of node.addEventListener from Mozilla
		if (bubbleUp == null){
			bubbleUp = false;
		}
		eventName = eventName.replace(/^on/, '');
		if (this.object.addEventListener) {
			return this.object.addEventListener(eventName, callBack, bubbleUp);
		} else if(this.object.attachEvent) {
			return this.object.attachEvent('on' + eventName, callBack);
		}
		throw new Error('element.addEventListener: could not add event listener for event ' + eventName);
	},

	removeEventListener: function(/*String*/eventName, /*function*/callBack, /*boolean?false*/bubbleUp) {
		//summary: cross-browser implementation of node.removeEventListener from Mozilla
		if (bubbleUp == null){
			bubbleUp = false;
		}
		eventName = eventName.replace(/^on/, '');
		if (this.object.removeEventListener) {
			return this.object.removeEventListener(eventName, callBack, bubbleUp);
		} else if(this.object.detachEvent) {
			return this.object.detachEvent('on' + eventName, callBack);
		}
		console.warn('element.removeEventListener: could not remove event listener for event ' + eventName + (typeof this.object.detachEvent));
		return false;
	},

	replaceChild: function(newNode, oldNode) {
		newNode = this._changeNodeDocument(newNode, oldNode.ownerDocument);
		this.object.replaceChild(newNode, oldNode);
	},

	appendChild: function(childNode) {
		childNode = this._changeNodeDocument(childNode, this.object.ownerDocument);
		this.object.appendChild(childNode);
	},

	_changeNodeDocument: function(node, newDoc) {
		// summary: in IE you can not insert a node in a document, that has been created in another document
		// so we simply clone the node in correct document by inserting its outer HTML
		if (node.ownerDocument != newDoc && node.outerHTML != null) {
			var nodeHtml = node.outerHTML;
			node = newDoc.createElement('span');
			node.outerHTML = nodeHtml;
		}
		return node;
	},


	getLabel: function() {
		// summary: this.object needs an id and there has to exist a label node for this id
		// returns: assigned label for this node
		var id = this.object.id;
		if (id == null){
			 return;
		}
		var labels = this.object.ownerDocument.getElementsByTagName('label');
		for( var i=0,iLength=labels.length ; i<iLength ; i++ ) {
			if (labels[i].htmlFor == id){
				return labels[i].innerHTML;
			}
		}
	},

	isEmpty: function(){
		//summary: check if object has methodes or properties assigned
		for(var el in this.object){
			return false;
		}
		return true;
	}
});

$E = function (/*Object*/object) {
	return new epages.html.Element(object); // epages.html.Element
};

}

if(!dojo._hasResource["epages.widget.LocalizedWidget"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.LocalizedWidget"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.widget.LocalizedWidget");





dojo.declare("epages.widget.LocalizedWidget", [epages.widget.TypedWidget], {
	// summary:Base class for all widgets which use an additional translation file
	
	// all LocalizedWidgets share the same translation object
	translation: 			new epages.io.Translation(),
	translationName: 	null,

	constructor: function() {
		this.translation.loadLocale(this.getTranslationName());
	},

	translate: function(/*String*/key, /*Object?*/vars) {
		return this.translation.get(key, vars);
	},

	getTranslationName: function () {
		// summary: return the translation file name (without locale and .xml)
		// description: convert this.templatePath to this.translationName of translation name is null
		// example:
		//   | dojo.declare(
		//   |   "epages.cartridges.de_epages.design.Toolcollection",
		//   |   [epages.widget.LocalizedWidget], {
		//   |     widgetType  : "Toolcollection",
		//   |     templatePath: dojo.uri.dojoUri("../epages/cartridges/de_epages/design/widget/Toolcollection/Toolcollection.html"),
		//   |     translationName: dojo.uri.dojoUri("../epages/cartridges/de_epages/design/widget/templates/translation"),
		//   |     widgetsInTemplate : true
		//   | });
		// returns: translationName
		if (this.translationName == null){
			this.translationName = this.templatePath.toString().replace('.html','');
		}
		return this.translationName; //String
	},

	createNodesFromText:  function(/*String*/text){
		return dojo._toDom(this.translation.replaceLanguageTags(text));
	},


	buildRendering: function(){
		// summary:
		//    Construct the UI for this widget from a template, setting this.domNode.
    // description: 
		//    Lookup cached version of template, and download to cache if it
		//    isn't there already.  Returns either a DomNode or a string, depending on
		//    whether or not the template contains ${foo} replacement parameters.
		this._attachPoints = [];
		var cached = this.getCachedTemplate(this.templatePath, this.templateString, this._skipNodeCache, this.translation);


		var node;
		if(dojo.isString(cached)){
//##### START of epages changes #####
			var className = this.declaredClass, _this = this;
			// Cache contains a string because we need to do property replacement
			// do the property replacement
			var tstr = dojo.string.substitute(cached, this, function(value, key){
				if(key.charAt(0) == '!'){ value = _this[key.substr(1)]; }
				if(typeof value == "undefined"){ throw new Error(className+" template:"+key); } // a debugging aide
				if(!value){ return ""; }

				// Substitution keys beginning with ! will skip the transform step,
				// in case a user wishes to insert unescaped markup, e.g. ${!foo}
				return key.charAt(0) == "!" ? value :
					// Safer substitution, see heading "Attribute values" in
					// http://www.w3.org/TR/REC-html40/appendix/notes.html#h-B.3.2
					value.toString().replace(/"/g,"&quot;"); //TODO: add &amp? use encodeXML method?
			}, this);
			node = this.createNodesFromText(tstr);

//##### END of epages changes #####
		}else{
			// if it's a node, all we have to do is clone it
			node = cached.cloneNode(true);
		}

		this.domNode = node;

		// recurse through the node, looking for, and attaching to, our
		// attachment points which should be defined on the template node.
		this._attachTemplateNodes(node);

				if(this.widgetsInTemplate){
				// Make sure dojoType is used for parsing widgets in template.
				// The dojo.parser.query could be changed from multiversion support.
				var parser = dojo.parser, qry, attr;
				if(parser._query != "[dojoType]"){
					qry = parser._query;
					attr = parser._attrName;
					parser._query = "[dojoType]";
					parser._attrName = "dojoType";
				}

				// Store widgets that we need to start at a later point in time
				var cw = (this._startupWidgets = dojo.parser.parse(node, {
					noStart: !this._earlyTemplatedStartup
				}));

				// Restore the query.
				if(qry){
					parser._query = qry;
					parser._attrName = attr;
				}

				this._supportingWidgets = dijit.findWidgets(node);

				this._attachTemplateNodes(cw, function(n,p){
					return n[p];
				});
			}

		this._fillContent(this.srcNodeRef);
	},

	getCachedTemplate: function(templatePath, templateString, alwaysUseString, translation){
		// summary:
		//    static method to get a template based on the templatePath or
		//    templateString key
		// templatePath: String
		//    the URL to get the template from. dojo.uri.Uri is often passed as well.
		// templateString: String?
		//    a string to use in lieu of fetching the template from a URL
		// returns:
		//  Either string (if there are ${} variables that need to be replaced) or just
		//  a DOM tree (if the node can be cloned directly)

		// is it already cached?
		var tmplts = dijit._Templated._templateCache;
		var key = templateString || templatePath;
		var cached = tmplts[key];
		if(cached){
			return cached;
		}

		// If necessary, load template string from template path
		if(!templateString){
			templateString =dojo.cache(templatePath, {sanitize: true});
		}

		templateString = dojo.string.trim(templateString);
		if(templateString.match(/\$\{([^\}]+)\}/g) || alwaysUseString){
			// there are variables in the template so all we can do is cache the string
			return (tmplts[key] = templateString); //String
		}else{
			// there are no variables in the template so we can cache the DOM tree
			return (tmplts[key] = this.createNodesFromText(templateString)); //Node
		}
	}

});

}

if(!dojo._hasResource["epages.event.interval"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.event.interval"] = true;
dojo.provide("epages.event.interval");

epages.event.interval = {
	// summary: cross browser function to set intervals
	// description: cross browser function to set intervals without using the built in function "setInterval" (which can cause serious timing problems).
	// set: set an interval (e.g.: var myinterval = epages.event.interval.set(function(){alert("test")}, 1000);
	// clear: clear the given interval (e.g.: epages.event.interval.clear(myinterval));
	
	_container: [],
	_setIntervalSecure: function(/* string */intervalId, /* function */task, /* uinteger */delay) {
		if(this._container[intervalId] != null) {
			setTimeout(dojo.hitch(this, function(){this._setIntervalSecure(intervalId, task, delay)}), delay);
			task();
		}
	},
	
	set: function(/* function */task, /* uinteger */delay) {
		var intervalId = this._container.length;
		this._container.push(intervalId);
		setTimeout(dojo.hitch(this, function(){this._setIntervalSecure(intervalId, task, delay)}), delay);
		return intervalId;
	},
	
	clear: function(/* string */intervalId) {
		this._container[intervalId] = null;
	}
	
};

}

if(!dojo._hasResource['epages.widget.Slides']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.widget.Slides'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.widget.Slides');







dojo.declare("epages.widget.Slides", [epages.widget.LocalizedWidget], {
	templateString:"<div class=\"SlideShow\">\n  <div class=\"SlideshowContainer\">\n    <div class=\"MainContainer\" dojoAttachPoint=\"mainNode\">\n      <div class=\"DescriptionContainer\" dojoAttachPoint=\"descriptionNode\"></div>\n      <div class=\"MiscContainer\" dojoAttachPoint=\"miscNode\">\n        <div class=\"MiscClipper\" dojoAttachPoint=\"miscNodeClipper\">\n          <div class=\"Counter\" dojoAttachPoint=\"countNode\"></div>\n          <div class=\"Date\" dojoAttachPoint=\"dateNode\"></div>\n        </div>\n      </div>\n      <div class=\"ImageContainer\">\n        <div class=\"ImageAligner\">\n          <table class=\"ImageTableTemplate\" dojoAttachPoint=\"imageTable\"><tr><td style=\"text-align:center;\">\n            <b></b>\n          </td></tr></table>\n        </div>\n      </div>\n      <div class=\"ControlContainer\">\n        <div class=\"ControlBar\" dojoAttachPoint=\"controlNode\"></div>\n      </div>\n    </div>\n  </div>\n</div>\n",
	imagePath:          epages.themeUrl('images'),
	translationName:    dojo.moduleUrl("epages.widget", "templates/translation"),
	loaderImagePath:    epages.themeUrl('images') + "/img_busy.gif",
	errorImagePath:     epages.themeUrl('images') + "/slideshow_img_broken_image.png",

	controlBarImages: [
		[epages.themeUrl('images') + "/slideshow_img_bg.png", epages.themeUrl('images') + "/slideshow_img_bg_small.png", epages.themeUrl('images') + "/slideshow_img_bg_smaller.png"],
		[epages.themeUrl('images') + "/slideshow_ico_l_rewind.png", epages.themeUrl('images') + "/slideshow_ico_s_rewind.png"],
		[epages.themeUrl('images') + "/slideshow_ico_l_pause.png", epages.themeUrl('images') + "/slideshow_ico_s_pause.png"],
		[epages.themeUrl('images') + "/slideshow_ico_l_play.png", epages.themeUrl('images') + "/slideshow_ico_s_play.png"],
		[epages.themeUrl('images') + "/slideshow_ico_l_overview.png", epages.themeUrl('images') + "/slideshow_ico_s_overview.png"],
		[epages.themeUrl('images') + "/slideshow_ico_l_details.png", epages.themeUrl('images') + "/slideshow_ico_s_details.png"],
		[epages.themeUrl('images') + "/slideshow_ico_l_forward.png", epages.themeUrl('images') + "/slideshow_ico_s_forward.png"]
										],

	delay:                 3500,
	protraction:           1200,
	imageWidth:            "450px",
	imageHeight:           "300px",
	tiny:                  false,
	stopped:               false,
	overview:              true,				// flag: enable / disable detailed (large) view
	imageClickOverview:    true,
	showName:              true,
	showDescription:       true,
	showControls:          true,
	showMisc:              true,
	showIndex:             0,

	_images:               undefined,
	_oldShowIndex:         0,
	_loadedIndex:          0,
	_loadedImages:         0,
	_pauseIcon:            0,
	_playIcon:             0,
	_fadeEasing:           dojo.fx.easing.quadOut,
	_overviewArea:         null,
	_overviewBackground:   null,
	_overviewImageCounter: null,
	_controlBarFadeOut:    null,
	_playerBeacon:         null,
	_hiddenDetails:        false,
	_changingImage:        true,
	_globalOverview:       true,
	_reAlignReady:         true,

	_delayExec: function(task, delay) {
		return setTimeout(dojo.hitch(this, task), delay);
	},

	_getAlphaImage: function (imageSrc, sizing) {

		var imageContainer = document.createElement("span");
		var imageHolder = document.createElement("span");

		var filterClassString = "";
		if(epages.Browser.engine == "MSIE" && imageSrc.match(".png")) {
			sizing = sizing ? "scale" : "crop";
			filterClassString = "class='AlphaImage'";
			imageHolder.style.zoom = "1";
			imageHolder.style.filter = "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + imageSrc + "', sizingMethod='" + sizing + "')";
		}

		var image = "<img " + filterClassString + " alt='' src='" + imageSrc + "' onerror=''/>";

		imageHolder.innerHTML = image;
		imageContainer.appendChild(imageHolder);
		imageContainer.className = "Image";

		return imageContainer;
	},

	_drawControlBar: function() {

		if(this.tiny) {
			this.controlNode.className = "ControlBarMini";
		}
		if(!this.showControls) {
			this.controlNode.style.display = "none";
		}

		var backgroundImageIndex = 0;
		if(!this.overview || !this.showDescription) {
			backgroundImageIndex = 1;
		}else if(!this.overview && !this.showDescription) {
			backgroundImageIndex = 2;
		}

		var controlBarBg = this.tiny ? document.createElement("div") : this._getAlphaImage(this.controlBarImages[0][backgroundImageIndex]);
		controlBarBg.className = "ControlBarBg";
		this.controlNode.appendChild(controlBarBg);

		if(!this.overview && this.showControls) {
			controlBarBg.parentNode.style.width = (controlBarBg.offsetWidth - (this.tiny ? 16 : 32)) + "px";
		}
		if(!this.showDescription && this.showControls) {
			controlBarBg.parentNode.style.width = (controlBarBg.offsetWidth - (this.tiny ? 16 : 32)) + "px";
		}

		var rewindIcon = this._getAlphaImage(this.controlBarImages[1][this.tiny ? 1 : 0]);
		rewindIcon.className = "SlideshowButton";
		this.controlNode.appendChild(rewindIcon);
		this.connect(rewindIcon, "onclick", "_rewindClick");

		var pauseIcon = this._getAlphaImage(this.controlBarImages[2][this.tiny ? 1 : 0]);
		pauseIcon.className = "SlideshowButton";
		if(this.stopped) {pauseIcon.style.position = "absolute";pauseIcon.style.visibility = "hidden";}
		this.controlNode.appendChild(pauseIcon);
		this.connect(pauseIcon, "onclick", "_pauseClick");
		this._pauseIcon = pauseIcon;

		var playIcon = this._getAlphaImage(this.controlBarImages[3][this.tiny ? 1 : 0]);
		playIcon.className = "SlideshowButton";
		if(!this.stopped) {playIcon.style.position = "absolute";playIcon.style.visibility = "hidden";}
		this.controlNode.appendChild(playIcon);
		this.connect(playIcon, "onclick", "_playClick");
		this._playIcon = playIcon;

		if(this.overview) {
			var overviewIcon = this._getAlphaImage(this.controlBarImages[4][this.tiny ? 1 : 0]);
			overviewIcon.className = "SlideshowButton";
			this.controlNode.appendChild(overviewIcon);
			this.connect(overviewIcon, "onclick", "_overviewClick");
		}

		if(this.showDescription) {
			var detailsIcon = this._getAlphaImage(this.controlBarImages[5][this.tiny ? 1 : 0]);
			detailsIcon.className = "SlideshowButton";
			this.controlNode.appendChild(detailsIcon);
			this.connect(detailsIcon, "onclick", "_detailsClick");
		}

		var forwardIcon = this._getAlphaImage(this.controlBarImages[6][this.tiny ? 1 : 0]);
		forwardIcon.className = "SlideshowButton";
		this.controlNode.appendChild(forwardIcon);
		this.connect(forwardIcon, "onclick", "_forwardClick");

		dojo.style(this.controlNode, "opacity", 0);

		return [rewindIcon, playIcon, pauseIcon, overviewIcon ? overviewIcon : null, detailsIcon ? detailsIcon : null, forwardIcon];
	},

	_controlBarButtonOver: function(eventObject) {
		dojo.addClass(eventObject.currentTarget, "Highlighted");
		document.onselectstart = function() { return false; };
	},

	_controlBarButtonOut: function(eventObject) {
		dojo.removeClass(eventObject.currentTarget, "Highlighted");
		dojo.removeClass(eventObject.currentTarget, "Hit");
		document.onselectstart = function() { return true; };
	},

	_controlBarButtonDown: function(eventObject) {
		dojo.addClass(eventObject.currentTarget, "Hit");
	},

	_controlBarButtonUp: function(eventObject) {
		dojo.removeClass(eventObject.currentTarget, "Hit");
	},

	_showControlBar: function() {
		clearTimeout(this._controlBarFadeOut);
		dojo.fadeIn({node: this.controlNode, duration:350, easing: this._fadeEasing}).play();
	},

	_hideControlBar: function() {
		this._controlBarFadeOut = this._delayExec(function() {
			if(this.controlNode.offsetWidth == 0) {
				dojo.style(this.controlNode, "opacity", 0);
			}else{
				dojo.fadeOut({node: this.controlNode, duration:350}).play();
			}
		}, 1000);
	},

	_drawErrorImage: function(eventObject) {
		var imgNode = eventObject.currentTarget;
		imgNode.src = this.errorImagePath;
		imgNode.parentNode.style.filter = "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + this.errorImagePath + "', sizingMethod='scale')";
	},

	_playClickStartTimer: function() {
		this._playIcon.style.position = "absolute";
		this._playIcon.style.visibility = "hidden";
		this._pauseIcon.style.position = "relative";
		this._pauseIcon.style.visibility = "visible";
		this._playerBeacon = epages.event.interval.set(dojo.hitch(this, this._setNextImage), this.delay);
	},

	_playClick: function() {
		this._setNextImage();
		this._playClickStartTimer();
	},

	_pauseClick: function() {
		this._pauseIcon.style.position = "absolute";
		this._pauseIcon.style.visibility = "hidden";
		this._playIcon.style.position = "relative";
		this._playIcon.style.visibility = "visible";
		epages.event.interval.clear(this._playerBeacon);
	},

	_overviewClick: function(image) {
		/* we don't want any mouse events in here */
		if(typeof(image) == "object") {
			image = null;
		}

		this._pauseClick();

		if(!this._overviewArea) {
			var overviewBackground = document.createElement("div");
			overviewBackground.className = "OverviewBackground";
			dojo.style(overviewBackground, "opacity", 0);

			dojo.addClass(dojo.body(), "OverviewAreaVisible");

			overviewBackground.innerHTML = "<div class='Background'></div>";

			var overviewArea = document.createElement("div");
			overviewArea.className = "OverviewArea";

			var info = this._images[this.showIndex];

			if(!info) {
				info = {};
				info.imageTable = this._createImageTable();
				info.imageTable.getElementsByTagName("b")[0].appendChild(this._getAlphaImage(epages.themeUrl('images') + "/plain.gif"));
				this._images.push(info);
			}else {
				this._oldShowIndex = this.showIndex;
			}

			var infoTable = this._images[this.showIndex].imageTable.cloneNode(true);

			var bNode = infoTable.getElementsByTagName("b")[0];
			bNode.innerHTML = "";
			bNode.appendChild(this._getAlphaImage(epages.themeUrl('images') + "/plain.gif"));

			overviewArea.appendChild(infoTable);

			var backgroundEventLayer = document.createElement("div");
			backgroundEventLayer.className = "BackgroundEventLayer";
			overviewArea.getElementsByTagName("td")[0].appendChild(backgroundEventLayer);

			var rewindIcon = this._getAlphaImage(epages.themeUrl("images") + "/slideshow_ico_l_rewind_overview.png");
			rewindIcon.className = "Image SlideshowButton";
			this.connect(rewindIcon, "onclick", "_setPrevImage");
			this.connect(rewindIcon, "onmouseover", "_controlBarButtonOver");
			this.connect(rewindIcon, "onmouseout", "_controlBarButtonOut");
			this.connect(rewindIcon, "onmousedown", "_controlBarButtonDown");
			this.connect(rewindIcon, "onmouseup", "_controlBarButtonUp");
			var rewindIconContainer = document.createElement("i");
			rewindIconContainer.appendChild(rewindIcon);
			rewindIconContainer.className = "OverviewRewindButton";

			var forwardIcon = this._getAlphaImage(epages.themeUrl("images") + "/slideshow_ico_l_forward_overview.png");
			forwardIcon.className = "Image SlideshowButton";
			this.connect(forwardIcon, "onclick", "_setNextImage");
			this.connect(forwardIcon, "onmouseover", "_controlBarButtonOver");
			this.connect(forwardIcon, "onmouseout", "_controlBarButtonOut");
			this.connect(forwardIcon, "onmousedown", "_controlBarButtonDown");
			this.connect(forwardIcon, "onmouseup", "_controlBarButtonUp");
			var forwardIconContainer = document.createElement("i");
			forwardIconContainer.appendChild(forwardIcon);
			forwardIconContainer.className = "OverviewForwardButton";

			var closeIcon = this._getAlphaImage(epages.themeUrl("images") + "/layer_img_closebutton.png");
			closeIcon.className = "Image SlideshowButton";
			closeIcon.style.clip = "rect(0, 40px, 20px, 0)";
			this.connect(closeIcon, "onclick", "_destroyOverview");
			this.connect(closeIcon, "onmouseover", "_controlBarButtonOver");
			this.connect(closeIcon, "onmouseout", "_controlBarButtonOut");
			var closeIconContainer = document.createElement("i");
			closeIconContainer.appendChild(closeIcon);
			closeIconContainer.className = "OverviewCloseButton";

			var overviewImageCounter = document.createElement("b");
			overviewImageCounter.className = "OverviewImageCounter";
			if(!this.showMisc) {
				overviewImageCounter.style.display = "none";
			}

			dojo.style(overviewArea, "background", "url(" + this.loaderImagePath + ") center no-repeat");
			dojo.style(overviewArea.getElementsByTagName("span")[0], "opacity", 0);

			var overviewImageSrc = info.imageLarge ? info.imageLarge : info.image;
			var overviewImage = overviewArea.getElementsByTagName("img")[0];
			overviewImage.src = image || overviewImageSrc;
			overviewImage.style.height = "auto";
			overviewImage.style.width = "auto";
			if(overviewImage.src.match(".ico") || overviewImage.src.match(".cur")) {
				overviewImage.parentNode.style.filter = "fade()";
			}else {
				//overviewImage.style.filter = "alpha(opacity=0)";
				//overviewImage.parentNode.style.filter = "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + overviewImage.src + "', sizingMethod='scale')";
			};
			dojo.body().appendChild(overviewBackground);
			dojo.body().appendChild(overviewArea);

			var imageLargeDuplicated = true;
			var prevImage = this._images[0];

			for( var i=0,iLength=this._images.length ; i<iLength ; i++ ) {
				if(this._images[i].imageLarge != prevImage.imageLarge) {
					imageLargeDuplicated = false;
					break;
				}else {
					prevImage = this._images[i];
				}
			}

			if(this._images.length > 1 && !image && !imageLargeDuplicated) {
				if(this.showControls) {
					overviewArea.getElementsByTagName("span")[1].appendChild(rewindIconContainer);
					overviewArea.getElementsByTagName("span")[1].appendChild(forwardIconContainer);
				}
				overviewArea.getElementsByTagName("span")[1].appendChild(overviewImageCounter);
			}
			overviewArea.getElementsByTagName("span")[1].appendChild(closeIconContainer);

			// hack to fetch image load event. the image has to be loaded to access
			// its dimensions for calculating the resulting dimensions in relation
			// to the browser window size.
			var loadImageInstance = new Image();
			loadImageInstance.onload = dojo.hitch(this, function() {
				this._delayExec(this._drawOverviewImage, 1);
			});
			loadImageInstance.src = image || overviewImageSrc;

			this.connect(overviewImage, "onerror", "_drawErrorImage");
			this.connect(backgroundEventLayer, "onclick", "_destroyOverview");

			overviewBackground.style.zoom = 1;
			dojo.style(overviewBackground, "opacity", 1);

			this._overviewBackground = overviewBackground;
			this._overviewArea = overviewArea;
			this._overviewImageCounter = overviewImageCounter;

			this._changeOverviewDimensions();

		}
	},

	_changeOverviewDimensions: function() {
		if(this._overviewArea != null) {

			var overviewImage = this._overviewArea.getElementsByTagName("img")[0];
			var windowHeight = window.innerHeight ? window.innerHeight : document.documentElement.clientHeight;
			var windowWidth = window.innerWidth ? window.innerWidth : document.documentElement.clientWidth;

			var currentHeight = 0;

			if(windowHeight > dojo.body().offsetHeight + 10) {
				currentHeight = windowHeight;
			}else{
				currentHeight = dojo.body().offsetHeight + 10;
			}
			this._overviewBackground.style.height = currentHeight + "px";
			this._overviewArea.style.height = windowHeight + "px";

			setTimeout(dojo.hitch(this, function() {
				var absoluteWidth = this._images[this.showIndex]._overviewWidth;
				var absoluteHeight = this._images[this.showIndex]._overviewHeight;

				if(absoluteWidth && absoluteHeight && (absoluteWidth > windowWidth - 50 || absoluteHeight > windowHeight - 50)) {
					if((windowWidth / windowHeight) / (absoluteWidth / absoluteHeight) > 1) {
						overviewImage.style.height = (windowHeight - 50) + "px";
						overviewImage.style.width = "auto";
					}else {
						overviewImage.style.width = (windowWidth - 50) + "px";
						overviewImage.style.height = "auto";
					}
				}
				this._reAlignOverview();
			}), 1);

		}
	},

	_reAlignOverview: function() {
		if(this._overviewArea != null && this._reAlignReady) {
			this._reAlignReady = false;
			this._delayExec(function(){
				if(this._overviewArea != null) {
					var scrollAmount = dojo.body().pageYOffset ? dojo.body().pageYOffset : document.documentElement.scrollTop;
					dojo.fx.slideTo({
						node: this._overviewArea,
						top: scrollAmount,
						duration: 350,
						easing: this._fadeEasing
					}).play();
				}
				this._reAlignReady = true;
			}, 50);
		}
	},

	_detailsClick: function() {
		if(this._hiddenDetails) {
			this._hiddenDetails = false;
			this.descriptionNode.style.visibility = "visible";
			this.miscNode.style.visibility = "visible";
		}else{
			this._hiddenDetails = true;
			this.descriptionNode.style.visibility = "hidden";
			this.miscNode.style.visibility = "hidden";
		}
	},

	_forwardClick: function() {
		this._pauseClick();
		this._setNextImage();
	},

	_rewindClick: function() {
		this._pauseClick();
		this._setPrevImage();
	},

	_drawOverviewImage: function() {
		this._delayExec(function() {
			var overviewImage = this._overviewArea.getElementsByTagName("img")[0];

			if(!this._images[this.showIndex]._overviewWidth) {
				overviewImage.style.position = "absolute";
				this._images[this.showIndex]._overviewWidth = overviewImage.width;
				this._images[this.showIndex]._overviewHeight = overviewImage.height;
				overviewImage.style.position = "static";
			}

			if(this._images[this.showIndex]._overviewHeight < 100) {
				overviewImage.style.marginTop = (45 - this._images[this.showIndex]._overviewHeight / 2) + "px";
			}else{
				overviewImage.style.marginTop = "0";
			}

			this._changeOverviewDimensions();

			this._overviewImageCounter.innerHTML = (this.showIndex + 1) + " | " + this._images.length;

			this._overviewArea.getElementsByTagName("b")[0].style.visibility = "visible";
			dojo.style(this._overviewArea.getElementsByTagName("b")[0], "opacity", "1");
			dojo.style(this._overviewArea, "background", "");
			dojo.fadeIn({node: this._overviewArea.getElementsByTagName("span")[0], duration: this.protraction, easing: this._fadeEasing}).play();

		}, 400);
	},

	_destroyOverview: function() {
		if(this._overviewArea) {
			if(dojo.style(this._overviewArea.getElementsByTagName("span")[0], "opacity") > 0.5) {
				dojo.fadeOut({node: this._overviewArea, duration: this.protraction / 2, easing: this._fadeEasing}).play();
				this._delayExec(function() {
					if(this._overviewArea) {
						dojo.body().removeChild(this._overviewArea);
						dojo.body().removeChild(this._overviewBackground);
						delete this._overviewArea;
						delete this._overviewBackground;
						this.showIndex = this._oldShowIndex;
						delete this._oldShowIndex;

						dojo.removeClass(dojo.body(), "OverviewAreaVisible");
					}
				}, this.protraction / 2.2);
			}
		}
	},

	_checkGlobalOverview: function() {
		var isPlainImage = this._images[this.showIndex].image.match("dijit/themes/epages/images/plain.gif") || this._images[this.showIndex].image.match("transparentpixel.gif");
		if(this._globalOverview && !isPlainImage){
			this._overviewClick();
		}
	},

	_showImageDetails: function() {

		var info = this._images[this.showIndex];
		this.descriptionNode.innerHTML = info.description;
		this.dateNode.innerHTML = info.date;
		this.countNode.innerHTML = (this.showIndex + 1) + " | " + (this._images.length);

		this.miscNode.style.top = this.miscNodeClipper.offsetHeight + "px";
		this.descriptionNode.style.top = "-" + this.descriptionNode.offsetHeight + "px";

		dojo.style(this.miscNode, "opacity", 0.8);
		dojo.style(this.descriptionNode, "opacity", 0.8);

		if(this.descriptionNode.innerHTML.length > 1) {
			dojo.fx.slideTo({node: this.descriptionNode, duration: 400, easing: this._fadeEasing}).play();
		}
		dojo.fx.slideTo({node: this.miscNode, duration: 400, easing: this._fadeEasing}).play();

	},

	_hideImageDetails: function() {
		dojo.fadeOut({node: this.miscNode, duration: 200, easing: this._fadeEasing}).play();
		dojo.fadeOut({node: this.descriptionNode, duration: 200, easing: this._fadeEasing}).play();
	},

	_setNextImage: function() {
		if(this._overviewArea) {
			if(dojo.style(this._overviewArea.getElementsByTagName("span")[0], "opacity") >= 0.5) {
				this._setImage(this.showIndex > this._images.length - 2 ? 0 : this.showIndex + 1);
			}
		}else{
			this._setImage(this.showIndex > this._images.length - 2 ? 0 : this.showIndex + 1);
		}
	},

	_setPrevImage: function() {
		if(this._overviewArea) {
			if(dojo.style(this._overviewArea.getElementsByTagName("span")[0], "opacity") >= 0.5) {
				this._setImage(this.showIndex == 0 ? this._images.length - 1 : this.showIndex - 1);
			}
		}else{
			this._setImage(this.showIndex == 0 ? this._images.length - 1 : this.showIndex - 1);
		}
	},

	_setImage: function(imageIndex) {
		if(this._images[imageIndex]) {
			if(this._overviewArea) {
				if(!this._oldShowIndex) {
					this._oldShowIndex = this.showIndex;
				}

				var overviewImageContainer = this._overviewArea.getElementsByTagName("span")[0];
				var overviewImage = overviewImageContainer.getElementsByTagName("img")[0];

				dojo.style(this._overviewArea, "background", "url(" + this.loaderImagePath + ") center no-repeat");
				dojo.fadeOut({node: overviewImageContainer, duration: this.protraction, easing: this._fadeEasing}).play();

				this._delayExec(function() {
					var info = this._images[this.showIndex];
					dojo.style(overviewImageContainer, "opacity", 0);
					var overviewImageSrc = info.imageLarge || info.image;
					var overviewImage = this._overviewArea.getElementsByTagName("img")[0];
					overviewImage.src = overviewImageSrc;
					overviewImage.style.width = "auto";
					overviewImage.style.height = "auto";
					//overviewImage.style.filter = "alpha(opacity=0)";
					//overviewImage.parentNode.style.filter = "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + overviewImageSrc + "', sizingMethod='crop')";

					// hack to fetch image load event
					var test = new Image();
					test.onload = dojo.hitch(this, function() {
						this._delayExec(this._drawOverviewImage, 1);
					});
					test.src = overviewImageSrc;
				}, this.protraction);

			}else {
				var oldContainer = this._images[this.showIndex].imageTable.getElementsByTagName("b")[0];
				var newContainer = this._images[imageIndex].imageTable.getElementsByTagName("b")[0];

				//be sure that the slideshow stops fading when it is not visible (display:none)
				if(oldContainer.offsetWidth == 0) {
					this._pauseClick();
				}else{
					var newImage = newContainer.getElementsByTagName("img")[0];
					if(typeof(newImage) == "undefined") {
						newContainer.appendChild(this._getAlphaImage(this._images[imageIndex].image, true));
						newImage = newContainer.getElementsByTagName("img")[0];
					}
					if(typeof(newImage) != "undefined") {
						if(this._images[imageIndex].fit == "true" || this._images[imageIndex].fit == true) {
							if(newImage.offsetHeight > newImage.offsetWidth) {
								newImage.style.height = (this.mainNode.offsetHeight) + "px";
								if(newImage.offsetWidth >= this.mainNode.offsetWidth) {
									newImage.style.height = "auto";
									newImage.style.width = (this.mainNode.offsetWidth) + "px";
								}
							}else{
								newImage.style.width = (this.mainNode.offsetWidth) + "px";
								if(newImage.offsetHeight >= this.mainNode.offsetHeight) {
									newImage.style.width = "auto";
									newImage.style.height = (this.mainNode.offsetHeight) + "px";
								}
							}
						}else if(this._images[imageIndex].fit == null) {
							this._delayExec(function() {
								if(newImage.offsetHeight > newImage.offsetWidth) {
									if(newImage.offsetHeight > this.mainNode.offsetHeight) {
										newImage.style.height = (this.mainNode.offsetHeight) + "px";
										newImage.style.width = "auto";
									}
								}else{
									if(newImage.offsetWidth > this.mainNode.offsetWidth) {
										newImage.style.width = (this.mainNode.offsetWidth) + "px";
										newImage.style.height = "auto";
									}
								}
							},1);
						}
					}

					if(this.showIndex != imageIndex) {
						dojo.fadeOut({node: oldContainer, duration: this.protraction, easing: this._fadeEasing}).play();
						this._delayExec(function(){
							this._fadeOutHide(oldContainer);
						}, this.protraction);
					}

					dojo.style(newContainer, "visibility", "visible");
					dojo.fadeIn({node: newContainer, duration: this.protraction, easing: this._fadeEasing}).play();

					this._hideImageDetails();
					this._delayExec(this._showImageDetails, this.protraction / 2);
					this._images[this.showIndex].imageTable.style.zIndex = 0;
					this._images[imageIndex].imageTable.style.zIndex = 1;
				}
			}
		}
		this.showIndex = imageIndex;
	},

	_fadeOutHide: function(domNode) {
		if(dojo.style(domNode, "opacity") == 0) {
			dojo.style(domNode, "visibility", "hidden");
		}
	},

	_loadImagesSoft: function() {
		dojo.disconnect(this._images[this._loadedIndex].onloadHandle);

		if(this._images[this._loadedIndex].imageToStage) {
			this._setImage(this._images[this._loadedIndex].imageToStage);
		}else if (this._loadedIndex == this.showIndex && this._overviewArea == null) {
			this._setImage(this.showIndex);
		}

		if(this._loadedImages < this._images.length) {
			this._delayExec(this._loadImages, 1000);
		}else{
			this.mainNode.style.background = "none";
		}
	},

	_loadImages: function() {
		this._loadedImages++;

		this._loadedIndex++;
		if(this._loadedIndex >= this._images.length){
			this._loadedIndex = 0;
		}

		var info = this._images[this._loadedIndex];
		var imageTable = info.imageTable;

		this.mainNode.style.background = "transparent url(" + this.loaderImagePath + ") center no-repeat";

		imageTable.style.zIndex = 0;

		var imageHolder = imageTable.getElementsByTagName("b")[0];
		imageHolder.style.zoom = "1";
		dojo.style(imageHolder, "opacity", 0);
		dojo.style(imageHolder, "visibility", "hidden");

		if(typeof(imageHolder.getElementsByTagName("img")[0]) == "undefined") {
			imageHolder.appendChild(this._getAlphaImage(info.image, true));
		}
		var image = imageHolder.getElementsByTagName("img")[0];
		this.connect(image, "onerror", "_drawErrorImage");

		// hack to fetch image load event
		var test = new Image();
		test.onload = dojo.hitch(this,'_loadImagesSoft');
		test.src = image.src;
	},

	_createImageTable: function() {
		var imageTable = this.imageTable.cloneNode(true);
		imageTable.className = "ImageTable";
		this.imageTable.parentNode.appendChild(imageTable);
		return imageTable;
	},

	_handleKeyEvent: function(evt) {
		evt = evt ? evt: window.event;
		switch (evt.which || evt.keyCode) {
			case 27:
				this._destroyOverview();
				break;
			case 37:
				this._setPrevImage();
				break;
			case 39:
				this._setNextImage();
				break;
		}
	},

	openOverview: function(image) {
		this._overviewClick(image);
	},

	setImage: function(imageIndex) {
		this._pauseClick();
		this._setImage(imageIndex);
	},

	setNextImage: function() {
		this._setNextImage();
	},

	setPrevImage: function() {
		this._setPrevImage();
	},

	addImage: function(insObject, setImage) {
		if(insObject.image) {
			var alreadyAddedIn;
			for( var i=0,iLength=this._images.length ; i<iLength ; i++ ) {
				if(this._images[i].image == insObject.image) {
					alreadyAddedIn = i;
				}
			}
			if(!alreadyAddedIn) {
				this._images.push(insObject);
				this._images[this._images.length - 1].imageTable = this._createImageTable();
				this._images[this._images.length - 1].imageToStage = this._images.length - 1;
				this._loadImages();
			}else {
				this._setImage(alreadyAddedIn);
			}
		}
	},

	postCreate: function() {
		epages.widget.Slides.superclass.postCreate.apply(this, arguments);
		this._images = [];

		this.domNode.style.width = this.imageWidth;
		this.domNode.style.height = this.imageHeight;
		this.mainNode.parentNode.style.width =  this.imageWidth;
		this.mainNode.style.height =  this.imageHeight;

		if(!this.showDescription) {
			this.descriptionNode.style.display = "none";
		}
		if(!this.showMisc) {
			this.miscNode.style.display = "none";
		}

		var controlButtons = this._drawControlBar();

		for( var i=0,iLength=controlButtons.length ; i<iLength ; i++ ) {
			if(controlButtons[i]) {
				this.connect(controlButtons[i], "onmouseover", "_controlBarButtonOver");
				this.connect(controlButtons[i], "onmouseout", "_controlBarButtonOut");
				this.connect(controlButtons[i], "onmousedown", "_controlBarButtonDown");
				this.connect(controlButtons[i], "onmouseup", "_controlBarButtonUp");
			}
		}

		if(this.srcNodeRef) {
			if(this.srcNodeRef.className) {
				this.mainNode.parentNode.parentNode.className += " " + this.srcNodeRef.className;
			}
			// build images from source node
			var sourceDom = this.srcNodeRef.getElementsByTagName("ins");
			for( var i=0,iLength=sourceDom.length ; i<iLength ; i++ ) {
				var currentImageNode = {};
				currentImageNode.image = sourceDom[i].getAttribute("image") || epages.themeUrl('images') + "/plain.gif";
				currentImageNode.imageLarge = sourceDom[i].getAttribute("imageLarge");
				currentImageNode.name = sourceDom[i].getAttribute("name");
				currentImageNode.description = sourceDom[i].innerHTML;
				currentImageNode.date = sourceDom[i].getAttribute("date");
				currentImageNode.time = sourceDom[i].getAttribute("time");
				currentImageNode.fit = sourceDom[i].getAttribute("fit");

				currentImageNode.imageTable = this._createImageTable();

				this._images.push(currentImageNode);
			}
		}

		this.showIndex = new Number(this.showIndex);
		// start one before, because loadimages increment it first
		this._loadedIndex = this.showIndex - 1;
		if (this._loadedIndex == -1){
			this._loadedIndex = this._images.length;
		}

		this.connect(this.mainNode, "onmouseover", "_showControlBar");
		this.connect(this.mainNode, "onmouseout", "_hideControlBar");

		if(this.imageClickOverview && this.overview) {
			this.connect(this.miscNode.offsetHeight ? this.miscNode : this.mainNode, "onclick", "_checkGlobalOverview");
			this.connect(this.controlNode, "onmouseover", function(){ this._globalOverview = false; } );
			this.connect(this.controlNode, "onmouseout", function(){ this._globalOverview = true; } );
		}else{
			this.mainNode.style.cursor = "default";
		}

		this.connect(window, "onscroll", "_reAlignOverview");
		this.connect(window, "onresize", "_changeOverviewDimensions");
		this.connect(document, "onkeyup", "_handleKeyEvent");

		if(this._images.length > 0) {
			this._delayExec(this._loadImages, 1);
			if(!this.stopped && this._images.length > 1){
				this._delayExec(this._playClickStartTimer, 1000);
			}
		}

	}
});

}

if(!dojo._hasResource['epages.epages_scripts']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.epages_scripts'] = true;
/* ---------------------------------------------------------------------------------------------------
	 ePages 5 - epages_scripts.js
	 --------------------------------------------------------------------------------------------------- */
dojo.provide('epages.epages_scripts');





/* - General Functions ------------------------------------------------------------------------------- */

window.openWindow = function (URL, windowName, features, PathToStoreFront) {
	if (PathToStoreFront === null){
		PathToStoreFront = undefined; // old fashion
	}
	if(features=="PopUp") {
		features="width=1000, height=730, toolbar=no, status=no, resizable=yes, menubar=no, location=no, scrollbars=yes";
	}
	if(features=="PopUpPrint") {
		features="width=790, height=580, toolbar=yes, status=no, resizable=yes, menubar=yes, location=no, scrollbars=yes";
	}
	if(features=="RTE" || windowName=="RTE") {
		features="width=996, height=700, toolbar=no, status=no, resizable=yes, menubar=no, location=no, scrollbars=yes";
	}
	if(features=="HelpWindow") {
		features="width=1000, height=730, toolbar=no, status=no, resizable=yes, menubar=no, location=no, scrollbars=yes";
		windowName="WWHFrame";
	 }
	if(features=="StylePreview") {
		features="width=470, height=310, toolbar=no, status=no, resizable=no, menubar=no, location=no, scrollbars=no";
		windowName="StylePreview";
	 }
	if(features=="DetailedImageView") {
		features="width=1000, height=730, toolbar=no, status=no, resizable=yes, menubar=no, location=no, scrollbars=yes";
		windowName="StylePreview";
	 }
	if(features=="CheckLink") {
		if(URL.indexOf("?") != 0) {
			if(URL.split('//').length == 1){
				URL = "http://"+URL;
			}
		} else if(PathToStoreFront!=undefined){
				URL = PathToStoreFront+URL;
		}
		features="toolbar=yes, status=yes, resizable=yes, menubar=yes, location=yes, scrollbars=yes";
	}

	if(URL != "http://") {
		var newwin=window.open(URL,windowName,features);
		if(newwin){
			newwin.focus();
		}
	}

	return newwin;
};

window.linkCorrection = function (oInputField) {
// summary: inserts http protocol if there is no protocol
	var Value=oInputField.value;
	var splittedString = Value.split('//');
	if(Value.indexOf("?") != 0) {
		if(splittedString.length == 1){
			oInputField.value ="http://"+Value;
			epages.event.fire(oInputField, "change");
		}
	}
};

window.OnCheckAll = function (form, name, checked) {
//summary: used to mark all check boxes in a list as "checked"
		var originalTarget = arguments.callee.caller ? arguments.callee.caller.arguments[0].originalTarget : undefined;

		// we have to wait until the originalTarget.checked was set
		window.setTimeout(function(){
			if (form) {
				var triggerNode;

				checked = originalTarget? originalTarget.checked : checked;
				dojo.addClass(form.getElementsByTagName("tbody")[0], "HideElement");

				for( var i=0,l=form.length ; i<l ; i++ ) {
					var input = form[i];

					if(input.nodeName == 'INPUT') {
						if((input.type == 'checkbox' || input.className.match("Checkbox")) && input.name == name && !input.disabled && input.checked != checked) {
							input.checked = checked;
							// we need that for the ContentList widget (row selection)
							var widget = $$(dojo.attr(input,'widgetid') || input.id);
							if( widget ){
								widget.setChecked ? widget.setChecked(checked) : widget.attr('checked',checked);
							}
							if(checked) {
								dojo.addClass( epages.parentByTagName(input,'tr'), "RowSelected");
							}else {
								dojo.removeClass( epages.parentByTagName(input,'tr'), "RowSelected");
							}
							triggerNode = input;
							epages.event.fire( triggerNode, 'change' );
						}
					}
				}
				dojo.removeClass(form.getElementsByTagName("tbody")[0], "HideElement");
			}
		}, 0);
};

window.DeactivateButton = function (Button) {
// summary: function to disable an input field
// Button must be an input/button object
		if(Button.className.match("CustomButton")) {
				fakeButton = Button.getElementsByTagName("*")[0];
				fakeButton.disabled="true";
				dojo.addClass(Button, "Disabled");
		}
		else if(Button.getAttribute('widgetid')){
			$$(Button.getAttribute('widgetid')).disable();
		}
		else {
				Button.disabled="true";
				dojo.addClass(Button, "Disabled");
		}
};

window.DisableLink = function (Link) {
	// summary: function to disable a link
	if($(Link)) {
		$(Link).className += ' Opacity40';
		$(Link).href = 'javascript:void(0)';
		$(Link).style.cursor = 'default';
	}
};

window.toggleTopic = function(/* dom node */ el, /* string? */ label1, /* string? */ label2) {
	if(el.parentNode) {
		var className = el.parentNode.className;
		if(className.match("Closed")) {
			epages.html.replaceClass(el.parentNode, "Open", "Closed");
		} else {
			epages.html.replaceClass(el.parentNode, "Closed", "Open");
		}
		if(label1 && label2) {
			if(el.innerHTML == label1) {
				el.innerHTML = label2;
			} else {
				el.innerHTML = label1;
			}
		}
	}
};

window.toggleDisplay = function (elementId) {
// summary: switches the display properties of an element (specified by its id attribute)
// by changing the class name (HideElement / ShowElement)
	if ($(elementId).className != 'HideElement') {
		$(elementId).className = 'HideElement';
	} else {
		$(elementId).className = 'ShowElement';
	}
};

window.hideElement = function (elementId) {
		if(!$(elementId).className.match(/HideElement/)){
			$(elementId).className += ' HideElement';
		}
};

window.showElement = function (elementId) {
		$(elementId).className=$(elementId).className.replace(/HideElement/,"");
};

window.changeDataById = function (newdata, id) {
	myobject = $(id);
	if(myobject.firstChild) {
		myobject.firstChild.data = newdata;
	} else {
		mydata = document.createTextNode(newdata);
		myobject.appendChild(mydata);
	}
};

window.getSelectedData = function (selectElement) {
// summary: scans all option tags in a select tag to find the data of the selected item
	if(selectElement) {
		myNode= selectElement.firstChild;
		while (myNode!=null) {
			if(myNode.value==selectElement.value && myNode.value!="") {
				return myNode.firstChild.data;
			}
			myNode = myNode.nextSibling;
		}
		return "";
	}
};

window.disableFormFieldsInElement = function (ElementId) {
// summary: disables all form fields that are sub elements of a given ElementId
	userattrinputs = $(ElementId).getElementsByTagName("input");
	for( var i=0,iLength=userattrinputs.length ; i<iLength ; i++ ) {
		userattrinputs[i].disabled=true;
		if($(ElementId).parentNode.className.match("Cropper")) {
			 $(ElementId).parentNode.className += " Disabled";
		}
		if(userattrinputs[i].type != 'checkbox' && userattrinputs[i].type != 'radio') {
				if(userattrinputs[i].type == "button" || userattrinputs[i].type == "submit") {
					userattrinputs[i].parentNode.className = userattrinputs[i].parentNode.className + " Disabled";
				}else{
					userattrinputs[i].className=userattrinputs[i].className+" Disabled";
				}
		}
	}
	userattrtextareas = $(ElementId).getElementsByTagName("textarea");
	for( var i=0,iLength=userattrtextareas.length ; i<iLength ; i++ ) {
		userattrtextareas[i].disabled=true;
		if($(ElementId).parentNode.className.match("Cropper")) {
			 $(ElementId).parentNode.className += " Disabled";
		}
		userattrtextareas[i].className=userattrtextareas[i].className+" Disabled";
	}
	userattrselects = $(ElementId).getElementsByTagName("select");
	for( var i=0,iLength=userattrselects.length ; i<iLength ; i++ ) {
		userattrselects[i].disabled=true;
		if($(ElementId).parentNode.className.match("Cropper")) {
			 $(ElementId).parentNode.className += " Disabled";
		}
		userattrselects[i].className=userattrselects[i].className+" Disabled";
	}
};

window.enableFormFieldsInElement = function (ElementId) {
// summary: enables all form fields that are sub elements of a given ElementId
	userattrinputs = $(ElementId).getElementsByTagName("input");
	for( var i=0,iLength=userattrinputs.length ; i<iLength ; i++ ) {
		userattrinputs[i].disabled=false;
		if($(ElementId).parentNode.className.match("Cropper")) {
			 $(ElementId).parentNode.className = $(ElementId).parentNode.className.replace(/Disabled/g, "");
		}
		userattrinputs[i].parentNode.className=userattrinputs[i].parentNode.className.replace(/ Disabled/,"");
		userattrinputs[i].parentNode.className=userattrinputs[i].parentNode.className.replace(/Disabled/,"");
		userattrinputs[i].className=userattrinputs[i].className.replace(/ Disabled/,"");
		userattrinputs[i].className=userattrinputs[i].className.replace(/Disabled/,"");
	}
	userattrtextareas = $(ElementId).getElementsByTagName("textarea");
	for( var i=0,iLength=userattrtextareas.length ; i<iLength ; i++ ) {
		userattrtextareas[i].disabled=false;
		if($(ElementId).parentNode.className.match("Cropper")) {
			 $(ElementId).parentNode.className = $(ElementId).parentNode.className.replace(/Disabled/g, "");
		}
		userattrtextareas[i].className=userattrtextareas[i].className.replace(/ Disabled/,"");
		userattrtextareas[i].className=userattrtextareas[i].className.replace(/Disabled/,"");
	}
	userattrselects = $(ElementId).getElementsByTagName("select");
	for( var i=0,iLength=userattrselects.length ; i<iLength ; i++ ) {
		userattrselects[i].disabled=false;
		if($(ElementId).parentNode.className.match("Cropper")) {
			 $(ElementId).parentNode.className = $(ElementId).parentNode.className.replace(/Disabled/g, "");
		}
		userattrselects[i].className=userattrselects[i].className.replace(/ Disabled/,"");
		userattrselects[i].className=userattrselects[i].className.replace(/Disabled/,"");
	}
};

window.disableFormFieldById = function (ElementId) {
// summary: function to disable an input field specified by id
	var node = $(ElementId),
		widget = $$(ElementId),
		parent = node.parentNode;

	if( dojo.hasClass( parent, 'Cropper' ) ){
		dojo.addClass( parent, 'Disabled' );
	}
	if( widget ){
		widget.attr('disabled',true);
		dojo.addClass( node, 'Disabled' );
		return;
	}

	node.disabled=false;
	if( arguments.length>1 ? arguments[1] : true ){
		dojo.addClass( node, 'Disabled' );
		dojo.addClass( parent, 'Disabled' );
	}
};

window.enableFormFieldById = function (ElementId) {
// summary: function to enable an input field specified by id
	var node = $(ElementId),
		widget = $$(ElementId),
		parent = node.parentNode;

	if( dojo.hasClass( parent, 'Cropper' ) ){
		dojo.removeClass( parent, 'Disabled' );
	}
	if( widget ){
		widget.attr('disabled',false);
		dojo.removeClass( node, 'Disabled' );
		return;
	}

	node.disabled=false;
	if( arguments.length>1 ? arguments[1] : true ){
		dojo.removeClass( node, 'Disabled' );
		dojo.removeClass( parent, 'Disabled' );
	}
};

window.setValue = function (Value, TargetID) {
	$(TargetID).value = Value;
};

/* - Special Functions ------------------------------------------------------------------------------- */

window.autofillAddress = function (/*Object*/changedObject) {
// summary: this function fills out the "DisplayName" input field (name="DisplayName") automatically
// changedObject: object with the "changed" data --> CustomerGeneral.TabPage
	changedObject.form.DisplayName.value=changedObject.form.FirstName.value + ' ' + changedObject.form.LastName.value;
	if( changedObject.form.UserAlias ) {
		changedObject.form.UserAlias.value=changedObject.form.FirstName.value.slice(0,1) + changedObject.form.LastName.value;
	}
	if( changedObject.form.UserName ) {
		changedObject.form.UserName.value=changedObject.form.FirstName.value + ' ' + changedObject.form.LastName.value;
	}
};

window.SFautofillAddress = function (FirstNameId, LastNameId, DisplayNameId) {
// summary: fills out the "DisplayName" input field (name="DisplayName") automatically
	$(DisplayNameId).value=$(FirstNameId).value + ' ' + $(LastNameId).value;
};

window.showNotAllowedDialog = function(domNode, message) {
	dojo["require"]("epages.uimessagehandler");
	

	var position = $E(domNode).getAbsolutePosition();
	var screenW = document.getElementsByTagName("body")[0].clientWidth;
	var screenH = document.getElementsByTagName("body")[0].clientHeight;
	var orientation = 'top';
	var xoff = 0;
	var yoff = 0;

	if(position.x > (screenW / 2)) {
		orientation = 'right';
	}

	if(position.y > (screenH - 30)) {
		orientation = 'bottom';
		yoff = 0;
		xoff = 0;
	}

	if (orientation=='top') {
		xoff = 10;
		yoff = domNode.offsetHeight;
	}

	if(orientation == 'right' || orientation == 'left') {
		yoff = domNode.offsetHeight / 2;
	}

	dojo.publish("uimessage/show", ["", message, "Bubble", {
		typeClass: "Warning Wide",
		sizeClass: "Medium",
		x: position.x + xoff,
		y: position.y + yoff,
		orientation: orientation
	}]);
	dojo.connect(dojo.body(), "mouseup", this, function() {
		dojo.publish("uimessage/hide");
	});
};

/* - Dialog Area ------------------------------------------------------------------------------------ */
window.DialogArea = function () {
// summary: is used as constructor for an DialogArea-Object
	this.areaName = new Array();
	this.areaId = new Array();
	this.areaDisplayName = new Array();
	this.areaActivated = new Array();          // false = area disabled    ; true = area is a activated

	this.addArea = function(areaName, areaId) {
	//  this function is used to register the areas in a dialog
		this.areaName.push(areaName);
		this.areaId.push(areaId);
		if(this.addArea.arguments.length>3) {
			this.areaDisplayName.push(this.addArea.arguments[2]);
			this.areaActivated.push(this.addArea.arguments[3]);
		} else {
			this.areaDisplayName.push("");
			this.areaActivated.push(true);
		}
	};

	this.createAreaLinks = function() {
			for( var i=0,l=this.areaName.length ; i<l ; i++ ) {
					var oAreaLink;
					if(this.areaActivated[i]) {
							oAreaLink=document.createElement("a");
							oAreaLink.href="javascript:epagesDialog.toggleArea('"+this.areaName[i]+"');";
							oAreaLink.name=this.areaName[i];
							oAreaLink.id=this.areaName[i];
							oAreaLink.className="HideArea";
					} else {
							oAreaLink=document.createElement("span");
							oAreaLink.name=this.areaName[i];
							oAreaLink.id=this.areaName[i];
							oAreaLink.className="disabled";
					}
					var oLinkText=document.createTextNode(this.areaDisplayName[i]);
					oAreaLink.appendChild(oLinkText);
					$("ToggleTabpageArea").appendChild(oAreaLink);
			}
	};

	this.showArea = function(areaName) {
	// summary: used to show an Area
		areaId="";
	// search for the AreaName in the epagesDialog Object
		for( var i=0,iLength=this.areaName.length ; i<iLength ; i++ ) {
			if(this.areaName[i] == areaName){
				areaId = this.areaId[i];
			}
		}
		try {
				dojo.removeClass(document.getElementsByName(areaName)[0], "HideArea");
				dojo.addClass(document.getElementsByName(areaName)[0], "ShowArea");
		} catch(ex) {
				dojo.removeClass($(areaName), "HideArea");
				dojo.addClass($(areaName), "ShowArea");
		}
		// Replace visibility class
		$(areaId).className = $(areaId).className.replace(/HideElement/g, '');
		$(areaId).className += ' ShowElement';
		if(dojo.isIE) {
				// workaround silly MSIE display errors (elements with position:relative are still hidden after setting them visible)
				setTimeout("$('"+areaId+"').className='ShowElement';", 10);
		}
		actualDialogArea = areaName;

	};

	this.hideArea = function(areaName) {
	// summary: used to show an Area
		areaId="";
	// search for the AreaName in the epagesDialog Object
		for( var i=0,iLength=this.areaName.length ; i<iLength ; i++ ) {
			if(this.areaName[i] == areaName){
				areaId = this.areaId[i];
			}
		}
		dojo.removeClass(document.getElementsByName(areaName)[0], "ShowArea");
		dojo.addClass(document.getElementsByName(areaName)[0], "HideArea");
		// Replace visibility class
		$(areaId).className = $(areaId).className.replace(/ShowElement/g, '');
		$(areaId).className += ' HideElement';
		actualDialogArea = "";
	};

	this.toggleArea = function(areaName) {
	//  summary: used to toggle the view of an area
	//  and to hide all unselected areas
		this.showArea(areaName);

	// loop through all dialog areas and hide them
		for( var i=0,iLength=this.areaName.length ; i<iLength ; i++ ) {
			tempName=this.areaName[i]; tempId=this.areaId[i];
			if(areaName != tempName) {
				if(this.areaActivated[i]) {
						dojo.removeClass(document.getElementsByName(tempName)[0], "ShowArea");
						dojo.addClass(document.getElementsByName(tempName)[0], "HideArea");
						// Replace visibility class
						$(tempId).className = $(areaId).className.replace(/ShowElement/g, '');
						$(tempId).className += ' HideElement';
				}
			}
		}
		epages.event.fire(window,'resize');
	};

	this.toggleAreaDisplay = function(areaName) {
	// summary: used to toggle the view of the specified area
	// display settings of other areas remain
		if(document.getElementsByName(areaName)[0].className.match('HideArea')) {
			this.showArea(areaName);
		} else {
			this.hideArea(areaName);
		}
	};

	this.selectArea = function(areaName) {
	// summary: used to show the selected area
	//  and to hide all the other areas
		this.showArea(areaName);
	// loop through all dialog areas and hide them
		for( var i=0,iLength=this.areaName.length ; i<iLength ; i++ ) {
			tempName=this.areaName[i]; tempId=this.areaId[i];
			if(areaName != tempName) {
				dojo.removeClass(document.getElementsByName(tempName)[0], "ShowArea");
				dojo.addClass(document.getElementsByName(tempName)[0], "HideArea");
				// Replace visibility class
				$(tempId).className = $(areaId).className.replace(/ShowElement/g, '');
				$(tempId).className += ' HideElement';
			}
		}
	};
};

window.appendDialogArea = function (formElement) {
	if(actualDialogArea!="") {
		formElement.action += "&DialogArea="+actualDialogArea;
	}
};

actualDialogArea = "";
epagesDialog = new DialogArea();

/* - Switch Wizard Pages ----------------------------------------------------------------------------- */
window.WizardPages = function () {
	// summary: constructor for wizard pages
	this.TabId = new Array();
	this.AreaId = new Array();

	this.addPage = function(TabId, AreaId) {
		this.TabId.push(TabId);
		this.AreaId.push(AreaId);
	};

	this.showStep = function(Index) {
	// summary: used to show the selected page of the wizard
		ActualWizardPage=Index;

		window.scrollTo(0,0);

		// change tab
		$(this.TabId[Index]).className="selected";
		$(this.TabId[Index]).getElementsByTagName("span")[0].firstChild.className="selected";
		try{$(this.TabId[Index]).getElementsByTagName("span")[0].appendChild(oHelpTopic);} catch(ex) { }
		$(this.AreaId[Index]).className="ShowElement";
		for( var i=0,iLength=this.TabId.length ; i<iLength ; i++ ) {
			if(i != Index) {
				$(this.TabId[i]).className="unselected";
				$(this.TabId[i]).getElementsByTagName("span")[0].firstChild.className="disabled";
				$(this.AreaId[i]).className = 'HideElement';
			}
		}
	};
};

ActualWizardPage = 0;
WizardPages= new WizardPages();

/* - our "lightbox" ----------------------------------------------------------------------------- */

window.showImage = function(image) {
	
	(new epages.widget.Slides).openOverview(image);
};


/* - showMore / showLess -- */

	window.showMore = function(alias, refNode) {
		// summary: wipe in hidden node / hide reference node (clicked node)if specified
		if(refNode) {
			refNode.style.display='none';
		}
		dojo.fx.wipeIn({ node: $(alias),  duration: 200}).play();
	};
	window.showLess = function(alias) {
		// summary: wipe out hidden node
		dojo.fx.wipeOut({ node: $(alias), duration: 200}).play();
	};


}

if(!dojo._hasResource['epages.lang.clipboard']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.lang.clipboard'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.lang.clipboard');


epages.lang.Clipboard = function() {
	this._hash = new epages.lang.Hash();
};

epages.lang.Clipboard.prototype = {
	_hash: undefined,
	_counter: 0,

	get: function(/*String*/key) {
		returnValue = this._hash.get("key" + key);
		return returnValue; //Object
	},

	add: function(/*Object*/value) {
		// summary:
		//		adds a value and returns its index
		// example:
		// 	| var clipboard = new epages.lang.Clipboard();
		//	| var index = clipboard.add("test");
		var addIndex = this._counter;
		this._hash.set("key" + addIndex, value);
		do {
			this._counter++;
		} while(this._hash.existsKey("key" + this._counter));
		return addIndex; //Integer
	},

	set: function(/*String*/key, /*Object*/value) {
		// summary:
		//		change the value at the specified position and returns true on success
		//		returns false if position does not exist
		// example:
		// 	| var clipboard = new epages.lang.Clipboard();
		//	| boolean = clipboard.set(5, "test");
		if (this._hash.existsKey("key" + key)) {
			this._hash.set("key" + key, value);
			return true; // Boolean
		} else {
			return false; // Boolean
		}
	}
}

}

if(!dojo._hasResource['epages.lang.hitch']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.lang.hitch'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.lang.hitch');


epages.lang.hitch = function (/*Object*/o, /*function*/func, /*Array?*/parameters) {
	if (o === undefined && func === undefined && parameters === undefined) {
		// it seems to be a constructor
		return;
	} else {
		if (parameters === undefined) {
			// no given parameters ==> use default hitch function
			return dojo.hitch(o, func);
		}
		var clipboardParams = [];
		for( var i=0,iLength=parameters.length ; i<iLength ; i++ ) {
			var clipboardIndex = epages.lang.hitch.prototype.clipBoard.add(parameters[i]);
			clipboardParams.push("epages.lang.hitch.prototype.clipBoard.get(" + clipboardIndex + ")");
		}
		// find out methods name in o
		if (typeof(func) == "string") {
			var funcName = func;
		} else {
			for (member in o) {
				if (typeof o[member] == "function" &&
						o[member] == func) {
					var funcName = member;
					break;
				}
			}
		}
		var returnValue;
		if (funcName === undefined) {
			// not a member function
			returnValue = eval("dojo.hitch(o, function() { func(" + clipboardParams.join(", ") + "); });");
		} else {
			// If possible the following line should be replaced with something
			// that does a function call and provides function parameters as an array
			// or something else non-static.
			returnValue = eval("dojo.hitch(o, function() { o." + funcName + "(" + clipboardParams.join(", ") + "); });");
		}
		return returnValue;
	}
};

epages.lang.hitch.prototype = {
	clipBoard : new epages.lang.Clipboard()
};

}

if(!dojo._hasResource["epages.lang.uri"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.lang.uri"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.lang.uri");


epages.lang.uri = {

	parts: function(uri) {
		// summary:
		//		returns an object with the parts of an uri
		// description:
		//		available parts are: protocol, host, path, query, parameters (Object), anchor
		// example:
		// 	|	var parts = epages.lang.uri.parts('http://www.host.com/path/to/somewhere?action=go#top');
		//	|	parts == {
		//	|		protocol: 'http',
		//	|		host: 'www.host.com',
		//	|		path: '/path/to/somewhere',
		//	|		query: '?action=go',
		// 	|		anchor: '#top',
		//	|		parameters: {
		//	|			action: 'go'
		//	|		}
		// 	|	}
		var parts = {};
		var regExpResult = uri.match(/^((?:(.+)\:\/\/([^\/]+))?((?:\/|[^\?#]).*?)?(\?.*?)?(#.*)?)$/);
		if (regExpResult) {
			parts = {
				'href':				regExpResult[1],
				'protocol': 	regExpResult[2],
				'host': 			regExpResult[3],
				'path': 			regExpResult[4],
				'query': 			regExpResult[5],
				'anchor':			regExpResult[6],
				'parameters': {}
			};
			parts.parameters = this.splitQueryString(parts.query);
		}
		return parts;
	},

	splitQueryString: function(uri) {
		// summary:
		//		returns an object containing the elements of a query string
		// example:
		// 	|	var parts = epages.lang.uri.parts('?action=go');
		//	|	parts == {
		//	|		action: 'go'
		// 	|	}
		var returnValue = {};
		var urlSplits = (new RegExp(/\??(.*?)(#.*)?$/g)).exec(uri);
		if (urlSplits) {
			var queryString = urlSplits[1];
			var splits = queryString.split('&');
			for( var i=0,iLength=splits.length ; i<iLength ; i++ ) {
				var querySplits = (new RegExp(/(.+)\=(.*)/)).exec(splits[i]);
				if (querySplits) {
					returnValue[decodeURIComponent(querySplits[1])] = decodeURIComponent(querySplits[2]);
				}
			}
		}
		return returnValue;
	},

	toQueryString: function(/*Object*/data) {
		// summary:
		//	Generates a query string from a data structure.
		// description:
		//	Needs a hash (hashlike) or an array[string[2]]. The first element
		//	of each sub array will be used as key, the second as the value.
		// example:
		//	| r = epages.lang.uri.toQueryString( { test: 123, test2: abc} );
		//	| r = epages.lang.uri.toQueryString( [ ['test', '123'], ['test2', 'abc'] ] );
		//	| // r (in both cases) == 'test=123&test2=abc'
		if (dojo.isArray(data)) {
			// expects strict array structure
			var returnValue = [];
			for( var i=0,iLength=data.length ; i<iLength ; i++ ) {
				if (!dojo.isArray(data[i])) {
					console.warn('data element is not an array: ' + (typeof data[i]));
					continue;
				}
				returnValue.push(encodeURIComponent(data[i][0]) + '=' + encodeURIComponent(data[i][1]));
			}
			return returnValue.join('&');
		} else if (dojo.isObject(data)) {
			// use the function provided by a hash
			return $H(data).toQueryString();
		}
	},

	fromParts: function(parts) {
		// summary:
		//		returns the uri for an object of its parts
		var result = '';
		if (parts.protocol) {
			result += parts.protocol + '://';
		}
		if (parts.host) {
			result += parts.host;
		}
		if (parts.path) {
			result += parts.path;
		}
		if (dojo.isObject(parts.parameters)) {
			var qs = this.toQueryString(parts.parameters);
			if (qs){
				result += '?' + qs;
			}
		} else if (parts.query) {
			result += parts.query;
		}
		if (parts.anchor) {
			result += parts.anchor;
		}
		return result;
	},

	isAbsolute: function(/*String*/uri) {
		// summary: uri starts with scheme or a slash
		var rx = new RegExp(/^((http|https|ftp)\:\/\/|\/)/g);
		return rx.test(uri);
	},

	getRelative: function(/*String*/baseUrl, /*String*/url) {
		var baseUrlParts = epages.lang.uri.parts(baseUrl);
		var urlParts = epages.lang.uri.parts(url);

		// protocols or hosts differ
		if ((urlParts.protocol != null && urlParts.protocol != baseUrlParts.protocol) ||
				(urlParts.host != null && urlParts.host != baseUrlParts.host)){
					return url;
		}

		baseUrlParts.path = baseUrlParts.path.replace(/\/+$/, '');
		urlParts.path = urlParts.path.replace(/\/+$/, '');
		var basePathSplitted = baseUrlParts.path.split('/');
		var urlPathSplitted = urlParts.path.split('/');

		// remove equal parts
		while (basePathSplitted.length > 0) {
			var basePathPart = basePathSplitted.shift();
			var urlPathPart = urlPathSplitted.shift();
			if (urlPathPart == null) {
				basePathSplitted.unshift(basePathPart);
				break;
			} else if (basePathPart != urlPathPart) {
				basePathSplitted.unshift(basePathPart);
				urlPathSplitted.unshift(urlPathPart);
				break;
			}
		}
		var result = '';
		for( var i=0,iLength=basePathSplitted.length ; i<iLength ; i++ ) { result += '../'; }
		return result + urlPathSplitted.join('/');
	}

};

}

if(!dojo._hasResource["dojo.date"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.date"] = true;
dojo.provide("dojo.date");

dojo.getObject("date", true, dojo);

/*=====
dojo.date = {
	// summary: Date manipulation utilities
}
=====*/

dojo.date.getDaysInMonth = function(/*Date*/dateObject){
	//	summary:
	//		Returns the number of days in the month used by dateObject
	var month = dateObject.getMonth();
	var days = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
	if(month == 1 && dojo.date.isLeapYear(dateObject)){ return 29; } // Number
	return days[month]; // Number
};

dojo.date.isLeapYear = function(/*Date*/dateObject){
	//	summary:
	//		Determines if the year of the dateObject is a leap year
	//	description:
	//		Leap years are years with an additional day YYYY-02-29, where the
	//		year number is a multiple of four with the following exception: If
	//		a year is a multiple of 100, then it is only a leap year if it is
	//		also a multiple of 400. For example, 1900 was not a leap year, but
	//		2000 is one.

	var year = dateObject.getFullYear();
	return !(year%400) || (!(year%4) && !!(year%100)); // Boolean
};

// FIXME: This is not localized
dojo.date.getTimezoneName = function(/*Date*/dateObject){
	//	summary:
	//		Get the user's time zone as provided by the browser
	// dateObject:
	//		Needed because the timezone may vary with time (daylight savings)
	//	description:
	//		Try to get time zone info from toString or toLocaleString method of
	//		the Date object -- UTC offset is not a time zone.  See
	//		http://www.twinsun.com/tz/tz-link.htm Note: results may be
	//		inconsistent across browsers.

	var str = dateObject.toString(); // Start looking in toString
	var tz = ''; // The result -- return empty string if nothing found
	var match;

	// First look for something in parentheses -- fast lookup, no regex
	var pos = str.indexOf('(');
	if(pos > -1){
		tz = str.substring(++pos, str.indexOf(')'));
	}else{
		// If at first you don't succeed ...
		// If IE knows about the TZ, it appears before the year
		// Capital letters or slash before a 4-digit year
		// at the end of string
		var pat = /([A-Z\/]+) \d{4}$/;
		if((match = str.match(pat))){
			tz = match[1];
		}else{
		// Some browsers (e.g. Safari) glue the TZ on the end
		// of toLocaleString instead of putting it in toString
			str = dateObject.toLocaleString();
			// Capital letters or slash -- end of string,
			// after space
			pat = / ([A-Z\/]+)$/;
			if((match = str.match(pat))){
				tz = match[1];
			}
		}
	}

	// Make sure it doesn't somehow end up return AM or PM
	return (tz == 'AM' || tz == 'PM') ? '' : tz; // String
};

// Utility methods to do arithmetic calculations with Dates

dojo.date.compare = function(/*Date*/date1, /*Date?*/date2, /*String?*/portion){
	//	summary:
	//		Compare two date objects by date, time, or both.
	//	description:
	//  	Returns 0 if equal, positive if a > b, else negative.
	//	date1:
	//		Date object
	//	date2:
	//		Date object.  If not specified, the current Date is used.
	//	portion:
	//		A string indicating the "date" or "time" portion of a Date object.
	//		Compares both "date" and "time" by default.  One of the following:
	//		"date", "time", "datetime"

	// Extra step required in copy for IE - see #3112
	date1 = new Date(+date1);
	date2 = new Date(+(date2 || new Date()));

	if(portion == "date"){
		// Ignore times and compare dates.
		date1.setHours(0, 0, 0, 0);
		date2.setHours(0, 0, 0, 0);
	}else if(portion == "time"){
		// Ignore dates and compare times.
		date1.setFullYear(0, 0, 0);
		date2.setFullYear(0, 0, 0);
	}
	
	if(date1 > date2){ return 1; } // int
	if(date1 < date2){ return -1; } // int
	return 0; // int
};

dojo.date.add = function(/*Date*/date, /*String*/interval, /*int*/amount){
	//	summary:
	//		Add to a Date in intervals of different size, from milliseconds to years
	//	date: Date
	//		Date object to start with
	//	interval:
	//		A string representing the interval.  One of the following:
	//			"year", "month", "day", "hour", "minute", "second",
	//			"millisecond", "quarter", "week", "weekday"
	//	amount:
	//		How much to add to the date.

	var sum = new Date(+date); // convert to Number before copying to accomodate IE (#3112)
	var fixOvershoot = false;
	var property = "Date";

	switch(interval){
		case "day":
			break;
		case "weekday":
			//i18n FIXME: assumes Saturday/Sunday weekend, but this is not always true.  see dojo.cldr.supplemental

			// Divide the increment time span into weekspans plus leftover days
			// e.g., 8 days is one 5-day weekspan / and two leftover days
			// Can't have zero leftover days, so numbers divisible by 5 get
			// a days value of 5, and the remaining days make up the number of weeks
			var days, weeks;
			var mod = amount % 5;
			if(!mod){
				days = (amount > 0) ? 5 : -5;
				weeks = (amount > 0) ? ((amount-5)/5) : ((amount+5)/5);
			}else{
				days = mod;
				weeks = parseInt(amount/5);
			}
			// Get weekday value for orig date param
			var strt = date.getDay();
			// Orig date is Sat / positive incrementer
			// Jump over Sun
			var adj = 0;
			if(strt == 6 && amount > 0){
				adj = 1;
			}else if(strt == 0 && amount < 0){
			// Orig date is Sun / negative incrementer
			// Jump back over Sat
				adj = -1;
			}
			// Get weekday val for the new date
			var trgt = strt + days;
			// New date is on Sat or Sun
			if(trgt == 0 || trgt == 6){
				adj = (amount > 0) ? 2 : -2;
			}
			// Increment by number of weeks plus leftover days plus
			// weekend adjustments
			amount = (7 * weeks) + days + adj;
			break;
		case "year":
			property = "FullYear";
			// Keep increment/decrement from 2/29 out of March
			fixOvershoot = true;
			break;
		case "week":
			amount *= 7;
			break;
		case "quarter":
			// Naive quarter is just three months
			amount *= 3;
			// fallthrough...
		case "month":
			// Reset to last day of month if you overshoot
			fixOvershoot = true;
			property = "Month";
			break;
//		case "hour":
//		case "minute":
//		case "second":
//		case "millisecond":
		default:
			property = "UTC"+interval.charAt(0).toUpperCase() + interval.substring(1) + "s";
	}

	if(property){
		sum["set"+property](sum["get"+property]()+amount);
	}

	if(fixOvershoot && (sum.getDate() < date.getDate())){
		sum.setDate(0);
	}

	return sum; // Date
};

dojo.date.difference = function(/*Date*/date1, /*Date?*/date2, /*String?*/interval){
	//	summary:
	//		Get the difference in a specific unit of time (e.g., number of
	//		months, weeks, days, etc.) between two dates, rounded to the
	//		nearest integer.
	//	date1:
	//		Date object
	//	date2:
	//		Date object.  If not specified, the current Date is used.
	//	interval:
	//		A string representing the interval.  One of the following:
	//			"year", "month", "day", "hour", "minute", "second",
	//			"millisecond", "quarter", "week", "weekday"
	//		Defaults to "day".

	date2 = date2 || new Date();
	interval = interval || "day";
	var yearDiff = date2.getFullYear() - date1.getFullYear();
	var delta = 1; // Integer return value

	switch(interval){
		case "quarter":
			var m1 = date1.getMonth();
			var m2 = date2.getMonth();
			// Figure out which quarter the months are in
			var q1 = Math.floor(m1/3) + 1;
			var q2 = Math.floor(m2/3) + 1;
			// Add quarters for any year difference between the dates
			q2 += (yearDiff * 4);
			delta = q2 - q1;
			break;
		case "weekday":
			var days = Math.round(dojo.date.difference(date1, date2, "day"));
			var weeks = parseInt(dojo.date.difference(date1, date2, "week"));
			var mod = days % 7;

			// Even number of weeks
			if(mod == 0){
				days = weeks*5;
			}else{
				// Weeks plus spare change (< 7 days)
				var adj = 0;
				var aDay = date1.getDay();
				var bDay = date2.getDay();

				weeks = parseInt(days/7);
				mod = days % 7;
				// Mark the date advanced by the number of
				// round weeks (may be zero)
				var dtMark = new Date(date1);
				dtMark.setDate(dtMark.getDate()+(weeks*7));
				var dayMark = dtMark.getDay();

				// Spare change days -- 6 or less
				if(days > 0){
					switch(true){
						// Range starts on Sat
						case aDay == 6:
							adj = -1;
							break;
						// Range starts on Sun
						case aDay == 0:
							adj = 0;
							break;
						// Range ends on Sat
						case bDay == 6:
							adj = -1;
							break;
						// Range ends on Sun
						case bDay == 0:
							adj = -2;
							break;
						// Range contains weekend
						case (dayMark + mod) > 5:
							adj = -2;
					}
				}else if(days < 0){
					switch(true){
						// Range starts on Sat
						case aDay == 6:
							adj = 0;
							break;
						// Range starts on Sun
						case aDay == 0:
							adj = 1;
							break;
						// Range ends on Sat
						case bDay == 6:
							adj = 2;
							break;
						// Range ends on Sun
						case bDay == 0:
							adj = 1;
							break;
						// Range contains weekend
						case (dayMark + mod) < 0:
							adj = 2;
					}
				}
				days += adj;
				days -= (weeks*2);
			}
			delta = days;
			break;
		case "year":
			delta = yearDiff;
			break;
		case "month":
			delta = (date2.getMonth() - date1.getMonth()) + (yearDiff * 12);
			break;
		case "week":
			// Truncate instead of rounding
			// Don't use Math.floor -- value may be negative
			delta = parseInt(dojo.date.difference(date1, date2, "day")/7);
			break;
		case "day":
			delta /= 24;
			// fallthrough
		case "hour":
			delta /= 60;
			// fallthrough
		case "minute":
			delta /= 60;
			// fallthrough
		case "second":
			delta /= 1000;
			// fallthrough
		case "millisecond":
			delta *= date2.getTime() - date1.getTime();
	}

	// Round for fractional values and DST leaps
	return Math.round(delta); // Number (integer)
};

}

if(!dojo._hasResource["dojo.cldr.supplemental"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.cldr.supplemental"] = true;
dojo.provide("dojo.cldr.supplemental");


dojo.getObject("cldr.supplemental", true, dojo);

dojo.cldr.supplemental.getFirstDayOfWeek = function(/*String?*/locale){
// summary: Returns a zero-based index for first day of the week
// description:
//		Returns a zero-based index for first day of the week, as used by the local (Gregorian) calendar.
//		e.g. Sunday (returns 0), or Monday (returns 1)

	// from http://www.unicode.org/cldr/data/common/supplemental/supplementalData.xml:supplementalData/weekData/firstDay
	var firstDay = {/*default is 1=Monday*/
		mv:5,
		ae:6,af:6,bh:6,dj:6,dz:6,eg:6,er:6,et:6,iq:6,ir:6,jo:6,ke:6,kw:6,
		ly:6,ma:6,om:6,qa:6,sa:6,sd:6,so:6,sy:6,tn:6,ye:6,
		ar:0,as:0,az:0,bw:0,ca:0,cn:0,fo:0,ge:0,gl:0,gu:0,hk:0,
		il:0,'in':0,jm:0,jp:0,kg:0,kr:0,la:0,mh:0,mn:0,mo:0,mp:0,
		mt:0,nz:0,ph:0,pk:0,sg:0,th:0,tt:0,tw:0,um:0,us:0,uz:0,
		vi:0,zw:0
// variant. do not use?		gb:0,
	};

	var country = dojo.cldr.supplemental._region(locale);
	var dow = firstDay[country];
	return (dow === undefined) ? 1 : dow; /*Number*/
};

dojo.cldr.supplemental._region = function(/*String?*/locale){
	locale = dojo.i18n.normalizeLocale(locale);
	var tags = locale.split('-');
	var region = tags[1];
	if(!region){
		// IE often gives language only (#2269)
		// Arbitrary mappings of language-only locales to a country:
		region = {de:"de", en:"us", es:"es", fi:"fi", fr:"fr", he:"il", hu:"hu", it:"it",
			ja:"jp", ko:"kr", nl:"nl", pt:"br", sv:"se", zh:"cn"}[tags[0]];
	}else if(region.length == 4){
		// The ISO 3166 country code is usually in the second position, unless a
		// 4-letter script is given. See http://www.ietf.org/rfc/rfc4646.txt
		region = tags[2];
	}
	return region;
};

dojo.cldr.supplemental.getWeekend = function(/*String?*/locale){
// summary: Returns a hash containing the start and end days of the weekend
// description:
//		Returns a hash containing the start and end days of the weekend according to local custom using locale,
//		or by default in the user's locale.
//		e.g. {start:6, end:0}

	// from http://www.unicode.org/cldr/data/common/supplemental/supplementalData.xml:supplementalData/weekData/weekend{Start,End}
	var weekendStart = {/*default is 6=Saturday*/
		'in':0,
		af:4,dz:4,ir:4,om:4,sa:4,ye:4,
		ae:5,bh:5,eg:5,il:5,iq:5,jo:5,kw:5,ly:5,ma:5,qa:5,sd:5,sy:5,tn:5
	};

	var weekendEnd = {/*default is 0=Sunday*/
		af:5,dz:5,ir:5,om:5,sa:5,ye:5,
		ae:6,bh:5,eg:6,il:6,iq:6,jo:6,kw:6,ly:6,ma:6,qa:6,sd:6,sy:6,tn:6
	};

	var country = dojo.cldr.supplemental._region(locale);
	var start = weekendStart[country];
	var end = weekendEnd[country];
	if(start === undefined){start=6;}
	if(end === undefined){end=0;}
	return {start:start, end:end}; /*Object {start,end}*/
};

}

if(!dojo._hasResource["dojo.regexp"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.regexp"] = true;
dojo.provide("dojo.regexp");

dojo.getObject("regexp", true, dojo);

/*=====
dojo.regexp = {
	// summary: Regular expressions and Builder resources
};
=====*/

dojo.regexp.escapeString = function(/*String*/str, /*String?*/except){
	//	summary:
	//		Adds escape sequences for special characters in regular expressions
	// except:
	//		a String with special characters to be left unescaped

	return str.replace(/([\.$?*|{}\(\)\[\]\\\/\+^])/g, function(ch){
		if(except && except.indexOf(ch) != -1){
			return ch;
		}
		return "\\" + ch;
	}); // String
};

dojo.regexp.buildGroupRE = function(/*Object|Array*/arr, /*Function*/re, /*Boolean?*/nonCapture){
	//	summary:
	//		Builds a regular expression that groups subexpressions
	//	description:
	//		A utility function used by some of the RE generators. The
	//		subexpressions are constructed by the function, re, in the second
	//		parameter.  re builds one subexpression for each elem in the array
	//		a, in the first parameter. Returns a string for a regular
	//		expression that groups all the subexpressions.
	// arr:
	//		A single value or an array of values.
	// re:
	//		A function. Takes one parameter and converts it to a regular
	//		expression.
	// nonCapture:
	//		If true, uses non-capturing match, otherwise matches are retained
	//		by regular expression. Defaults to false

	// case 1: a is a single value.
	if(!(arr instanceof Array)){
		return re(arr); // String
	}

	// case 2: a is an array
	var b = [];
	for(var i = 0; i < arr.length; i++){
		// convert each elem to a RE
		b.push(re(arr[i]));
	}

	 // join the REs as alternatives in a RE group.
	return dojo.regexp.group(b.join("|"), nonCapture); // String
};

dojo.regexp.group = function(/*String*/expression, /*Boolean?*/nonCapture){
	// summary:
	//		adds group match to expression
	// nonCapture:
	//		If true, uses non-capturing match, otherwise matches are retained
	//		by regular expression.
	return "(" + (nonCapture ? "?:":"") + expression + ")"; // String
};

}

if(!dojo._hasResource["dojo.date.locale"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.date.locale"] = true;
dojo.provide("dojo.date.locale");







dojo.getObject("date.locale", true, dojo);

// Localization methods for Date.   Honor local customs using locale-dependent dojo.cldr data.


// Load the bundles containing localization information for
// names and formats

//NOTE: Everything in this module assumes Gregorian calendars.
// Other calendars will be implemented in separate modules.

(function(){
	// Format a pattern without literals
	function formatPattern(dateObject, bundle, options, pattern){
		return pattern.replace(/([a-z])\1*/ig, function(match){
			var s, pad,
				c = match.charAt(0),
				l = match.length,
				widthList = ["abbr", "wide", "narrow"];
			switch(c){
				case 'G':
					s = bundle[(l < 4) ? "eraAbbr" : "eraNames"][dateObject.getFullYear() < 0 ? 0 : 1];
					break;
				case 'y':
					s = dateObject.getFullYear();
					switch(l){
						case 1:
							break;
						case 2:
							if(!options.fullYear){
								s = String(s); s = s.substr(s.length - 2);
								break;
							}
							// fallthrough
						default:
							pad = true;
					}
					break;
				case 'Q':
				case 'q':
					s = Math.ceil((dateObject.getMonth()+1)/3);
//					switch(l){
//						case 1: case 2:
							pad = true;
//							break;
//						case 3: case 4: // unimplemented
//					}
					break;
				case 'M':
					var m = dateObject.getMonth();
					if(l<3){
						s = m+1; pad = true;
					}else{
						var propM = ["months", "format", widthList[l-3]].join("-");
						s = bundle[propM][m];
					}
					break;
				case 'w':
					var firstDay = 0;
					s = dojo.date.locale._getWeekOfYear(dateObject, firstDay); pad = true;
					break;
				case 'd':
					s = dateObject.getDate(); pad = true;
					break;
				case 'D':
					s = dojo.date.locale._getDayOfYear(dateObject); pad = true;
					break;
				case 'E':
					var d = dateObject.getDay();
					if(l<3){
						s = d+1; pad = true;
					}else{
						var propD = ["days", "format", widthList[l-3]].join("-");
						s = bundle[propD][d];
					}
					break;
				case 'a':
					var timePeriod = (dateObject.getHours() < 12) ? 'am' : 'pm';
					s = options[timePeriod] || bundle['dayPeriods-format-wide-' + timePeriod];
					break;
				case 'h':
				case 'H':
				case 'K':
				case 'k':
					var h = dateObject.getHours();
					// strange choices in the date format make it impossible to write this succinctly
					switch (c){
						case 'h': // 1-12
							s = (h % 12) || 12;
							break;
						case 'H': // 0-23
							s = h;
							break;
						case 'K': // 0-11
							s = (h % 12);
							break;
						case 'k': // 1-24
							s = h || 24;
							break;
					}
					pad = true;
					break;
				case 'm':
					s = dateObject.getMinutes(); pad = true;
					break;
				case 's':
					s = dateObject.getSeconds(); pad = true;
					break;
				case 'S':
					s = Math.round(dateObject.getMilliseconds() * Math.pow(10, l-3)); pad = true;
					break;
				case 'v': // FIXME: don't know what this is. seems to be same as z?
				case 'z':
					// We only have one timezone to offer; the one from the browser
					s = dojo.date.locale._getZone(dateObject, true, options);
					if(s){break;}
					l=4;
					// fallthrough... use GMT if tz not available
				case 'Z':
					var offset = dojo.date.locale._getZone(dateObject, false, options);
					var tz = [
						(offset<=0 ? "+" : "-"),
						dojo.string.pad(Math.floor(Math.abs(offset)/60), 2),
						dojo.string.pad(Math.abs(offset)% 60, 2)
					];
					if(l==4){
						tz.splice(0, 0, "GMT");
						tz.splice(3, 0, ":");
					}
					s = tz.join("");
					break;
//				case 'Y': case 'u': case 'W': case 'F': case 'g': case 'A': case 'e':
//					console.log(match+" modifier unimplemented");
				default:
					throw new Error("dojo.date.locale.format: invalid pattern char: "+pattern);
			}
			if(pad){ s = dojo.string.pad(s, l); }
			return s;
		});
	}

/*=====
	dojo.date.locale.__FormatOptions = function(){
	//	selector: String
	//		choice of 'time','date' (default: date and time)
	//	formatLength: String
	//		choice of long, short, medium or full (plus any custom additions).  Defaults to 'short'
	//	datePattern:String
	//		override pattern with this string
	//	timePattern:String
	//		override pattern with this string
	//	am: String
	//		override strings for am in times
	//	pm: String
	//		override strings for pm in times
	//	locale: String
	//		override the locale used to determine formatting rules
	//	fullYear: Boolean
	//		(format only) use 4 digit years whenever 2 digit years are called for
	//	strict: Boolean
	//		(parse only) strict parsing, off by default
		this.selector = selector;
		this.formatLength = formatLength;
		this.datePattern = datePattern;
		this.timePattern = timePattern;
		this.am = am;
		this.pm = pm;
		this.locale = locale;
		this.fullYear = fullYear;
		this.strict = strict;
	}
=====*/

dojo.date.locale._getZone = function(/*Date*/dateObject, /*boolean*/getName, /*dojo.date.locale.__FormatOptions?*/options){
	// summary:
	//		Returns the zone (or offset) for the given date and options.  This
	//		is broken out into a separate function so that it can be overridden
	//		by timezone-aware code.
	//
	// dateObject:
	//		the date and/or time being formatted.
	//
	// getName:
	//		Whether to return the timezone string (if true), or the offset (if false)
	//
	// options:
	//		The options being used for formatting
	if(getName){
		return dojo.date.getTimezoneName(dateObject);
	}else{
		return dateObject.getTimezoneOffset();
	}
};


dojo.date.locale.format = function(/*Date*/dateObject, /*dojo.date.locale.__FormatOptions?*/options){
	// summary:
	//		Format a Date object as a String, using locale-specific settings.
	//
	// description:
	//		Create a string from a Date object using a known localized pattern.
	//		By default, this method formats both date and time from dateObject.
	//		Formatting patterns are chosen appropriate to the locale.  Different
	//		formatting lengths may be chosen, with "full" used by default.
	//		Custom patterns may be used or registered with translations using
	//		the dojo.date.locale.addCustomFormats method.
	//		Formatting patterns are implemented using [the syntax described at
	//		unicode.org](http://www.unicode.org/reports/tr35/tr35-4.html#Date_Format_Patterns)
	//
	// dateObject:
	//		the date and/or time to be formatted.  If a time only is formatted,
	//		the values in the year, month, and day fields are irrelevant.  The
	//		opposite is true when formatting only dates.

	options = options || {};

	var locale = dojo.i18n.normalizeLocale(options.locale),
		formatLength = options.formatLength || 'short',
		bundle = dojo.date.locale._getGregorianBundle(locale),
		str = [],
		sauce = dojo.hitch(this, formatPattern, dateObject, bundle, options);
	if(options.selector == "year"){
		return _processPattern(bundle["dateFormatItem-yyyy"] || "yyyy", sauce);
	}
	var pattern;
	if(options.selector != "date"){
		pattern = options.timePattern || bundle["timeFormat-"+formatLength];
		if(pattern){str.push(_processPattern(pattern, sauce));}
	}
	if(options.selector != "time"){
		pattern = options.datePattern || bundle["dateFormat-"+formatLength];
		if(pattern){str.push(_processPattern(pattern, sauce));}
	}

	return str.length == 1 ? str[0] : bundle["dateTimeFormat-"+formatLength].replace(/\{(\d+)\}/g,
		function(match, key){ return str[key]; }); // String
};

dojo.date.locale.regexp = function(/*dojo.date.locale.__FormatOptions?*/options){
	// summary:
	//		Builds the regular needed to parse a localized date

	return dojo.date.locale._parseInfo(options).regexp; // String
};

dojo.date.locale._parseInfo = function(/*dojo.date.locale.__FormatOptions?*/options){
	options = options || {};
	var locale = dojo.i18n.normalizeLocale(options.locale),
		bundle = dojo.date.locale._getGregorianBundle(locale),
		formatLength = options.formatLength || 'short',
		datePattern = options.datePattern || bundle["dateFormat-" + formatLength],
		timePattern = options.timePattern || bundle["timeFormat-" + formatLength],
		pattern;
	if(options.selector == 'date'){
		pattern = datePattern;
	}else if(options.selector == 'time'){
		pattern = timePattern;
	}else{
		pattern = bundle["dateTimeFormat-"+formatLength].replace(/\{(\d+)\}/g,
			function(match, key){ return [timePattern, datePattern][key]; });
	}

	var tokens = [],
		re = _processPattern(pattern, dojo.hitch(this, _buildDateTimeRE, tokens, bundle, options));
	return {regexp: re, tokens: tokens, bundle: bundle};
};

dojo.date.locale.parse = function(/*String*/value, /*dojo.date.locale.__FormatOptions?*/options){
	// summary:
	//		Convert a properly formatted string to a primitive Date object,
	//		using locale-specific settings.
	//
	// description:
	//		Create a Date object from a string using a known localized pattern.
	//		By default, this method parses looking for both date and time in the string.
	//		Formatting patterns are chosen appropriate to the locale.  Different
	//		formatting lengths may be chosen, with "full" used by default.
	//		Custom patterns may be used or registered with translations using
	//		the dojo.date.locale.addCustomFormats method.
	//
	//		Formatting patterns are implemented using [the syntax described at
	//		unicode.org](http://www.unicode.org/reports/tr35/tr35-4.html#Date_Format_Patterns)
	//		When two digit years are used, a century is chosen according to a sliding
	//		window of 80 years before and 20 years after present year, for both `yy` and `yyyy` patterns.
	//		year < 100CE requires strict mode.
	//
	// value:
	//		A string representation of a date

	// remove non-printing bidi control chars from input and pattern
	var controlChars = /[\u200E\u200F\u202A\u202E]/g,
		info = dojo.date.locale._parseInfo(options),
		tokens = info.tokens, bundle = info.bundle,
		re = new RegExp("^" + info.regexp.replace(controlChars, "") + "$",
			info.strict ? "" : "i"),
		match = re.exec(value && value.replace(controlChars, ""));

	if(!match){ return null; } // null

	var widthList = ['abbr', 'wide', 'narrow'],
		result = [1970,0,1,0,0,0,0], // will get converted to a Date at the end
		amPm = "",
		valid = dojo.every(match, function(v, i){
		if(!i){return true;}
		var token=tokens[i-1];
		var l=token.length;
		switch(token.charAt(0)){
			case 'y':
				if(l != 2 && options.strict){
					//interpret year literally, so '5' would be 5 A.D.
					result[0] = v;
				}else{
					if(v<100){
						v = Number(v);
						//choose century to apply, according to a sliding window
						//of 80 years before and 20 years after present year
						var year = '' + new Date().getFullYear(),
							century = year.substring(0, 2) * 100,
							cutoff = Math.min(Number(year.substring(2, 4)) + 20, 99),
							num = (v < cutoff) ? century + v : century - 100 + v;
						result[0] = num;
					}else{
						//we expected 2 digits and got more...
						if(options.strict){
							return false;
						}
						//interpret literally, so '150' would be 150 A.D.
						//also tolerate '1950', if 'yyyy' input passed to 'yy' format
						result[0] = v;
					}
				}
				break;
			case 'M':
				if(l>2){
					var months = bundle['months-format-' + widthList[l-3]].concat();
					if(!options.strict){
						//Tolerate abbreviating period in month part
						//Case-insensitive comparison
						v = v.replace(".","").toLowerCase();
						months = dojo.map(months, function(s){ return s.replace(".","").toLowerCase(); } );
					}
					v = dojo.indexOf(months, v);
					if(v == -1){
//						console.log("dojo.date.locale.parse: Could not parse month name: '" + v + "'.");
						return false;
					}
				}else{
					v--;
				}
				result[1] = v;
				break;
			case 'E':
			case 'e':
				var days = bundle['days-format-' + widthList[l-3]].concat();
				if(!options.strict){
					//Case-insensitive comparison
					v = v.toLowerCase();
					days = dojo.map(days, function(d){return d.toLowerCase();});
				}
				v = dojo.indexOf(days, v);
				if(v == -1){
//					console.log("dojo.date.locale.parse: Could not parse weekday name: '" + v + "'.");
					return false;
				}

				//TODO: not sure what to actually do with this input,
				//in terms of setting something on the Date obj...?
				//without more context, can't affect the actual date
				//TODO: just validate?
				break;
			case 'D':
				result[1] = 0;
				// fallthrough...
			case 'd':
				result[2] = v;
				break;
			case 'a': //am/pm
				var am = options.am || bundle['dayPeriods-format-wide-am'],
					pm = options.pm || bundle['dayPeriods-format-wide-pm'];
				if(!options.strict){
					var period = /\./g;
					v = v.replace(period,'').toLowerCase();
					am = am.replace(period,'').toLowerCase();
					pm = pm.replace(period,'').toLowerCase();
				}
				if(options.strict && v != am && v != pm){
//					console.log("dojo.date.locale.parse: Could not parse am/pm part.");
					return false;
				}

				// we might not have seen the hours field yet, so store the state and apply hour change later
				amPm = (v == pm) ? 'p' : (v == am) ? 'a' : '';
				break;
			case 'K': //hour (1-24)
				if(v == 24){ v = 0; }
				// fallthrough...
			case 'h': //hour (1-12)
			case 'H': //hour (0-23)
			case 'k': //hour (0-11)
				//TODO: strict bounds checking, padding
				if(v > 23){
//					console.log("dojo.date.locale.parse: Illegal hours value");
					return false;
				}

				//in the 12-hour case, adjusting for am/pm requires the 'a' part
				//which could come before or after the hour, so we will adjust later
				result[3] = v;
				break;
			case 'm': //minutes
				result[4] = v;
				break;
			case 's': //seconds
				result[5] = v;
				break;
			case 'S': //milliseconds
				result[6] = v;
//				break;
//			case 'w':
//TODO				var firstDay = 0;
//			default:
//TODO: throw?
//				console.log("dojo.date.locale.parse: unsupported pattern char=" + token.charAt(0));
		}
		return true;
	});

	var hours = +result[3];
	if(amPm === 'p' && hours < 12){
		result[3] = hours + 12; //e.g., 3pm -> 15
	}else if(amPm === 'a' && hours == 12){
		result[3] = 0; //12am -> 0
	}

	//TODO: implement a getWeekday() method in order to test
	//validity of input strings containing 'EEE' or 'EEEE'...

	var dateObject = new Date(result[0], result[1], result[2], result[3], result[4], result[5], result[6]); // Date
	if(options.strict){
		dateObject.setFullYear(result[0]);
	}

	// Check for overflow.  The Date() constructor normalizes things like April 32nd...
	//TODO: why isn't this done for times as well?
	var allTokens = tokens.join(""),
		dateToken = allTokens.indexOf('d') != -1,
		monthToken = allTokens.indexOf('M') != -1;

	if(!valid ||
		(monthToken && dateObject.getMonth() > result[1]) ||
		(dateToken && dateObject.getDate() > result[2])){
		return null;
	}

	// Check for underflow, due to DST shifts.  See #9366
	// This assumes a 1 hour dst shift correction at midnight
	// We could compare the timezone offset after the shift and add the difference instead.
	if((monthToken && dateObject.getMonth() < result[1]) ||
		(dateToken && dateObject.getDate() < result[2])){
		dateObject = dojo.date.add(dateObject, "hour", 1);
	}

	return dateObject; // Date
};

function _processPattern(pattern, applyPattern, applyLiteral, applyAll){
	//summary: Process a pattern with literals in it

	// Break up on single quotes, treat every other one as a literal, except '' which becomes '
	var identity = function(x){return x;};
	applyPattern = applyPattern || identity;
	applyLiteral = applyLiteral || identity;
	applyAll = applyAll || identity;

	//split on single quotes (which escape literals in date format strings)
	//but preserve escaped single quotes (e.g., o''clock)
	var chunks = pattern.match(/(''|[^'])+/g),
		literal = pattern.charAt(0) == "'";

	dojo.forEach(chunks, function(chunk, i){
		if(!chunk){
			chunks[i]='';
		}else{
			chunks[i]=(literal ? applyLiteral : applyPattern)(chunk.replace(/''/g, "'"));
			literal = !literal;
		}
	});
	return applyAll(chunks.join(''));
}

function _buildDateTimeRE(tokens, bundle, options, pattern){
	pattern = dojo.regexp.escapeString(pattern);
	if(!options.strict){ pattern = pattern.replace(" a", " ?a"); } // kludge to tolerate no space before am/pm
	return pattern.replace(/([a-z])\1*/ig, function(match){
		// Build a simple regexp.  Avoid captures, which would ruin the tokens list
		var s,
			c = match.charAt(0),
			l = match.length,
			p2 = '', p3 = '';
		if(options.strict){
			if(l > 1){ p2 = '0' + '{'+(l-1)+'}'; }
			if(l > 2){ p3 = '0' + '{'+(l-2)+'}'; }
		}else{
			p2 = '0?'; p3 = '0{0,2}';
		}
		switch(c){
			case 'y':
				s = '\\d{2,4}';
				break;
			case 'M':
				s = (l>2) ? '\\S+?' : '1[0-2]|'+p2+'[1-9]';
				break;
			case 'D':
				s = '[12][0-9][0-9]|3[0-5][0-9]|36[0-6]|'+p3+'[1-9][0-9]|'+p2+'[1-9]';
				break;
			case 'd':
				s = '3[01]|[12]\\d|'+p2+'[1-9]';
				break;
			case 'w':
				s = '[1-4][0-9]|5[0-3]|'+p2+'[1-9]';
				break;
			case 'E':
				s = '\\S+';
				break;
			case 'h': //hour (1-12)
				s = '1[0-2]|'+p2+'[1-9]';
				break;
			case 'k': //hour (0-11)
				s = '1[01]|'+p2+'\\d';
				break;
			case 'H': //hour (0-23)
				s = '1\\d|2[0-3]|'+p2+'\\d';
				break;
			case 'K': //hour (1-24)
				s = '1\\d|2[0-4]|'+p2+'[1-9]';
				break;
			case 'm':
			case 's':
				s = '[0-5]\\d';
				break;
			case 'S':
				s = '\\d{'+l+'}';
				break;
			case 'a':
				var am = options.am || bundle['dayPeriods-format-wide-am'],
					pm = options.pm || bundle['dayPeriods-format-wide-pm'];
				s = am + '|' + pm;
				if(!options.strict){
					if(am != am.toLowerCase()){ s += '|' + am.toLowerCase(); }
					if(pm != pm.toLowerCase()){ s += '|' + pm.toLowerCase(); }
					if(s.indexOf('.') != -1){ s += '|' + s.replace(/\./g, ""); }
				}
				s = s.replace(/\./g, "\\.");
				break;
			default:
			// case 'v':
			// case 'z':
			// case 'Z':
				s = ".*";
//				console.log("parse of date format, pattern=" + pattern);
		}

		if(tokens){ tokens.push(match); }

		return "(" + s + ")"; // add capture
	}).replace(/[\xa0 ]/g, "[\\s\\xa0]"); // normalize whitespace.  Need explicit handling of \xa0 for IE.
}
})();

(function(){
var _customFormats = [];
dojo.date.locale.addCustomFormats = function(/*String*/packageName, /*String*/bundleName){
	// summary:
	//		Add a reference to a bundle containing localized custom formats to be
	//		used by date/time formatting and parsing routines.
	//
	// description:
	//		The user may add custom localized formats where the bundle has properties following the
	//		same naming convention used by dojo.cldr: `dateFormat-xxxx` / `timeFormat-xxxx`
	//		The pattern string should match the format used by the CLDR.
	//		See dojo.date.locale.format() for details.
	//		The resources must be loaded by dojo.requireLocalization() prior to use

	_customFormats.push({pkg:packageName,name:bundleName});
};

dojo.date.locale._getGregorianBundle = function(/*String*/locale){
	var gregorian = {};
	dojo.forEach(_customFormats, function(desc){
		var bundle = dojo.i18n.getLocalization(desc.pkg, desc.name, locale);
		gregorian = dojo.mixin(gregorian, bundle);
	}, this);
	return gregorian; /*Object*/
};
})();

dojo.date.locale.addCustomFormats("dojo.cldr","gregorian");

dojo.date.locale.getNames = function(/*String*/item, /*String*/type, /*String?*/context, /*String?*/locale){
	// summary:
	//		Used to get localized strings from dojo.cldr for day or month names.
	//
	// item:
	//	'months' || 'days'
	// type:
	//	'wide' || 'narrow' || 'abbr' (e.g. "Monday", "Mon", or "M" respectively, in English)
	// context:
	//	'standAlone' || 'format' (default)
	// locale:
	//	override locale used to find the names

	var label,
		lookup = dojo.date.locale._getGregorianBundle(locale),
		props = [item, context, type];
	if(context == 'standAlone'){
		var key = props.join('-');
		label = lookup[key];
		// Fall back to 'format' flavor of name
		if(label[0] == 1){ label = undefined; } // kludge, in the absence of real aliasing support in dojo.cldr
	}
	props[1] = 'format';

	// return by copy so changes won't be made accidentally to the in-memory model
	return (label || lookup[props.join('-')]).concat(); /*Array*/
};

dojo.date.locale.isWeekend = function(/*Date?*/dateObject, /*String?*/locale){
	// summary:
	//	Determines if the date falls on a weekend, according to local custom.

	var weekend = dojo.cldr.supplemental.getWeekend(locale),
		day = (dateObject || new Date()).getDay();
	if(weekend.end < weekend.start){
		weekend.end += 7;
		if(day < weekend.start){ day += 7; }
	}
	return day >= weekend.start && day <= weekend.end; // Boolean
};

// These are used only by format and strftime.  Do they need to be public?  Which module should they go in?

dojo.date.locale._getDayOfYear = function(/*Date*/dateObject){
	// summary: gets the day of the year as represented by dateObject
	return dojo.date.difference(new Date(dateObject.getFullYear(), 0, 1, dateObject.getHours()), dateObject) + 1; // Number
};

dojo.date.locale._getWeekOfYear = function(/*Date*/dateObject, /*Number*/firstDayOfWeek){
	if(arguments.length == 1){ firstDayOfWeek = 0; } // Sunday

	var firstDayOfYear = new Date(dateObject.getFullYear(), 0, 1).getDay(),
		adj = (firstDayOfYear - firstDayOfWeek + 7) % 7,
		week = Math.floor((dojo.date.locale._getDayOfYear(dateObject) + adj - 1) / 7);

	// if year starts on the specified day, start counting weeks at 1
	if(firstDayOfYear == firstDayOfWeek){ week++; }

	return week; // Number
};

}

if(!dojo._hasResource["epages.localize"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.localize"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.localize");








(function(){

epages.localize = {
	// summary: formats a number by using formatting chars from the user's locale
	formatNumber: function(/*Float*/value, /*Integer?*/decimalDigits) {
		var negativeString = (value < 0) ? '-' : '';
		var valueAbs = Math.abs(value);

		if (decimalDigits == null){
			decimalDigits = 2;
		}
		var precision = Math.pow(10, decimalDigits);
		var intPart = Math.floor(Math.round(valueAbs * precision) / precision);
		var ratPart = Math.round(Math.abs(valueAbs - intPart) * precision);
		if (ratPart != 0) {
			return negativeString +intPart + epages.vars.Locale.decimalSep + ratPart;
		} else {
			return negativeString+intPart;
		}
	},

	formatBytes: function(bytes, decimalDigits) {
		if (decimalDigits == null){
			decimalDigits = 2;
		}
		var unit = "Byte";
		if (bytes >= 1073741824) {
			// GB
			bytes /= 1073741824;
			unit = "GB";
		} else if (bytes >= 1048576) {
			// MB
			bytes /= 1048576;
			unit = "MB";
		} else if (bytes >= 1024) {
			// kB
			bytes /= 1024;
			unit = "kB";
		}
		return epages.localize.formatNumber(bytes, decimalDigits) + " " + unit;
	},

  // assign epages pattern elements to dojo pattern elements
  // see http://www.unicode.org/reports/tr35/tr35-4.html#Date_Format_Patterns for more
  // information
  // IMPORTANT! Only patterns that are supported by epages (existing Locales) are defined
	_patternCache: $H(),
	_patternMap: {
	  // -- YEAR -- //
 		// full year, 2007
		'%{ce_year}': 'yyyy',
 		// short year, 2 digits: 07
		'%y': 'yy',

		// -- MONTH -- //
 		// localized full month name: Oktober
		'%B': 'MMMM',
 		// localized month abbreviation: Okt
		'%b': 'MMM',
 		// month, 2 digits: 05 (may)
		'%m': 'MM',
 		// month, 5
		'%{month}': 'M',

		// -- DAY -- //
		// day, 2 digits, leading zero: '07'
		'%d': 'dd',
		// day, 2 digits, leading zero: '07'
		'%{day}': 'd',
 		// localized day name: Montag
		'%A': 'EEEE',

		// -- HOUR -- //
 		// hour, 24h, 2 digits, leading zero: '09'
		'%H': 'HH',
 		// hour, 24h
		'%{hour}': 'H',
 		// hour, 12h
		'%{hour_12}': 'h',

		// -- MINUTE -- //
 		// minutes, 2 digits, leading zero: '05'
		'%M': 'mm',

		// -- SECOND -- //
		// seconds, 2 digits, leading zero: '05'
		'%S': 'ss',

		// -- SPECIAL -- //
 		// AM or PM, upper case: AM
		'%p': 'a',
 		// time zone, '+0100'
    	'%{time_zone_long_name}': 'ZZ'
	},


	getDojoDateTimePattern: function(epagesPattern) {
		// summary: converts an epages date pattern to a Dojo date pattern.
	  // note: this function does not support all declared specifiers
		if (epagesPattern == null){
			epagesPattern = epages.vars.Locale.dateFormat;
		}
		if (this._patternCache.existsKey(epagesPattern)){
			return this._patternCache.get(epagesPattern); //String
		}
	  var dojoPattern = epagesPattern;
		// relace elements in string with values
		var elementPatterns = $A($A($H(epages.localize._patternMap).keys()).sort(function(a, b) { return b.length - a.length; }));

		elementPatterns.each(function(element) {
		  var rx = new RegExp(element, 'g');
		  dojoPattern = dojoPattern.replace(rx, function() {
		    return epages.localize._patternMap[element];
		  });
		});
		return dojoPattern; //String
	},

	formatDateTime: function(/*Date*/date, /*String?*/epagesPattern) {
	  // summary: replaces the pattern specifiers with real values
		if (date == null){
			return '';
		}
		if (epagesPattern == null){
			epagesPattern = epages.vars.Locale.dateFormat;
		}
		var d = dojo.date.locale.format(date, {
		  datePattern: this.getDojoDateTimePattern(epagesPattern),
		  timePattern: ' '
		});
		// trim last to chars --> spaces
		return d.substring(0, d.length - 2);
	},

	parseDateTime: function (/*String*/ dateString, /*String*/ epagesPattern) {
		if (epagesPattern == null){
			epagesPattern = epages.vars.Locale.dateFormat;
		}
		return dojo.date.locale.parse('~ ' + dateString, {
			selector: 'timeOnly',
			timePattern: this.getDojoDateTimePattern(epagesPattern),
			datePattern: '~'
		});
	},

	parseNumber: function(/*String*/ numberString){
		var thousandExp = new RegExp( dojo.regexp.escapeString(epages.vars.Locale.thousandSep), 'g' ),
			decimalExp = new RegExp( dojo.regexp.escapeString(epages.vars.Locale.decimalSep), 'g' );

		return parseFloat( numberString.replace(thousandExp,'').replace(decimalExp,'.') );
	},
	getFormat: function(type) {
		var ret = _format[type];

		if( !ret ){
			switch(type){
				case 'date':
					ret = _format[type] = epages.localize.getDojoDateTimePattern( epages.vars.Locale.dateFormat );
				break;
				case 'datetime':
					ret = _format[type] = epages.localize.getDojoDateTimePattern( epages.vars.Locale.datetimeFormat );
				break;
				case 'time':
					ret = _format[type] = epages.localize.getDojoDateTimePattern( epages.vars.Locale.timeFormat );
				break;
				case 'number':
					ret = _format[type] = dojo.regexp.escapeString('-? ?[0-9'+_separator.thousand+']+['+_separator.decimal+']?[0-9]*', '([]{}+?*)');
				break;
				case 'money':
					ret = _format[type] = dojo.regexp.escapeString('(['+_separator.money+']? ?-? ?[0-9'+_separator.thousand+']{1,}['+_separator.decimal+']?[0-9]{0,2}|-? ?[0-9'+_separator.thousand+']{1,}['+_separator.decimal+']?[0-9]{0,2} ?['+_separator.money+']?)', '([|]{}?)')
				break;
			}
		}

		return ret;
	},
	getPattern: function(type) {
		var ret = _pattern[type];

		if( !ret ){
			switch(type){

				case 'date':
				case 'datetime':
				case 'time':
				case 'month':
				case 'week':
					ret = _pattern[type] = dojo.date.locale.regexp({ selector:'date',	datePattern: this.getFormat(type),		timePattern:'' })
				break;
				case 'number':
					ret = _pattern[type] = dojo.regexp.escapeString('-? ?[0-9'+epages.vars.Locale.thousandSep+']+['+epages.vars.Locale.decimalSep+']?[0-9]*', '([]{}+?*)');
				break;
				case 'money':
					ret = _pattern[type] = dojo.regexp.escapeString('(['+epages.vars.Locale.moneySymbol||''+']? ?-? ?[0-9'+epages.vars.Locale.thousandSep+']{1,}['+epages.vars.Locale.decimalSep+']?[0-9]{0,2}|-? ?[0-9'+epages.vars.Locale.thousandSep+']{1,}['+epages.vars.Locale.decimalSep+']?[0-9]{0,2} ?['+epages.vars.Locale.moneySymbol||''+']?)', '([|]{}?)')
				break;
			}
		}

		return ret;
	},
	getSeparator: function(type) {
		return _separator[type];
	},
	date2obj: function( input , type ) {
		return dojo.date.locale.parse(
					input,
					{
						selector: 		'date',
						datePattern: 	_format[type],
						timePattern: 	''
					}
				);
	},
	obj2date: function( input , type ) {
		return dojo.date.locale.format(
					input,
					{
						selector: 		'date',
						datePattern: 	_format[type],
						timePattern: 	''
					}
				);
	},
	date2unix: function( input , type ) {
		var ret = epages.localize.date2obj( input , type );
		return ret ? ( ret.getTime() / 1000 ) : null;
	},
	unix2date: function( input , type ) {
		return epages.localize.obj2date( new Date(input*1000) , type );
	},
	str2number: function( input ) {
		var ret = parseFloat(
						(input+'')
							.replace( new RegExp( dojo.regexp.escapeString('[^0-9-' +epages.vars.Locale.decimalSep + ']', '^([]{})$'), 'g') , '' )
							.replace( new RegExp( dojo.regexp.escapeString('[' + epages.vars.Locale.decimalSep + ']', 	'^([]{})$'), 'g') , '.' )
					);

		return isNaN(ret) ? null : ret;
	},
	number2str: function( input ) {
		return (input+'').replace( /\./g , _separator.decimal );
	}
};

// private vars for use in epages.localize
var _format = {
		month:			'MM (yyyy)',
		week:			'w (yyyy)'
	},
	_pattern = {
		space: 			'\ \n\r\t\
',
		alpha: 			'A-Za-z',
		digit: 			'0-9',
		email:			dojo.regexp.escapeString('[A-Za-z0-9._-]{1,}@[A-Za-z0-9._-]{2,}[A-Za-z]{2,4}', '([]{})'),
		url: 			'([A-Z]:\\[^/:\*\?<>\|]+\.\w{2,6})|(\\{2}[^/:\*\?<>\|]+\.\w{2,6})',
		tel: 			'[0-9\/\+\-\.\ ]{0,}',
		integer:		'-?[0-9]*'
	};

})();

}

if(!dojo._hasResource['epages.io.json']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.io.json'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.io.json');

epages.io.Json = function () {};
dojo.extend(epages.io.Json, {

	defaultErrorCallback: function(error,args) {
  	var response = args.xhr.status == 404 ? {} : dojo.fromJson(args.xhr.responseText);
    console.warn('epages.io.Json: error in request');

		if (response.Errors !== undefined) {
			dojo.publish("epages/interfaceerror", [{
				code:	    response.Errors[0].Reason,
				message:  response.Errors[0].Message,
				guid:     response.Errors[0].GUID,
				vars:     {
	          				url:		  args.url,
	          				status:	  args.xhr.status,
	          				response: response
	          		  }
			}]);
		}
	},

	loadSync: function (/*String*/url, /*object?*/formData, /*Function?*/errorCallback, /*Boolean*/preventCache) {
		// summary:
		//		returns a javascript object, which was loaded via http from given url.
		// 		additional parameters will be added in the post.
		// example:
		//		JsonLoader = new epages.io.Json();
		//		Answer = JsonLoader.loadSync('http://www.mydomain.de/test.Json', { filename: "test.Json" });
		//		// returns JsonDocument object
		var returnData;
		var requestMethod = formData !== undefined ? dojo.xhrPost : dojo.xhrGet;
		var _this = this;
		var opt = {
			url: 						url,
			sync: 					true,
			preventCache:		preventCache !== undefined ? preventCache : epages.constants.preventCache,
			error:					function(error,args) {
												returnData = {
													'error': {
														error: error,
														args: args,
														data: dojo.fromJson(args.xhr.responseText)
													}
												};
												if (errorCallback != null){
													errorCallback({'error':[error,args]});
												}else{
													_this.defaultErrorCallback(error,args);
												}
											},
			load: 					function(data, evt){
												var result = dojo.fromJson(data);
												if(result.Errors){
													returnData = {
														'error': {
															data: result
														}
													};
												}
												else{
													returnData = { 'data': dojo.fromJson(data) };
												}
											}
		};
		// test cases doesnt allow posts
		if(url.match('\.(js|json)$')) {
			requestMethod = dojo.xhrGet;
		} else {
			dojo.mixin(opt, {
				headers:	{ Accept: 'text/x-json' },
				content:	formData
			});
		}
		requestMethod(opt);
		return returnData; /*Object*/
	},

	loadAsync: function (/*String*/url, /*Function*/callback, /*object?*/formData, /*Function?*/errorCallback) {
		// summary:
		//		loads a document via http from given url.
		//		the function doesnt wait for the result.
		//		if the result is available the callback function is called with the data.
		// example:
		//		JsonLoader = new epages.io.Json();
		//		JsonDoc = JsonLoader.loadAsync('http://www.mydomain.de/test.Json', function (data) { /* do what you want */ });
		//		// returns JsonDocument object
		var requestMethod = formData !== undefined ? dojo.xhrPost : dojo.xhrGet;
		var _this = this;
		var opt = {
			url: 			url,
			error:		function(error,args) {
									var c = errorCallback || callback;
									var response = dojo.fromJson(args.xhr.responseText);
									if (c) {
										c({
											'error': [ error, args ],
											'data': (typeof response == "object") ? dojo.fromJson(args.xhr.responseText) : {}
										});
									} else {
										_this.defaultErrorCallback(error,args);
									}
								},
			load: 		function(data, ioArgs) {
									if (callback != null){
										var result = dojo.fromJson(data);
										if(result.Errors){
											callback({
												'error': {
													data: result
												}
											});
										} else {
											callback({
												'data': result,
												'ioArgs': ioArgs
											});
										}
									}
								}
		};
		// test cases doesnt allow posts
		if(url.match('\.(js|json)$')) {
			requestMethod = dojo.xhrGet;
		} else {
			dojo.mixin(opt, {
				headers:	{ Accept: 'text/x-json' },
				content:	formData
			});
		}
		requestMethod(opt);
		return;
	}
});

}

if(!dojo._hasResource["epages.format"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.format"] = true;
/*
	Copyright (c) 2006-2008, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.format");


epages.format = {

	slice: function(/*String*/value,/* integer */ length, /* boolean? */ sliceWords) {
	// summary: returns a truncated string
		if (value === undefined){
			 throw new Error("value not defined");
		}
		if (typeof value != "string"){
			throw new Error("Not a string value!");
		}
		if(!length) { 
			length = 30; 
		}
		if(!sliceWords === undefined) { 
			sliceWords= true; 
		}
		
		var valueLength = value.length;
		var absLength = length < 0 ? -length : length;
		if(valueLength < absLength){
			return value;
		}
		if (length < 0) {
				// start of new Position 70 + (- 60) + 3 = 10 + 3 = 13
				// length of new string 3 + (70 - 13) = 3 + 57 = 60
				value = value.substr((valueLength+length+3),(absLength-3));
				if(!sliceWords) {
					var firstspace = value.indexOf(" ");
					value = value.substr(firstspace,value.length);
				}
				return '...'+ value;
		}
		value = value.substr(0,length - 3);
		if(!sliceWords) {
			var lastspace = value.lastIndexOf(" ");
			value = value.substr(0,lastspace+1);
		}
		return value+'...';
	},

	scrunch: function(/*String*/ value, /* integer? */ length, /* float? */ ratio) {
		if(ratio=== undefined){
			ratio = 0.5;
		}
		if(ratio < 0 || ratio > 1){
			throw new Error("ratio value invalid only values from 0..1 allowed");
		}
		if (value === undefined){
			throw new Error("value not defined");
		}
		if (typeof value != "string"){
			throw new Error("Not a string value!");
		}
		if(!length){
			length = 30;
		}
		var absLength = length < 0 ? -length : length;
		var valueLength = value.length;
		if(valueLength <= absLength){
			return value;
		}

		var part1Length = Math.floor((length - 3) * ratio);
		var part2Length = Math.floor((length - 3) * (1 - ratio));
		var remainder = length - 3 - (part1Length + part2Length);

		var part1= value.substr(0, part1Length );
		var part2= value.substr(Math.max(0, valueLength - part2Length - remainder), valueLength);
		return part1+'...'+part2;
	}

};

}

if(!dojo._hasResource["epages.storage"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.storage"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/

dojo.provide("epages.storage");



(function(dj){
		  
	var trim = function(string) {
			return (string+'').replace(/[\ \r\n\t]*(.*)[\ \r\n\t]*/,"$1");
		};	
	
	var storageId = function( name ) {
			return 'SiteID::'+epages.vars.SiteID+'::'+name;
		},
		domain = 			'; domain=' + document.domain,
		path = 				'; path=/',
		
		isLocalStorage = 	window.localStorage && window.localStorage.setItem ? true : false,
		isSessionStorage = 	window.sessionStorage && window.sessionStorage.setItem ? true : false,
		
		setCookie = function(name, value, expires) {
			if( typeof expires == 'number' ) {
				var date = new Date();
					date.setDate( expires );
				expires = '; expires=' + date.toUTCString();
			}
			else{
				expires = '';
			}
			document.cookie = [name, '=', dj.toJson(value), expires, path, domain].join('');
			return value;
		},
		
		getCookie = function(name) {
			var value = null;
			if (document.cookie && document.cookie != '') {
				var cookies = document.cookie.split(';');
				for (var i = 0; i < cookies.length; i++) {
					var cookie = trim(cookies[i]);
					// Does this cookie string begin with the name we want?
					if (cookie.substring(0, name.length + 1) == (name + '=')) { 
						value = dj.fromJson(cookie.substring(name.length + 1));
						break;
					}
				}
			}
			return value;
		},
		
		removeCookie = function( name ) {
			return setCookie( name, null, -365);
		},
		
		clearCookie = function( prefix ) {
			if (document.cookie && document.cookie != '') {
				var cookies = document.cookie.split(';');
				for (var i = 0; i < cookies.length; i++) {
					var cookie = trim(cookies[i]);
					if( cookie.match(new RegExp('^'+prefix,'g')) ) {
						removeCookie( cookie.substr(0,cookie.indexOf('=')) ) 
					}
				}
			}
			return null;
		};
		
	//simulate the storage fallback:
	//isLocalStorage = false;
	//isSessionStorage = false;
		
	
	dj.mixin(epages,{
		localStorage: {
			setItem: function( name, value ) {
				return isLocalStorage ? window.localStorage.setItem( storageId(name), dj.toJson(value) ) : setCookie( 'localStorage::'+storageId(name), value, 365 );
			},
			getItem: function( name ) {
				if( isSessionStorage ) {
					var ret = window.localStorage.getItem( storageId(name) );
					return ret ? dj.fromJson( ret ) : ret;
				}
				else {
					return  getCookie( 'localStorage::'+storageId(name) );
				}
			},
			removeItem: function( name ) {
				return isLocalStorage ? window.localStorage.removeItem( storageId(name) ) : removeCookie( 'localStorage::'+storageId(name) );
			},
			clear: function( name ) {
				return isLocalStorage ? window.localStorage.clear() : clearCookie('localStorage::'+siteId());
			}
		},
		sessionStorage: {
			setItem: function( name, value ) {
				return isSessionStorage ? window.sessionStorage.setItem( storageId(name), dj.toJson(value) ) : setCookie( 'sessionStorage::'+storageId(name), value );
			},
			getItem: function( name ) {
				if( isSessionStorage ) {
					var ret = window.sessionStorage.getItem( storageId(name) );
					return ret ? dj.fromJson( ret ) : ret;
				}
				else {
					return  getCookie( 'sessionStorage::'+storageId(name) );
				}
			},
			removeItem: function( name ) {
				return isSessionStorage ? window.sessionStorage.removeItem( storageId(name) ) : removeCookie( 'sessionStorage::'+storageId(name) );
			},
			clear: function( name ) {
				return isSessionStorage ? window.sessionStorage.clear() : clearCookie('sessionStorage::'+siteId());
			}
		}
	});

})(dojo);

}

if(!dojo._hasResource["epages.loaderani"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.loaderani"] = true;
/*
	Copyright (c) 2006-2010, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.loaderani");

epages.loaderani = {

	// summary: shows a loading animation
	// example:
	// | //	to create an animation:
  // | window.aniNode = epages.loaderani.create({width:16, height:16, left:0, top:0, zIndex:1});
  // | //	or
  // | window.aniNode = epages.loaderani.create();
  // | // to remove that animation:
  // | epages.loaderani.destroy(window.aniNode);

	defaultWidth: 50,
	defaultHeight: 50,
	defaultLeft: -9999,
	defaultTop: -9999,
	defaultZIndex: 1
}


epages.loaderani.create = function(/* object */ dimensions, /* dom Node ?*/ domNode) {
// summary: moves the loader animation to the right position
// description:
// animation has to be inside the DOM with id LoaderAniNode already
// dimensions
// | width - integer
// | height - integer
// | top - integer
// | left - integer
// | zIndex - integer
	dimensions = dimensions || {};
	dimensions.width = dimensions.width || this.defaultWidth;
	dimensions.height = dimensions.height || this.defaultHeight;
	dimensions.left = dimensions.left || this.defaultLeft;
	dimensions.top = dimensions.top || this.defaultTop;
	dimensions.zIndex = dimensions.zIndex || this.defaultZIndex;
	var LoaderAniNode = $('LoaderAniNode'); //find existing animation
	if(LoaderAniNode) {
		LoaderAniNode.style.left = dimensions.left + "px";
		LoaderAniNode.style.top = dimensions.top + "px";
		LoaderAniNode.style.zIndex = dimensions.zIndex;
		if(LoaderAniNode.getElementsByTagName("object") && LoaderAniNode.getElementsByTagName("object")[0]) {
			LoaderAniNode.getElementsByTagName("object")[0].width = dimensions.width;
			LoaderAniNode.getElementsByTagName("object")[0].height = dimensions.height;
		}
	}
	return LoaderAniNode;
};

epages.loaderani.destroy = function(aniNode) {
// summary: moves the loader animation out of the visible area
		var LoaderAniNode = $('LoaderAniNode');
		if(LoaderAniNode){
			LoaderAniNode.style.left = "-9999px";
			LoaderAniNode.style.top = "-9999px";
		}
};

}

if(!dojo._hasResource["epages.event.interactionrestrictor"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.event.interactionrestrictor"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.event.interactionrestrictor");



epages.event.interactionRestrictor = function(/*Object?*/ position) {
	// summary: busylayer for a specific dom element
	// position: specifies an alternative position where the overlay is displayed 
	// example:
	//  | dojo.publish("interactionRestrictor/suspend", ["layerId", domNode, (hideLayer)]);
	//  | dojo.publish("interactionRestrictor/permit", ["layerId"]);

	dojo.subscribe("interactionRestrictor/suspend", function(layerId, domNode, hideLayer,position) {
		if(!$(layerId) && domNode && domNode.offsetWidth) {
			dojo.body().className += " SuspendUserInteraction";
			var suspendAnimation = document.createElement("div");
			if(!position){
				var suspendPosition = new epages.html.Element(domNode).getAbsolutePosition(dojo.body());
				var position = {
					Width  : domNode.offsetWidth,
					Height : domNode.offsetHeight,
					Left   : suspendPosition.x,
					Top    : suspendPosition.y
				}
			}
			suspendAnimation.id = layerId;
			suspendAnimation.className = "SuspendUserInteractionAnimation";
			suspendAnimation.style.width = position.Width + "px";
			suspendAnimation.style.height = position.Height + "px";
			suspendAnimation.style.left = position.Left + "px";
			suspendAnimation.style.top = position.Top + "px";
			suspendAnimation.style.zIndex = 11000;
			if(hideLayer) {
				dojo.addClass(suspendAnimation, "SuspendUserInteractionHidden");
			}else if(domNode.offsetHeight > 0) {
				suspendAnimation.loaderani = epages.loaderani.create({width:16,height:16,top:(position.Top + position.Height / 2 - 8),left:(position.Left + position.Width / 2 - 8),zIndex:11001});
			}
			dojo.body().appendChild(suspendAnimation);
		}
	});
	dojo.subscribe("interactionRestrictor/permit", function(layerId) {
		if($(layerId)) {
			dojo.removeClass(dojo.body(), "SuspendUserInteraction");
			epages.loaderani.destroy($(layerId).loaderani);
			dojo.body().removeChild($(layerId));
		}
	});
};

new epages.event.interactionRestrictor;

}

if(!dojo._hasResource['epages.mimetype']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.mimetype'] = true;
/*
 * @charset			utf-8		(ÄÖÜ äöü ß)
 *
 * Copyright (c) 2006-2010, epages GmbH
 * All Rights Reservedojo.
 * epages.mimetype
 */

dojo.provide('epages.mimetype');

(function(dojo) {

	dojo.declare('epages.Mimetype',null,{
	// summary: 		mimetype and filetype handling
	// description: 	privat class
	// TODO:			improve this class and make it to a public class
	//					by preserving the epages.mimetype API

		/*
		 * private
		 */
		 _MIMETYPE_MAP: {
			// image
			'image/png':																	['png' ],
			'image/jpeg':																	['jpe', 'jpeg', 'jpg' ],
			'image/gif':																	['gif' ],
			'image/bmp':																	['bmp' ],
			'image/vnd.microsoft.icon':														['ico' ],
			'image/tiff':																	['tif', 'tif' ],
			'image/svg+xml':																['svg', 'svgz' ],
			'image/x-win-bitmap':															['cur' ],
			// audio/video
			'audio/basic':																	['au'],
			'audio/mpeg':																	['mp3' ],
			'audio/mp4a-latm':																['m4p', 'm4b', 'm4a' ],
			'audio/x-wav':																	['wav' ],
			'audio/ogg':																	['ogg', 'oga', 'spx' ],
			'audio/flac':																	['flac' ],
			'audio/x-ms-wma':																['wma' ],
			'audio/x-pn-realaudio':															['ra','ram' ],
			'application/vnd.rn-realmedia':													['rm' ],
			'video/ogg':																	['ogv' ],
			'video/mp4':																	['mp4' ],
			'video/mpeg':																	['mpe', 'mpg', 'mpeg', 'mpga' ],
			'video/quicktime':																['qt', 'mov' ],
			'video/x-msvideo':																['avi' ],
			'video/x-flv':																	['flv' ],
			'video/x-ms-wmv':																['wmv'],
			// web
			'text/plain':																	['txt' ],
			'text/html':																	['htm', 'html', 'shtml', 'php', 'php4' ],
			'text/css':																		['css' ],
			'text/x-actionscript':															['as'],
			'application/javascript':														['js' ],
			'application/json':																['json' ],
			'application/xml':																['xml', 'plist' ],
			'application/x-shockwave-flash':												['swf' ],
			// archives
			'application/zip':																['zip' ],
			'application/gzip':																['gz' ],
			'application/x-tar':															['tar' ],
			'application/x-rar-compressed':													['rar' ],
			'application/x-msdownload':														['exe', 'msi' ],
			'application/vnd.ms-cab-compressed':											['cab' ],
			// adobe
			'application/pdf':																['pdf' ],
			'image/vnd.adobe.photoshop':													['psd' ],
			'application/postscript':														['ai', 'eps', 'ps' ],
			// ms office
			'application/msword':															['doc' ],
			'application/x-dot':															['dot' ],
			'application/rtf':																['rtf' ],
			'application/vnd.ms-excel':														['xls','xla' ],
			'application/vnd.ms-powerpoint':												['ppt' ],
			'application/vnd.openxmlformats-officedocument.wordprocessingml.document': 		['docx'],
			'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':			['xlsx'],
			//
			'application/x-director':														['cdr']
		},

		_MIMETYPE_GROUPS: {
			'*/*':				['*/*' ],
			'icon/*':			['image/vnd.microsoft.icon', 'image/x-win-bitmap' ],
			'image/*':			['image/png', 'image/jpeg', 'image/gif' ],
			'document/*':		['application/pdf', 'application/msword', 'application/vnd.ms-excel', 'application/rtf', 'application/vnd.openxmlformats-officedocument.wordprocessingml.document', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet' ],
			'audio/*':			['audio/mpeg', 'audio/x-ms-wma', 'audio/ogg', 'audio/flac', 'audio/x-ms-wma' ],
			'video/*':			['video/x-msvideo', 'video/mp4', 'video/mpeg', 'video/x-ms-wmv', 'video/x-flv' ]
		},

		_MIMETYPE_PREVIEWABLE: 	['image/png', 'image/jpeg', 'image/gif', 'image/vnd.microsoft.icon' ],

		_ICON_MAP: {
			'ico_l_image':		['image/png','image/jpeg','image/gif','image/bmp','image/vnd.microsoft.icon','image/tiff','image/svg+xml','image/x-win-bitmap'],
			'ico_xl_box':		[this._UNKNOW,'text/x-actionscript','audio/basic','audio/x-wav','audio/mpeg','audio/x-ms-wma','audio/ogg','audio/flac','application/msword','application/x-dot','application/vnd.ms-excel','application/vnd.ms-powerpoint','text/plain','text/css','application/javascript','application/json','application/xml'],
			'ico_xl_file_avi':	['video/x-msvideo','video/mpeg','video/mp4'],
			'ico_xl_file_wmv':	['video/x-ms-wmv'],
			'ico_xl_file_swf':	['video/x-flv','application/x-shockwave-flash'],
			'ico_xl_file_mov':	['video/quicktime','video/ogg'],
			'ico_xl_file_rm':	['application/vnd.rn-realmedia'],
			'ico_xl_file_ram':	['audio/x-pn-realaudio'],
			'ico_xl_file_dcr':	['application/x-director'],
			'ico_xl_file_pdf':	['application/pdf'],
			'ico_xl_file_htm':	['text/html'],
			'ico_m_folder':		['application/zip','application/x-rar-compressed','application/gzip','application/x-tar']
		},

		_UNKNOW: 'application/octet-stream',

		_mimes: null,

		/*
		 * public
		 */

		/*
		 * init instance
		 */
		constructor: function( mime ) {
			this.setMime( mime || this._UNKNOW )
		},

		/*
		 * methods
		 */
		setBySuffix: function( suffix ) {
			suffix = suffix.toLowerCase();
			this._mime = this._UNKNOW;

			var map = this._MIMETYPE_MAP;

			for( var i in map ) {
				if( dojo.indexOf(map[i], suffix)>=0 ) {
					this._mime = i;
					break;
				}
			};

			return this;
		},

		setMime: function( mime ) {
			this._mime = mime;
			return this;
		},

		getMime: function() {
			return this._mime;
		},

		mimesByGroup: function( group ) {
			return this._MIMETYPE_GROUPS[group];
		},

		isGroup: function( group ) {
			var mimesGroup = this._MIMETYPE_GROUPS[group];

			if( group=='*/*' ) {
				return true;
			}
			else if(!mimesGroup) {
				return false;
			}
			else {
				if( dojo.indexOf(mimesGroup, this._mime)>=0 ) {
					return true;
				}
			}

			return false;
		},

		isPreviewable: function() {
			var prev = this._MIMETYPE_PREVIEWABLE;

			if( dojo.indexOf(prev, this._mime)>=0 ) {
				return true;
			}

			return false;
		},

		getIcon: function() {

			var map = this._ICON_MAP;
			for( var i in map ) {
				if( dojo.indexOf(map[i], this._mime)>=0 ) {
					return i;
				}
			}

			return 'ico_xl_box';
		}

	});

	var _mimetype = new epages.Mimetype();

	epages.mimetype = {
		mimeBySuffix: function( suffix ) {
		// summary: get mimetypeby suffix
			return _mimetype.setBySuffix( suffix );
		},
		isPreviewable: function( mime ) {
		// summary: to check is the givn mimetype previewable
			return _mimetype.setMime( mime ).isPreviewable();
		},
		isGroup: function( mime , group ) {
		// summary: to check is the givn mimetype in a mimetype group
			return _mimetype.setMime( mime ).isGroup( group );
		},
		getGroup: function( group ) {
		// summary: return a group of mimetypes
			return _mimetype._MIMETYPE_GROUPS[group] || ['*/*'];
		},
		isGroupBySuffix: function( suffix , group ) {
		// summary: to check is the givn fileSuffix in a mimetype group
			return _mimetype.setBySuffix( suffix ).isGroup( group );
		},
		getIcon: function( mime ) {
		// summary: returns a SpriteIconClass by the givn mimetype
			return _mimetype.setMime( mime ).getIcon();
		}
	};

})(dojo);

}

if(!dojo._hasResource["epages.widget.Form"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Form"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/

dojo.provide("epages.widget.Form");


dojo.declare("epages.widget.Form", [dijit._Widget], {
		// summary:
		//					widget linked to the <form/> html element
		//					to enhance the functionality of that particular node

	submitButtons: 	[], 		// array of all submit buttons found inside of the form element on startup
									// you can push your dynamically built button in here hence it will be registered
	
	_formName: 		null,
	_elems:			null,
	_submits:		null,
	_invalides:		null,

	_onSubmit: function() {
		for( var i=0,iLength=this.submitButtons.length ; i<iLength ; i++ ) {
			this.submitButtons[i].disabled = true;
		}
	},

	postCreate: function() {
		this.inherited("postCreate", arguments);
		
		this._elems = {};
		this._submits = {};
		this._invalides = {};
		
		//this.submitButtons = dojo.query("[type=submit]", this.domNode);
		
		//this.connect(this.domNode, "submit", "_onSubmit");
		
		// for new formElements Widgets
		this._formName = dojo.attr( this.domNode , 'name' );
		this.connect(this.domNode, 'submit', this.validate);
	},
	
	validate: function(event) {
		var elems = this._elems;
		var error = false;
		
		for( var i in elems ) {
			error = elems[i].validate() ? error : true;
		};
		
		if( error && event ) {
			event.preventDefault();
			console.log('error')
		}
		return !error;
	},
	
	addElem: function( instance ) {
		if( instance.attr('type')=='submit' ) {
			this._submits[instance.id] = instance;
		}
		this._elems[instance.id] = instance;
	},
	
	removeElem: function( id ) {
		if( this._elems[id] ) {
			delete( this._elems[id] );
		}
		if( this._submits[id] ) {
			delete( this._submits[id] );
		}
	},
	
	change: function() {
		var elems = this._elems;
		var error = false;
		for( var i in elems ) {
			error = elems[i].attr('valide') ? error : true;
		}
		
		var elems = this._submits;
		for( var i in elems ) {
			elems[i].attr('disabled',error);
		}
	},
	
	destroy: function() {
		this.inherited('destroy', arguments);
		
		var elems = this._elems;
		
		for( var i in elems ) {
			elems[i].destroy();
		}
	}
})

}

if(!dojo._hasResource['epages.widget.FormElements']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.widget.FormElements'] = true;
/*
	Copyright (c) 2010, ePages GmbH
	All Rights Reserved.
*/

dojo.provide('epages.widget.FormElements');












(function(dj){

	var windowFormWdgt = new epages.widget.Form( {}, document.createElement('form') );

	dj.declare('epages.widget.FormBase', [dijit._Widget], {

	// VARS
		wrapNode		: null,				// node of wrap which wrapped the domNode
		formNode		: null,				// node of parent form
		_type				: 'text',			// type of formElement
		_attr				: {},					// attributes of formElement
		_handles		: null,				// array of handles which will connect on this._connectHandles

		_translation	: epages.io.dictionary.translation,


	// CREATE
		postCreate: function(){
			this.inherited('postCreate', arguments);

			this._attr = {};
			this._handles = {};
			this._handleConnects = {};
			// get type
			if( this.domNode.nodeName.match(/^(TEXTAREA|SELECT)$/) ){
				this._attr.type = this.domNode.nodeName.toLowerCase();
			}
			else {
				this._attr.type = dj.attr(this.domNode,'type');
			}
			if( this._attr.type == 'datetime-local' ){
				this._attr.type = 'datetime';
			}
			if( !this._attr.type ){
				var match = (this.domNode.outerHTML).match(/[<\s]{1}type="?([A-Za-z]+)"?[>\s\/]{1}/);
				this._attr.type = match ? match[1] : 'text';
			}

			// get attributes
			var ATTR = ['autofocus','form','formaction','formmethod','formnovalidate','id','required','pattern','min','max','name','accept','checked','disabled','list','maxlength','multiple','placeholder','step','value'];

			for( var i=0,l=ATTR.length ; i<l ; i++ ){
				var name = ATTR[i];
				var value = dj.attr(this.domNode,name);
				// there is a bug in dojo.attr => use native javascript for this attribute
				if( name == 'multiple' ){
					value = this.domNode.getAttribute('multiple') === 'true' ? true : false;
				}
				// parse min, max & step to number
				if( name.match(/^(max|min|step)$/) ){
					value = epages.localize.str2number(value);
					if( value !== null ){
						this._attr[name] = value;
					}
				}
				// is defined
				else if( value !== undefined ){
					this._attr[name] = value;
				}
			}
			this._attr.id = this.id;
			this._attr.valide = dj.hasClass(this.domNode,'DialogError') ? false : true;

			// replace domNode for type compatibility
			if( this._attr.type.match(/^(color|date|datetime|email|month|number|search|tel|time|url|week)$/) ){
				var node = dj.clone(this.domNode);
				if( !(epages.Browser.engine == 'MSIE' && epages.Browser.version <= 8) ){
					dj.attr( node , 'type' , 'text' );
				}
				dj.place( node , this.domNode , 'after' );
				node.parentNode.removeChild(this.domNode);
				this.domNode = node;
			}

			// if element hidden by style copy to wrap node
			var style = '';
			var originalStyle = this.domNode.getAttribute('style') || '';
			if(originalStyle !== '') {
				// Start IE Hack
				if( typeof originalStyle === 'object' ){
					var ret = [];
					for( var i in originalStyle ){
						ret.push( i + ":" + name[i] );
					}
					originalStyle = ret.join(';');
				}
				// End IE Hack
				originalStyle.replace(/(display:\s*[a-z]+\s*;?|visibility:\s*[a-z]+\s*;?)/gi, function(str,a){
					style = style+a;
					return "";
				});
			}

			// wrap domNode
			this.wrapNode = dj.create('label',{
				'class': 'EpForm ' + this._attr.type.substr(0,1).toUpperCase() + this._attr.type.substr(1) + ' ' + dj.attr(this.domNode,'class'),
				'style': style
			},this.domNode,'after');
			this.wrapNode.appendChild(this.domNode);

				// set formWidget
				var formNode = (this._attr.form ? dj.query('form[name='+this._attr.form+']') : [this.domNode.form])[0];
				if( !formNode ){
					this.formWdgt = windowFormWdgt;
				}
				else{
					if (dj.hasClass(formNode, 'ep-js')) {
					// We do NOT want *dojo* AND *jQuery* form handling on the same *form*.
						return;
					}
					this.formWdgt = $$( dj.attr(formNode,'widgetid') );
					if( !this.formWdgt ){
						this.formWdgt = new epages.widget.Form( {}, formNode );
					}
				}

				// fix to disable validation by browser
				dj.removeAttr( this.domNode, 'formmethod' );
				dj.removeAttr( this.domNode, 'formaction' );
				dj.removeAttr( this.domNode, 'max' );
				dj.removeAttr( this.domNode, 'min' );
				dj.removeAttr( this.domNode, 'pattern' );
				dj.removeAttr( this.domNode, 'required' );
				dj.removeAttr( this.domNode, 'step' );

				// add this formElement to his form
				this.formWdgt.addElem( this );

				this.addHandle( 'domNode.focus', this.domNode, 'focus', function() {
					dj.addClass(this.domNode,'Active');
					dj.addClass(this.wrapNode,'Active');
				});
				this.addHandle( 'domNode.blur', this.domNode, 'blur', function() {
					dj.removeClass(this.domNode,'Active');
					dj.removeClass(this.wrapNode,'Active');
				});

				if( this._attr.type.match(/^(checkbox|radio)$/) ){
					this.attr( 'startupValue', this._attr.checked ? this._attr.value : '' );
				}
				else{
					this.attr( 'startupValue', this._attr.value );
				}

				// set focus
				if( this._attr.autofocus == true ){
					this._domNode.focus();
				}

				// set the id also
				this.domNode.setAttribute( 'id', this.id );

		},

		// init the readonly and disbaled status
		postAfterCreate: function(){
			this.attr( 'readonly', this._attr.readonly || false );
			this.attr( 'disabled', this._attr.disabled || false );
		},

		// METHODS
		style: function( node, name, value ){
			if( !node.nodeName && !this[node] ){
				value = name;
				name = node;
				node = this.domNode;
			}
			node = node.nodeName || this[node];

			if( typeof name == 'object' ){
				dj.style( node, name );
				return this;
			}
			else if( value == undefined ){
				return dj.style( node, name );
			}
			else{
				dj.style( node, name, value );
				return this;
			}
		},
		attr: function( name, value ){
			if( typeof name == 'object' ){
				for( var i in name ){
					this.attr( i, name[i] );
				}
				return this;
			}
			else {
				var methodName = '_attr'+name.substr(0,1).toUpperCase()+name.substr(1);
				if( value === undefined ){
					return this[methodName] ? this[methodName]() : this._attr[name];
				}
				else {
					return this._attr[name] = this[methodName] ? this[methodName](value) : value;
				}
			}
		},
		_attrMin: function( value ){
			return value ? epages.localize.str2number(value) : this._attr.min;
		},
		_attrMax: function( value ){
			return value ? epages.localize.str2number(value) : this._attr.max;
		},
		_attrStep: function( value ){
			return value ? epages.localize.str2number(value) : this._attr.step;
		},
		_attrType: function( value ){
			// value will be ignored, type can not modify
			return this._attr.type;
		},
		// set/get formElement multiple status
		_attrValue: function( value ){
			if( value ){
				this.domNode.setAttribute('value', value);
				return value;
			}
			else {
				return this._attr.value || '';
			}
		},
		// set/get formElement disabled status
		_attrForm: function( value ){
			if( value || value == '' ){
				var formNodeList;
				if( value == '' ){
					formNodeList = [this.domNodeForm];
				}
				else {
					formNodeList = dj.query('form[name='+value+']') || [];
				}
				if( formNodeList[0] ){
					this.formWdgt.removeElem( this.id );
					this.formWdgt = $$( dj.attr(formNodeList[0], 'widgetid') );
					if( !formWdgt ){
						this.formWdgt = windowFormWdgt;
						this.formWdgt.addElem( this );
					}
					this._attr.form = value;
				}
				return this._attr.form || '';
			}
			else {
				return this._attr.form;
			}
		},
		// set/get formElement disabled status
		_attrDisabled: function( bool ){
			if( bool === true ){
				dj.attr( this.domNode , 'disabled' , true );
				dj.addClass( this.wrapNode , 'Disabled' );

				this._disconnectHandles();
				return bool;
			}
			else if( bool === false ){
				dj.removeAttr( this.domNode , 'disabled' );
				dj.removeClass( this.wrapNode , 'Disabled' );

				if( !this._attr.readonly ){
					this._disconnectHandles();
					this._connectHandles();
				}
				return bool;
			}
			else {
				return this._attr.disabled || false;
			}
		},
		// set/get formElement readonly status
		_attrReadonly: function( bool ){
			if( bool === true ){
				dj.attr( this.domNode , 'readonly', true );
				dj.addClass( this.wrapNode , 'Readonly' );

				this._disconnectHandles();
				return bool;
			}
			else if( bool === false )  {
				dj.removeAttr( this.domNode , 'readonly' );
				dj.removeClass( this.wrapNode , 'Readonly' );

				if( !this.attr('disabled') ){
					this._disconnectHandles();
					this._connectHandles();
				}
				return bool;
			}
			else {
				return this._attr.readonly || false;
			}
		},
		// add handle with id
		addHandle: function( id, node, event, fn  ) {
			if( this._handleConnects[id] ) {
				this.removeHandle( id );
			}
			this._handles[id] = [ typeof node === 'string' ? this[node] : node, event, fn ];

			return this;
		},
		// remove handle by id
		removeHandle: function( id ) {
			if( this._handleConnects[id] ) {
				dj.disconnect( this._handleConnects[id] );
			}
			//delete( this._handles[id] );

			return this;
		},
		// connect handle by id
		connectHandle: function( id ) {
			if( this._handleConnects[id] ) {
				this.removeHandle( id );
			}
			if( this._handles[id] ) {
				var _handle = this._handles[id];
				this._handleConnects[id] = dj.connect( _handle[0], _handle[1], this, _handle[2] );
			}
			return this;
		},
		// disconnect handles by id
		disconnectHandle: function( id ) {
			dj.disconnect( this._handleConnects[id] );

			return this;
		},
		// connect all handles
		_connectHandles: function(){
			var _handles = this._handles;
			for( var i in _handles ){
				this.connectHandle( i );
			}
		},
		// disconnect all handles
		_disconnectHandles: function(){
			var _handles = this._handles;
			for( var i in _handles ){
				this.disconnectHandle( i );
			}
		},
		// replace pseudo pattern with regexp pattern
		_replacePattern: function(){
			if( this._attr.pattern ){
				this._attr.pattern = this._attr.pattern.replace(/(\[\:[a-z\-]+\:\])/,function( t, s ){
					return epages.localize.getPattern( s.substr(2,s.length-4) );
				} );
			}
		},
		// validate formElement
		validate: function(){
			var valide = true;

			if( !this.attr('formnovalidate') ){
				valide = this._validate();
				var maxL = Math.min( this.attr('maxlength') || epages.vars.MaxTextLength, epages.vars.MaxTextLength );
				valide =  maxL && maxL<(dj.attr(this.domNode,'value')+'').length ? false : valide;
				if( valide ){
					dj.removeClass( this.domNode , 'DialogError' );
					dj.removeClass( this.wrapNode , 'DialogError' );
				}
				else {
					dj.addClass( this.domNode , 'DialogError' );
					dj.addClass( this.wrapNode , 'DialogError' );
				}
				this.attr('valide', valide ? true : false );
				if (this.formWdgt) {
					this.formWdgt.change();
				}
			}
			else {
				this.attr('valide', valide ? true : false );
			}

			if( dj.attr( this.domNode,'value') !=  this.attr('startupValue') ){
				dj.addClass( this.domNode, 'Changed' );
				dj.addClass( this.wrapNode, 'Changed' );
			}
			else{
				dj.removeClass( this.domNode, 'Changed' );
				dj.removeClass( this.wrapNode, 'Changed' );
			}

			return valide;
		},
		// placeholder for validate function
		_validate: function(){
			return true;
		},
		// destroy a widget
		destroy: function(){
			this.inherited('destroy',arguments);

			this._disconnectHandles();
			this.formWdgt.removeElem( this.id );
		}

	});


	// WIDGET FormButton
	dj.declare('epages.widget.FormButton', [epages.widget.FormBase], {

	// CREATE
		postCreate: function(){
			this.inherited('postCreate', arguments);

			this.postAfterCreate();
		}

	});


	// WIDGET FormFile
	dj.declare('epages.widget.FormFile', [epages.widget.FormBase], {

		buttonNode: 		null,
		_domNode:				null,
		_handlesIndex: 	null,

		// CREATE
		postCreate: function(){
			this.inherited('postCreate', arguments);

			this.buttonNode = dj.create('span',{
			  'class':''
			},this.domNode,'after');

			this.buttonNode.innerHTML = this._translation.get( this._attr.multiple ? 'FileUploadMultiple' : 'FileUploadSingle');

			this.postAfterCreate();
		},

		// METHODS
		// set/get formElement multiple status
		_attrAccept: function( value ){
			if( value ){
				this.domNode.setAttribute('accept',value);
				return value;
			}
			else {
				return this._attr.accept || '';
			}
		},
		// set/get formElement multiple status
		_attrMultiple: function( bool ){
			if( bool === true ){
				this.domNode.setAttribute('multiple',true);
				return bool;
			}
			else if( bool === false ){
				this.domNode.removeAttribute('multiple');
				return bool;
			}
			else {
				return this._attr.multiple || false;
			}
		},

		_attrAccept: function( value ){
			if( value ){
				var instance = new epages.Mimetype();
				this._attr.accept = value.replace(/([A-Za-z]+\/\*)/,dj.hitch(this,function( string, found ){
					var mimes = instance.mimesByGroup( found );
					if( mimes ) {
						return mimes.join(',');
					}
					else {
						return '';
					}
				}));
				dj.attr( this.domNode, 'accept', this._attr.accept );
				return this._attr.accept;
			}
			else {
				return this._attr.accept;
			}
		},

		// set/get formElement value
		_attrValue: function( value ){
			if( value == '' ){
				this._disconnectHandles();

				var arr = [];
				for( var i=0,iLength=this._handles.length ; i<iLength ; i++ ){
					if( this._handles[i][0] == this.domNode ) {
						arr.push(i);
					}
				}

				this._domNode = this.domNode;
				if( epages.Browser.engine == "Gecko"){
					this.domNode.setAttribute('value','');
				}
				else{
					this.domNode = dj.place( this.domNode.cloneNode(), this._domNode, 'replace' );
					var node = dj.clone(this.domNode);
				}

				for( var i in this._handles ) {
					if( this._handles[i][0] == this._domNode ) {
						this._handles[i][0] = this.domNode;
					}
				}

				for( var i=0,iLength=arr.length ; i<iLength ; i++ ){
					this._handles[arr[i]][0] = this.domNode;
				}

				this._connectHandles();
			}
			else {
				return this._attr.value || '';
			}
		}

	});


// WIDGET FormFileUploder
	dj.declare('epages.widget.FormFileUploader', [epages.widget.FormFile], {

		_uploader:		null,

	// CREATE
		postCreate: function(){
			this.inherited('postCreate', arguments);

			this.addHandle( 'domNode.change.fileUploader', this.domNode, 'change', this._change  );
			this.addHandle( 'domNode.click.fileUploader', this.domNode, 'click', this._click  );

			this.attr({
				'sendaction':	dj.attr(this.domNode,'sendaction'),
				'deleteaction':	dj.attr(this.domNode,'deleteaction'),
				'finishaction':	dj.attr(this.domNode,'finishaction')
			});

			this.formWdgt.removeElem( this.id );

			this.postAfterCreate();
		},

	// METHODS
		// open the uploader if attr uploader is true
		_click:	function( event ){
			if( !this._uploader ){
				this._createUploader();
				this._uploader.hide();
			}
			else {
				event.preventDefault();
				this._uploader.show();
			}
		},
		// open the uploader if attr uploader is true
		_change: function(){
			if( !this._uploader ){
				this._createUploader();
			}
			this._uploader.show();
			this.attr('value', '');
			this._uploader.externalInput( this._domNode );
		},

		_createUploader: function(){
			dj.require('epages.widget.Uploader');

			this._uploader = new epages.widget.Uploader({
				options:{
					id: 						this.attr('id'),
					multiple : 			this.attr('multiple'),
					accept : 				this.attr('accept') || '*/*',
					sendaction : 		this.attr('sendaction'),
					deleteaction : 	this.attr('deleteaction'),
					finishaction : 	this.attr('finishaction')
				}
			}, dj.create('div'));
		}
	});


// WIDGET FormSelect
	dj.declare('epages.widget.FormSelect', [epages.widget.FormBase], {

	// CREATE
		postCreate: function(){
			this.inherited('postCreate', arguments);

			this.addHandle( 'domNode.change.select', this.domNode, 'change', this.validate  );

			this.postAfterCreate();
		},

	// METHODS
		// set/get formElement required status (required cann't be true for type select
		_attrRequired: function(){
			this._attr.required = false;
			return false;
		}
	});


// WIDGET FormText
	dj.declare('epages.widget.FormText', [epages.widget.FormBase], {

	// CREATE
		postCreate: function(){
			this.inherited('postCreate', arguments);

			this.addHandle( 'domNode.keyup.text', this.domNode 		, 'keyup' 	, this.validate );
			this.addHandle( 'domNode.blur.text',  this.domNode 		, 'blur' 		, this.validate );

			if( this.domNode.getAttribute("emptyValue") ){
				var domNode = this.domNode;
				var value = dj.attr( domNode, 'value' );
				var emptyValue = dj.attr( domNode, 'emptyValue' );

				if( !value || value == emptyValue ){
					dj.attr( domNode, 'value', emptyValue );
					dj.addClass( domNode, 'EmptyValue' );
				}

				dojo.connect( this.formWdgt.domNode, "submit", function() {
					domNode.value = domNode.value.replace(domNode.getAttribute('emptyValue'), '');
					dojo.removeClass(domNode, "EmptyValue");
				});
				this.addHandle( 'domNode.focus2.text', domNode, "focus", function() {
					domNode.value = domNode.value.replace(domNode.getAttribute('emptyValue'), '');
					dojo.removeClass(domNode, "EmptyValue");
				});
				this.addHandle( 'domNode.blur2.text', domNode, "blur", function() {
					if(domNode.value == "") {
						dojo.addClass(domNode, "EmptyValue");
						domNode.value = domNode.getAttribute("emptyValue");
					}
				});
	   }

			// replace domNode for type compatibility
			if( this._attr.type.match(/^(email|tel|url)$/) ){
				this._attr.pattern = epages.localize.getPattern( this._attr.type );
			}

			// handle mandatory
			if( dj.hasClass( this.domNode, 'Mandatory' ) && !dj.attr( this.domNode, 'value' ) ){
				dj.addClass( this.domNode, 'Unfilled' );
			}

			this.postAfterCreate();
		},

	// METHODS
		_validate: function(){
			var value = dj.attr( this.domNode , 'value' );
			var valide = false;
			if( value == '' && !this._attr.required ){
				valide = true;
			}
			if( value == '' && this._attr.required ){
				valide = false;
			}
			else if( this._attr.pattern && value.match(new RegExp('^'+this._attr.pattern+'$')) ){
				valide = true;
			}
			else if( !this._attr.pattern ){
				valide = true;
			}
			if( dj.hasClass( this.domNode, 'Mandatory' ) && !dj.attr( this.domNode, 'value' ) ){
				dj.addClass( this.domNode, 'Unfilled' );
			}
			else{
				dj.removeClass( this.domNode, 'Unfilled' );
			}
			return valide;
		}
	});


// WIDGET FormCheck
	dj.declare('epages.widget.FormCheck', [epages.widget.FormBase], {

	// CREATE
		postCreate: function(){
			this.inherited('postCreate', arguments);

			this.addHandle( 'domNode.change.check', this.domNode, 'change', this._change );
			if( epages.Browser.engine == 'MSIE' ){
				this.addHandle( 'domNode.click.check', this.domNode, 'click', this._ieChangeFix );
			}

			if( !this.domNode.value && !this.domNode.defaultValue ){
				this.domNode.defaultValue = "on";
			}

			this.attr( 'checked', this._attr.checked ? true : false );
			this.postAfterCreate();
		},

	// METHODS
		// set/get formElement checked status
		_attrChecked: function(bool){
			if(bool === true){
				if( this._attr.type == 'radio' ){
					var radios = this._getRadios();
					for( var i=0,l=radios.length ; i<l ; i++ ){
						radios[i].attr( 'checked', false );
						dojo.removeClass(radios[i].domNode,'DialogError');
						dojo.removeClass(radios[i].wrapNode,'DialogError');
					}
				}
				dj.attr( this.domNode, 'checked', true );
				dj.addClass( this.wrapNode, 'Checked' );
				return bool;
			}
			else if(bool === false){
				dj.attr( this.domNode, 'checked', false );
				dj.removeClass( this.wrapNode, 'Checked' );
				return bool;
			}
			else {
				return this._attr.checked;
			}
		},
		// a fix for the IE to fire the change action instantly
		_ieChangeFix: function(){
			this.domNode.blur();
		},
		// handle the change
		_change: function(){
			this.attr( 'checked', dj.attr( this.domNode , 'checked' ) ? true : false );
			this.validate();
		},
		// found all radio element with same name in this form and outside of this form which added to this form by the form attribute
		_getRadios: function(){
			var domNodeName = dj.attr(this.domNode,'name');
			var formNodeName = dj.attr(this.formWdgt.domNode,'name');

			var inForm;
			var exForm;
			if( this.formWdgt === windowFormWdgt ){
				inForm = dj.query('input[type=radio][name='+domNodeName+']',this.domNode.ownerDocument);
				exForm = [];
			}
			else{
				inForm = dj.query('input[type=radio][name='+domNodeName+']',this.formWdgt.domNode);
				exForm = dj.query('input[type=radio][name='+domNodeName+'][form='+formNodeName+']',document.body);
			}

			var radios = inForm.concat(exForm);
			var required = this.attr('required');

			var ret = [];
			for( var i=0,l=radios.length ; i<l ; i++ ){
				var wdgt = $$( dj.attr(radios[i],'widgetid') );
				if( wdgt ){
					ret.push( wdgt );
					required = wdgt.attr('required') || required;
					wdgt.attr('valide',true);
				}
			}
			this.attr('required',required);

			return ret;
		},

		_validate: function(){

			var value = dj.attr( this.domNode , 'value' );
			var valide = false;
			if( this._attr.type == 'checkbox' && ( (dj.attr(this.domNode,'checked') && this._attr.required) || !this._attr.required ) ){
				valide = true;
			}

			if( this._attr.type == 'radio' ){
				var radios = this._getRadios();
			}

			if( this._attr.type == 'radio' && ( (this.attr('checked') && this.attr('required')) || !this.attr('required') ) ){
				valide = true;
			}
			else if( this._attr.type == 'radio' ){
				for( var i=0,l=radios.length ; i<l ; i++ ){
					valide = radios[i].attr('checked') || valide;
				}
			}
			return valide;
		}

	});


// WIDGET FormNumber
	dj.declare('epages.widget.FormNumber', [epages.widget.FormBase], {

		stepUpNode: 			null,			// node of the step up button
		stepDownNode: 		null,			// node of the step down button

		_stepCount:				null,			// counter of intervals
		_stepSpeed: 			null,			// interval time
		_stepInterval: 		null,			// interval of step action

	// CREATE
		postCreate: function(){
			this.inherited('postCreate', arguments);

			this._replacePattern();

			this.stepUpNode = dj.create('a',{
					'href':'javascript:;',
					'class':'StepUp'
				});

			this.stepDownNode = dj.create('a',{
					'href':'javascript:;',
					'class':'StepDown'
				});

			this.wrapNode.appendChild(this.stepUpNode);
			this.wrapNode.appendChild(this.stepDownNode);

			this.addHandle( 'domNode.keyup.number',          this.domNode 			, 'keyup' 			, this.validate  );
			this.addHandle( 'domNode.blur.number',           this.domNode 			, 'blur' 				, this.validate  );

			this.addHandle( 'stepUpNode.mousedown.number',   this.stepUpNode 		, 'mousedown' 	, function(event){ event.preventDefault(); this._stepStart(+1); }  );
			this.addHandle( 'stepUpNode.mouseup.number',     this.stepUpNode 		, 'mouseup'   	, this._stepStop  );
			this.addHandle( 'stepUpNode.mouseout.number',    this.stepUpNode 		, 'mouseout'  	, this._stepStop  );

			this.addHandle( 'stepDownNode.mousedown.number', this.stepDownNode 	, 'mousedown' 	, function(event){ event.preventDefault(); this._stepStart(-1); }  );
			this.addHandle( 'stepDownNode.mouseup.number',   this.stepDownNode 	, 'mouseup' 		, this._stepStop  );
			this.addHandle( 'stepDownNode.mouseout.number',  this.stepDownNode 	, 'mouseout' 		, this._stepStop  );

			// set pattern
			this._attr.pattern = this._attr.pattern || epages.localize.getPattern( 'number' );

			this.postAfterCreate();
		},

	// METHODS
		// handle the step
		_stepAction: function( inc ){
			this._stepCount++;
			this._stepSpeedHandle( inc );

			var value = dj.attr( this.domNode , 'value' );
			var ret;
			var step = inc * (this._attr.step || 1);
			var attrMin = this._attr.min;
			var attrMax = this._attr.max;


			ret = epages.localize.str2number(value);
			ret = ret!==null ? ret : 0;
			var i = (ret+'').indexOf('.');
			var l = i>=0 ? (ret+'').substr(i+1).length : 0;
			ret = ret+step;
			ret = (attrMin && attrMin > ret.toFixed(l)) ? attrMin : (attrMax && attrMax < ret.toFixed(l)) ? attrMax : ret.toFixed(l);
			ret = epages.localize.number2str( ret );
			dj.attr( this.domNode , 'value' , ret );
		},
		// start the step action
		_stepStart: function( inc ){
			this._stepCount = 0;
			this._stepSpeed = 250;

			this._stepAction(inc);
			this._stepInterval = window.setInterval( dj.hitch(this,function(){
				this._stepAction(inc);
			}), this._stepSpeed );
		},
		// stop the step action
		_stepStop: function(){
			window.clearInterval( this._stepInterval );
			epages.event.fire(this.domNode,'blur');
		},
		// handle the speed of the step action
		_stepSpeedHandle: function( inc ){
			if( dj.indexOf([10,30,50],this._stepCount)>=0 ){
				this._stepSpeed = this._stepSpeed / 2;
				window.clearInterval( this._stepInterval );
				this._stepInterval = window.setInterval( dj.hitch(this,function(){
					this._stepAction(inc);
				}), this._stepSpeed );
			}
		},

		_validate: function(){
			var value = dj.attr( this.domNode , 'value' );
			var valide = false;

			if( value=='' && !this._attr.required ){
				valide = true;
			}
			else if( value.match(new RegExp('^'+this._attr.pattern+'$')) ){
				var val = epages.localize.str2number(value);
				var attrMin = this._attr.min;
				var attrMax = this._attr.max;
				valide = (attrMin && attrMin > val) ? false : (attrMax && attrMax < val) ? false : true;

			}
			return valide;
		}

	});


// WIDGET FormDate
	dj.declare('epages.widget.FormDate', [epages.widget.FormNumber], {

	// CREATE
		postCreate: function(){
			this.inherited('postCreate', arguments);

			// set pattern by type
			this._attr.pattern = epages.localize.getPattern( this._attr.type );
		},

	// METHODS
		_stepAction: function( inc ){
			this._stepCount++;
			this._stepSpeedHandle( inc );

			var value = dj.attr( this.domNode , 'value' );
			var ret;
			var attrStep = this._attr.step || 1;
			var attrMin = this._attr.min;
			var attrMax = this._attr.max;

			var dateObj = epages.localize.date2obj( value , this._attr.type ) || new Date();
			switch( this._attr.type ){
				case 'datetime':
					dateObj.setHours( dateObj.getHours() + (inc * attrStep) );
				break;
				case 'month':
					dateObj.setMonth( dateObj.getMonth() + (inc * attrStep) );
				break;
				case 'time':
					dateObj.setHours( dateObj.getHours() + (inc * attrStep) );
				break;
				case 'week':
					dateObj.setDate( dateObj.getDate() + (inc * attrStep * 7) );
				break;
				case 'date':
				default:
					dateObj.setDate( dateObj.getDate() + (inc * attrStep) );
				break;
			}
			var dateTime = dateObj.getTime()/1000;
				dateTime = (attrMin && attrMin > dateTime) ? attrMin : (attrMax && attrMax < dateTime) ? attrMax : dateTime;

			dateObj.setTime( dateTime*1000 );

			ret = epages.localize.obj2date( dateObj , this._attr.type );

			dj.attr( this.domNode , 'value' , ret );
		},

		_validate: function(){
			var value = dj.attr( this.domNode , 'value' );
			var valide = false;

			if( value=='' && !this._attr.required ){
				valide = true;
			}
			else if( value.match(new RegExp('^'+this._attr.pattern+'$')) ){
				var dateTime = epages.localize.date2obj( value , this._attr.type ).getTime()/1000;
				var attrMin = this._attr.min;
				var attrMax = this._attr.max;

				valide = (attrMin && attrMin > dateTime) ? false : (attrMax && attrMax < dateTime) ? false : true;

			}
			return valide;
		}

	});

})(dojo);

}

if(!dojo._hasResource["epages.widget.FormElement"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.FormElement"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/

dojo.provide("epages.widget.FormElement");


(function(dj){

	epages.changeInputType = function( node, type ){
			var _node = dj.clone(node);
				dj.attr( _node , 'type' , type );
				dj.attr( _node , 'value' , node.value );
				dj.place( _node , node , 'after' );
				_node.parentNode.removeChild(node);
			return _node;
		};

	epages.widget.FormElement = function( options, domNode ){
		this.destroy();

		var nodeName = domNode.nodeName.toLowerCase(),
			nodeType,
			widget;

		if( nodeName == 'select' ){
			widget = new epages.widget.FormSelect(options,domNode);
		}
		else if( nodeName == 'textarea' ){
			widget = new epages.widget.FormText(options,domNode);
		}
		else{
			if( dojo.hasClass( domNode, 'Checkbox' ) ){
				domNode = domNode.type != 'checkbox' ? epages.changeInputType( domNode, 'checkbox' ) : domNode;
				widget = new epages.widget.FormCheck(options,domNode);
			}
			else if( dojo.hasClass( domNode, 'Radio' ) ){
				domNode = domNode.type != 'radio' ? epages.changeInputType( domNode, 'radio' ) : domNode;
				widget = new epages.widget.FormCheck(options,domNode);
			}

			nodeType = domNode.getAttribute('type');

			if( /^(file)$/i.test(nodeType) ){
				widget = new epages.widget.FormFile(options,domNode);
			}
			else if( /^(text|password)$/i.test(nodeType) ){
				widget = new epages.widget.FormText(options,domNode);
			}
		}

		if( widget ){

			widget.elementNode = widget.domNode;
			widget.setValue = function( val ) {
				return this.attr( 'value', val );
			}

			widget.setStartUpValue = function( val ) {
				this.attr( 'startupValue', val );
				this.validate();

				return this;
			}

			widget.getValue = function() {
				return this.attr( 'value' );
			}

			widget.isChecked = function() {
				return this.attr( 'checked' );
			}

			widget.setChecked = function( val ){
				return this.attr( 'checked', val );
			}

			return widget;
		}
	};
	epages.widget.FormElement.prototype = new dijit._Widget();

})(dojo);

}


dojo.i18n._preloadLocalizations("epages.nls.ep_base", ["ROOT","ca","da","de","en","es","fi","fr","it","nl","no","pt","ro","ru","sv","xx"]);

/* package: ep_shop.js.uncompressed */
/*
	Copyright (c) 2004-2011, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/

/*
	This is an optimized version of Dojo, built for deployment and not for
	development. To get sources and documentation, please visit:

		http://dojotoolkit.org
*/

if(!dojo._hasResource['epages.template']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.template'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.template');




$TMPL = /*epages.Template*/function (/*string*/template,/*hash*/ vars, /*boolean?*/ encodeVars, /*boolean?*/ enableRegExVars) {
	if(encodeVars === undefined){
		encodeVars=true;
	}
	if(enableRegExVars === undefined){	// default reg ex vars are allowed
		enableRegExVars=true;
	}

	return new epages.Template({
		template: template,
		vars: vars,
		encodeVars: encodeVars,
		enableRegExVars : enableRegExVars
	});
};

epages.Template = function(options) {
	this.setOptions(options);

	// get Template from DOM
	if (this.options.template === undefined && this.options.templateDom != undefined) {
		if (typeof this.options.templateDom != 'object'){
			this.options.templateDom = $(this.options.templateDom);
		}
		this.options.template = $E(this.options.templateDom).firstComment();
	}
};

epages.Template.prototype = {
	options : undefined,

	setOptions: function(options) {
		this.options = {
			encodeVars  : true,
			enableRegExVars: false,
			templateDom : undefined,
			template    : undefined,
			vars        : undefined,
			addTemplate : true
		};
		dojo.mixin(this.options, options);
	},

	setTemplate: function (template) {
		this.options.template = template;
	},

	encodeXml: function(string) {
		if (string !== undefined) {
			if (typeof string == "number"){
				string = string.toString();
			}
			string = string
				.replace(/&/g,"&amp;")     // qoute &
				.replace(/"/g,"&quot;")    // qoute "
				.replace(/>/g,"&gt;")      // qoute >
				.replace(/</g,"&lt;");     // qoute <
		}
		return string;
	},

	maskRegExVars: function(string) {
		if (string !== undefined) {
			if (typeof string == "number"){
				string = string.toString();
			}
			if (typeof string == "string"){
				string = string.replace(/\$/g, "\\$");     // mask $
			}
		}
		return string;
	},

	unmaskRegExVars: function(string) {
		if (string !== undefined) {
			if (typeof string == "number"){
				string = string.toString();
			}
			if (typeof string == "string"){
				string = string.replace(/\\\$/g, "$");     // unmask $
			}
		}
		return string;
	},

	processHash: function(vars) {
		// declare some vars for iterator function
		if (vars.each === undefined){
			vars = $H(vars);
		}
		var template=this.options.template;
		if (template === undefined) {
			console.warn('epages.Template: template is empty');
			return '';
		}

		var me=this;
		// insert hash vars into template
		var iterator= function(pair) {
			var tempValue = pair.value;
			var encValue = me.options.encodeVars ? me.encodeXml(tempValue) : tempValue;
			// insert string
			encValue = me.options.enableRegExVars ? encValue : me.maskRegExVars(encValue);

			var templateRegExp = new RegExp('\\(%' + pair.key + '%\\)', "g" );
			template = template.replace( templateRegExp, encValue );
			template = me.options.enableRegExVars ? template : me.unmaskRegExVars(template);
		};
		// call iterator for each key/value pair
		vars.each(iterator);
		return template;
	},

	processLoop: function(loop) {
		var content = '';
		var me=this;
		loop.each(function (el) {
			content += me.processHash(el);
		});
		return content;
	},

	generateOutput: function () {
		return this.processHash(this.options.vars);
	},

	insertTemplate: function (element) {
		if (!this.options.addTemplate){
			return;
		}
		var comment = document.createElement("COMMENT");
		comment.data = this.options.template;
		// element.insertAdjacentElement("afterBegin",comment);
		if (element.firstChild === undefined){
			element.insertChild(comment);
		}else{
			element.insertBefore(comment, element.firstChild);
		}
		return;
	},

	insertLoop: function (loop, targetDom) {
		if (targetDom === undefined){
			targetDom = this.options.templateDom;
		}
		if (typeof this.options.targetDom != 'object'){
			targetDom = $(targetDom);
		}
		targetDom.innerHTML = this.processLoop(loop);
		this.insertTemplate(targetDom);
	},

	insert: function(targetDom) {
		if (targetDom === undefined){
			targetDom = this.options.templateDom;
		}
		if (typeof this.options.targetDom != 'object'){
			targetDom = $(targetDom);
		}
		targetDom.innerHTML = this.generateOutput();
		this.processTemplate(targetDom);
	}
};

}

if(!dojo._hasResource['epages.event.adjustonresize']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.event.adjustonresize'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/

dojo.provide('epages.event.adjustonresize');



epages.event.AdjustOnResize = function(/*DOMObject*/scrollbarElement, /* Object */ options) {
// summary: constructor for adjustonresize
// scrollbarElement  - dom node
// options 				   - object
// 		deltaWindowWidth  - integer or null
// 		deltaWindowHeight - integer or null
// 		callback 					- callback function

	// set element with scrollbar
	this.scrollbarElement=scrollbarElement;
	// set options
	this.setOptions(options);

	this.appendEvent();
};

epages.event.AdjustOnResize.prototype = {
	options						: undefined,
	scrollbarElement  : undefined,

	setOptions: function(/*Object*/ options) {
		if(this.options === undefined){
			this.options={
				deltaWindowHeight : undefined,
				deltaWindowWidth  : undefined,
				callback          : undefined,
				topicname         : 'AdjustOnResize'
			};
			}
		dojo.mixin(this.options, options);
		// update display
		this.resizeElement();

		dojo.addClass(document.getElementsByTagName("html")[0], "AdjustOnResize");
	},

	appendEvent: function() {
		// dojo.connect sometimes has problems with "onresize" on the window object
		// dojo.connect(window, 'onresize', epages.lang.hitch(this, function() { this.resizeElement()}));

		if(epages.Browser.engine=="MSIE"){          // MSIE version
			window.attachEvent('onresize', epages.lang.hitch(this, function() { this.resizeElement();}));
		} else {                                  // W3C version
			window.addEventListener("resize",epages.lang.hitch(this, function() { this.resizeElement();}),false);
		}
	},

	resizeElement: function() {
		var elementHeight = null;
		var elementWidth = null;

		//adjust height
		if(this.options.deltaWindowHeight != null) {
			var windowHeight = (window.innerHeight !== undefined) ? window.innerHeight : document.documentElement.clientHeight;  // height of the visible area in the window
			elementHeight=windowHeight-this.options.deltaWindowHeight;
			if(elementHeight>0) {
				if(this.options.lastElementHeight && this.options.lastElementHeight == elementHeight){
					return false;
				}
				this.options.lastElementHeight = elementHeight;
				this.scrollbarElement.style.height = elementHeight+'px';
			}
		}

		// adjust width
		if(this.options.deltaWindowWidth != null) {
			var windowWidth = (window.innerWidth !== undefined) ? window.innerWidth : document.documentElement.clientWidth;  // width of the visible area in the window
			elementWidth=windowWidth-this.options.deltaWindowWidth;
			if(elementWidth>0) {
				if(this.options.lastElementWidth && this.options.lastElementWidth == elementWidth){
					return false;
				}
				this.options.lastElementWidth = elementWidth;
				this.scrollbarElement.style.width = elementWidth+'px';
			}
		}
		dojo.publish(this.options.topicname+"/resize", [elementWidth, elementHeight]);

		if(this.options.callback !== undefined){
			if(typeof this.options.callback == 'function'){
				this.options.callback();
			}else{
				console.warn('option "callback" is not a function in epages.event.adjustonresize');
	}
}
	}
};

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Sidebarcontroller"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Sidebarcontroller"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.presentation.widget.Sidebarcontroller

*/
dojo.provide("epages.cartridges.de_epages.presentation.widget.Sidebarcontroller");





dojo.declare("epages.cartridges.de_epages.presentation.widget.Sidebarcontroller",
	[dijit._Widget, dijit._Container],
	{
		contentPane             : "",
		_contentScrollBarHandler: undefined,
		_sideBarPaddings				: undefined,

		startup:	function() {
			this.inherited("startup", arguments);
			// get contentPane DomeNode
			if(this.contentPane!= ""){
				this.contentPane=$(this.contentPane);
			}

			this._sideBarPaddings = new epages.lang.Hash();

			// register sidebars
			var children = this.getChildren();

			for(var	i=0,l=children.length; i<l; i++)	{
				if(children[i].declaredClass=="epages.cartridges.de_epages.presentation.widget.Sidebar") {
						dojo.subscribe(children[i].id + '/afterShowSidebar',	this, '_setPadding');
						dojo.subscribe(children[i].id + '/afterShowSidebar',	this, '_resizeMinHeight');
						dojo.subscribe(children[i].id + '/afterHideSidebar',	this, '_setPadding');
						dojo.subscribe(children[i].id + '/afterSetWidth', 		this, '_setPadding');
						if(children[i].isVisible){
							children[i].show(children[i].isOverlay,true);
						}
				}
			}
			dojo.subscribe('Sidebar/changeHeight', this, '_checkHeight' );
			//dojo.subscribe('contentPane/resize',   this, '_resizeHeight');

			dojo.subscribe('Sidebar/changeHeight', this, '_resizeMinHeight');
			this._resizeMinHeight(); // sadly this is needed for Fx3 and IE
		},

		enableScrollMode: function(/*Object*/ options){
			options['topicname']="contentPane";
			// add scrollbar handler
			if(this._contentScrollBarHandler === undefined) {
				this._contentScrollBarHandler = new epages.event.AdjustOnResize(this.contentPane, options);
				this.domNode.style.minHeight = "";
			} else {
				this._contentScrollBarHandler.setOptions(options);
			}

			// remove document scrollbar
			// document.getElementsByTagName("html")[0].style.overflow="hidden";
		},

		_setPadding: function(/*Widget*/ options)  {
			// this._sideBarPaddings.set(options.side, options.width);

			// set mainlayout padding
			if(options.side.toLowerCase()=="left" && isNaN(options.width)==false) {
				$('Content').style.marginLeft=options.width+"px";
			}

			// this block causes a missaligned content-container in safari
			// it was removed with EPG-25495
			/*if(options.side.toLowerCase()=="right" && isNaN(options.width)==false) {
				$('Content').style.marginRight=options.width+"px";
			}*/

			// if scroll mode is enabled -> change values of scrollbar handler
			//if(this._contentScrollBarHandler !== undefined) {
				// var deltaWindowWidth=0;
				// this._sideBarPaddings.each(function(pair){
					// deltaWindowWidth+=pair.value;
				// });

				// var pageWidthSpace = (epages.vars.Layout.pageWidthSpace) ? epages.vars.Layout.pageWidthSpace : 0;

				// this._contentScrollBarHandler.setOptions({
				//	deltaWindowWidth: deltaWindowWidth + pageWidthSpace
				// });
			// }
			epages.event.fire(window,'resize');
		},

		_resizeHeight: function(width, height) {
			this.domNode.style.height=height+"px";
		},

		_resizeMinHeight: function() {
			// var scNode = $("SidebarContent");
			// if(scNode) {
				// scNode.parentNode.style.visibility = "hidden";
			// } else {
				// console.warn('SidebarContent node not found in '+this.declaredClass);
			// }
			// minimize jitter of .PropertyContainer on recalc
			// if($("EmbeddedStorefront")) {
				// this.domNode.style.minHeight = "0";
			// }else {
				// this.domNode.style.minHeight = (($("RightSidebarTabs") || dojo.body()).offsetHeight + ($("TrialShopBox") ? $("TrialShopBox").offsetHeight : 0)) + "px";
			// }
			// setTimeout(function() {
				// var scNode = $("SidebarContent");
				// if(scNode) {
					// scNode.parentNode.style.visibility = "visible";
					// dojo.addClass(scNode, "Opacity90");
					// dojo.removeClass(scNode, "Opacity90");
				// } else {
					// console.warn('SidebarContent node not found in '+this.declaredClass);
				// }
			// }, 1);
			// minimize jitter of .PropertyContainer on recalc
		},

		_checkHeight: function(/* widget */ sidebar) {
		// check height of all sidebar content elements and set minheight
			var child = sidebar.containerNode.firstChild;
			var height = 0;
			while (child != null) {
				if(child.nodeType == 1 && child.offsetHeight){
					height += child.offsetHeight;
				}
				child = child.nextSibling;
			}
			//if(height != 0) this._setMinHeight(height);
			//this causes height problems with the left sidebar when the windows gets to slim (EPG-9594) - do we really need this?
		},

		_setMinHeight: function(/* integer */ height) {

		}

	});

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Sidebar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Sidebar"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.presentation.widget.Sidebar

*/

dojo.provide("epages.cartridges.de_epages.presentation.widget.Sidebar");




dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.Sidebar",
	[epages.widget.LocalizedWidget, dijit._Contained], {
		side              : "",
		width             : "",
		isVisible         : '',
		isOverlay         : false,
		title             : "",
		displayTitlebar   : true,
		minimizeOnHide    : false,
		url               : '?',
		userId            : '',
		pageTypeId        : '',

		WIDTH_OFFSET      : 1, // Integer; width offset (borders, margins, paddings)

		templateString:"<div class=\"Sidebar ${side}\">\n  <div class=\"MinimizeNode\"dojoAttachPoint=\"minimizeNode\">\n    <i class=\"Sprite ico_s_sidebar\" title=\"{DoShowSidebar}\"></i>\n  </div>\n  <div class=\"PropertyContainer\">\n    <div class=\"SidebarTitlebar\"\n         dojoAttachPoint=\"titlebarNode\">\n      <span class=\"SidebarTitle\" dojoAttachPoint=\"titleNode\">${title}</span>\n      <div class=\"CloseButton EnableHover\" dojoAttachPoint=\"closeButtonNode\" title=\"{DoHideSidebar}\"></div>\n    </div>\n    <div id=\"SidebarContent\" class=\"SidebarContent\" dojoAttachPoint=\"containerNode\"></div>\n  </div>\n</div>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget', "templates/translation"),
		imagePath       :epages.themeUrl('images'),

		postCreate: function() {
			this.inherited("postCreate", arguments);

			this.isVisible=epages.string.toBoolean(this.isVisible);
			this.minimizeOnHide=epages.string.toBoolean(this.minimizeOnHide);
			this.displayTitlebar=epages.string.toBoolean(this.displayTitlebar);
			this.setTitlebar(this.displayTitlebar);

			// stretch to page length
			this.domNode.style.height="100%";
			this.setWidth(parseInt(this.width));
			this._appendEvents();
			if(this.minimizeOnHide) {
				dojo.addClass(this.domNode, "Minimize");
			} else {
				this.domNode.style.display="none";
			}
		},

		setTitlebar: function(displayTitlebar) {
			if(displayTitlebar) {
				dojo.addClass(this.domNode, "WithTitlebar");
				this.displayTitlebar=true;
			} else {
				dojo.removeClass(this.domNode, "WithTitlebar");
				this.displayTitlebar=false;
			}
		},

		_appendEvents: function() {
			this.connect(this.closeButtonNode, 'onclick', 'hide');
			this.connect(this.minimizeNode,    'onclick', 'showLastOverlayState');
		},

		setWidth: function(width) {
			if(isNaN(width)){
				console.warn('Attribute "width" is not a number in '+this.declaredClass+'. Couldn\'t calculate new width');
			}else {
				this.width=width;
				this.domNode.style.width=this.width+"px";

				if(!this.isOverlay && this.isVisible){
					dojo.publish(this.id+"/afterSetWidth", [{
						width    : this.width+this.WIDTH_OFFSET,
						side     : this.side
					}]);
				}
			}
		},

		setTitle: function(title) {
				this.title=title;
				this.titleNode.innerHTML=title;
		},

		sendShow: function () {
			if(this.userId != '') {
				var json = new epages.io.Json;
				var options = {
					'ViewAction':     'JSONViewResponse',
					'ChangeAction':   'Save',
					'ObjectID':       this.userId,
					'ShowSidebar':    this.isVisible ? 1 : 0
				};
				if (!this.isVisible && this.pageTypeId != '') {
					options.ChangeAction = 'SaveSidebar';
					options.PageTypeID = this.pageTypeId;
				}
				json.loadAsync(this.url, function (result) {},options);
			}
		},

		show: function(/*Boolean?*/ overlay, startUp) {
			this.isOverlay = (overlay==true) ? true : false;
			this.isVisible = true;
			// display changes
			this.domNode.style.display="";
			dojo.removeClass(this.domNode, "Minimize");
			if(!startUp){ 
				this.sendShow();
			}
			this._toggleOverlayDisplay();
			dojo.publish(this.id+"/afterShowSidebar", [{
				width    : (this.isOverlay) ? 0 : this.width+this.WIDTH_OFFSET,
				side     : this.side
			}]);
		},

		hide: function() {
			this.isVisible=false;
			if(this.minimizeOnHide) {
				dojo.addClass(this.domNode, "Minimize");
			} else {
				this.domNode.style.display="none";
			}
			this.sendShow();
			dojo.publish(this.id+"/afterShowSidebar", [{
				width    : 0,
				side     : this.side
			}]);
		},

		toggleView: function() {
			if(this.isVisible){
				this.hide();
			}else{
				this.show(this.isOverlay);
			}
		},

		_toggleOverlayDisplay: function() {
			this.domNode.style.height=(this.isOverlay) ? "auto" : "100%";
			if(this.isOverlay) {
				dojo.addClass(this.domNode,"Unpinned");
				dojo.removeClass(this.domNode,"Pinned");
			} else {
				dojo.addClass(this.domNode,"Pinned");
				dojo.removeClass(this.domNode,"Unpinned");
			}
		},

		showLastOverlayState: function() {
				this.show(this.isOverlay);
		}
	});

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.SidebarTabs"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.SidebarTabs"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.presentation.widget.SidebarTabs

*/
dojo.provide("epages.cartridges.de_epages.presentation.widget.SidebarTabs");




dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.SidebarTabs",
	[epages.widget.LocalizedWidget],
	{
		menu: '',
		forceHelp: '',
		url: '?',
		userId: '',
		pagetypeId: '',
		sideBarMenu: '',
		sideBarId: '',

		_sidebar: undefined,
		_tabs: undefined,
		_lastTab: undefined,
		_tabSelectedByClick: false,

		templateString:"<div class=\"SidebarTabs\">\n  <div class=\"Tabs\"  dojoAttachPoint=\"tabNode\">\n    <div class=\"CloseButton EnableHover\" style=\"display:none\" dojoAttachPoint=\"closeSidebarNode\" title=\"{DoHideSidebar}\"></div>\n  </div>\n  <div class=\"Block\" dojoAttachPoint=\"blockNode\"></div>\n</div>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget', "templates/translation"),

		postMixInProperties: function() {
			this.inherited("postMixInProperties", arguments);
			this._tabs = [];
			this.forceHelp = epages.string.toBoolean(this.forceHelp);
			this._sidebar = $$(this.sideBarId);
		},

		postCreate  : function() {
			this.inherited("postCreate", arguments);
			// make a copy of childNodes
			var children = [];
			dojo.forEach(this.srcNodeRef.childNodes, function (el) { children.push(el); });

			var tab = true, cTab = -1, enableFirst = true;

			for( var i=0,l=children.length ; i<l ; i++ ) {
				var node = children[i];
				if (node.tagName == 'DIV') {
					if (tab) {
						cTab++;
						this.tabNode.appendChild(node);
						this._tabs[cTab] = { tab : node, menu : node.getAttribute('ep_menu')};
						this.connect(node,'click', '_clickTab');
						if ($$(this.sideBarMenu) && node.getAttribute('ep_menulabel')) {
							var caller = function (me, node) {
								return function () {
									me._clickTab({currentTarget:node});
									if(me._sidebar && !me._sidebar.isVisible){
										me._sidebar.show();
									}
								};
							};
							var menuItem  = new dijit.MenuItem({
								label: node.getAttribute('ep_menulabel'),
								onClick: caller(this, node)
							});
							$$(this.sideBarMenu).addChild(menuItem);
							if (node.getAttribute('ep_menuicon')){
								menuItem.iconNode.style.background = 'url('+node.getAttribute('ep_menuicon')+') no-repeat top left';
							}
						}
					} else {
						this._tabs[cTab].block = node;
						if(this.forceHelp && this._tabs[cTab].menu == 'help' ||
							 !this.forceHelp  && this.menu == this._tabs[cTab].menu
						) {
							this._selectTab(this._tabs[cTab].tab, node);
							enableFirst = false;
						} else {
							node.style.display = 'none';
						}
						this.blockNode.appendChild(node);
					}
					tab = !tab;
				}
			}
			if (enableFirst){
				this._selectTab(this._tabs[0].tab, this._tabs[0].block);
			}

			this.connect(window, "onbeforeunload", "_saveTab");
			if(this._sidebar !== undefined) {
				this.closeSidebarNode.style.display="";
				this.connect(this.closeSidebarNode, "onclick", "_closeSidebar");
			}
		},

		_closeSidebar: function() {
			if(this._sidebar){
				this._sidebar.hide();
			}
		},

		_clickTab: function (evt) {
			this._tabSelectedByClick=true;
			var tab = evt.currentTarget, block = undefined;
			for( var i=0,l=this._tabs.length ; i<l ; i++ )
				if (this._tabs[i].tab == tab){
					block = this._tabs[i].block;
				}
			this._selectTab(tab, block);
		},

		_selectTab: function(/* domnode */ tab, /* domnode */ block) {
			if(this._lastTab !== undefined && tab !== this._lastTab.tab) {
				// hide last selected
				dojo.removeClass(this._lastTab.tab, "Selected");
				if(this._lastTab.tab.children.length){
					var iconNode = this._lastTab.tab.children[0];
					if(dojo.attr(iconNode,'data-active-icon') && dojo.attr(iconNode,'data-icon')){
						dojo.removeClass(iconNode,dojo.attr(iconNode,'data-active-icon'));
						dojo.addClass(iconNode,dojo.attr(iconNode,'data-icon'));
					}
				}
				this._lastTab.block.style.display = 'none';
			}
			// show new selected
			if(tab.children.length){
				var iconNode = tab.children[0];
				if(dojo.attr(iconNode,'data-active-icon') && dojo.attr(iconNode,'data-icon')){
					dojo.addClass(iconNode,dojo.attr(iconNode,'data-active-icon'));
					dojo.removeClass(iconNode,dojo.attr(iconNode,'data-icon'));
				}
			}
			dojo.addClass(tab, "Selected");

			block.style.display = '';
			this._lastTab= {
				tab: tab,
				block: block,
				menu : tab.getAttribute('ep_menu')
			};

			var _this=this;
			window.setTimeout(function() {
				dojo.publish('Sidebar/changeHeight', [$$(_this.sideBarId)]);	// sidebarcontroller subscribes
			}, 10); // need a short time to display inital tab
			dojo.publish('Sidebar/selectTab',[this._lastTab]);
		},

		_saveTab: function() {
			if(this.userId != '' && this._lastTab !== undefined && this._tabSelectedByClick) {
				var json = new epages.io.Json;
				json.loadSync(this.url, {
					'ViewAction':     'JSONViewResponse',
					'ChangeAction':   'SaveSidebar',
					'ObjectID':       this.userId,
					'PageTypeID':     this.pagetypeId,
					'SidebarMenuName': this._lastTab.menu
				});
			}
		},
		selectTab: function(/*ep_menu string*/ ep_menu){
			var tab = undefined;
			var block = undefined;
			for( var i=0,iLength=this._tabs.length ; i<iLength ; i++ ){
				if(this._tabs[i].menu == ep_menu){
					tab = this._tabs[i].tab;
					block = this._tabs[i].block;
				}
			}
			if(tab != undefined){
				this._selectTab(tab, block);
				if(this._sidebar !== undefined){
					this._sidebar.show();
				}
			}
		},


		currentTab: function(){
			if(this._lastTab !== undefined){
				return this._lastTab;
			}
			return false;
		}
});


}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Tray"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Tray"] = true;
/*
	Copyright (c) 2006-2008, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.presentation.widget.Tray

*/
dojo.provide("epages.cartridges.de_epages.presentation.widget.Tray");






dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.Tray",
	[epages.widget.LocalizedWidget],
	{
		objectId          : '',
		url               : '?',
		sidebarTabsId     : 'RightSidebarTabs',
		sidebarId         : 'RightSidebar',

		_groups           : undefined,
		_addObject        : undefined,
		_sidebarTabs      : undefined,
		_sidebar          : undefined,

		templateString:"<div class=\"Tray\">\n  <h4>{Tray}</h4>\n  <ul class=\"List\" dojoAttachPoint=\"containerNode\"></ul>\n  <div class=\"MessageItem\" dojoAttachPoint=\"emptyNode\" style=\"display:none;\">{TrayEmpty}</div>\n  <div dojoAttachPoint=\"addNode\" style=\"display:none;\">\n    <hr />\n    <ul class=\"List\">\n      <li>\n        <div class=\"Item ElementAddToTray ClickCursor\" dojoAttachEvent=\"onclick:_addToTray\">\n          <i class=\"Sprite ico_s_tray_addto\" title=\"{ElementAddToTray}\"></i>\n          <a dojoAttachPoint=\"addNodeTitle\" title=\"{ElementAddToTray}\"></a>\n        </div>\n      </li>\n    <ul>\n  </div>\n  <div dojoAttachPoint=\"existsNode\" style=\"display:none;\">\n    <hr />\n    <ul class=\"List\">\n      <li>\n        <div class=\"Item\">\n          <i class=\"Sprite ico_s_tray\" title=\"{ElementExistsInTray}\"></i>\n          <span dojoAttachPoint=\"existsNodeTitle\" title=\"{ElementExistsInTray}\"></span>\n        </div>\n      </li>\n    <ul>\n  </div>\n  <div dojoAttachPoint=\"deleteTrayNode\">\n    <hr />\n    <ul class=\"List\">\n      <li>\n        <div class=\"Item ClickCursor\" dojoAttachEvent=\"onclick:_deleteTray\">\n          <i class=\"Sprite ico_s_delete\"></i>\n          <a>{DeleteTray}</a>\n        </div>\n      </li>\n    </ul>\n  </div>\n  <div dojoAttachPoint=\"itemNode\" style=\"display:none;\">\n    <li>\n      <div class=\"Item\">\n        <span class=\"ItemTitle FloatLeft\" title=\"\"></span>\n        <i class=\"ItemDeleteNode FloatRight ClickCursor Sprite ico_s_remove\" title=\"{RemoveTrayGroup}\"></i>\n        <div class=\"ClearBoth\"></div>\n      </div>\n    </li>\n  </div>\n  <hr />\n</div>\n",
		imagePath       : epages.themeUrl('images'),
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget', 'templates/translation'),

		postCreate  : function() {
			this.inherited("postCreate", arguments);
			dojo.subscribe('Sidebar/selectTab', this, '_onTabSelect');
			if($$(this.sidebarId)){
				this._sidebar = $$(this.sidebarId);
			}
			if($$(this.sidebarTabsId)){
				this._sidebarTabs = $$(this.sidebarTabsId);
				var tab = this._sidebarTabs.currentTab();
				//check if tab is selected and sidebar is visible before loading
				if(tab && this._sidebar.isVisible){
					this._onTabSelect(tab);
				}
			}else{
				this._loadTray();
				this._updateLayout();
			}
		},

		_onTabSelect:function(tab){
			if(tab && tab.menu == 'tray' && this._groups == undefined){
				this._loadTray();
				this._updateLayout();
			}
		},

		_loadTray: function(){
			var currentTray = this._sendRequest('JSONGetTray');
			if(currentTray){
				this._groups = currentTray.data;
				this._groups.sort(function(a, b) {
					if (a.Name < b.Name){
						return -1;
					}
					if (a.Name > b.Name){ 
						return  1;
					}
					return 0; 
				});
				this.containerNode.innerHTML = '';
				for( var i=0,iLength=this._groups.length ; i<iLength ; i++ ){
					var item = this.itemNode.cloneNode(true);
					item.style.display = '';
					var titleNode = epages.html.getElementsByClassName('ItemTitle',item)[0];
					titleNode.innerHTML = epages.format.slice(this._groups[i].Name,30)+" ("+this._groups[i].CountElements+")";
					titleNode.title = this._groups[i].Name;
					var deleteNode = epages.html.getElementsByClassName('ItemDeleteNode',item)[0];
					this.connect(deleteNode, 'onclick', 'deleteItem');
					this._groups[i].itemNode = item;
					this._groups[i].deleteNode = deleteNode;
					this.containerNode.appendChild(item);
				}
			}
		},

		_updateLayout: function(){
			if(this._groups.length == 0){
				this.emptyNode.style.display = '';
				this.deleteTrayNode.style.display = 'none';
				this.containerNode.style.display = 'none';
			}
			else{
				this.emptyNode.style.display = 'none';
				this.deleteTrayNode.style.display = '';
				this.containerNode.style.display = '';
			}
			if(this._addObject){
				this.showAddToTray(this._addObject);
			}
			else{
				this.existsNode.style.display = 'none';
				this.addNode.style.display = 'none';
			}
		},

		showAddToTray: function(addObject){
			this._addObject = addObject;
			if(this._groups){
				var exists = false;
				for( var i=0,iLength=this._groups.length ; i<iLength ; i++ ){
					for( var j=0,jLength=this._groups[i].Objects.length ; j<jLength ; j++ ){
						if(this._groups[i].Objects[j].ObjectID == addObject.objectId){
							exists = true;
						}
					}
				}
				if(exists){
					this.existsNode.style.display = '';
					this.existsNodeTitle.innerHTML = addObject.name;
					this.addNode.style.display = 'none';
				}
				else{
					this.addNode.style.display = '';
					this.addNodeTitle.innerHTML = addObject.name;
					this.existsNode.style.display = 'none';
				}
			}
		},

		deleteItem: function(evt){
			originalTarget = evt.originalTarget || evt.srcElement;
			var group = undefined;
			var index = undefined;
			for( var i=0,iLength=this._groups.length ; i<iLength ; i++ ){
				if(this._groups[i].deleteNode == originalTarget){
					group = this._groups[i];
					index = i;
				}
			}
			if(group){
				if(this._sendRequest('DeleteTrayGroup',{TrayGroupID:group.TrayGroupID})){
					this.containerNode.removeChild(group.itemNode);
					$A(this._groups).remove(index);
					this._updateLayout();
				}
			}
		},

		_deleteTray: function(){
			if(this._sendRequest('DeleteTray')){
				this._groups = [];
				this.containerNode.innerHTML = "";
				this._updateLayout();
			}
		},

		_sendRequest: function(changeAction,opt){
			var json = new epages.io.Json;
				var options = {
					'ViewAction':     'JSONViewResponse',
					'ChangeAction':   changeAction,
					'ObjectID':       this.objectId
				};
				if(opt){
					dojo.mixin(options,opt);
				}
				var result = json.loadSync(this.url,options);
				if(result.error){
					return false;
				}
				return result;
		},

		_addToTray: function(){
			if(this._addObject){
				if(this._sendRequest('AddListToTray',{ListObjectID:this._addObject.objectId})){
					var groupexists = false;
					for( var i=0,iLength=this._groups.length ; i<iLength ; i++ ){
						if(this._groups[i].Name == this._addObject.className){
							groupexists = true;
							this._groups[i].Objects.push({
								Alias: this._addObject.alias,
								Name: this._addObject.name,
								ObjectID: this._addObject.objectId
							});
							this._groups[i].CountElements++;
							var item = this._groups[i].itemNode;
							var titleNode = epages.html.getElementsByClassName('ItemTitle',item)[0];
							titleNode.innerHTML = this._groups[i].Name+" ("+this._groups[i].CountElements+")";
						}
					}
					if(!groupexists){
						this._loadTray();
					}
					this._updateLayout();
				}
			}
		}
});


}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Favorites"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Favorites"] = true;
/*
	Copyright (c) 2006-2008, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.presentation.widget.Favorites

*/
dojo.provide("epages.cartridges.de_epages.presentation.widget.Favorites");






dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.Favorites",
	[epages.widget.LocalizedWidget],
	{
		objectId          : '',
		url               : '?',
		sidebarTabsId     : 'RightSidebarTabs',
		sidebarId         : 'RightSidebar',
		currentName       : '',
		currentURI        : '',

		_favorites        : undefined,
		_sidebarTabs      : undefined,
		_sidebar          : undefined,

		templateString:"<div class=\"Favorites\">\n  <h4>{Favorites}</h4>\n  <div class=\"MessageItem\" dojoAttachPoint=\"emptyNode\" style=\"display:none;\">{FavoritesEmpty}</div>\n  <div dojoAttachPoint=\"addNode\" style=\"display:none;\">\n    <ul class=\"List\">\n      <li>\n        <div class=\"Item ElementAddToTray ClickCursor\" dojoAttachEvent=\"onclick:_onClickAddNode\">\n          <i class=\"Sprite ico_s_favorite_add\" title=\"{ElementAddToFavorites}\"></i>\n          <a dojoAttachPoint=\"addNodeTitle\">{ElementAddToFavorites}</a>\n        </div>\n      </li>\n    </ul>\n    <hr/>\n  </div>\n  <div dojoAttachPoint=\"existsNode\" style=\"display:none;\">\n    <ul class=\"List\">\n      <li>\n        <div class=\"Item\">\n          <span dojoAttachPoint=\"existsNodeTitle\" title=\"{ElementExistsInFavorites}\"></span>\n        </div>\n      </li>\n    <ul>\n    <hr />\n  </div>\n  <ul class=\"List\" dojoAttachPoint=\"containerNode\"></ul>\n  <div dojoAttachPoint=\"deleteNode\">\n    <hr />\n    <ul class=\"List\">\n      <li>\n        <div class=\"Item ClickCursor\" dojoAttachEvent=\"onclick:_deleteFavorites\">\n          <i class=\"Sprite ico_s_delete\"></i>\n          <a>{DeleteAllFavorites}</a>\n        </div>\n      </li>\n    </ul>\n  </div>\n  <div dojoAttachPoint=\"itemNode\" style=\"display:none;\">\n    <li>\n      <div class=\"Item\">\n        <a class=\"ItemLink FloatLeft\" href=\"\" title=\"\"></a>\n        <i class=\"ItemDeleteNode FloatRight ClickCursor Sprite ico_s_remove\" title=\"{DeleteFavorite}\"></i>\n        <div class=\"ClearBoth\"></div>\n      </div>\n    </li>\n  </div>\n</div>\n",
		imagePath       : epages.themeUrl('images'),
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget', 'templates/translation'),

		postCreate  : function() {
			this.inherited("postCreate", arguments);
			dojo.subscribe('Sidebar/selectTab', this, '_onTabSelect');
			if($$(this.sidebarId)){
				this._sidebar = $$(this.sidebarId);
			}
			if($$(this.sidebarTabsId)){
				this._sidebarTabs = $$(this.sidebarTabsId);
				var tab = this._sidebarTabs.currentTab();
				//check if tab is selected and sidebar is visible before loading
				if(tab && this._sidebar.isVisible){
					this._onTabSelect(tab);
				}
			}else{
				this._loadFavorites();
				this._updateLayout();
			}
		},

		_onTabSelect:function(tab){
			if(tab && tab.menu == 'favorites' && this._favorites == undefined){
				this._loadFavorites();
				this._updateLayout();
			}
		},

		_loadFavorites: function(){
			var currentFavorites = this._sendRequest('JSONGetFavorites');
			if(currentFavorites){
				this._favorites = currentFavorites.data;
				this._favorites.sort(function(a, b) {
					if (a.Name < b.Name){
						return -1;
					}
					if (a.Name > b.Name){
						return  1;
					}
					return 0; 
				});
				this.containerNode.innerHTML = '';
				for( var i=0,iLength=this._favorites.length ; i<iLength ; i++ ){
					var item = this.itemNode.cloneNode(true);
					item.style.display = '';
					var linkNode = epages.html.getElementsByClassName('ItemLink',item)[0];
					linkNode.innerHTML += epages.format.scrunch(this._favorites[i].Name,30,0.4);
					linkNode.title = this._favorites[i].Name;
					linkNode.href = this._favorites[i].URI;
					var deleteNode = epages.html.getElementsByClassName('ItemDeleteNode',item)[0];
					this.connect(deleteNode, 'onclick', 'deleteItem');
					this._favorites[i].itemNode = item;
					this._favorites[i].deleteNode = deleteNode;
					this.containerNode.appendChild(item);
				}
			}
		},

		_updateLayout: function(){
			if(this._favorites.length == 0){
				this.emptyNode.style.display = '';
				this.deleteNode.style.display = 'none';
				this.containerNode.style.display = 'none';
			}
			else{
				this.emptyNode.style.display = 'none';
				this.deleteNode.style.display = '';
				this.containerNode.style.display = '';
			}
			this.showAddToFavorites();
		},

		showAddToFavorites: function(){
			if(this._favorites){
				var exists = false;
				var existName="";
				for( var i=0,iLength=this._favorites.length ; i<iLength ; i++ ){
						if(this._favorites[i].Name == this.currentName){
							exists = true;
							existsName = this._favorites[i].Name;
					}
				}
				if(exists){
					this.existsNode.style.display = '';
					this.existsNodeTitle.innerHTML = epages.format.scrunch(existsName,30,0.4);
					this.addNode.style.display = 'none';
				}
				else{
					this.addNode.style.display = '';
					this.addNodeTitle.title = this.currentName;
					this.existsNode.style.display = 'none';
				}
			}
		},

		deleteItem: function(evt){
			originalTarget = evt.originalTarget || evt.srcElement;
			var favorite = undefined;
			var index = undefined;
			for( var i=0,iLength=this._favorites.length ; i<iLength ; i++ ){
				if(this._favorites[i].deleteNode == originalTarget){
					favorite = this._favorites[i];
					index = i;
				}
			}
			if(favorite){
				if(this._sendRequest('RemoveFavorite',{EventFavoriteID:favorite.EventFavoriteID})){
					this.containerNode.removeChild(favorite.itemNode);
					$A(this._favorites).remove(index);
					this._updateLayout();
				}
			}
		},

		_deleteFavorites: function(){
			if(this._sendRequest('DeleteFavorites')){
				this._favorites = [];
				this.containerNode.innerHTML = "";
				this._updateLayout();
			}
		},

		_sendRequest: function(changeAction,opt){
			var json = new epages.io.Json;
				var options = {
					'ViewAction':     'JSONViewResponse',
					'ChangeAction':   changeAction,
					'ObjectID':       this.objectId
				};
				if(opt){
					dojo.mixin(options,opt);
				}
				var result = json.loadSync(this.url,options);
				if(result.error){
					return false;
				}
				return result;
		},

		_addToFavorites:function(obj){
			var item = this.itemNode.cloneNode(true);
				item.style.display = '';
				var linkNode = epages.html.getElementsByClassName('ItemLink',item)[0];
				linkNode.innerHTML += epages.format.scrunch(obj.Name,30,0.4);
				linkNode.title = obj.Name;
				linkNode.href = obj.URI;
				var deleteNode = epages.html.getElementsByClassName('ItemDeleteNode',item)[0];
				this.connect(deleteNode, 'onclick', 'deleteItem');
				this.containerNode.appendChild(item);
				this._favorites.push({
					URI: obj.URI,
					Name: obj.Name,
					ObjectID: this.objectId,
					EventFavoriteID: obj.EventFavoriteID,
					itemNode: item,
					deleteNode: deleteNode
				});
				this._updateLayout();
		},

		_onClickAddNode: function(){
			var favoriteId = this._sendRequest('JSONAddFavorite',{URI: this.currentURI,Name: this.currentName});
			if(favoriteId != false){
				this._addToFavorites({
					URI  : this.currentURI,
					Name : this.currentName,
					EventFavoriteID : favoriteId.data.EventFavoriteID
				});
			}
		},

		addHistoryToFavorites: function(obj){
			var exists = false;
			if(this._favorites){
				for( var i=0,iLength=this._favorites.length ; i<iLength ; i++ ){
					if(this._favorites[i].URI == obj.URI){ 
						exists = true;
					}
				}
			}
			if(exists == false){
				var favoriteId = this._sendRequest('JSONAddFavorite',{URI: obj.URI,Name: obj.Name});
				if(favoriteId != false){
					if(this._favorites){
						this._addToFavorites({
							URI  : obj.URI,
							Name : obj.Name,
							EventFavoriteID : favoriteId.data.EventFavoriteID
						});
					}
					return true;
				}
			}
			return false;
		}
});


}

if(!dojo._hasResource["dojox.fx._base"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojox.fx._base"] = true;
dojo.provide("dojox.fx._base");
// summary: Experimental and extended Animations beyond Dojo Core / Base functionality.
//	Provides advanced Lines, Animations, and convenience aliases.


dojo.mixin(dojox.fx, {

	// anim: Function
	//	Alias of `dojo.anim` - the shorthand `dojo.animateProperty` with auto-play
	anim: dojo.anim,

	// animateProperty: Function
	//	Alias of `dojo.animateProperty` - animate any CSS property
	animateProperty: dojo.animateProperty,

	// fadeTo: Function
	//		Fade an element from an opacity to an opacity.
	//		Omit `start:` property to detect. `end:` property is required.
	//		Ultimately an alias to `dojo._fade`
	fadeTo: dojo._fade,

	// fadeIn: Function
	//	Alias of `dojo.fadeIn` - Fade a node in.
	fadeIn: dojo.fadeIn,
	
	// fadeOut: Function
	//	Alias of `dojo.fadeOut` - Fades a node out.
	fadeOut: dojo.fadeOut,

	// combine: Function
	//	Alias of `dojo.fx.combine` - Run an array of animations in parallel
	combine: dojo.fx.combine,

	// chain: Function
	//	Alias of `dojo.fx.chain` - Run an array of animations in sequence
	chain: dojo.fx.chain,

	// slideTo: Function
	//	Alias of `dojo.fx.slideTo` - Slide a node to a defined top/left coordinate
	slideTo: dojo.fx.slideTo,

	// wipeIn: Function
	//	Alias of `dojo.fx.wipeIn` - Wipe a node to visible
	wipeIn: dojo.fx.wipeIn,

	// wipeOut: Function
	//	Alias of `dojo.fx.wipeOut` - Wipe a node to non-visible
	wipeOut: dojo.fx.wipeOut

});

dojox.fx.sizeTo = function(/* Object */args){
	// summary:
	//		Creates an animation that will size a node
	//
	// description:
	//		Returns an animation that will size the target node
	//		defined in args Object about it's center to
	//		a width and height defined by (args.width, args.height),
	//		supporting an optional method: chain||combine mixin
	//		(defaults to chain).
	//
	//	- works best on absolutely or relatively positioned elements
	//
	// example:
	//	|	// size #myNode to 400px x 200px over 1 second
	//	|	dojo.fx.sizeTo({
	//	|		node:'myNode',
	//	|		duration: 1000,
	//	|		width: 400,
	//	|		height: 200,
	//	|		method: "combine"
	//	|	}).play();
	//

	var node = args.node = dojo.byId(args.node),
		abs = "absolute";

	var method = args.method || "chain";
	if(!args.duration){ args.duration = 500; } // default duration needed
	if(method == "chain"){ args.duration = Math.floor(args.duration / 2); }
	
	var top, newTop, left, newLeft, width, height = null;

	var init = (function(n){
		return function(){
			var cs = dojo.getComputedStyle(n),
				pos = cs.position,
				w = cs.width,
				h = cs.height
			;
			
			top = (pos == abs ? n.offsetTop : parseInt(cs.top) || 0);
			left = (pos == abs ? n.offsetLeft : parseInt(cs.left) || 0);
			width = (w == "auto" ? 0 : parseInt(w));
			height = (h == "auto" ? 0 : parseInt(h));
			
			newLeft = left - Math.floor((args.width - width) / 2);
			newTop = top - Math.floor((args.height - height) / 2);

			if(pos != abs && pos != 'relative'){
				var ret = dojo.coords(n, true);
				top = ret.y;
				left = ret.x;
				n.style.position = abs;
				n.style.top = top + "px";
				n.style.left = left + "px";
			}
		}
	})(node);

	var anim1 = dojo.animateProperty(dojo.mixin({
		properties: {
			height: function(){
				init();
				return { end: args.height || 0, start: height };
			},
			top: function(){
				return { start: top, end: newTop };
			}
		}
	}, args));
	var anim2 = dojo.animateProperty(dojo.mixin({
		properties: {
			width: function(){
				return { start: width, end: args.width || 0 }
			},
			left: function(){
				return { start: left, end: newLeft }
			}
		}
	}, args));

	var anim = dojo.fx[(args.method == "combine" ? "combine" : "chain")]([anim1, anim2]);
	return anim; // dojo.Animation

};

dojox.fx.slideBy = function(/* Object */args){
	// summary:
	//		Returns an animation to slide a node by a defined offset.
	//
	// description:
	//		Returns an animation that will slide a node (args.node) from it's
	//		current position to it's current posision plus the numbers defined
	//		in args.top and args.left. standard dojo.fx mixin's apply.
	//
	// example:
	//	|	// slide domNode 50px down, and 22px left
	//	|	dojox.fx.slideBy({
	//	|		node: domNode, duration:400,
	//	|		top: 50, left: -22
	//	|	}).play();

	var node = args.node = dojo.byId(args.node),
		top, left;

	var init = (function(n){
		return function(){
			var cs = dojo.getComputedStyle(n);
			var pos = cs.position;
			top = (pos == 'absolute' ? n.offsetTop : parseInt(cs.top) || 0);
			left = (pos == 'absolute' ? n.offsetLeft : parseInt(cs.left) || 0);
			if(pos != 'absolute' && pos != 'relative'){
				var ret = dojo.coords(n, true);
				top = ret.y;
				left = ret.x;
				n.style.position = "absolute";
				n.style.top = top + "px";
				n.style.left = left + "px";
			}
		}
	})(node);
	init();
	
	var _anim = dojo.animateProperty(dojo.mixin({
		properties: {
			// FIXME: is there a way to update the _Line after creation?
			// null start values allow chaining to work, animateProperty will
			// determine them for us (except in ie6? -- ugh)
			top: top + (args.top || 0),
			left: left + (args.left || 0)
		}
	}, args));
	dojo.connect(_anim, "beforeBegin", _anim, init);
	return _anim; // dojo.Animation
};

dojox.fx.crossFade = function(/* Object */args){
	// summary:
	//		Returns an animation cross fading two element simultaneously
	//
	// args:
	//	args.nodes: Array - two element array of domNodes, or id's
	//
	//	all other standard animation args mixins apply. args.node ignored.
	//

	// simple check for which node is visible, maybe too simple?
	var node1 = args.nodes[0] = dojo.byId(args.nodes[0]),
		op1 = dojo.style(node1,"opacity"),
		node2 = args.nodes[1] = dojo.byId(args.nodes[1]),
		op2 = dojo.style(node2, "opacity")
	;
	
	var _anim = dojo.fx.combine([
		dojo[(op1 == 0 ? "fadeIn" : "fadeOut")](dojo.mixin({
			node: node1
		},args)),
		dojo[(op1 == 0 ? "fadeOut" : "fadeIn")](dojo.mixin({
			node: node2
		},args))
	]);
	return _anim; // dojo.Animation
};

dojox.fx.highlight = function(/*Object*/ args){
	// summary:
	//		Highlight a node
	//
	// description:
	//		Returns an animation that sets the node background to args.color
	//		then gradually fades back the original node background color
	//
	// example:
	//	|	dojox.fx.highlight({ node:"foo" }).play();

	var node = args.node = dojo.byId(args.node);

	args.duration = args.duration || 400;
	
	// Assign default color light yellow
	var startColor = args.color || '#ffff99',
		endColor = dojo.style(node, "backgroundColor")
	;

	// safari "fix"
	// safari reports rgba(0, 0, 0, 0) (black) as transparent color, while
	// other browsers return "transparent", rendered as white by default by
	// dojo.Color; now dojo.Color maps "transparent" to
	// djConfig.transparentColor ([r, g, b]), if present; so we can use
	// the color behind the effect node
	if(endColor == "rgba(0, 0, 0, 0)"){
		endColor = "transparent";
	}

	var anim = dojo.animateProperty(dojo.mixin({
		properties: {
			backgroundColor: { start: startColor, end: endColor }
		}
	}, args));

	if(endColor == "transparent"){
		dojo.connect(anim, "onEnd", anim, function(){
			node.style.backgroundColor = endColor;
		});
	}

	return anim; // dojo.Animation
};

 
dojox.fx.wipeTo = function(/*Object*/ args){
	// summary:
	//		Animate a node wiping to a specific width or height
	//
	// description:
	//		Returns an animation that will expand the
	//		node defined in 'args' object from it's current to
	//		the height or width value given by the args object.
	//
	//		default to height:, so leave height null and specify width:
	//		to wipeTo a width. note: this may be deprecated by a
	//
	//		Note that the final value should not include
	//		units and should be an integer.  Thus a valid args object
	//		would look something like this:
	//
	//		|	dojox.fx.wipeTo({ node: "nodeId", height: 200 }).play();
	//
	//		Node must have no margin/border/padding, so put another
	//		node inside your target node for additional styling.

	args.node = dojo.byId(args.node);
	var node = args.node, s = node.style;

	var dir = (args.width ? "width" : "height"),
		endVal = args[dir],
		props = {}
	;

	props[dir] = {
		// wrapped in functions so we wait till the last second to query (in case value has changed)
		start: function(){
			// start at current [computed] height, but use 1px rather than 0
			// because 0 causes IE to display the whole panel
			s.overflow = "hidden";
			if(s.visibility == "hidden" || s.display == "none"){
				s[dir] = "1px";
				s.display = "";
				s.visibility = "";
				return 1;
			}else{
				var now = dojo.style(node,dir);
				return Math.max(now, 1);
			}
		},
		end: endVal
	};

	var anim = dojo.animateProperty(dojo.mixin({ properties: props }, args));
	return anim; // dojo.Animation
};

}

if(!dojo._hasResource["dojox.fx"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojox.fx"] = true;
dojo.provide("dojox.fx");



}

/*
	Copyright (c) 2004-2011, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/


if(!dojo._hasResource["epages.cartridges.de_epages.presentation.SearchBar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.SearchBar"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.presentation.widget.searchbar

*/


	dojo.provide("epages.cartridges.de_epages.presentation.SearchBar");
	
	
	
	
	

	(function () {

		var replMap = {
			'<': '&lt;',
			'>': '&gt;',
			'"': '&quot;',
			"'": "\&#039;"
		},
			htmlEscape = function (value) {
				return (value + '').replace(/(<|>|"|')/g, function (all, $1) {
					return replMap[$1];
				});
			};

		epages.cartridges.de_epages.presentation.SearchBar = {

			_ELEMENT_DOJOTYPE: " dojoType='epages.widget.FormElement' ", // FormElement widget dojotype attribute
			_SEARCH_INPUT_PREFIX: "searchInput_", // prefix on which all inputs ids are extended on
			_SEARCHBAR_ANI_DURATION: 350, // default animation duration / delay

			_STORAGE_ID: "Presentation::SearchBar.Status", // namespace of this module inside of epages.Storage
			_STORAGE_EXTENDED_KEYWORD: "max", // value for the extended SearchBar stored in epages.Storage
			_STORAGE_MINIMIZED_KEYWORD: "min", // value for the minimized SearchBar stored in epages.Storage

			searchBarContainer: null, // parent node of the SearchBar
			searchBarHTMLArray: [], // collection of html snipplets which is parsed and merged on init

			searchBarId: null, // id of the SearchBar

			searchBarNodes: { // collection of important node references for easy access
				searchBarPlaceHolder: null,
				searchBar: null,

				wildSearch: null,
				wildSearchInput: null,
				wildSearchButton: null,
				extender: null,

				detailedSearch: null,
				detailedSearchPrimary: null,
				detailedSearchSecondary: null,

				searchBarButton: null,
				minimizer: null,

				widthContainer: null
			},

			_searchInputCounter: 0, // length of all inputs inside of a SearchBar
			_searchBarFormAction: "", // merged action of the SearchBar <form>

			_forcedDetailedSearch: false, // is there a wild search on this page?
			_isExtended: false, // is the detailed search form about to be expanded?
			_isExtendedToEnd: false, // is the detailed serach form expanded?
			_allowHardRecalc: true, // is it allowed to update all dimension properties of the SearchBar?

			_detailedSearchBarHeight: 0, // height of the detailed search form in px

			_mainDetailInputNode: null, // main input of the detail search

			_secondaryFieldsHighlightBeacon: null, // timer reference for the opacity animation delay of the secondary search fields

			_getStoredSearchBarStatus: function () {
				var hash = epages.localStorage.getItem(this._STORAGE_ID) || {};
				return hash[this.searchBarId] || null;
			},
			_setStoredSearchBarStatus: function (keyword /* String */ ) {
				var hash = epages.localStorage.getItem(this._STORAGE_ID) || {};
				hash[this.searchBarId] = keyword;

				epages.localStorage.setItem(this._STORAGE_ID, hash);
			},

			createSearchBar: function (searchBarId /* String */ , extendAtStartup /* Boolean */ , action /* Object */ , generalTranslations /* Object */ , fields /* Object */, classes /* Object */  ) {
				// summary:
				//		Creates a new SearchBar instance
				// description:
				//		Calling this method will cause an injection of a new SearchBar node in the page at the point where the script is declared.
				// searchBarId:
				//		A unique ID for the SearchBar.
				// extendAtStartup:
				//		States whether the detailed search or the wild search form is visible on startup.
				// action:
				//		ViewAction and ObjectID for the SearchBar form.
				// generalTranslations:
				//		Collection of page specific translation string for the SearchBar.
				// fields:
				//		Collection of input fields.
				// example:
				//	// Have a look at "MBO*.Toolbar.html"

				// no need to proceed if there is no id given
				if (!searchBarId) {
					return;
				}

				this.searchBarId = searchBarId;

				this.unity = (djConfig.unity !== undefined && djConfig.unity === true) ? true : false;
				if (djConfig.unity === undefined) {
					this.unity = fields.unity ? fields.unity : false;
				}

				if (!fields.primary.length) {
					// no primary fields > no detailed search
					this._forcedDetailedSearch = extendAtStartup = this._isExtendedToEnd = false;
				}

				this._isExtended = this._forcedDetailedSearch = extendAtStartup;

				// merge the form action
				this._searchBarFormAction = "?ViewAction=" + action.viewAction + "&ObjectID=" + action.objectId;

				// inject the container nodes
				var posElem = !!$('RightSidebar') === false ? document.querySelector('#SearchBarContainer') : $('RightSidebar'),
					container = dojo.create('div', {
						'class': 'SearchBarRoot ' + ((classes && classes.form) ? classes.form : "")
					}, posElem, 'before');

				var searchBarNode = dojo.create(
					'div', {
						'id': 'SearchBar',
						'class': 'SearchBar HideElementSoft'
					},
					container,
					'last');

				this.searchBarContainer = searchBarNode;

				// convert the object to a html collection
				var formString = "<form action='" + this._searchBarFormAction + "' method='post' id='WildSearch' class='WildSearch'>";
				if(!this.unity) {
					formString += "<div><div id='Extender' class='" + (fields.primary.length ? "" : "HideElementSoft ") + "fa fa-chevron-up Extender EnableHover' title='" + generalTranslations.extendButtonTitle + "'></div>";
				}
				// "<label unselectable='unselectable' for='WildSearchInput'>" + generalTranslations.wildSearchLabel+ "</label>";

				if (generalTranslations.wildSearchString) {
					generalTranslations.wildSearchString = htmlEscape(generalTranslations.wildSearchString);
				}

				if (generalTranslations.wildSearchLabel == undefined) {
					generalTranslations.wildSearchLabel = '';
				}

				if (generalTranslations.wildSearchCustomInput) {
					var inp = generalTranslations.wildSearchCustomInput;
					if(this.unity) {
						formString += "<input placeholder='" + generalTranslations.wildSearchLabel + "' value='" + (generalTranslations.wildSearchString || "") + "' name='WildSearchString' class='ep-ui-smartsearch ep-js ep-searchbar-wildsearchinput' data-js='.uiInput()'' />";
					} else {
						formString += "<input placeholder='" + generalTranslations.wildSearchLabel + "' value='" + (generalTranslations.wildSearchString || "") + "' name='WildSearchString' class='ep-ui-smartsearch ep-js' data-js='.uiInput()'' />";
					}
				} else {
					if(this.unity) {
						formString += "<input placeholder='" + generalTranslations.wildSearchLabel + "' value='" + (generalTranslations.wildSearchString || "") + "' type='text' name='WildSearchString' id='WildSearchInput' class='WildSearchInput ep-searchbar-wildsearchinput'/>";
					} else {
						formString += "<input placeholder='" + generalTranslations.wildSearchLabel + "' value='" + (generalTranslations.wildSearchString || "") + "' " + this._ELEMENT_DOJOTYPE + " type='text' name='WildSearchString' id='WildSearchInput' class='WildSearchInput'/>";
					}
				}

				if (this.unity) {
					formString += "<button id='WildSearchButton' class='ep-button ep-button-fake fa fa-search fa-lg SearchBarMiniButton CursorPointer' title='" + generalTranslations.searchButtonTitle + "'></button>";
				} else {
					formString += "<span id='WildSearchButton' class='fa fa-search fa-lg SearchBarMiniButton CursorPointer' title='" + generalTranslations.searchButtonTitle + "'></span>";
				}

				formString += "<input type='submit' class='HideElementSoft'/>";

				this.searchBarHTMLArray.push(formString);
				for (var i = 0, iLength = fields.hidden.length; i < iLength; i++) {
					this.searchBarHTMLArray.push("<input type='hidden' name='" + fields.hidden[i].name + "' value='" + fields.hidden[i].value + "'/>");
				}

				if (this.unity) {
					this.searchBarHTMLArray.push(
						"<button id='Extender'  onclick='return false;' class='" + (fields.primary.length ? "" : "HideElementSoft ") + "ep-button ep-button-searchbar-toggle Extender' title='" + generalTranslations.extendButtonTitle + "'>" + generalTranslations.extendButtonTitle + " <i class='fa fa-chevron-down'></i></button>" +
						"<button id='Minimizer'  onclick='return false;' class='" + (fields.primary.length ? "" : "HideElementSoft ") + "ep-button ep-button-searchbar-toggle Extender HideElementSoft' title='" + generalTranslations.extendButtonTitle + "'>" + generalTranslations.extendButtonTitle + " <i class='fa fa-chevron-up'></i></button>" +
						"</form>");
				} else {
					this.searchBarHTMLArray.push("</div></form>");
				}

				this.searchBarHTMLArray.push("<form action='" + this._searchBarFormAction + "' method='post' id='DetailedSearch' class='DetailedSearch" + " HideElementSoft" + "'><div>");

				for (var i = 0, iLength = fields.hidden.length; i < iLength; i++) {
					this.searchBarHTMLArray.push("<input type='hidden' name='" + fields.hidden[i].name + "' value='" + fields.hidden[i].value + "'/>");
				}

				this.searchBarHTMLArray.push("<div id='DetailedSearchPrimary' class='Primary'>");
				this._buildFormElements(fields.primary);

				this.searchBarHTMLArray.push("</div><div id='DetailedSearchSecondary' class='Secondary'>");

				if (fields.secondary && fields.secondary.length) {
					this._buildFormElements(fields.secondary);
				}

				if (this.unity) {
					this.searchBarHTMLArray.push("</div><div id='DetailedSearchTertiary' class='Tertiary'>");

					if (fields.tertiary && fields.tertiary.length) {
						this._buildFormElements(fields.tertiary);
					}
				}

				this.searchBarHTMLArray.push("</div>" + ((this.unity) ? "" : ("<div id='Minimizer' class='Minimizer EnableHover' title='" + generalTranslations.minimizeButtonTitle + "'></div>")));
				this.searchBarHTMLArray.push("<div class='SearchBarButtonContainer'><div><input dojoType='epages.widget.Button' type='submit' id='SearchBarButton' class='SearchBarButton Button' value='" + generalTranslations.searchButtonTitle + "' iconSrc='dialog_ico_s_loupe'/></div><div class='RoundCornerPatch'></div></div></form>");

				this._initSearchBar();
			},

			_getFieldCount: function (fieldArray) {
				var fieldArrayFiltered = [];
				var isGroupOpened = false;
				for (var i = 0, iLength = fieldArray.length; i < iLength; i++) {
					if (isGroupOpened) {
						if (fieldArray[i].type == "endgroup") {
							isGroupOpened = false;
						}
					} else {
						if (fieldArray[i].type == "startgroup") {
							isGroupOpened = true;
						}
						fieldArrayFiltered.push(fieldArray[i]);
						fieldArrayFiltered.push(fieldArray[i]);
					}
				}
				return fieldArrayFiltered;
			},

			_buildFormElements: function (elementArray) {
				// traverse the element array and build up the specific html code for every entry
				for (var i = 0, iLength = elementArray.length; i < iLength; i++) {
					if (elementArray[i].defaultValue) {
						elementArray[i].defaultValue = htmlEscape(elementArray[i].defaultValue);
					}

					switch (elementArray[i].type) {
					case "select":
						this._formElements.getSelect(elementArray[i], this._getInputId(), this);
						break;
					case "checkbox":
						this._formElements.getCheckbox(elementArray[i], this._getInputId(), this);
						break;
					case "date":
						this._formElements.getDateInput(elementArray[i], this._getInputId(), this);
						break;
					case "datetime":
						this._formElements.getDateTimeInput(elementArray[i], this._getInputId(), this);
						break;
					case "multioptions":
						this._formElements.getMultiOptionsInput(elementArray[i], this._getInputId(), this);
						break;
					case "startgroup":
						this._formElements.getGroupStart(elementArray[i], this);
						break;
					case "endgroup":
						this._formElements.getGroupEnd(this);
						break;
					case "custom":
						this._formElements.getCustom(elementArray[i], this);
						break;
					default:
						this._formElements.getInput(elementArray[i], this._getInputId(), this);
						break;
					}
				}
			},

			_formElements: {
				// collection of all available input types inside of a SearchBar (called via "_buildFormElements")
				_getLabel: function (label, id, adjacentText) {
					return "<label unselectable='unselectable' for='" + id + "'>" + label + this._getAdjacentText(adjacentText) + "</label>";
				},
				_getAdjacentText: function (text) {
					return (text ? " " + text + "" : "");
				},
				getSelect: function (arrayEntry, id, scope) {
					scope.searchBarHTMLArray.push("<span class='EnableHover SearchGroup SelectGroup " + (arrayEntry.cssClass || "") + "'>" + this._getLabel(arrayEntry.label, id, arrayEntry.adjacentText) +
						"<select " + scope._ELEMENT_DOJOTYPE + " id='" + id + "' name='" + arrayEntry.name + "'>");
					for (var i = 0, iLength = arrayEntry.options.length; i < iLength; i++) {
						scope.searchBarHTMLArray.push("<option value='" + arrayEntry.options[i].value + "' " + (arrayEntry.options[i].selected ? "selected='selected'" : "") + ">" + arrayEntry.options[i].label + "</option>");
					}
					scope.searchBarHTMLArray.push("</select></span>");
				},
				getCheckbox: function (arrayEntry, id, scope) {
					scope.searchBarHTMLArray.push("<span class='EnableHover SearchGroup CheckboxGroup " + (arrayEntry.cssClass || "") + "'>" + this._getLabel(arrayEntry.label, id, arrayEntry.adjacentText) +
						"<input value='" + arrayEntry.defaultValue + "' id='" + id + "' " + scope._ELEMENT_DOJOTYPE + " type='text' class='Checkbox' name='" + arrayEntry.name + "' " + (arrayEntry.checked ? "checked='checked'" : "") + "/>" +
						"</span>");
				},
				getDateInput: function (arrayEntry, id, scope) {
					scope.searchBarHTMLArray.push("<span class='EnableHover SearchGroup DateGroup " + (arrayEntry.cssClass || "") + "'>" + this._getLabel(arrayEntry.label, id, arrayEntry.adjacentText) +
						"<input onchange='epages.cartridges.de_epages.presentation.SearchBar._checkErrorState()' empty='true' selector='date' class='SearchDate ep-date-input' id='" + id + "' type='text' name='" + arrayEntry.name + "' value='" + (arrayEntry.defaultValue || "") + "'/></span>");
				},
				getDateTimeInput: function (arrayEntry, id, scope) {
					scope.searchBarHTMLArray.push("<span class='EnableHover SearchGroup DateTimeGroup " + (arrayEntry.cssClass || "") + "'>" + this._getLabel(arrayEntry.label, id, arrayEntry.adjacentText) +
						"<input onchange='epages.cartridges.de_epages.presentation.SearchBar._checkErrorState()' selector='datetime' class='SearchDate ep-date-time-input' id='" + id + "' type='text' empty='true' name='" + arrayEntry.name + "' value='" + (arrayEntry.defaultValue || "") + "'/></span>");
				},
				getMultiOptionsInput: function (arrayEntry, id, scope) {
					scope.searchBarHTMLArray.push("<span class='EnableHover SearchGroup SelectGroup MultiOptionsGroup " + (arrayEntry.cssClass || "") + "'>" + this._getLabel(arrayEntry.label, id, arrayEntry.adjacentText));

					var optionCollection = [];
					var preSelectedValueCollection = [];
					for (var i = 0, iLength = arrayEntry.options.length; i < iLength; i++) {
						optionCollection.push("<option ep_name='" + arrayEntry.options[i].name + "'>" + arrayEntry.options[i].label + "</option>");
						if (arrayEntry.options[i].defaultValue) {
							preSelectedValueCollection.push(scope._getMultipleOptionsPreSelected(arrayEntry.options[i].name, arrayEntry.options[i].label, arrayEntry.translations[3], arrayEntry.translations[0], arrayEntry.translations[1], (arrayEntry.options[i].defaultValue == 2 ? true : false)));
						}
					}

					scope.searchBarHTMLArray.push("<span class='MultiOptionsGroupSelectContainer'><span class='SelectedEntries'>" + preSelectedValueCollection.join("") + "</span>" +
						"<select onchange='epages.cartridges.de_epages.presentation.SearchBar._addMultipleOptionsOption(this)' " + scope._ELEMENT_DOJOTYPE + " id='" + id + "' ep_nottranslation='" + arrayEntry.translations[3] + "' ep_removetranslation='" + arrayEntry.translations[4] + "'>");

					scope.searchBarHTMLArray = scope.searchBarHTMLArray.concat(optionCollection);

					var insertHiddenStyle = (scope.searchBarId.match(/SearchOrders/)) ? " style=\"display:none;\"" : "";
					scope.searchBarHTMLArray.push("</select><span class='DetailSelector LeftPadding'" + insertHiddenStyle + ">" +
						"<input id='radio_" + id + "_true' name='radio_" + id + "_true' type='text' disabled='disabled' class='Disabled Checked Radio' checked='checked'/><label class='RightPadding' for='radio_" + id + "_true'>" + arrayEntry.translations[0] + "</label>" +
						"<input id='radio_" + id + "_false' name='radio_" + id + "_false' type='text' disabled='disabled' class='Disabled Radio' /><label for='radio_" + id + "_false'>" + arrayEntry.translations[1] + "</label>" +
						"</span></span></span>");
				},
				getInput: function (arrayEntry, id, scope) {
					scope.searchBarHTMLArray.push("<span class='EnableHover SearchGroup InputGroup " + (arrayEntry.cssClass || "") + "'>" + this._getLabel(arrayEntry.label, id, arrayEntry.adjacentText) +
						"<input " + scope._ELEMENT_DOJOTYPE + " id='" + id + "' type='text' name='" + arrayEntry.name + "' value='" + (arrayEntry.defaultValue || "") + "'/></span>");
				},
				getGroupStart: function (arrayEntry, scope) {
					scope.searchBarHTMLArray.push("<span class='EnableHover Group " + (arrayEntry.cssClass || "") + "'>");
				},
				getGroupEnd: function (scope) {
					scope.searchBarHTMLArray.push("</span>");
				},
				getCustom: function (arrayEntry, scope) {
					scope.searchBarHTMLArray.push(arrayEntry.html);
				}
			},

			_getMultipleOptionsPreSelected: function (inputName, selectValue, removeTranslation, yesTranslation, noTranslation, selectReverse) {
				if ($(inputName + "_true")) {
					return "";
				}
				return "<span class='SelectedEntry'>" +
					"<span class='SelectedEntryLabel'>" + selectValue + "</span>" +
					"<input id='" + inputName + "_true' value='1' name='" + inputName + "' type='text' class='Radio' dojoType='epages.widget.FormElement' " + (selectReverse ? "" : "checked='checked'") + "/><label class='RightPadding' for='" + inputName + "_true'>" + yesTranslation + "</label>" +
					"<input id='" + inputName + "_false' value='2' name='" + inputName + "' type='text' class='Radio' dojoType='epages.widget.FormElement' " + (selectReverse ? "checked='checked'" : "") + "/><label for='" + inputName + "_false'>" + noTranslation + "</label>" +
					"<i title='" + removeTranslation + "' class='RemoveButton " + ((this.unity) ? "fa fa-remove" : "Sprite ico_s_remove") + "' onclick='epages.cartridges.de_epages.presentation.SearchBar._removeMultipleOptionsSelector(this)'></i>" +
					"</span>";
			},

			_addMultipleOptionsOption: function (selectNode) {

				if (selectNode.selectedIndex === 0) {
					return;
				}

				var selectContainer = selectNode.parentNode.parentNode;
				selectContainer = epages.Browser.engine == "MSIE" ? selectContainer.parentNode : selectContainer;

				var entriesContainer = dojo.query(".SelectedEntries", selectContainer)[0];
				var selectLabels = dojo.query("label", selectContainer);
				var inputName = selectNode.options[selectNode.selectedIndex].getAttribute("ep_name");

				var removeTranslation = selectNode.getAttribute("ep_removetranslation");
				var selectValue = selectNode.value || selectNode.options[selectNode.selectedIndex].innerHTML;

				var labelsLength = selectLabels.length;

				var newSelectedEntryHTML = this._getMultipleOptionsPreSelected(inputName, selectValue, removeTranslation, selectLabels[labelsLength - 2].innerHTML, selectLabels[labelsLength - 1].innerHTML, false);
				var tempContainer = document.createElement("div");

				if (newSelectedEntryHTML.length > 2) {
					tempContainer.innerHTML = newSelectedEntryHTML;
					entriesContainer.appendChild(tempContainer.firstChild);
					dojo.parser.parse(entriesContainer.lastChild);
				}

				selectNode.selectedIndex = 0;
				this._hardRecalcSearchBarHeight();
			},

			_removeMultipleOptionsSelector: function (iconNode) {
				var entry = iconNode.parentNode;
				var entriesContainer = entry.parentNode;

				dojo.query("input.Radio", entry).forEach(function (radioWidget) {
					$$(radioWidget.id).destroy();
				});

				entriesContainer.removeChild(entry);

				this._hardRecalcSearchBarHeight();
			},

			_getInputId: function () {
				// returns the ID for a new SearchBar element
				this._searchInputCounter++;
				return this._SEARCH_INPUT_PREFIX + this._searchInputCounter;
			},

			_injectSearchBarCode: function () {
				// merge the html snipplets
				//this.searchBarContainer.innerHTML = this.searchBarHTMLArray.join("");

				// parse the merged html
				//dojo.parser.parse(this.searchBarContainer);

				// workaround parseOnLoad <> dojo.parser conflict
				var temp = document.createElement('div');
				var self = this;
				temp.innerHTML = self.searchBarHTMLArray.join("");

				dojo.parser.parse(temp);
				dojo.query('*[dojoType]', temp).forEach(function (node, i) {
					dojo.removeAttr(node, 'dojoType');
				});
				self.searchBarContainer.appendChild(temp);


				// link the node references
				self.searchBarNodes.searchBarPlaceHolder = $("SearchBarPlaceHolder");
				self.searchBarNodes.searchBar = $("SearchBar");

				self.searchBarNodes.wildSearch = $("WildSearch");
				self.searchBarNodes.wildSearchInput = $("WildSearchInput");
				self.searchBarNodes.wildSearchString = dojo.query('[name=WildSearchString]')[0];
				self.searchBarNodes.wildSearchButton = $("WildSearchButton");
				self.searchBarNodes.extender = $("Extender");

				self.searchBarNodes.detailedSearch = $("DetailedSearch");
				self.searchBarNodes.detailedSearchPrimary = $("DetailedSearchPrimary");
				self.searchBarNodes.detailedSearchSecondary = $("DetailedSearchSecondary");

				self.searchBarNodes.searchBarButton = $("SearchBarButton");
				self.searchBarNodes.minimizer = $("Minimizer");

				self.searchBarNodes.widthContainer = $("DetailedSearchWidthContainer") || document.createElement("div");

				// is there an equivalent wild search input element inside of the detail search mask?
				self._mainDetailInputNode = dojo.query(".MainDetailInputNode input", self.searchBarNodes.detailedSearchPrimary)[0];

				require([
				    "jquery",

				    "ep/ui/datepicker",
				    "$ready!"
				], function ($) {
				    var searchbar = $('#SearchBar');
				    var dateInputs = searchbar.find('.ep-date-input');
				    var dateTimeInputs = searchbar.find('.ep-date-time-input');

						if (dateInputs.length) {
							dateInputs.uiDatepicker({
								'type': 'date',
								'format': 'd',
								'time': false,
								'bubble': true,
								'unity': self.unity
							});
						}

						if (dateTimeInputs.length) {
							dateTimeInputs.uiDatepicker({
								'type': 'date',
								'format': 'l',
								'time': true,
								'bubble': true,
								'unity': self.unity
							});
						}

				});
			},

			_appendSearchBarEvents: function () {
				dojo.connect(this.searchBarNodes.wildSearchButton, "click", this, "_searchBarMiniButtonClick");
				dojo.connect(this.searchBarNodes.extender, "click", this, "_extenderClick");

				dojo.connect(this.searchBarNodes.searchBarButton, "click", this, "_searchBarButtonClick");
				dojo.connect(this.searchBarNodes.searchBar, "keyup", this, "_checkErrorState");
				dojo.connect(this.searchBarNodes.minimizer, "click", this, "_minimizerClick");
			},

			showSearchBar: function (soft /* Boolean */ ) {
				var duration = this.unity ? 0 : 350;  // animation duration: 0ms for unity, default (350ms) for core

				this.searchBarNodes.detailedSearch.style.height = '0';
				dojo.removeClass(this.searchBarNodes.detailedSearch, 'HideElementSoft');

				if (!this.unity) {
					dojo.addClass(this.searchBarNodes.wildSearch, 'HideElementSoft');
				} else {

					if (this.searchBarNodes.wildSearchInput === null) {
						dojo.addClass(this.searchBarNodes.wildSearchString, 'HideElementSoft');
					} else {
						dojo.addClass(this.searchBarNodes.wildSearchInput, 'HideElementSoft');
					}

					dojo.addClass(this.searchBarNodes.extender, 'HideElementSoft');
					dojo.addClass(this.searchBarNodes.wildSearchButton, 'HideElementSoft');
					dojo.removeClass(this.searchBarNodes.minimizer, 'HideElementSoft');

				}

				dojo.fx.wipeIn({
					node: this.searchBarNodes.detailedSearch,
					duration: duration
				}).play();
				this._setStoredSearchBarStatus(this._STORAGE_EXTENDED_KEYWORD);
				this._isExtended = true;
				if (this._mainDetailInputNode) {
					this._mainDetailInputNode.focus();
					this._mainDetailInputNode.select();
				}
			},

			hideSearchBar: function ( /* Boolean */ soft) {
				var duration = this.unity ? 0 : 350;  // animation duration: 0ms for unity, default (350ms) for core

				require([
					"jquery"
				], function ($) {
					var searchbar = $('#SearchBar'),
						dateInputs,
						dateTimeInputs;

					if (searchbar) {
						dateInputs = searchbar.find('.ep-date-input');
						dateTimeInputs = searchbar.find('.ep-date-time-input');

						for (i=0; i<dateInputs.length; i++) {
							if (dateInputs.eq(i).data('uiUiDatepicker') && dateInputs.eq(i).uiDatepicker('isOpen')) {
								dateInputs.eq(i).uiDatepicker('hide');
							}
						}

						for (i=0; i<dateTimeInputs.length; i++) {
							if (dateTimeInputs.eq(i).data('uiUiDatepicker') && dateTimeInputs.eq(i).uiDatepicker('isOpen')) {
								dateTimeInputs.eq(0).uiDatepicker('hide');
							}
						}
					}
				});

				dojo.fx.wipeOut({
					node: this.searchBarNodes.detailedSearch,
					duration: duration,
					onEnd: dojo.hitch(this, function () {

						if (!this.unity) {
							dojo.removeClass(this.searchBarNodes.wildSearch, 'HideElementSoft');
						} else {

							if (this.searchBarNodes.wildSearchInput === null) {
								dojo.removeClass(this.searchBarNodes.wildSearchString, 'HideElementSoft');
							} else {
								dojo.removeClass(this.searchBarNodes.wildSearchInput, 'HideElementSoft');
							}

							dojo.removeClass(this.searchBarNodes.extender, 'HideElementSoft');
							dojo.removeClass(this.searchBarNodes.wildSearchButton, 'HideElementSoft');
							dojo.addClass(this.searchBarNodes.minimizer, 'HideElementSoft');
						}
					})
				}).play();
				this._setStoredSearchBarStatus(this._STORAGE_MINIMIZED_KEYWORD);
				this._isExtended = false;
			},

			_minimizerClick: function (evt) {
				this.hideSearchBar(true);
			},

			_extenderClick: function (evt) {
				this.showSearchBar(true);
			},

			_searchBarButtonClick: function (evt) {
				this.submitForm(this.searchBarNodes.detailedSearch);
			},

			_checkErrorState: function () {
				var searchBarButtonWidget = $$(this.searchBarNodes.searchBarButton.id);
				if (dojo.query("input.DialogError", this.searchBarNodes.detailedSearch).length) {
					searchBarButtonWidget.disable();
				} else {
					searchBarButtonWidget.enable();
					dojo.removeClass(this.searchBarNodes.searchBarButton.parentNode, "Active");
				}
			},

			_searchBarMiniButtonClick: function (evt) {
				this.submitForm(this.searchBarNodes.wildSearch);
			},

			submitForm: function (formNode) {
				if (!dojo.query("input.DialogError", formNode).length) {
					formNode.submit();
				}
			},

			_hardRecalcSearchBarHeight: function () {
				this._detailedSearchBarHeight = this.searchBarNodes.detailedSearch.offsetHeight - 10;
				setTimeout(dojo.hitch(this, function () {
					this._detailedSearchBarHeight = this.searchBarNodes.detailedSearch.offsetHeight - 10;
					if (this._isExtended) {
						if (!(epages.Browser.engine == "MSIE" && (epages.Browser.version == "7" || epages.Browser.version == "8"))) {
							//this.searchBarNodes.searchBarPlaceHolder.style.height = "auto";
						}
						//this.searchBarNodes.searchBarPlaceHolder.style.height = this._detailedSearchBarHeight + "px";
					}
				}), 1);
			},

			_hardRecalcDimensions: function () {
				if (!this._allowHardRecalc) {
					return;
				}
				var limitNode = this.searchBarNodes.detailedSearchSecondary.parentNode;
				//this.searchBarNodes.searchBar.style.visibility = "hidden";
				//limitNode.style.width = "auto";
				limitNode.style.filter = "alpha()";
				this.searchBarNodes.widthContainer.style.display = "inline";
				setTimeout(dojo.hitch(this, function () {
					var hiddenClassSet = dojo.hasClass(this.searchBarNodes.detailedSearch, "HideElementSoft");
					dojo.removeClass(this.searchBarNodes.detailedSearch, "HideElementSoft");

					//limitNode.style.width = (epages.Browser.engine == "MSIE" ? this.searchBarNodes.detailedSearchSecondary : this.searchBarNodes.widthContainer).offsetWidth + "px";
					this.searchBarNodes.widthContainer.style.display = "block";
					if (hiddenClassSet) {
						dojo.addClass(this.searchBarNodes.detailedSearch, "HideElementSoft");
					}
					limitNode.style.filter = "none";
					this.searchBarNodes.searchBar.style.visibility = "visible";
				}), 1);
				this._hardRecalcSearchBarHeight();
			},

			_initSearchBar: function () {
				this._injectSearchBarCode();
				this._appendSearchBarEvents();

				if (!this._forcedDetailedSearch) {
					var searchBarStatus = this._getStoredSearchBarStatus();
					if (searchBarStatus == this._STORAGE_EXTENDED_KEYWORD) {
						this.showSearchBar(false);
					} else {
						this.hideSearchBar(false);
					}
				}
				this.searchBarNodes.searchBar.style.visibility = "hidden";
				dojo.removeClass(this.searchBarContainer, "HideElementSoft");
				if ($$('RightSidebar')) {
					this._checkWildSearchBarPadding({
						width: $$('RightSidebar').isVisible
					});
				}
				this._hardRecalcDimensions();

				setTimeout(dojo.hitch(this, function () {

					this._hardRecalcDimensions();
					if (!this._isExtended) {
						this._allowHardRecalc = false;
					}

					dojo.connect(window, "resize", this, "_hardRecalcDimensions");

					// only IE fires the resize event when the sidebar status changed
					if (epages.Browser.engine != "MSIE") {
						var sideBarController = $("Sidebarcontroller");
						if (sideBarController) {
							dojo.addOnLoad(dojo.hitch(this, function () {

								dojo.subscribe(dojo.query("[id*=Sidebar]", sideBarController)[0].id + "/afterShowSidebar", dojo.hitch(this, function () {
									setTimeout(dojo.hitch(this, function () {
										this._hardRecalcDimensions();
									}), 1);
								}));

							}));
						}
					}

					// sometimes it is necessary to update the dimension styles after all surrounding elements are rendered
					setTimeout(dojo.hitch(this, function () {
						var temp_allowHardRecalc = this._allowHardRecalc;
						this._allowHardRecalc = true;
						this._hardRecalcDimensions();
						this._allowHardRecalc = temp_allowHardRecalc;

						this._checkErrorState();
						if (this._isExtended) {
							this.showSearchBar();
						}
						dojo.publish("SearchBar/ready", [this.searchBarNodes.searchBar]);
					}), 1);

				}), 10);

				dojo.subscribe('RightSidebar/afterShowSidebar', this, '_checkWildSearchBarPadding');
				dojo.subscribe('RightSidebar/afterHideSidebar', this, '_checkWildSearchBarPadding');

			},

			_checkWildSearchBarPadding: function (options) {
				if (options.width) {
					this.searchBarNodes.wildSearch.style.marginRight = '230px';
				} else {
					this.searchBarNodes.wildSearch.style.marginRight = '10px';
				}

			}

		};

	})();

}

if(!dojo._hasResource["dojo.html"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.html"] = true;
dojo.provide("dojo.html");


dojo.getObject("html", true, dojo);

// the parser might be needed..
(function(){ // private scope, sort of a namespace

	// idCounter is incremented with each instantiation to allow asignment of a unique id for tracking, logging purposes
	var idCounter = 0,
		d = dojo;
	
	dojo.html._secureForInnerHtml = function(/*String*/ cont){
		// summary:
		//		removes !DOCTYPE and title elements from the html string.
		//
		//		khtml is picky about dom faults, you can't attach a style or <title> node as child of body
		//		must go into head, so we need to cut out those tags
		//	cont:
		//		An html string for insertion into the dom
		//
		return cont.replace(/(?:\s*<!DOCTYPE\s[^>]+>|<title[^>]*>[\s\S]*?<\/title>)/ig, ""); // String
	};

/*====
	dojo.html._emptyNode = function(node){
		// summary:
		//		removes all child nodes from the given node
		//	node: DOMNode
		//		the parent element
	};
=====*/
	dojo.html._emptyNode = dojo.empty;

	dojo.html._setNodeContent = function(/* DomNode */ node, /* String|DomNode|NodeList */ cont){
		// summary:
		//		inserts the given content into the given node
		//	node:
		//		the parent element
		//	content:
		//		the content to be set on the parent element.
		//		This can be an html string, a node reference or a NodeList, dojo.NodeList, Array or other enumerable list of nodes
		
		// always empty
		d.empty(node);

		if(cont) {
			if(typeof cont == "string") {
				cont = d._toDom(cont, node.ownerDocument);
			}
			if(!cont.nodeType && d.isArrayLike(cont)) {
				// handle as enumerable, but it may shrink as we enumerate it
				for(var startlen=cont.length, i=0; i<cont.length; i=startlen==cont.length ? i+1 : 0) {
					d.place( cont[i], node, "last");
				}
			} else {
				// pass nodes, documentFragments and unknowns through to dojo.place
				d.place(cont, node, "last");
			}
		}

		// return DomNode
		return node;
	};

	// we wrap up the content-setting operation in a object
	dojo.declare("dojo.html._ContentSetter", null,
		{
			// node: DomNode|String
			//		An node which will be the parent element that we set content into
			node: "",

			// content: String|DomNode|DomNode[]
			//		The content to be placed in the node. Can be an HTML string, a node reference, or a enumerable list of nodes
			content: "",
			
			// id: String?
			//		Usually only used internally, and auto-generated with each instance
			id: "",

			// cleanContent: Boolean
			//		Should the content be treated as a full html document,
			//		and the real content stripped of <html>, <body> wrapper before injection
			cleanContent: false,
			
			// extractContent: Boolean
			//		Should the content be treated as a full html document, and the real content stripped of <html>, <body> wrapper before injection
			extractContent: false,

			// parseContent: Boolean
			//		Should the node by passed to the parser after the new content is set
			parseContent: false,

			// parserScope: String
			//		Flag passed to parser.  Root for attribute names to search for.   If scopeName is dojo,
			//		will search for data-dojo-type (or dojoType).  For backwards compatibility
			//		reasons defaults to dojo._scopeName (which is "dojo" except when
			//		multi-version support is used, when it will be something like dojo16, dojo20, etc.)
			parserScope: dojo._scopeName,

			// startup: Boolean
			//		Start the child widgets after parsing them.   Only obeyed if parseContent is true.
			startup: true,
			
			// lifecyle methods
			constructor: function(/* Object */params, /* String|DomNode */node){
				//	summary:
				//		Provides a configurable, extensible object to wrap the setting on content on a node
				//		call the set() method to actually set the content..
 
				// the original params are mixed directly into the instance "this"
				dojo.mixin(this, params || {});

				// give precedence to params.node vs. the node argument
				// and ensure its a node, not an id string
				node = this.node = dojo.byId( this.node || node );
	
				if(!this.id){
					this.id = [
						"Setter",
						(node) ? node.id || node.tagName : "",
						idCounter++
					].join("_");
				}
			},
			set: function(/* String|DomNode|NodeList? */ cont, /* Object? */ params){
				// summary:
				//		front-end to the set-content sequence
				//	cont:
				//		An html string, node or enumerable list of nodes for insertion into the dom
				//		If not provided, the object's content property will be used
				if(undefined !== cont){
					this.content = cont;
				}
				// in the re-use scenario, set needs to be able to mixin new configuration
				if(params){
					this._mixin(params);
				}

				this.onBegin();
				this.setContent();
				this.onEnd();

				return this.node;
			},
			setContent: function(){
				// summary:
				//		sets the content on the node

				var node = this.node;
				if(!node) {
				    // can't proceed
					throw new Error(this.declaredClass + ": setContent given no node");
				}
				try{
					node = dojo.html._setNodeContent(node, this.content);
				}catch(e){
					// check if a domfault occurs when we are appending this.errorMessage
					// like for instance if domNode is a UL and we try append a DIV
	
					// FIXME: need to allow the user to provide a content error message string
					var errMess = this.onContentError(e);
					try{
						node.innerHTML = errMess;
					}catch(e){
						console.error('Fatal ' + this.declaredClass + '.setContent could not change content due to '+e.message, e);
					}
				}
				// always put back the node for the next method
				this.node = node; // DomNode
			},
			
			empty: function() {
				// summary
				//	cleanly empty out existing content

				// destroy any widgets from a previous run
				// NOTE: if you dont want this you'll need to empty
				// the parseResults array property yourself to avoid bad things happenning
				if(this.parseResults && this.parseResults.length) {
					dojo.forEach(this.parseResults, function(w) {
						if(w.destroy){
							w.destroy();
						}
					});
					delete this.parseResults;
				}
				// this is fast, but if you know its already empty or safe, you could
				// override empty to skip this step
				dojo.html._emptyNode(this.node);
			},
	
			onBegin: function(){
				// summary
				//		Called after instantiation, but before set();
				//		It allows modification of any of the object properties
				//		- including the node and content provided - before the set operation actually takes place
				//		This default implementation checks for cleanContent and extractContent flags to
				//		optionally pre-process html string content
				var cont = this.content;
	
				if(dojo.isString(cont)){
					if(this.cleanContent){
						cont = dojo.html._secureForInnerHtml(cont);
					}
  
					if(this.extractContent){
						var match = cont.match(/<body[^>]*>\s*([\s\S]+)\s*<\/body>/im);
						if(match){ cont = match[1]; }
					}
				}

				// clean out the node and any cruft associated with it - like widgets
				this.empty();
				
				this.content = cont;
				return this.node; /* DomNode */
			},
	
			onEnd: function(){
				// summary
				//		Called after set(), when the new content has been pushed into the node
				//		It provides an opportunity for post-processing before handing back the node to the caller
				//		This default implementation checks a parseContent flag to optionally run the dojo parser over the new content
				if(this.parseContent){
					// populates this.parseResults if you need those..
					this._parse();
				}
				return this.node; /* DomNode */
			},
	
			tearDown: function(){
				// summary
				//		manually reset the Setter instance if its being re-used for example for another set()
				// description
				//		tearDown() is not called automatically.
				//		In normal use, the Setter instance properties are simply allowed to fall out of scope
				//		but the tearDown method can be called to explicitly reset this instance.
				delete this.parseResults;
				delete this.node;
				delete this.content;
			},
  
			onContentError: function(err){
				return "Error occured setting content: " + err;
			},
			
			_mixin: function(params){
				// mix properties/methods into the instance
				// TODO: the intention with tearDown is to put the Setter's state
				// back to that of the original constructor (vs. deleting/resetting everything regardless of ctor params)
				// so we could do something here to move the original properties aside for later restoration
				var empty = {}, key;
				for(key in params){
					if(key in empty){ continue; }
					// TODO: here's our opportunity to mask the properties we dont consider configurable/overridable
					// .. but history shows we'll almost always guess wrong
					this[key] = params[key];
				}
			},
			_parse: function(){
				// summary:
				//		runs the dojo parser over the node contents, storing any results in this.parseResults
				//		Any errors resulting from parsing are passed to _onError for handling

				var rootNode = this.node;
				try{
					// store the results (widgets, whatever) for potential retrieval
					var inherited = {};
					dojo.forEach(["dir", "lang", "textDir"], function(name){
						if(this[name]){
							inherited[name] = this[name];
						}
					}, this);
					this.parseResults = dojo.parser.parse({
						rootNode: rootNode,
						noStart: !this.startup,
						inherited: inherited,
						scope: this.parserScope
					});
				}catch(e){
					this._onError('Content', e, "Error parsing in _ContentSetter#"+this.id);
				}
			},
  
			_onError: function(type, err, consoleText){
				// summary:
				//		shows user the string that is returned by on[type]Error
				//		overide/implement on[type]Error and return your own string to customize
				var errText = this['on' + type + 'Error'].call(this, err);
				if(consoleText){
					console.error(consoleText, err);
				}else if(errText){ // a empty string won't change current content
					dojo.html._setNodeContent(this.node, errText, true);
				}
			}
	}); // end dojo.declare()

	dojo.html.set = function(/* DomNode */ node, /* String|DomNode|NodeList */ cont, /* Object? */ params){
			// summary:
			//		inserts (replaces) the given content into the given node. dojo.place(cont, node, "only")
			//		may be a better choice for simple HTML insertion.
			// description:
			//		Unless you need to use the params capabilities of this method, you should use
			//		dojo.place(cont, node, "only"). dojo.place() has more robust support for injecting
			//		an HTML string into the DOM, but it only handles inserting an HTML string as DOM
			//		elements, or inserting a DOM node. dojo.place does not handle NodeList insertions
			//		or the other capabilities as defined by the params object for this method.
			//	node:
			//		the parent element that will receive the content
			//	cont:
			//		the content to be set on the parent element.
			//		This can be an html string, a node reference or a NodeList, dojo.NodeList, Array or other enumerable list of nodes
			//	params:
			//		Optional flags/properties to configure the content-setting. See dojo.html._ContentSetter
			//	example:
			//		A safe string/node/nodelist content replacement/injection with hooks for extension
			//		Example Usage:
			//		dojo.html.set(node, "some string");
			//		dojo.html.set(node, contentNode, {options});
			//		dojo.html.set(node, myNode.childNodes, {options});
		if(undefined == cont){
			console.warn("dojo.html.set: no cont argument provided, using empty string");
			cont = "";
		}
		if(!params){
			// simple and fast
			return dojo.html._setNodeContent(node, cont, true);
		}else{
			// more options but slower
			// note the arguments are reversed in order, to match the convention for instantiation via the parser
			var op = new dojo.html._ContentSetter(dojo.mixin(
					params,
					{ content: cont, node: node }
			));
			return op.set();
		}
	};
})();

}

if(!dojo._hasResource["dijit.layout._ContentPaneResizeMixin"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.layout._ContentPaneResizeMixin"] = true;
dojo.provide("dijit.layout._ContentPaneResizeMixin");




dojo.declare("dijit.layout._ContentPaneResizeMixin", null, {
	// summary:
	//		Resize() functionality of ContentPane.   If there's a single layout widget
	//		child then it will call resize() with the same dimensions as the ContentPane.
	//		Otherwise just calls resize on each child.
	//
	//		Also implements basic startup() functionality, where starting the parent
	//		will start the children

	// doLayout: Boolean
	//		- false - don't adjust size of children
	//		- true - if there is a single visible child widget, set it's size to
	//				however big the ContentPane is
	doLayout: true,

	// isContainer: [protected] Boolean
	//		Indicates that this widget acts as a "parent" to the descendant widgets.
	//		When the parent is started it will call startup() on the child widgets.
	//		See also `isLayoutContainer`.
	isContainer: true,

	// isLayoutContainer: [protected] Boolean
	//		Indicates that this widget will call resize() on it's child widgets
	//		when they become visible.
	isLayoutContainer: true,

	_startChildren: function(){
		// summary:
		//		Call startup() on all children including non _Widget ones like dojo.dnd.Source objects

		// This starts all the widgets
		dojo.forEach(this.getChildren(), function(child){
			child.startup();
			child._started = true;
		});
	},

	startup: function(){
		// summary:
		//		See `dijit.layout._LayoutWidget.startup` for description.
		//		Although ContentPane doesn't extend _LayoutWidget, it does implement
		//		the same API.

		if(this._started){ return; }

		var parent = dijit._Contained.prototype.getParent.call(this);
		this._childOfLayoutWidget = parent && parent.isLayoutContainer;

		// I need to call resize() on my child/children (when I become visible), unless
		// I'm the child of a layout widget in which case my parent will call resize() on me and I'll do it then.
		this._needLayout = !this._childOfLayoutWidget;

		this.inherited(arguments);

		this._startChildren();

		if(this._isShown()){
			this._onShow();
		}

		if(!this._childOfLayoutWidget){
			// If my parent isn't a layout container, since my style *may be* width=height=100%
			// or something similar (either set directly or via a CSS class),
			// monitor when my size changes so that I can re-layout.
			// For browsers where I can't directly monitor when my size changes,
			// monitor when the viewport changes size, which *may* indicate a size change for me.
			this.connect(dojo.isIE ? this.domNode : dojo.global, 'onresize', function(){
				// Using function(){} closure to ensure no arguments to resize.
				this._needLayout = !this._childOfLayoutWidget;
				this.resize();
			});
		}
	},

	_checkIfSingleChild: function(){
		// summary:
		//		Test if we have exactly one visible widget as a child,
		//		and if so assume that we are a container for that widget,
		//		and should propagate startup() and resize() calls to it.
		//		Skips over things like data stores since they aren't visible.

		var childNodes = dojo.query("> *", this.containerNode).filter(function(node){
				return node.tagName !== "SCRIPT"; // or a regexp for hidden elements like script|area|map|etc..
			}),
			childWidgetNodes = childNodes.filter(function(node){
				return dojo.hasAttr(node, "data-dojo-type") || dojo.hasAttr(node, "dojoType") || dojo.hasAttr(node, "widgetId");
			}),
			candidateWidgets = dojo.filter(childWidgetNodes.map(dijit.byNode), function(widget){
				return widget && widget.domNode && widget.resize;
			});

		if(
			// all child nodes are widgets
			childNodes.length == childWidgetNodes.length &&

			// all but one are invisible (like dojo.data)
			candidateWidgets.length == 1
		){
			this._singleChild = candidateWidgets[0];
		}else{
			delete this._singleChild;
		}

		// So we can set overflow: hidden to avoid a safari bug w/scrollbars showing up (#9449)
		dojo.toggleClass(this.containerNode, this.baseClass + "SingleChild", !!this._singleChild);
	},

	resize: function(changeSize, resultSize){
		// summary:
		//		See `dijit.layout._LayoutWidget.resize` for description.
		//		Although ContentPane doesn't extend _LayoutWidget, it does implement
		//		the same API.

		// For the TabContainer --> BorderContainer --> ContentPane case, _onShow() is
		// never called, so resize() is our trigger to do the initial href download (see [20099]).
		// However, don't load href for closed TitlePanes.
		if(!this._wasShown && this.open !== false){
			this._onShow();
		}

		this._resizeCalled = true;

		this._scheduleLayout(changeSize, resultSize);
	},

	_scheduleLayout: function(changeSize, resultSize){
		// summary:
		//		Resize myself, and call resize() on each of my child layout widgets, either now
		//		(if I'm currently visible) or when I become visible
		if(this._isShown()){
			this._layout(changeSize, resultSize);
		}else{
			this._needLayout = true;
			this._changeSize = changeSize;
			this._resultSize = resultSize;
		}
	},

	_layout: function(changeSize, resultSize){
		// summary:
		//		Resize myself according to optional changeSize/resultSize parameters, like a layout widget.
		//		Also, since I am a Container widget, each of my children expects me to
		//		call resize() or layout() on them.
		//
		//		Should be called on initialization and also whenever we get new content
		//		(from an href, or from set('content', ...))... but deferred until
		//		the ContentPane is visible

		// Set margin box size, unless it wasn't specified, in which case use current size.
		if(changeSize){
			dojo.marginBox(this.domNode, changeSize);
		}

		// Compute content box size of containerNode in case we [later] need to size our single child.
		var cn = this.containerNode;
		if(cn === this.domNode){
			// If changeSize or resultSize was passed to this method and this.containerNode ==
			// this.domNode then we can compute the content-box size without querying the node,
			// which is more reliable (similar to LayoutWidget.resize) (see for example #9449).
			var mb = resultSize || {};
			dojo.mixin(mb, changeSize || {}); // changeSize overrides resultSize
			if(!("h" in mb) || !("w" in mb)){
				mb = dojo.mixin(dojo.marginBox(cn), mb); // just use dojo.marginBox() to fill in missing values
			}
			this._contentBox = dijit.layout.marginBox2contentBox(cn, mb);
		}else{
			this._contentBox = dojo.contentBox(cn);
		}

		this._layoutChildren();

		delete this._needLayout;
	},
	
	_layoutChildren: function(){
		// Call _checkIfSingleChild() again in case app has manually mucked w/the content
		// of the ContentPane (rather than changing it through the set("content", ...) API.
		if(this.doLayout){
			this._checkIfSingleChild();
		}

		if(this._singleChild && this._singleChild.resize){
			var cb = this._contentBox || dojo.contentBox(this.containerNode);

			// note: if widget has padding this._contentBox will have l and t set,
			// but don't pass them to resize() or it will doubly-offset the child
			this._singleChild.resize({w: cb.w, h: cb.h});
		}else{
			// All my child widgets are independently sized (rather than matching my size),
			// but I still need to call resize() on each child to make it layout.
			dojo.forEach(this.getChildren(), function(widget){
				if(widget.resize){
					widget.resize();
				}
			});
		}
	},

	_isShown: function(){
		// summary:
		//		Returns true if the content is currently shown.
		// description:
		//		If I am a child of a layout widget then it actually returns true if I've ever been visible,
		//		not whether I'm currently visible, since that's much faster than tracing up the DOM/widget
		//		tree every call, and at least solves the performance problem on page load by deferring loading
		//		hidden ContentPanes until they are first shown

		if(this._childOfLayoutWidget){
			// If we are TitlePane, etc - we return that only *IF* we've been resized
			if(this._resizeCalled && "open" in this){
				return this.open;
			}
			return this._resizeCalled;
		}else if("open" in this){
			return this.open;		// for TitlePane, etc.
		}else{
			var node = this.domNode, parent = this.domNode.parentNode;
			return (node.style.display != 'none') && (node.style.visibility != 'hidden') && !dojo.hasClass(node, "dijitHidden") &&
					parent && parent.style && (parent.style.display != 'none');
		}
	},

	_onShow: function(){
		// summary:
		//		Called when the ContentPane is made visible
		// description:
		//		For a plain ContentPane, this is called on initialization, from startup().
		//		If the ContentPane is a hidden pane of a TabContainer etc., then it's
		//		called whenever the pane is made visible.
		//
		//		Does layout/resize of child widget(s)

		if(this._needLayout){
			// If a layout has been scheduled for when we become visible, do it now
			this._layout(this._changeSize, this._resultSize);
		}

		this.inherited(arguments);

		// Need to keep track of whether ContentPane has been shown (which is different than
		// whether or not it's currently visible).
		this._wasShown = true;
	}
});

}

if(!dojo._hasResource["dijit.layout.ContentPane"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.layout.ContentPane"] = true;
dojo.provide("dijit.layout.ContentPane");







dojo.declare(
	"dijit.layout.ContentPane", [dijit._Widget, dijit.layout._ContentPaneResizeMixin],
{
	// summary:
	//		A widget containing an HTML fragment, specified inline
	//		or by uri.  Fragment may include widgets.
	//
	// description:
	//		This widget embeds a document fragment in the page, specified
	//		either by uri, javascript generated markup or DOM reference.
	//		Any widgets within this content are instantiated and managed,
	//		but laid out according to the HTML structure.  Unlike IFRAME,
	//		ContentPane embeds a document fragment as would be found
	//		inside the BODY tag of a full HTML document.  It should not
	//		contain the HTML, HEAD, or BODY tags.
	//		For more advanced functionality with scripts and
	//		stylesheets, see dojox.layout.ContentPane.  This widget may be
	//		used stand alone or as a base class for other widgets.
	//		ContentPane is useful as a child of other layout containers
	//		such as BorderContainer or TabContainer, but note that those
	//		widgets can contain any widget as a child.
	//
	// example:
	//		Some quick samples:
	//		To change the innerHTML: cp.set('content', '<b>new content</b>')
	//
	//		Or you can send it a NodeList: cp.set('content', dojo.query('div [class=selected]', userSelection))
	//
	//		To do an ajax update: cp.set('href', url)

	// href: String
	//		The href of the content that displays now.
	//		Set this at construction if you want to load data externally when the
	//		pane is shown.  (Set preload=true to load it immediately.)
	//		Changing href after creation doesn't have any effect; Use set('href', ...);
	href: "",

/*=====
	// content: String || DomNode || NodeList || dijit._Widget
	//		The innerHTML of the ContentPane.
	//		Note that the initialization parameter / argument to set("content", ...)
	//		can be a String, DomNode, Nodelist, or _Widget.
	content: "",
=====*/

	// extractContent: Boolean
	//		Extract visible content from inside of <body> .... </body>.
	//		I.e., strip <html> and <head> (and it's contents) from the href
	extractContent: false,

	// parseOnLoad: Boolean
	//		Parse content and create the widgets, if any.
	parseOnLoad: true,

	// parserScope: String
	//		Flag passed to parser.  Root for attribute names to search for.   If scopeName is dojo,
	//		will search for data-dojo-type (or dojoType).  For backwards compatibility
	//		reasons defaults to dojo._scopeName (which is "dojo" except when
	//		multi-version support is used, when it will be something like dojo16, dojo20, etc.)
	parserScope: dojo._scopeName,

	// preventCache: Boolean
	//		Prevent caching of data from href's by appending a timestamp to the href.
	preventCache: false,

	// preload: Boolean
	//		Force load of data on initialization even if pane is hidden.
	preload: false,

	// refreshOnShow: Boolean
	//		Refresh (re-download) content when pane goes from hidden to shown
	refreshOnShow: false,

	// loadingMessage: String
	//		Message that shows while downloading
	loadingMessage: "<span class='dijitContentPaneLoading'>${loadingState}</span>",

	// errorMessage: String
	//		Message that shows if an error occurs
	errorMessage: "<span class='dijitContentPaneError'>${errorState}</span>",

	// isLoaded: [readonly] Boolean
	//		True if the ContentPane has data in it, either specified
	//		during initialization (via href or inline content), or set
	//		via set('content', ...) / set('href', ...)
	//
	//		False if it doesn't have any content, or if ContentPane is
	//		still in the process of downloading href.
	isLoaded: false,

	baseClass: "dijitContentPane",

	// ioArgs: Object
	//		Parameters to pass to xhrGet() request, for example:
	// |	<div dojoType="dijit.layout.ContentPane" href="./bar" ioArgs="{timeout: 500}">
	ioArgs: {},

	// onLoadDeferred: [readonly] dojo.Deferred
	//		This is the `dojo.Deferred` returned by set('href', ...) and refresh().
	//		Calling onLoadDeferred.addCallback() or addErrback() registers your
	//		callback to be called only once, when the prior set('href', ...) call or
	//		the initial href parameter to the constructor finishes loading.
	//
	//		This is different than an onLoad() handler which gets called any time any href
	//		or content is loaded.
	onLoadDeferred: null,

	// Override _Widget's attributeMap because we don't want the title attribute (used to specify
	// tab labels) to be copied to ContentPane.domNode... otherwise a tooltip shows up over the
	// entire pane.
	attributeMap: dojo.delegate(dijit._Widget.prototype.attributeMap, {
		title: []
	}),

	// Flag to parser that I'll parse my contents, so it shouldn't.
	stopParser: true,

	// template: [private] Boolean
	//		Flag from the parser that this ContentPane is inside a template
	//		so the contents are pre-parsed.
	// (TODO: this declaration can be commented out in 2.0)
	template: false,

	create: function(params, srcNodeRef){
		// Convert a srcNodeRef argument into a content parameter, so that the original contents are
		// processed in the same way as contents set via set("content", ...), calling the parser etc.
		// Avoid modifying original params object since that breaks NodeList instantiation, see #11906.
		if((!params || !params.template) && srcNodeRef && !("href" in params) && !("content" in params)){
			var df = dojo.doc.createDocumentFragment();
			srcNodeRef = dojo.byId(srcNodeRef)
			while(srcNodeRef.firstChild){
				df.appendChild(srcNodeRef.firstChild);
			}
			params = dojo.delegate(params, {content: df});
		}
		this.inherited(arguments, [params, srcNodeRef]);
	},

	postMixInProperties: function(){
		this.inherited(arguments);
		var messages = dojo.i18n.getLocalization("dijit", "loading", this.lang);
		this.loadingMessage = dojo.string.substitute(this.loadingMessage, messages);
		this.errorMessage = dojo.string.substitute(this.errorMessage, messages);
	},

	buildRendering: function(){
		this.inherited(arguments);

		// Since we have no template we need to set this.containerNode ourselves, to make getChildren() work.
		// For subclasses of ContentPane that do have a template, does nothing.
		if(!this.containerNode){
			this.containerNode = this.domNode;
		}

		// remove the title attribute so it doesn't show up when hovering
		// over a node  (TODO: remove in 2.0, no longer needed after #11490)
		this.domNode.title = "";

		if(!dojo.attr(this.domNode,"role")){
			dijit.setWaiRole(this.domNode, "group");
		}
	},

	_startChildren: function(){
		// summary:
		//		Call startup() on all children including non _Widget ones like dojo.dnd.Source objects

		// This starts all the widgets
		this.inherited(arguments);

		// And this catches stuff like dojo.dnd.Source
		if(this._contentSetter){
			dojo.forEach(this._contentSetter.parseResults, function(obj){
				if(!obj._started && !obj._destroyed && dojo.isFunction(obj.startup)){
					obj.startup();
					obj._started = true;
				}
			}, this);
		}
	},

	setHref: function(/*String|Uri*/ href){
		// summary:
		//		Deprecated.   Use set('href', ...) instead.
		dojo.deprecated("dijit.layout.ContentPane.setHref() is deprecated. Use set('href', ...) instead.", "", "2.0");
		return this.set("href", href);
	},
	_setHrefAttr: function(/*String|Uri*/ href){
		// summary:
		//		Hook so set("href", ...) works.
		// description:
		//		Reset the (external defined) content of this pane and replace with new url
		//		Note: It delays the download until widget is shown if preload is false.
		//	href:
		//		url to the page you want to get, must be within the same domain as your mainpage

		// Cancel any in-flight requests (a set('href', ...) will cancel any in-flight set('href', ...))
		this.cancel();

		this.onLoadDeferred = new dojo.Deferred(dojo.hitch(this, "cancel"));
		this.onLoadDeferred.addCallback(dojo.hitch(this, "onLoad"));

		this._set("href", href);

		// _setHrefAttr() is called during creation and by the user, after creation.
		// Assuming preload == false, only in the second case do we actually load the URL;
		// otherwise it's done in startup(), and only if this widget is shown.
		if(this.preload || (this._created && this._isShown())){
			this._load();
		}else{
			// Set flag to indicate that href needs to be loaded the next time the
			// ContentPane is made visible
			this._hrefChanged = true;
		}

		return this.onLoadDeferred;		// dojo.Deferred
	},

	setContent: function(/*String|DomNode|Nodelist*/data){
		// summary:
		//		Deprecated.   Use set('content', ...) instead.
		dojo.deprecated("dijit.layout.ContentPane.setContent() is deprecated.  Use set('content', ...) instead.", "", "2.0");
		this.set("content", data);
	},
	_setContentAttr: function(/*String|DomNode|Nodelist*/data){
		// summary:
		//		Hook to make set("content", ...) work.
		//		Replaces old content with data content, include style classes from old content
		//	data:
		//		the new Content may be String, DomNode or NodeList
		//
		//		if data is a NodeList (or an array of nodes) nodes are copied
		//		so you can import nodes from another document implicitly

		// clear href so we can't run refresh and clear content
		// refresh should only work if we downloaded the content
		this._set("href", "");

		// Cancel any in-flight requests (a set('content', ...) will cancel any in-flight set('href', ...))
		this.cancel();

		// Even though user is just setting content directly, still need to define an onLoadDeferred
		// because the _onLoadHandler() handler is still getting called from setContent()
		this.onLoadDeferred = new dojo.Deferred(dojo.hitch(this, "cancel"));
		if(this._created){
			// For back-compat reasons, call onLoad() for set('content', ...)
			// calls but not for content specified in srcNodeRef (ie: <div dojoType=ContentPane>...</div>)
			// or as initialization parameter (ie: new ContentPane({content: ...})
			this.onLoadDeferred.addCallback(dojo.hitch(this, "onLoad"));
		}

		this._setContent(data || "");

		this._isDownloaded = false; // mark that content is from a set('content') not a set('href')

		return this.onLoadDeferred; 	// dojo.Deferred
	},
	_getContentAttr: function(){
		// summary:
		//		Hook to make get("content") work
		return this.containerNode.innerHTML;
	},

	cancel: function(){
		// summary:
		//		Cancels an in-flight download of content
		if(this._xhrDfd && (this._xhrDfd.fired == -1)){
			this._xhrDfd.cancel();
		}
		delete this._xhrDfd; // garbage collect

		this.onLoadDeferred = null;
	},

	uninitialize: function(){
		if(this._beingDestroyed){
			this.cancel();
		}
		this.inherited(arguments);
	},

	destroyRecursive: function(/*Boolean*/ preserveDom){
		// summary:
		//		Destroy the ContentPane and its contents

		// if we have multiple controllers destroying us, bail after the first
		if(this._beingDestroyed){
			return;
		}
		this.inherited(arguments);
	},

	_onShow: function(){
		// summary:
		//		Called when the ContentPane is made visible
		// description:
		//		For a plain ContentPane, this is called on initialization, from startup().
		//		If the ContentPane is a hidden pane of a TabContainer etc., then it's
		//		called whenever the pane is made visible.
		//
		//		Does necessary processing, including href download and layout/resize of
		//		child widget(s)

		this.inherited(arguments);

		if(this.href){
			if(!this._xhrDfd && // if there's an href that isn't already being loaded
				(!this.isLoaded || this._hrefChanged || this.refreshOnShow)
			){
				return this.refresh();	// If child has an href, promise that fires when the load is complete
			}
		}
	},

	refresh: function(){
		// summary:
		//		[Re]download contents of href and display
		// description:
		//		1. cancels any currently in-flight requests
		//		2. posts "loading..." message
		//		3. sends XHR to download new data

		// Cancel possible prior in-flight request
		this.cancel();

		this.onLoadDeferred = new dojo.Deferred(dojo.hitch(this, "cancel"));
		this.onLoadDeferred.addCallback(dojo.hitch(this, "onLoad"));
		this._load();
		return this.onLoadDeferred;		// If child has an href, promise that fires when refresh is complete
	},

	_load: function(){
		// summary:
		//		Load/reload the href specified in this.href

		// display loading message
		this._setContent(this.onDownloadStart(), true);

		var self = this;
		var getArgs = {
			preventCache: (this.preventCache || this.refreshOnShow),
			url: this.href,
			handleAs: "text"
		};
		if(dojo.isObject(this.ioArgs)){
			dojo.mixin(getArgs, this.ioArgs);
		}

		var hand = (this._xhrDfd = (this.ioMethod || dojo.xhrGet)(getArgs));

		hand.addCallback(function(html){
			try{
				self._isDownloaded = true;
				self._setContent(html, false);
				self.onDownloadEnd();
			}catch(err){
				self._onError('Content', err); // onContentError
			}
			delete self._xhrDfd;
			return html;
		});

		hand.addErrback(function(err){
			if(!hand.canceled){
				// show error message in the pane
				self._onError('Download', err); // onDownloadError
			}
			delete self._xhrDfd;
			return err;
		});

		// Remove flag saying that a load is needed
		delete this._hrefChanged;
	},

	_onLoadHandler: function(data){
		// summary:
		//		This is called whenever new content is being loaded
		this._set("isLoaded", true);
		try{
			this.onLoadDeferred.callback(data);
		}catch(e){
			console.error('Error '+this.widgetId+' running custom onLoad code: ' + e.message);
		}
	},

	_onUnloadHandler: function(){
		// summary:
		//		This is called whenever the content is being unloaded
		this._set("isLoaded", false);
		try{
			this.onUnload();
		}catch(e){
			console.error('Error '+this.widgetId+' running custom onUnload code: ' + e.message);
		}
	},

	destroyDescendants: function(){
		// summary:
		//		Destroy all the widgets inside the ContentPane and empty containerNode

		// Make sure we call onUnload (but only when the ContentPane has real content)
		if(this.isLoaded){
			this._onUnloadHandler();
		}

		// Even if this.isLoaded == false there might still be a "Loading..." message
		// to erase, so continue...

		// For historical reasons we need to delete all widgets under this.containerNode,
		// even ones that the user has created manually.
		var setter = this._contentSetter;
		dojo.forEach(this.getChildren(), function(widget){
			if(widget.destroyRecursive){
				widget.destroyRecursive();
			}
		});
		if(setter){
			// Most of the widgets in setter.parseResults have already been destroyed, but
			// things like Menu that have been moved to <body> haven't yet
			dojo.forEach(setter.parseResults, function(widget){
				if(widget.destroyRecursive && widget.domNode && widget.domNode.parentNode == dojo.body()){
					widget.destroyRecursive();
				}
			});
			delete setter.parseResults;
		}

		// And then clear away all the DOM nodes
		dojo.html._emptyNode(this.containerNode);

		// Delete any state information we have about current contents
		delete this._singleChild;
	},

	_setContent: function(/*String|DocumentFragment*/ cont, /*Boolean*/ isFakeContent){
		// summary:
		//		Insert the content into the container node

		// first get rid of child widgets
		this.destroyDescendants();

		// dojo.html.set will take care of the rest of the details
		// we provide an override for the error handling to ensure the widget gets the errors
		// configure the setter instance with only the relevant widget instance properties
		// NOTE: unless we hook into attr, or provide property setters for each property,
		// we need to re-configure the ContentSetter with each use
		var setter = this._contentSetter;
		if(! (setter && setter instanceof dojo.html._ContentSetter)){
			setter = this._contentSetter = new dojo.html._ContentSetter({
				node: this.containerNode,
				_onError: dojo.hitch(this, this._onError),
				onContentError: dojo.hitch(this, function(e){
					// fires if a domfault occurs when we are appending this.errorMessage
					// like for instance if domNode is a UL and we try append a DIV
					var errMess = this.onContentError(e);
					try{
						this.containerNode.innerHTML = errMess;
					}catch(e){
						console.error('Fatal '+this.id+' could not change content due to '+e.message, e);
					}
				})/*,
				_onError */
			});
		};

		var setterParams = dojo.mixin({
			cleanContent: this.cleanContent,
			extractContent: this.extractContent,
			parseContent: this.parseOnLoad,
			parserScope: this.parserScope,
			startup: false,
			dir: this.dir,
			lang: this.lang
		}, this._contentSetterParams || {});

		setter.set( (dojo.isObject(cont) && cont.domNode) ? cont.domNode : cont, setterParams );

		// setter params must be pulled afresh from the ContentPane each time
		delete this._contentSetterParams;

		if(this.doLayout){
			this._checkIfSingleChild();
		}

		if(!isFakeContent){
			if(this._started){
				// Startup each top level child widget (and they will start their children, recursively)
				this._startChildren();
	
				// Call resize() on each of my child layout widgets,
				// or resize() on my single child layout widget...
				// either now (if I'm currently visible) or when I become visible
				this._scheduleLayout();
			}

			this._onLoadHandler(cont);
		}
	},

	_onError: function(type, err, consoleText){
		this.onLoadDeferred.errback(err);

		// shows user the string that is returned by on[type]Error
		// override on[type]Error and return your own string to customize
		var errText = this['on' + type + 'Error'].call(this, err);
		if(consoleText){
			console.error(consoleText, err);
		}else if(errText){// a empty string won't change current content
			this._setContent(errText, true);
		}
	},

	// EVENT's, should be overide-able
	onLoad: function(data){
		// summary:
		//		Event hook, is called after everything is loaded and widgetified
		// tags:
		//		callback
	},

	onUnload: function(){
		// summary:
		//		Event hook, is called before old content is cleared
		// tags:
		//		callback
	},

	onDownloadStart: function(){
		// summary:
		//		Called before download starts.
		// description:
		//		The string returned by this function will be the html
		//		that tells the user we are loading something.
		//		Override with your own function if you want to change text.
		// tags:
		//		extension
		return this.loadingMessage;
	},

	onContentError: function(/*Error*/ error){
		// summary:
		//		Called on DOM faults, require faults etc. in content.
		//
		//		In order to display an error message in the pane, return
		//		the error message from this method, as an HTML string.
		//
		//		By default (if this method is not overriden), it returns
		//		nothing, so the error message is just printed to the console.
		// tags:
		//		extension
	},

	onDownloadError: function(/*Error*/ error){
		// summary:
		//		Called when download error occurs.
		//
		//		In order to display an error message in the pane, return
		//		the error message from this method, as an HTML string.
		//
		//		Default behavior (if this method is not overriden) is to display
		//		the error message inside the pane.
		// tags:
		//		extension
		return this.errorMessage;
	},

	onDownloadEnd: function(){
		// summary:
		//		Called when download is finished.
		// tags:
		//		callback
	}
});

}

if(!dojo._hasResource["dojox.html._base"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojox.html._base"] = true;
/*
	Status: dont know where this will all live exactly
	Need to pull in the implementation of the various helper methods
	Some can be static method, others maybe methods of the ContentSetter (?)
	
	Gut the ContentPane, replace its _setContent with our own call to dojox.html.set()
	

*/

dojo.provide("dojox.html._base");



(function() {

	if(dojo.isIE){
		var alphaImageLoader = /(AlphaImageLoader\([^)]*?src=(['"]))(?![a-z]+:|\/)([^\r\n;}]+?)(\2[^)]*\)\s*[;}]?)/g;
	}

	// css at-rules must be set before any css declarations according to CSS spec
	// match:
	// @import 'http://dojotoolkit.org/dojo.css';
	// @import 'you/never/thought/' print;
	// @import url("it/would/work") tv, screen;
	// @import url(/did/you/now.css);
	// but not:
	// @namespace dojo "http://dojotoolkit.org/dojo.css"; /* namespace URL should always be a absolute URI */
	// @charset 'utf-8';
	// @media print{ #menuRoot {display:none;} }
		
	// we adjust all paths that dont start on '/' or contains ':'
	//(?![a-z]+:|\/)

	var cssPaths = /(?:(?:@import\s*(['"])(?![a-z]+:|\/)([^\r\n;{]+?)\1)|url\(\s*(['"]?)(?![a-z]+:|\/)([^\r\n;]+?)\3\s*\))([a-z, \s]*[;}]?)/g;

	var adjustCssPaths = dojox.html._adjustCssPaths = function(cssUrl, cssText){
		//	summary:
		//		adjusts relative paths in cssText to be relative to cssUrl
		//		a path is considered relative if it doesn't start with '/' and not contains ':'
		//	description:
		//		Say we fetch a HTML page from level1/page.html
		//		It has some inline CSS:
		//			@import "css/page.css" tv, screen;
		//			...
		//			background-image: url(images/aplhaimage.png);
		//
		//		as we fetched this HTML and therefore this CSS
		//		from level1/page.html, these paths needs to be adjusted to:
		//			@import 'level1/css/page.css' tv, screen;
		//			...
		//			background-image: url(level1/images/alphaimage.png);
		//
		//		In IE it will also adjust relative paths in AlphaImageLoader()
		//			filter:progid:DXImageTransform.Microsoft.AlphaImageLoader(src='images/alphaimage.png');
		//		will be adjusted to:
		//			filter:progid:DXImageTransform.Microsoft.AlphaImageLoader(src='level1/images/alphaimage.png');
		//
		//		Please note that any relative paths in AlphaImageLoader in external css files wont work, as
		//		the paths in AlphaImageLoader is MUST be declared relative to the HTML page,
		//		not relative to the CSS file that declares it

		if(!cssText || !cssUrl){ return; }

		// support the ImageAlphaFilter if it exists, most people use it in IE 6 for transparent PNGs
		// We are NOT going to kill it in IE 7 just because the PNGs work there. Somebody might have
		// other uses for it.
		// If user want to disable css filter in IE6  he/she should
		// unset filter in a declaration that just IE 6 doesn't understands
		// like * > .myselector { filter:none; }
		if(alphaImageLoader){
			cssText = cssText.replace(alphaImageLoader, function(ignore, pre, delim, url, post){
				return pre + (new dojo._Url(cssUrl, './'+url).toString()) + post;
			});
		}

		return cssText.replace(cssPaths, function(ignore, delimStr, strUrl, delimUrl, urlUrl, media){
			if(strUrl){
				return '@import "' + (new dojo._Url(cssUrl, './'+strUrl).toString()) + '"' + media;
			}else{
				return 'url(' + (new dojo._Url(cssUrl, './'+urlUrl).toString()) + ')' + media;
			}
		});
	};

	// attributepaths one tag can have multiple paths, example:
	// <input src="..." style="url(..)"/> or <a style="url(..)" href="..">
	// <img style='filter:progid...AlphaImageLoader(src="noticeTheSrcHereRunsThroughHtmlSrc")' src="img">
	var htmlAttrPaths = /(<[a-z][a-z0-9]*\s[^>]*)(?:(href|src)=(['"]?)([^>]*?)\3|style=(['"]?)([^>]*?)\5)([^>]*>)/gi;

	var adjustHtmlPaths = dojox.html._adjustHtmlPaths = function(htmlUrl, cont){
		var url = htmlUrl || "./";

		return cont.replace(htmlAttrPaths,
			function(tag, start, name, delim, relUrl, delim2, cssText, end){
				return start + (name ?
							(name + '=' + delim + (new dojo._Url(url, relUrl).toString()) + delim)
						: ('style=' + delim2 + adjustCssPaths(url, cssText) + delim2)
				) + end;
			}
		);
	};
	
	var snarfStyles = dojox.html._snarfStyles = function	(/*String*/cssUrl, /*String*/cont, /*Array*/styles){
		/****************  cut out all <style> and <link rel="stylesheet" href=".."> **************/
		// also return any attributes from this tag (might be a media attribute)
		// if cssUrl is set it will adjust paths accordingly
		styles.attributes = [];

		return cont.replace(/(?:<style([^>]*)>([\s\S]*?)<\/style>|<link\s+(?=[^>]*rel=['"]?stylesheet)([^>]*?href=(['"])([^>]*?)\4[^>\/]*)\/?>)/gi,
			function(ignore, styleAttr, cssText, linkAttr, delim, href){
				// trim attribute
				var i, attr = (styleAttr||linkAttr||"").replace(/^\s*([\s\S]*?)\s*$/i, "$1");
				if(cssText){
					i = styles.push(cssUrl ? adjustCssPaths(cssUrl, cssText) : cssText);
				}else{
					i = styles.push('@import "' + href + '";');
					attr = attr.replace(/\s*(?:rel|href)=(['"])?[^\s]*\1\s*/gi, ""); // remove rel=... and href=...
				}
				if(attr){
					attr = attr.split(/\s+/);// split on both "\n", "\t", " " etc
					var atObj = {}, tmp;
					for(var j = 0, e = attr.length; j < e; j++){
						tmp = attr[j].split('='); // split name='value'
						atObj[tmp[0]] = tmp[1].replace(/^\s*['"]?([\s\S]*?)['"]?\s*$/, "$1"); // trim and remove ''
					}
					styles.attributes[i - 1] = atObj;
				}
				return "";
			}
		);
	};

	var snarfScripts = dojox.html._snarfScripts = function(cont, byRef){
		// summary
		//		strips out script tags from cont
		// invoke with
		//	byRef = {errBack:function(){/*add your download error code here*/, downloadRemote: true(default false)}}
		//	byRef will have {code: 'jscode'} when this scope leaves
		byRef.code = "";

		//Update script tags nested in comments so that the script tag collector doesn't pick
		//them up.
		cont = cont.replace(/<[!][-][-](.|\s)*?[-][-]>/g,
			function(comment){
				return comment.replace(/<(\/?)script\b/ig,"&lt;$1Script");
			}
		);

		function download(src){
			if(byRef.downloadRemote){
				// console.debug('downloading',src);
				//Fix up src, in case there were entity character encodings in it.
				//Probably only need to worry about a subset.
				src = src.replace(/&([a-z0-9#]+);/g, function(m, name) {
					switch(name) {
						case "amp"	: return "&";
						case "gt"	: return ">";
						case "lt"	: return "<";
						default:
							return name.charAt(0)=="#" ? String.fromCharCode(name.substring(1)) : "&"+name+";";
					}
				});
				dojo.xhrGet({
					url: src,
					sync: true,
					load: function(code){
						byRef.code += code+";";
					},
					error: byRef.errBack
				});
			}
		}
		
		// match <script>, <script type="text/..., but not <script type="dojo(/method)...
		return cont.replace(/<script\s*(?![^>]*type=['"]?(?:dojo\/|text\/html\b))(?:[^>]*?(?:src=(['"]?)([^>]*?)\1[^>]*)?)*>([\s\S]*?)<\/script>/gi,
			function(ignore, delim, src, code){
				if(src){
					download(src);
				}else{
					byRef.code += code;
				}
				return "";
			}
		);
	};
	
	var evalInGlobal = dojox.html.evalInGlobal = function(code, appendNode){
		// we do our own eval here as dojo.eval doesn't eval in global crossbrowser
		// This work X browser but but it relies on a DOM
		// plus it doesn't return anything, thats unrelevant here but not for dojo core
		appendNode = appendNode || dojo.doc.body;
		var n = appendNode.ownerDocument.createElement('script');
		n.type = "text/javascript";
		appendNode.appendChild(n);
		n.text = code; // DOM 1 says this should work
	};

	dojo.declare("dojox.html._ContentSetter", [dojo.html._ContentSetter], {
		// adjustPaths: Boolean
		//		Adjust relative paths in html string content to point to this page
		//		Only useful if you grab content from a another folder than the current one
		adjustPaths: false,
		referencePath: ".",
		renderStyles: false,

		executeScripts: false,
		scriptHasHooks: false,
		scriptHookReplacement: null,
		
		_renderStyles: function(styles){
			// insert css from content into document head
			this._styleNodes = [];
			var st, att, cssText, doc = this.node.ownerDocument;
			var head = doc.getElementsByTagName('head')[0];

			for(var i = 0, e = styles.length; i < e; i++){
				cssText = styles[i]; att = styles.attributes[i];
				st = doc.createElement('style');
				st.setAttribute("type", "text/css"); // this is required in CSS spec!

				for(var x in att){
					st.setAttribute(x, att[x]);
				}

				this._styleNodes.push(st);
				head.appendChild(st); // must insert into DOM before setting cssText

				if(st.styleSheet){ // IE
					st.styleSheet.cssText = cssText;
				}else{ // w3c
					st.appendChild(doc.createTextNode(cssText));
				}
			}
		},

		empty: function() {
			this.inherited("empty", arguments);
			
			// empty out the styles array from any previous use
			this._styles = [];
		},
		
		onBegin: function() {
			// summary
			//		Called after instantiation, but before set();
			//		It allows modification of any of the object properties - including the node and content
			//		provided - before the set operation actually takes place
			//		This implementation extends that of dojo.html._ContentSetter
			//		to add handling for adjustPaths, renderStyles on the html string content before it is set
			this.inherited("onBegin", arguments);
			
			var cont = this.content,
				node = this.node;
				
			var styles = this._styles;// init vars

			if(dojo.isString(cont)){
				if(this.adjustPaths && this.referencePath){
					cont = adjustHtmlPaths(this.referencePath, cont);
				}

				if(this.renderStyles || this.cleanContent){
					cont = snarfStyles(this.referencePath, cont, styles);
				}

				// because of a bug in IE, script tags that is first in html hierarchy doesnt make it into the DOM
				//	when content is innerHTML'ed, so we can't use dojo.query to retrieve scripts from DOM
				if(this.executeScripts){
					var _t = this;
					var byRef = {
						downloadRemote: true,
						errBack:function(e){
							_t._onError.call(_t, 'Exec', 'Error downloading remote script in "'+_t.id+'"', e);
						}
					};
					cont = snarfScripts(cont, byRef);
					this._code = byRef.code;
				}
			}
			this.content = cont;
		},
		
		onEnd: function() {
			// summary
			//		Called after set(), when the new content has been pushed into the node
			//		It provides an opportunity for post-processing before handing back the node to the caller
			//		This implementation extends that of dojo.html._ContentSetter
			
			var code = this._code,
				styles = this._styles;
				
			// clear old stylenodes from the DOM
			// these were added by the last set call
			// (in other words, if you dont keep and reuse the ContentSetter for a particular node
			// .. you'll have no practical way to do this)
			if(this._styleNodes && this._styleNodes.length){
				while(this._styleNodes.length){
					dojo.destroy(this._styleNodes.pop());
				}
			}
			// render new style nodes
			if(this.renderStyles && styles && styles.length){
				this._renderStyles(styles);
			}

			if(this.executeScripts && code){
				if(this.cleanContent){
					// clean JS from html comments and other crap that browser
					// parser takes care of in a normal page load
					code = code.replace(/(<!--|(?:\/\/)?-->|<!\[CDATA\[|\]\]>)/g, '');
				}
				if(this.scriptHasHooks){
					// replace _container_ with this.scriptHookReplace()
					// the scriptHookReplacement can be a string
					// or a function, which when invoked returns the string you want to substitute in
					code = code.replace(/_container_(?!\s*=[^=])/g, this.scriptHookReplacement);
				}
				try{
					evalInGlobal(code, this.node);
				}catch(e){
					this._onError('Exec', 'Error eval script in '+this.id+', '+e.message, e);
				}
			}
			this.inherited("onEnd", arguments);
		},
		tearDown: function() {
			this.inherited(arguments);
			delete this._styles;
			// only tear down -or another set() - will explicitly throw away the
			// references to the style nodes we added
			if(this._styleNodes && this._styleNodes.length){
				while(this._styleNodes.length){
					dojo.destroy(this._styleNodes.pop());
				}
			}
			delete this._styleNodes;
			// reset the defaults from the prototype
			dojo.mixin(this, dojo.getObject(this.declaredClass).prototype);
		}
		
	});
	
	dojox.html.set = function(/* DomNode */ node, /* String|DomNode|NodeList */ cont, /* Object? */ params){
		// TODO: add all the other options
			// summary:
			//		inserts (replaces) the given content into the given node
			//	node:
			//		the parent element that will receive the content
			//	cont:
			//		the content to be set on the parent element.
			//		This can be an html string, a node reference or a NodeList, dojo.NodeList, Array or other enumerable list of nodes
			//	params:
			//		Optional flags/properties to configure the content-setting. See dojo.html._ContentSetter
			//	example:
			//		A safe string/node/nodelist content replacement/injection with hooks for extension
			//		Example Usage:
			//		dojo.html.set(node, "some string");
			//		dojo.html.set(node, contentNode, {options});
			//		dojo.html.set(node, myNode.childNodes, {options});
	 
		if(!params){
			// simple and fast
			return dojo.html._setNodeContent(node, cont, true);
		}else{
			// more options but slower
			var op = new dojox.html._ContentSetter(dojo.mixin(
					params,
					{ content: cont, node: node }
			));
			return op.set();
		}
	};
	
})();

}

if(!dojo._hasResource["dojox.layout.ContentPane"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojox.layout.ContentPane"] = true;
dojo.provide("dojox.layout.ContentPane");




dojo.declare("dojox.layout.ContentPane", dijit.layout.ContentPane, {
	// summary:
	//		An extended version of dijit.layout.ContentPane.
	//		Supports infile scripts and external ones declared by <script src=''
	//		relative path adjustments (content fetched from a different folder)
	//		<style> and <link rel='stylesheet' href='..'> tags,
	//		css paths inside cssText is adjusted (if you set adjustPaths = true)
	//
	//		NOTE that dojo.require in script in the fetched file isn't recommended
	//		Many widgets need to be required at page load to work properly

	// adjustPaths: Boolean
	//		Adjust relative paths in html string content to point to this page.
	//		Only useful if you grab content from a another folder then the current one
	adjustPaths: false,

	// cleanContent: Boolean
	//	summary:
	//		cleans content to make it less likely to generate DOM/JS errors.
	//	description:
	//		useful if you send ContentPane a complete page, instead of a html fragment
	//		scans for
	//
	//			* title Node, remove
	//			* DOCTYPE tag, remove
	cleanContent: false,

	// renderStyles: Boolean
	//		trigger/load styles in the content
	renderStyles: false,

	// executeScripts: Boolean
	//		Execute (eval) scripts that is found in the content
	executeScripts: true,

	// scriptHasHooks: Boolean
	//		replace keyword '_container_' in scripts with 'dijit.byId(this.id)'
	// NOTE this name might change in the near future
	scriptHasHooks: false,

	/*======
	// ioMethod: dojo.xhrGet|dojo.xhrPost
	//		reference to the method that should grab the content
	ioMethod: dojo.xhrGet,
	
	// ioArgs: Object
	//		makes it possible to add custom args to xhrGet, like ioArgs.headers['X-myHeader'] = 'true'
	ioArgs: {},
	======*/

	constructor: function(){
		// init per instance properties, initializer doesn't work here because how things is hooked up in dijit._Widget
		this.ioArgs = {};
		this.ioMethod = dojo.xhrGet;
	},

	onExecError: function(e){
		// summary:
		//		event callback, called on script error or on java handler error
		//		overide and return your own html string if you want a some text
		//		displayed within the ContentPane
	},

	_setContent: function(cont){
		// override dijit.layout.ContentPane._setContent, to enable path adjustments
		
		var setter = this._contentSetter;
		if(! (setter && setter instanceof dojox.html._ContentSetter)) {
			setter = this._contentSetter = new dojox.html._ContentSetter({
				node: this.containerNode,
				_onError: dojo.hitch(this, this._onError),
				onContentError: dojo.hitch(this, function(e){
					// fires if a domfault occurs when we are appending this.errorMessage
					// like for instance if domNode is a UL and we try append a DIV
					var errMess = this.onContentError(e);
					try{
						this.containerNode.innerHTML = errMess;
					}catch(e){
						console.error('Fatal '+this.id+' could not change content due to '+e.message, e);
					}
				})/*,
				_onError */
			});
		};

		// stash the params for the contentSetter to allow inheritance to work for _setContent
		this._contentSetterParams = {
			adjustPaths: Boolean(this.adjustPaths && (this.href||this.referencePath)),
			referencePath: this.href || this.referencePath,
			renderStyles: this.renderStyles,
			executeScripts: this.executeScripts,
			scriptHasHooks: this.scriptHasHooks,
			scriptHookReplacement: "dijit.byId('"+this.id+"')"
		};

		this.inherited("_setContent", arguments);
	}
	// could put back _renderStyles by wrapping/aliasing dojox.html._ContentSetter.prototype._renderStyles
});

}

if(!dojo._hasResource["dijit.form._FormMixin"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form._FormMixin"] = true;
dojo.provide("dijit.form._FormMixin");



dojo.declare("dijit.form._FormMixin", null, {
	// summary:
	//		Mixin for containers of form widgets (i.e. widgets that represent a single value
	//		and can be children of a <form> node or dijit.form.Form widget)
	// description:
	//		Can extract all the form widgets
	//		values and combine them into a single javascript object, or alternately
	//		take such an object and set the values for all the contained
	//		form widgets

/*=====
	// value: Object
	//		Name/value hash for each child widget with a name and value.
	//		Child widgets without names are not part of the hash.
	//
	//		If there are multiple child widgets w/the same name, value is an array,
	//		unless they are radio buttons in which case value is a scalar (since only
	//		one radio button can be checked at a time).
	//
	//		If a child widget's name is a dot separated list (like a.b.c.d), it's a nested structure.
	//
	//		Example:
	//	|	{ name: "John Smith", interests: ["sports", "movies"] }
=====*/

	// state: [readonly] String
	//		Will be "Error" if one or more of the child widgets has an invalid value,
	//		"Incomplete" if not all of the required child widgets are filled in.  Otherwise, "",
	//		which indicates that the form is ready to be submitted.
	state: "",

	//	TODO:
	//	* Repeater
	//	* better handling for arrays.  Often form elements have names with [] like
	//	* people[3].sex (for a list of people [{name: Bill, sex: M}, ...])
	//
	//

		reset: function(){
			dojo.forEach(this.getDescendants(), function(widget){
				if(widget.reset){
					widget.reset();
				}
			});
		},

		validate: function(){
			// summary:
			//		returns if the form is valid - same as isValid - but
			//		provides a few additional (ui-specific) features.
			//		1 - it will highlight any sub-widgets that are not
			//			valid
			//		2 - it will call focus() on the first invalid
			//			sub-widget
			var didFocus = false;
			return dojo.every(dojo.map(this.getDescendants(), function(widget){
				// Need to set this so that "required" widgets get their
				// state set.
				widget._hasBeenBlurred = true;
				var valid = widget.disabled || !widget.validate || widget.validate();
				if(!valid && !didFocus){
					// Set focus of the first non-valid widget
					dojo.window.scrollIntoView(widget.containerNode || widget.domNode);
					widget.focus();
					didFocus = true;
				}
	 			return valid;
	 		}), function(item){ return item; });
		},

		setValues: function(val){
			dojo.deprecated(this.declaredClass+"::setValues() is deprecated. Use set('value', val) instead.", "", "2.0");
			return this.set('value', val);
		},
		_setValueAttr: function(/*Object*/ obj){
			// summary:
			//		Fill in form values from according to an Object (in the format returned by get('value'))

			// generate map from name --> [list of widgets with that name]
			var map = { };
			dojo.forEach(this.getDescendants(), function(widget){
				if(!widget.name){ return; }
				var entry = map[widget.name] || (map[widget.name] = [] );
				entry.push(widget);
			});

			for(var name in map){
				if(!map.hasOwnProperty(name)){
					continue;
				}
				var widgets = map[name],						// array of widgets w/this name
					values = dojo.getObject(name, false, obj);	// list of values for those widgets

				if(values === undefined){
					continue;
				}
				if(!dojo.isArray(values)){
					values = [ values ];
				}
				if(typeof widgets[0].checked == 'boolean'){
					// for checkbox/radio, values is a list of which widgets should be checked
					dojo.forEach(widgets, function(w, i){
						w.set('value', dojo.indexOf(values, w.value) != -1);
					});
				}else if(widgets[0].multiple){
					// it takes an array (e.g. multi-select)
					widgets[0].set('value', values);
				}else{
					// otherwise, values is a list of values to be assigned sequentially to each widget
					dojo.forEach(widgets, function(w, i){
						w.set('value', values[i]);
					});
				}
			}

			/***
			 * 	TODO: code for plain input boxes (this shouldn't run for inputs that are part of widgets)

			dojo.forEach(this.containerNode.elements, function(element){
				if(element.name == ''){return};	// like "continue"
				var namePath = element.name.split(".");
				var myObj=obj;
				var name=namePath[namePath.length-1];
				for(var j=1,len2=namePath.length;j<len2;++j){
					var p=namePath[j - 1];
					// repeater support block
					var nameA=p.split("[");
					if(nameA.length > 1){
						if(typeof(myObj[nameA[0]]) == "undefined"){
							myObj[nameA[0]]=[ ];
						} // if

						nameIndex=parseInt(nameA[1]);
						if(typeof(myObj[nameA[0]][nameIndex]) == "undefined"){
							myObj[nameA[0]][nameIndex] = { };
						}
						myObj=myObj[nameA[0]][nameIndex];
						continue;
					} // repeater support ends

					if(typeof(myObj[p]) == "undefined"){
						myObj=undefined;
						break;
					};
					myObj=myObj[p];
				}

				if(typeof(myObj) == "undefined"){
					return;		// like "continue"
				}
				if(typeof(myObj[name]) == "undefined" && this.ignoreNullValues){
					return;		// like "continue"
				}

				// TODO: widget values (just call set('value', ...) on the widget)

				// TODO: maybe should call dojo.getNodeProp() instead
				switch(element.type){
					case "checkbox":
						element.checked = (name in myObj) &&
							dojo.some(myObj[name], function(val){ return val == element.value; });
						break;
					case "radio":
						element.checked = (name in myObj) && myObj[name] == element.value;
						break;
					case "select-multiple":
						element.selectedIndex=-1;
						dojo.forEach(element.options, function(option){
							option.selected = dojo.some(myObj[name], function(val){ return option.value == val; });
						});
						break;
					case "select-one":
						element.selectedIndex="0";
						dojo.forEach(element.options, function(option){
							option.selected = option.value == myObj[name];
						});
						break;
					case "hidden":
					case "text":
					case "textarea":
					case "password":
						element.value = myObj[name] || "";
						break;
				}
	  		});
	  		*/
			
			// Note: no need to call this._set("value", ...) as the child updates will trigger onChange events
			// which I am monitoring.
		},

		getValues: function(){
			dojo.deprecated(this.declaredClass+"::getValues() is deprecated. Use get('value') instead.", "", "2.0");
			return this.get('value');
		},
		_getValueAttr: function(){
			// summary:
			// 		Returns Object representing form values.   See description of `value` for details.
			// description:

			// The value is updated into this.value every time a child has an onChange event,
			// so in the common case this function could just return this.value.   However,
			// that wouldn't work when:
			//
			// 1. User presses return key to submit a form.  That doesn't fire an onchange event,
			// and even if it did it would come too late due to the setTimout(..., 0) in _handleOnChange()
			//
			// 2. app for some reason calls this.get("value") while the user is typing into a
			// form field.   Not sure if that case needs to be supported or not.

			// get widget values
			var obj = { };
			dojo.forEach(this.getDescendants(), function(widget){
				var name = widget.name;
				if(!name || widget.disabled){ return; }

				// Single value widget (checkbox, radio, or plain <input> type widget)
				var value = widget.get('value');

				// Store widget's value(s) as a scalar, except for checkboxes which are automatically arrays
				if(typeof widget.checked == 'boolean'){
					if(/Radio/.test(widget.declaredClass)){
						// radio button
						if(value !== false){
							dojo.setObject(name, value, obj);
						}else{
							// give radio widgets a default of null
							value = dojo.getObject(name, false, obj);
							if(value === undefined){
								dojo.setObject(name, null, obj);
							}
						}
					}else{
						// checkbox/toggle button
						var ary=dojo.getObject(name, false, obj);
						if(!ary){
							ary=[];
							dojo.setObject(name, ary, obj);
						}
						if(value !== false){
							ary.push(value);
						}
					}
				}else{
					var prev=dojo.getObject(name, false, obj);
					if(typeof prev != "undefined"){
						if(dojo.isArray(prev)){
							prev.push(value);
						}else{
							dojo.setObject(name, [prev, value], obj);
						}
					}else{
						// unique name
						dojo.setObject(name, value, obj);
					}
				}
			});

			/***
			 * code for plain input boxes (see also dojo.formToObject, can we use that instead of this code?
			 * but it doesn't understand [] notation, presumably)
			var obj = { };
			dojo.forEach(this.containerNode.elements, function(elm){
				if(!elm.name)	{
					return;		// like "continue"
				}
				var namePath = elm.name.split(".");
				var myObj=obj;
				var name=namePath[namePath.length-1];
				for(var j=1,len2=namePath.length;j<len2;++j){
					var nameIndex = null;
					var p=namePath[j - 1];
					var nameA=p.split("[");
					if(nameA.length > 1){
						if(typeof(myObj[nameA[0]]) == "undefined"){
							myObj[nameA[0]]=[ ];
						} // if
						nameIndex=parseInt(nameA[1]);
						if(typeof(myObj[nameA[0]][nameIndex]) == "undefined"){
							myObj[nameA[0]][nameIndex] = { };
						}
					} else if(typeof(myObj[nameA[0]]) == "undefined"){
						myObj[nameA[0]] = { }
					} // if

					if(nameA.length == 1){
						myObj=myObj[nameA[0]];
					} else{
						myObj=myObj[nameA[0]][nameIndex];
					} // if
				} // for

				if((elm.type != "select-multiple" && elm.type != "checkbox" && elm.type != "radio") || (elm.type == "radio" && elm.checked)){
					if(name == name.split("[")[0]){
						myObj[name]=elm.value;
					} else{
						// can not set value when there is no name
					}
				} else if(elm.type == "checkbox" && elm.checked){
					if(typeof(myObj[name]) == 'undefined'){
						myObj[name]=[ ];
					}
					myObj[name].push(elm.value);
				} else if(elm.type == "select-multiple"){
					if(typeof(myObj[name]) == 'undefined'){
						myObj[name]=[ ];
					}
					for(var jdx=0,len3=elm.options.length; jdx<len3; ++jdx){
						if(elm.options[jdx].selected){
							myObj[name].push(elm.options[jdx].value);
						}
					}
				} // if
				name=undefined;
			}); // forEach
			***/
			return obj;
		},

	 	isValid: function(){
	 		// summary:
	 		//		Returns true if all of the widgets are valid.
			//		Deprecated, will be removed in 2.0.  Use get("state") instead.

			return this.state == "";
		},

		onValidStateChange: function(isValid){
			// summary:
			//		Stub function to connect to if you want to do something
			//		(like disable/enable a submit button) when the valid
			//		state changes on the form as a whole.
			//
			//		Deprecated.  Will be removed in 2.0.  Use watch("state", ...) instead.
		},

		_getState: function(){
			// summary:
			//		Compute what this.state should be based on state of children
			var states = dojo.map(this._descendants, function(w){
				return w.get("state") || "";
			});

			return dojo.indexOf(states, "Error") >= 0 ? "Error" :
				dojo.indexOf(states, "Incomplete") >= 0 ? "Incomplete" : "";
		},

		disconnectChildren: function(){
			// summary:
			//		Remove connections to monitor changes to children's value, error state, and disabled state,
			//		in order to update Form.value and Form.state.
			dojo.forEach(this._childConnections || [], dojo.hitch(this, "disconnect"));
			dojo.forEach(this._childWatches || [], function(w){ w.unwatch(); });
		},

		connectChildren: function(/*Boolean*/ inStartup){
			// summary:
			//		Setup connections to monitor changes to children's value, error state, and disabled state,
			//		in order to update Form.value and Form.state.
			//
			//		You can call this function directly, ex. in the event that you
			//		programmatically add a widget to the form *after* the form has been
			//		initialized.

			var _this = this;

			// Remove old connections, if any
			this.disconnectChildren();

			this._descendants = this.getDescendants();

			// (Re)set this.value and this.state.   Send watch() notifications but not on startup.
			var set = inStartup ? function(name, val){ _this[name] = val; } : dojo.hitch(this, "_set");
			set("value", this.get("value"));
			set("state", this._getState());

			// Monitor changes to error state and disabled state in order to update
			// Form.state
			var conns = (this._childConnections = []),
				watches = (this._childWatches = []);
			dojo.forEach(dojo.filter(this._descendants,
				function(item){ return item.validate; }
			),
			function(widget){
				// We are interested in whenever the widget changes validity state - or
				// whenever the disabled attribute on that widget is changed.
				dojo.forEach(["state", "disabled"], function(attr){
					watches.push(widget.watch(attr, function(attr, oldVal, newVal){
						_this.set("state", _this._getState());
					}));
				});
			});

			// And monitor calls to child.onChange so we can update this.value
			var onChange = function(){
				// summary:
				//		Called when child's value or disabled state changes
				
				// Use setTimeout() to collapse value changes in multiple children into a single
				// update to my value.   Multiple updates will occur on:
				//	1. Form.set()
				//	2. Form.reset()
				//	3. user selecting a radio button (which will de-select another radio button,
				//		 causing two onChange events)
				if(_this._onChangeDelayTimer){
					clearTimeout(_this._onChangeDelayTimer);
				}
				_this._onChangeDelayTimer = setTimeout(function(){
					delete _this._onChangeDelayTimer;
					_this._set("value", _this.get("value"));
				}, 10);
			};
			dojo.forEach(
				dojo.filter(this._descendants, function(item){ return item.onChange; } ),
				function(widget){
					// When a child widget's value changes,
					// the efficient thing to do is to just update that one attribute in this.value,
					// but that gets a little complicated when a checkbox is checked/unchecked
					// since this.value["checkboxName"] contains an array of all the checkboxes w/the same name.
					// Doing simple thing for now.
					conns.push(_this.connect(widget, "onChange", onChange));

					// Disabling/enabling a child widget should remove it's value from this.value.
					// Again, this code could be more efficient, doing simple thing for now.
					watches.push(widget.watch("disabled", onChange));
				}
			);
		},

		startup: function(){
			this.inherited(arguments);

			// Initialize value and valid/invalid state tracking.  Needs to be done in startup()
			// so that children are initialized.
			this.connectChildren(true);

			// Make state change call onValidStateChange(), will be removed in 2.0
			this.watch("state", function(attr, oldVal, newVal){ this.onValidStateChange(newVal == ""); });
		},

		destroy: function(){
			this.disconnectChildren();
			this.inherited(arguments);
		}

	});

}

if(!dojo._hasResource["dijit.form.Form"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form.Form"] = true;
dojo.provide("dijit.form.Form");






dojo.declare(
	"dijit.form.Form",
	[dijit._Widget, dijit._Templated, dijit.form._FormMixin, dijit.layout._ContentPaneResizeMixin],
	{
		// summary:
		//		Widget corresponding to HTML form tag, for validation and serialization
		//
		// example:
		//	|	<form dojoType="dijit.form.Form" id="myForm">
		//	|		Name: <input type="text" name="name" />
		//	|	</form>
		//	|	myObj = {name: "John Doe"};
		//	|	dijit.byId('myForm').set('value', myObj);
		//	|
		//	|	myObj=dijit.byId('myForm').get('value');

		// HTML <FORM> attributes

		// name: String?
		//		Name of form for scripting.
		name: "",

		// action: String?
		//		Server-side form handler.
		action: "",

		// method: String?
		//		HTTP method used to submit the form, either "GET" or "POST".
		method: "",

		// encType: String?
		//		Encoding type for the form, ex: application/x-www-form-urlencoded.
		encType: "",

		// accept-charset: String?
		//		List of supported charsets.
		"accept-charset": "",

		// accept: String?
		//		List of MIME types for file upload.
		accept: "",

		// target: String?
		//		Target frame for the document to be opened in.
		target: "",

		templateString: "<form dojoAttachPoint='containerNode' dojoAttachEvent='onreset:_onReset,onsubmit:_onSubmit' ${!nameAttrSetting}></form>",

		attributeMap: dojo.delegate(dijit._Widget.prototype.attributeMap, {
			action: "",
			method: "",
			encType: "",
			"accept-charset": "",
			accept: "",
			target: ""
		}),

		postMixInProperties: function(){
			// Setup name=foo string to be referenced from the template (but only if a name has been specified)
			// Unfortunately we can't use attributeMap to set the name due to IE limitations, see #8660
			this.nameAttrSetting = this.name ? ("name='" + this.name + "'") : "";
			this.inherited(arguments);
		},

		execute: function(/*Object*/ formContents){
			// summary:
			//		Deprecated: use submit()
			// tags:
			//		deprecated
		},

		onExecute: function(){
			// summary:
			//		Deprecated: use onSubmit()
			// tags:
			//		deprecated
		},

		_setEncTypeAttr: function(/*String*/ value){
			this.encType = value;
			dojo.attr(this.domNode, "encType", value);
			if(dojo.isIE){ this.domNode.encoding = value; }
		},

		postCreate: function(){
			// IE tries to hide encType
			// TODO: remove in 2.0, no longer necessary with data-dojo-params
			if(dojo.isIE && this.srcNodeRef && this.srcNodeRef.attributes){
				var item = this.srcNodeRef.attributes.getNamedItem('encType');
				if(item && !item.specified && (typeof item.value == "string")){
					this.set('encType', item.value);
				}
			}
			this.inherited(arguments);
		},

		reset: function(/*Event?*/ e){
			// summary:
			//		restores all widget values back to their init values,
			//		calls onReset() which can cancel the reset by returning false

			// create fake event so we can know if preventDefault() is called
			var faux = {
				returnValue: true, // the IE way
				preventDefault: function(){ // not IE
							this.returnValue = false;
						},
				stopPropagation: function(){},
				currentTarget: e ? e.target : this.domNode,
				target: e ? e.target : this.domNode
			};
			// if return value is not exactly false, and haven't called preventDefault(), then reset
			if(!(this.onReset(faux) === false) && faux.returnValue){
				this.inherited(arguments, []);
			}
		},

		onReset: function(/*Event?*/ e){
			// summary:
			//		Callback when user resets the form. This method is intended
			//		to be over-ridden. When the `reset` method is called
			//		programmatically, the return value from `onReset` is used
			//		to compute whether or not resetting should proceed
			// tags:
			//		callback
			return true; // Boolean
		},

		_onReset: function(e){
			this.reset(e);
			dojo.stopEvent(e);
			return false;
		},

		_onSubmit: function(e){
			var fp = dijit.form.Form.prototype;
			// TODO: remove this if statement beginning with 2.0
			if(this.execute != fp.execute || this.onExecute != fp.onExecute){
				dojo.deprecated("dijit.form.Form:execute()/onExecute() are deprecated. Use onSubmit() instead.", "", "2.0");
				this.onExecute();
				this.execute(this.getValues());
			}
			if(this.onSubmit(e) === false){ // only exactly false stops submit
				dojo.stopEvent(e);
			}
		},

		onSubmit: function(/*Event?*/ e){
			// summary:
			//		Callback when user submits the form.
			// description:
			//		This method is intended to be over-ridden, but by default it checks and
			//		returns the validity of form elements. When the `submit`
			//		method is called programmatically, the return value from
			//		`onSubmit` is used to compute whether or not submission
			//		should proceed
			// tags:
			//		extension

			return this.isValid(); // Boolean
		},

		submit: function(){
			// summary:
			//		programmatically submit form if and only if the `onSubmit` returns true
			if(!(this.onSubmit() === false)){
				this.containerNode.submit();
			}
		}
	}
);

}

if(!dojo._hasResource["dijit._DialogMixin"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._DialogMixin"] = true;
dojo.provide("dijit._DialogMixin");



dojo.declare("dijit._DialogMixin", null,
	{
		// summary:
		//		This provides functions useful to Dialog and TooltipDialog

		attributeMap: dijit._Widget.prototype.attributeMap,

		execute: function(/*Object*/ formContents){
			// summary:
			//		Callback when the user hits the submit button.
			//		Override this method to handle Dialog execution.
			// description:
			//		After the user has pressed the submit button, the Dialog
			//		first calls onExecute() to notify the container to hide the
			//		dialog and restore focus to wherever it used to be.
			//
			//		*Then* this method is called.
			// type:
			//		callback
		},

		onCancel: function(){
			// summary:
			//	    Called when user has pressed the Dialog's cancel button, to notify container.
			// description:
			//	    Developer shouldn't override or connect to this method;
			//		it's a private communication device between the TooltipDialog
			//		and the thing that opened it (ex: `dijit.form.DropDownButton`)
			// type:
			//		protected
		},

		onExecute: function(){
			// summary:
			//	    Called when user has pressed the dialog's OK button, to notify container.
			// description:
			//	    Developer shouldn't override or connect to this method;
			//		it's a private communication device between the TooltipDialog
			//		and the thing that opened it (ex: `dijit.form.DropDownButton`)
			// type:
			//		protected
		},

		_onSubmit: function(){
			// summary:
			//		Callback when user hits submit button
			// type:
			//		protected
			this.onExecute();	// notify container that we are about to execute
			this.execute(this.get('value'));
		},

		_getFocusItems: function(){
			// summary:
			//		Finds focusable items in dialog,
			//		and sets this._firstFocusItem and this._lastFocusItem
			// tags:
			//		protected

			var elems = dijit._getTabNavigable(this.containerNode);
			this._firstFocusItem = elems.lowest || elems.first || this.closeButtonNode || this.domNode;
			this._lastFocusItem = elems.last || elems.highest || this._firstFocusItem;
		}
	}
);

}

if(!dojo._hasResource["dijit.DialogUnderlay"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.DialogUnderlay"] = true;
dojo.provide("dijit.DialogUnderlay");





dojo.declare(
	"dijit.DialogUnderlay",
	[dijit._Widget, dijit._Templated],
	{
		// summary:
		//		The component that blocks the screen behind a `dijit.Dialog`
		//
		// description:
		// 		A component used to block input behind a `dijit.Dialog`. Only a single
		//		instance of this widget is created by `dijit.Dialog`, and saved as
		//		a reference to be shared between all Dialogs as `dijit._underlay`
		//
		//		The underlay itself can be styled based on and id:
		//	|	#myDialog_underlay { background-color:red; }
		//
		//		In the case of `dijit.Dialog`, this id is based on the id of the Dialog,
		//		suffixed with _underlay.

		// Template has two divs; outer div is used for fade-in/fade-out, and also to hold background iframe.
		// Inner div has opacity specified in CSS file.
		templateString: "<div class='dijitDialogUnderlayWrapper'><div class='dijitDialogUnderlay' dojoAttachPoint='node'></div></div>",

		// Parameters on creation or updatable later

		// dialogId: String
		//		Id of the dialog.... DialogUnderlay's id is based on this id
		dialogId: "",

		// class: String
		//		This class name is used on the DialogUnderlay node, in addition to dijitDialogUnderlay
		"class": "",

		attributeMap: { id: "domNode" },

		_setDialogIdAttr: function(id){
			dojo.attr(this.node, "id", id + "_underlay");
			this._set("dialogId", id);
		},

		_setClassAttr: function(clazz){
			this.node.className = "dijitDialogUnderlay " + clazz;
			this._set("class", clazz);
		},

		postCreate: function(){
			// summary:
			//		Append the underlay to the body
			dojo.body().appendChild(this.domNode);
		},

		layout: function(){
			// summary:
			//		Sets the background to the size of the viewport
			//
			// description:
			//		Sets the background to the size of the viewport (rather than the size
			//		of the document) since we need to cover the whole browser window, even
			//		if the document is only a few lines long.
			// tags:
			//		private

			var is = this.node.style,
				os = this.domNode.style;

			// hide the background temporarily, so that the background itself isn't
			// causing scrollbars to appear (might happen when user shrinks browser
			// window and then we are called to resize)
			os.display = "none";

			// then resize and show
			var viewport = dojo.window.getBox();
			os.top = viewport.t + "px";
			os.left = viewport.l + "px";
			is.width = viewport.w + "px";
			is.height = viewport.h + "px";
			os.display = "block";
		},

		show: function(){
			// summary:
			//		Show the dialog underlay
			this.domNode.style.display = "block";
			this.layout();
			this.bgIframe = new dijit.BackgroundIframe(this.domNode);
		},

		hide: function(){
			// summary:
			//		Hides the dialog underlay
			this.bgIframe.destroy();
			delete this.bgIframe;
			this.domNode.style.display = "none";
		}
	}
);

}

if(!dojo._hasResource["dijit.TooltipDialog"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.TooltipDialog"] = true;
dojo.provide("dijit.TooltipDialog");






dojo.declare(
		"dijit.TooltipDialog",
		[dijit.layout.ContentPane, dijit._Templated, dijit.form._FormMixin, dijit._DialogMixin],
		{
			// summary:
			//		Pops up a dialog that appears like a Tooltip

			// title: String
			// 		Description of tooltip dialog (required for a11y)
			title: "",

			// doLayout: [protected] Boolean
			//		Don't change this parameter from the default value.
			//		This ContentPane parameter doesn't make sense for TooltipDialog, since TooltipDialog
			//		is never a child of a layout container, nor can you specify the size of
			//		TooltipDialog in order to control the size of an inner widget.
			doLayout: false,

			// autofocus: Boolean
			// 		A Toggle to modify the default focus behavior of a Dialog, which
			// 		is to focus on the first dialog element after opening the dialog.
			//		False will disable autofocusing. Default: true
			autofocus: true,

			// baseClass: [protected] String
			//		The root className to use for the various states of this widget
			baseClass: "dijitTooltipDialog",

			// _firstFocusItem: [private] [readonly] DomNode
			//		The pointer to the first focusable node in the dialog.
			//		Set by `dijit._DialogMixin._getFocusItems`.
			_firstFocusItem: null,

			// _lastFocusItem: [private] [readonly] DomNode
			//		The pointer to which node has focus prior to our dialog.
			//		Set by `dijit._DialogMixin._getFocusItems`.
			_lastFocusItem: null,

			templateString: dojo.cache("dijit", "templates/TooltipDialog.html", "<div role=\"presentation\" tabIndex=\"-1\">\n\t<div class=\"dijitTooltipContainer\" role=\"presentation\">\n\t\t<div class =\"dijitTooltipContents dijitTooltipFocusNode\" dojoAttachPoint=\"containerNode\" role=\"dialog\"></div>\n\t</div>\n\t<div class=\"dijitTooltipConnector\" role=\"presentation\"></div>\n</div>\n"),

			_setTitleAttr: function(/*String*/ title){
				this.containerNode.title = title;
				this._set("title", title)
			},

			postCreate: function(){
				this.inherited(arguments);
				this.connect(this.containerNode, "onkeypress", "_onKey");
			},

			orient: function(/*DomNode*/ node, /*String*/ aroundCorner, /*String*/ corner){
				// summary:
				//		Configure widget to be displayed in given position relative to the button.
				//		This is called from the dijit.popup code, and should not be called
				//		directly.
				// tags:
				//		protected
				var newC = "dijitTooltipAB" + (corner.charAt(1) == 'L' ? "Left" : "Right")
						+ " dijitTooltip"
						+ (corner.charAt(0) == 'T' ? "Below" : "Above");
				
				dojo.replaceClass(this.domNode, newC, this._currentOrientClass || "");
				this._currentOrientClass = newC;
			},

			focus: function(){
				// summary:
				//		Focus on first field
				this._getFocusItems(this.containerNode);
				dijit.focus(this._firstFocusItem);
			},

			onOpen: function(/*Object*/ pos){
				// summary:
				//		Called when dialog is displayed.
				//		This is called from the dijit.popup code, and should not be called directly.
				// tags:
				//		protected

				this.orient(this.domNode,pos.aroundCorner, pos.corner);
				this._onShow(); // lazy load trigger
			},

			onClose: function(){
				// summary:
				//		Called when dialog is hidden.
				//		This is called from the dijit.popup code, and should not be called directly.
				// tags:
				//		protected
				this.onHide();
			},

			_onKey: function(/*Event*/ evt){
				// summary:
				//		Handler for keyboard events
				// description:
				//		Keep keyboard focus in dialog; close dialog on escape key
				// tags:
				//		private

				var node = evt.target;
				var dk = dojo.keys;
				if(evt.charOrCode === dk.TAB){
					this._getFocusItems(this.containerNode);
				}
				var singleFocusItem = (this._firstFocusItem == this._lastFocusItem);
				if(evt.charOrCode == dk.ESCAPE){
					// Use setTimeout to avoid crash on IE, see #10396.
					setTimeout(dojo.hitch(this, "onCancel"), 0);
					dojo.stopEvent(evt);
				}else if(node == this._firstFocusItem && evt.shiftKey && evt.charOrCode === dk.TAB){
					if(!singleFocusItem){
						dijit.focus(this._lastFocusItem); // send focus to last item in dialog
					}
					dojo.stopEvent(evt);
				}else if(node == this._lastFocusItem && evt.charOrCode === dk.TAB && !evt.shiftKey){
					if(!singleFocusItem){
						dijit.focus(this._firstFocusItem); // send focus to first item in dialog
					}
					dojo.stopEvent(evt);
				}else if(evt.charOrCode === dk.TAB){
					// we want the browser's default tab handling to move focus
					// but we don't want the tab to propagate upwards
					evt.stopPropagation();
				}
			}
		}
	);

}

if(!dojo._hasResource["dijit.Dialog"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.Dialog"] = true;
dojo.provide("dijit.Dialog");















// dijit/TooltipDialog required for back-compat.  TODO: remove in 2.0

/*=====
dijit._underlay = function(kwArgs){
	// summary:
	//		A shared instance of a `dijit.DialogUnderlay`
	//
	// description:
	//		A shared instance of a `dijit.DialogUnderlay` created and
	//		used by `dijit.Dialog`, though never created until some Dialog
	//		or subclass thereof is shown.
};
=====*/
dojo.declare(
	"dijit._DialogBase",
	[dijit._Templated, dijit.form._FormMixin, dijit._DialogMixin, dijit._CssStateMixin],
	{
		// summary:
		//		A modal dialog Widget
		//
		// description:
		//		Pops up a modal dialog window, blocking access to the screen
		//		and also graying out the screen Dialog is extended from
		//		ContentPane so it supports all the same parameters (href, etc.)
		//
		// example:
		// |	<div dojoType="dijit.Dialog" href="test.html"></div>
		//
		// example:
		// |	var foo = new dijit.Dialog({ title: "test dialog", content: "test content" };
		// |	dojo.body().appendChild(foo.domNode);
		// |	foo.startup();

		templateString: dojo.cache("dijit", "templates/Dialog.html", "<div class=\"dijitDialog\" role=\"dialog\" aria-labelledby=\"${id}_title\">\n\t<div dojoAttachPoint=\"titleBar\" class=\"dijitDialogTitleBar\">\n\t<span dojoAttachPoint=\"titleNode\" class=\"dijitDialogTitle\" id=\"${id}_title\"></span>\n\t<span dojoAttachPoint=\"closeButtonNode\" class=\"dijitDialogCloseIcon\" dojoAttachEvent=\"ondijitclick: onCancel\" title=\"${buttonCancel}\" role=\"button\" tabIndex=\"-1\">\n\t\t<span dojoAttachPoint=\"closeText\" class=\"closeText\" title=\"${buttonCancel}\">x</span>\n\t</span>\n\t</div>\n\t\t<div dojoAttachPoint=\"containerNode\" class=\"dijitDialogPaneContent\"></div>\n</div>\n"),

		baseClass: "dijitDialog",

		cssStateNodes: {
			closeButtonNode: "dijitDialogCloseIcon"
		},

		attributeMap: dojo.delegate(dijit._Widget.prototype.attributeMap, {
			title: [
				{ node: "titleNode", type: "innerHTML" },
				{ node: "titleBar", type: "attribute" }
			],
			"aria-describedby":""
		}),

		// open: [readonly] Boolean
		//		True if Dialog is currently displayed on screen.
		open: false,

		// duration: Integer
		//		The time in milliseconds it takes the dialog to fade in and out
		duration: dijit.defaultDuration,

		// refocus: Boolean
		// 		A Toggle to modify the default focus behavior of a Dialog, which
		// 		is to re-focus the element which had focus before being opened.
		//		False will disable refocusing. Default: true
		refocus: true,

		// autofocus: Boolean
		// 		A Toggle to modify the default focus behavior of a Dialog, which
		// 		is to focus on the first dialog element after opening the dialog.
		//		False will disable autofocusing. Default: true
		autofocus: true,

		// _firstFocusItem: [private readonly] DomNode
		//		The pointer to the first focusable node in the dialog.
		//		Set by `dijit._DialogMixin._getFocusItems`.
		_firstFocusItem: null,

		// _lastFocusItem: [private readonly] DomNode
		//		The pointer to which node has focus prior to our dialog.
		//		Set by `dijit._DialogMixin._getFocusItems`.
		_lastFocusItem: null,

		// doLayout: [protected] Boolean
		//		Don't change this parameter from the default value.
		//		This ContentPane parameter doesn't make sense for Dialog, since Dialog
		//		is never a child of a layout container, nor can you specify the size of
		//		Dialog in order to control the size of an inner widget.
		doLayout: false,

		// draggable: Boolean
		//		Toggles the moveable aspect of the Dialog. If true, Dialog
		//		can be dragged by it's title. If false it will remain centered
		//		in the viewport.
		draggable: true,

		//aria-describedby: String
		//		Allows the user to add an aria-describedby attribute onto the dialog.   The value should
		//		be the id of the container element of text that describes the dialog purpose (usually
		//		the first text in the dialog).
		//		<div dojoType="dijit.Dialog" aria-describedby="intro" .....>
		//			<div id="intro">Introductory text</div>
		//			<div>rest of dialog contents</div>
		//		</div>
		"aria-describedby":"",

		postMixInProperties: function(){
			var _nlsResources = dojo.i18n.getLocalization("dijit", "common");
			dojo.mixin(this, _nlsResources);
			this.inherited(arguments);
		},

		postCreate: function(){
			dojo.style(this.domNode, {
				display: "none",
				position:"absolute"
			});
			dojo.body().appendChild(this.domNode);

			this.inherited(arguments);

			this.connect(this, "onExecute", "hide");
			this.connect(this, "onCancel", "hide");
			this._modalconnects = [];
		},

		onLoad: function(){
			// summary:
			//		Called when data has been loaded from an href.
			//		Unlike most other callbacks, this function can be connected to (via `dojo.connect`)
			//		but should *not* be overridden.
			// tags:
			//		callback

			// when href is specified we need to reposition the dialog after the data is loaded
			// and find the focusable elements
			this._position();
			if(this.autofocus && dijit._DialogLevelManager.isTop(this)){
				this._getFocusItems(this.domNode);
				dijit.focus(this._firstFocusItem);
			}
			this.inherited(arguments);
		},

		_endDrag: function(e){
			// summary:
			//		Called after dragging the Dialog. Saves the position of the dialog in the viewport.
			// tags:
			//		private
			if(e && e.node && e.node === this.domNode){
				this._relativePosition = dojo.position(e.node);
			}
		},

		_setup: function(){
			// summary:
			//		Stuff we need to do before showing the Dialog for the first
			//		time (but we defer it until right beforehand, for
			//		performance reasons).
			// tags:
			//		private

			var node = this.domNode;

			if(this.titleBar && this.draggable){
				this._moveable = (dojo.isIE == 6) ?
					new dojo.dnd.TimedMoveable(node, { handle: this.titleBar }) :	// prevent overload, see #5285
					new dojo.dnd.Moveable(node, { handle: this.titleBar, timeout: 0 });
				this._dndListener = dojo.subscribe("/dnd/move/stop",this,"_endDrag");
			}else{
				dojo.addClass(node,"dijitDialogFixed");
			}

			this.underlayAttrs = {
				dialogId: this.id,
				"class": dojo.map(this["class"].split(/\s/), function(s){ return s+"_underlay"; }).join(" ")
			};
		},

		_size: function(){
			// summary:
			// 		If necessary, shrink dialog contents so dialog fits in viewport
			// tags:
			//		private

			this._checkIfSingleChild();

			// If we resized the dialog contents earlier, reset them back to original size, so
			// that if the user later increases the viewport size, the dialog can display w/out a scrollbar.
			// Need to do this before the dojo.marginBox(this.domNode) call below.
			if(this._singleChild){
				if(this._singleChildOriginalStyle){
					this._singleChild.domNode.style.cssText = this._singleChildOriginalStyle;
				}
				delete this._singleChildOriginalStyle;
			}else{
				dojo.style(this.containerNode, {
					width:"auto",
					height:"auto"
				});
			}

			var mb = dojo._getMarginSize(this.domNode);
			var viewport = dojo.window.getBox();
			if(mb.w >= viewport.w || mb.h >= viewport.h){
				// Reduce size of dialog contents so that dialog fits in viewport

				var w = Math.min(mb.w, Math.floor(viewport.w * 0.75)),
					h = Math.min(mb.h, Math.floor(viewport.h * 0.75));

				if(this._singleChild && this._singleChild.resize){
					this._singleChildOriginalStyle = this._singleChild.domNode.style.cssText;
					this._singleChild.resize({w: w, h: h});
				}else{
					dojo.style(this.containerNode, {
						width: w + "px",
						height: h + "px",
						overflow: "auto",
						position: "relative"	// workaround IE bug moving scrollbar or dragging dialog
					});
				}
			}else{
				if(this._singleChild && this._singleChild.resize){
					this._singleChild.resize();
				}
			}
		},

		_position: function(){
			// summary:
			//		Position modal dialog in the viewport. If no relative offset
			//		in the viewport has been determined (by dragging, for instance),
			//		center the node. Otherwise, use the Dialog's stored relative offset,
			//		and position the node to top: left: values based on the viewport.
			// tags:
			//		private
			if(!dojo.hasClass(dojo.body(),"dojoMove")){
				var node = this.domNode,
					viewport = dojo.window.getBox(),
					p = this._relativePosition,
					bb = p ? null : dojo._getBorderBox(node),
					l = Math.floor(viewport.l + (p ? p.x : (viewport.w - bb.w) / 2)),
					t = Math.floor(viewport.t + (p ? p.y : (viewport.h - bb.h) / 2))
				;
				dojo.style(node,{
					left: l + "px",
					top: t + "px"
				});
			}
		},

		_onKey: function(/*Event*/ evt){
			// summary:
			//		Handles the keyboard events for accessibility reasons
			// tags:
			//		private

			if(evt.charOrCode){
				var dk = dojo.keys;
				var node = evt.target;
				if(evt.charOrCode === dk.TAB){
					this._getFocusItems(this.domNode);
				}
				var singleFocusItem = (this._firstFocusItem == this._lastFocusItem);
				// see if we are shift-tabbing from first focusable item on dialog
				if(node == this._firstFocusItem && evt.shiftKey && evt.charOrCode === dk.TAB){
					if(!singleFocusItem){
						dijit.focus(this._lastFocusItem); // send focus to last item in dialog
					}
					dojo.stopEvent(evt);
				}else if(node == this._lastFocusItem && evt.charOrCode === dk.TAB && !evt.shiftKey){
					if(!singleFocusItem){
						dijit.focus(this._firstFocusItem); // send focus to first item in dialog
					}
					dojo.stopEvent(evt);
				}else{
					// see if the key is for the dialog
					while(node){
						if(node == this.domNode || dojo.hasClass(node, "dijitPopup")){
							if(evt.charOrCode == dk.ESCAPE){
								this.onCancel();
							}else{
								return; // just let it go
							}
						}
						node = node.parentNode;
					}
					// this key is for the disabled document window
					if(evt.charOrCode !== dk.TAB){ // allow tabbing into the dialog for a11y
						dojo.stopEvent(evt);
					// opera won't tab to a div
					}else if(!dojo.isOpera){
						try{
							this._firstFocusItem.focus();
						}catch(e){ /*squelch*/ }
					}
				}
			}
		},

		show: function(){
			// summary:
			//		Display the dialog
			// returns: dojo.Deferred
			//		Deferred object that resolves when the display animation is complete

			if(this.open){ return; }

			if(!this._started){
				this.startup();
			}

			// first time we show the dialog, there's some initialization stuff to do
			if(!this._alreadyInitialized){
				this._setup();
				this._alreadyInitialized=true;
			}

			if(this._fadeOutDeferred){
				this._fadeOutDeferred.cancel();
			}

			this._modalconnects.push(dojo.connect(window, "onscroll", this, "layout"));
			this._modalconnects.push(dojo.connect(window, "onresize", this, function(){
				// IE gives spurious resize events and can actually get stuck
				// in an infinite loop if we don't ignore them
				var viewport = dojo.window.getBox();
				if(!this._oldViewport ||
						viewport.h != this._oldViewport.h ||
						viewport.w != this._oldViewport.w){
					this.layout();
					this._oldViewport = viewport;
				}
			}));
			this._modalconnects.push(dojo.connect(this.domNode, "onkeypress", this, "_onKey"));

			dojo.style(this.domNode, {
				opacity:0,
				display:""
			});

			this._set("open", true);
			this._onShow(); // lazy load trigger

			this._size();
			this._position();

			// fade-in Animation object, setup below
			var fadeIn;

			this._fadeInDeferred = new dojo.Deferred(dojo.hitch(this, function(){
				fadeIn.stop();
				delete this._fadeInDeferred;
			}));

			fadeIn = dojo.fadeIn({
				node: this.domNode,
				duration: this.duration,
				beforeBegin: dojo.hitch(this, function(){
					dijit._DialogLevelManager.show(this, this.underlayAttrs);
				}),
				onEnd: dojo.hitch(this, function(){
					if(this.autofocus && dijit._DialogLevelManager.isTop(this)){
						// find focusable items each time dialog is shown since if dialog contains a widget the
						// first focusable items can change
						this._getFocusItems(this.domNode);
						dijit.focus(this._firstFocusItem);
					}
					this._fadeInDeferred.callback(true);
					delete this._fadeInDeferred;
				})
			}).play();

			return this._fadeInDeferred;
		},

		hide: function(){
			// summary:
			//		Hide the dialog
			// returns: dojo.Deferred
			//		Deferred object that resolves when the hide animation is complete

			// if we haven't been initialized yet then we aren't showing and we can just return
			if(!this._alreadyInitialized){
				return;
			}
			if(this._fadeInDeferred){
				this._fadeInDeferred.cancel();
			}

			// fade-in Animation object, setup below
			var fadeOut;

			this._fadeOutDeferred = new dojo.Deferred(dojo.hitch(this, function(){
				fadeOut.stop();
				delete this._fadeOutDeferred;
			}));

			/*
			// original code from dojo/dijit
			fadeOut = dojo.fadeOut({
				node: this.domNode,
				duration: this.duration,
				onEnd: dojo.hitch(this, function(){
					this.domNode.style.display = "none";
					dijit._DialogLevelManager.hide(this);
					this.onHide();
					this._fadeOutDeferred.callback(true);
					delete this._fadeOutDeferred;
				})
			 }).play();
			*/

			// changed code from epages
			fadeOut = dojo.fadeOut({
				node: this.domNode,
				duration: this.duration,
				onEnd: dojo.hitch(this, function(){
					if (this.domNode) {
						this.domNode.style.display = "none";
					}
					dijit._DialogLevelManager.hide(this);
					this.onHide();{}
					if (this._fadeOutDeferred && this._fadeOutDeferred.callback) {
						this._fadeOutDeferred.callback(true);
						delete this._fadeOutDeferred;
					}
				})
			 }).play();

			if(this._scrollConnected){
				this._scrollConnected = false;
			}
			dojo.forEach(this._modalconnects, dojo.disconnect);
			this._modalconnects = [];

			if(this._relativePosition){
				delete this._relativePosition;
			}
			this._set("open", false);

			return this._fadeOutDeferred;
		},

		layout: function(){
			// summary:
			//		Position the Dialog and the underlay
			// tags:
			//		private
			if(this.domNode.style.display != "none"){
				if(dijit._underlay){	// avoid race condition during show()
					dijit._underlay.layout();
				}
				this._position();
			}
		},

		destroy: function(){
			if(this._fadeInDeferred){
				this._fadeInDeferred.cancel();
			}
			if(this._fadeOutDeferred){
				this._fadeOutDeferred.cancel();
			}
			if(this._moveable){
				this._moveable.destroy();
			}
			if(this._dndListener){
				dojo.unsubscribe(this._dndListener);
			}
			dojo.forEach(this._modalconnects, dojo.disconnect);

			dijit._DialogLevelManager.hide(this);

			this.inherited(arguments);
		}
	}
);

dojo.declare(
	"dijit.Dialog",
	[dijit.layout.ContentPane, dijit._DialogBase],
	{}
);

dijit._DialogLevelManager = {
	// summary:
	//		Controls the various active "levels" on the page, starting with the
	//		stuff initially visible on the page (at z-index 0), and then having an entry for
	//		each Dialog shown.

	show: function(/*dijit._Widget*/ dialog, /*Object*/ underlayAttrs){
		// summary:
		//		Call right before fade-in animation for new dialog.
		//		Saves current focus, displays/adjusts underlay for new dialog,
		//		and sets the z-index of the dialog itself.
		//
		//		New dialog will be displayed on top of all currently displayed dialogs.
		//
		//		Caller is responsible for setting focus in new dialog after the fade-in
		//		animation completes.

		var ds = dijit._dialogStack;

		// Save current focus
		ds[ds.length-1].focus = dijit.getFocus(dialog);

		// Display the underlay, or if already displayed then adjust for this new dialog
		var underlay = dijit._underlay;
		if(!underlay || underlay._destroyed){
			underlay = dijit._underlay = new dijit.DialogUnderlay(underlayAttrs);
		}else{
			underlay.set(dialog.underlayAttrs);
		}

		// Set z-index a bit above previous dialog
		var zIndex = ds[ds.length-1].dialog ? ds[ds.length-1].zIndex + 2 : 400;
		if(ds.length == 1){	// first dialog
			underlay.show();
		}
		dojo.style(dijit._underlay.domNode, 'zIndex', zIndex - 1);

		// Dialog
		dojo.style(dialog.domNode, 'zIndex', zIndex);

		ds.push({dialog: dialog, underlayAttrs: underlayAttrs, zIndex: zIndex});
	},

	hide: function(/*dijit._Widget*/ dialog){
		// summary:
		//		Called when the specified dialog is hidden/destroyed, after the fade-out
		//		animation ends, in order to reset page focus, fix the underlay, etc.
		//		If the specified dialog isn't open then does nothing.
		//
		//		Caller is responsible for either setting display:none on the dialog domNode,
		//		or calling dijit.popup.hide(), or removing it from the page DOM.

		var ds = dijit._dialogStack;

		if(ds[ds.length-1].dialog == dialog){
			// Removing the top (or only) dialog in the stack, return focus
			// to previous dialog

			ds.pop();

			var pd = ds[ds.length-1];	// the new active dialog (or the base page itself)

			// Adjust underlay
			if(ds.length == 1){
				// Returning to original page.
				// Hide the underlay, unless the underlay widget has already been destroyed
				// because we are being called during page unload (when all widgets are destroyed)
				if(!dijit._underlay._destroyed){
					dijit._underlay.hide();
				}
			}else{
				// Popping back to previous dialog, adjust underlay
				dojo.style(dijit._underlay.domNode, 'zIndex', pd.zIndex - 1);
				dijit._underlay.set(pd.underlayAttrs);
			}

			// Adjust focus
			if(dialog.refocus){
				// If we are returning control to a previous dialog but for some reason
				// that dialog didn't have a focused field, set focus to first focusable item.
				// This situation could happen if two dialogs appeared at nearly the same time,
				// since a dialog doesn't set it's focus until the fade-in is finished.
				var focus = pd.focus;
				if(!focus || (pd.dialog && !dojo.isDescendant(focus.node, pd.dialog.domNode))){
					pd.dialog._getFocusItems(pd.dialog.domNode);
					focus = pd.dialog._firstFocusItem;
				}

				try{
					dijit.focus(focus);
				}catch(e){
					/* focus() will fail if user opened the dialog by clicking a non-focusable element */
				}
			}
		}else{
			// Removing a dialog out of order (#9944, #10705).
			// Don't need to mess with underlay or z-index or anything.
			var idx = dojo.indexOf(dojo.map(ds, function(elem){return elem.dialog}), dialog);
			if(idx != -1){
				ds.splice(idx, 1);
			}
		}
	},

	isTop: function(/*dijit._Widget*/ dialog){
		// summary:
		//		Returns true if specified Dialog is the top in the task
		var ds = dijit._dialogStack;
		return ds[ds.length-1].dialog == dialog;
	}
};

// Stack representing the various active "levels" on the page, starting with the
// stuff initially visible on the page (at z-index 0), and then having an entry for
// each Dialog shown.
// Each element in stack has form {
//		dialog: dialogWidget,
//		focus: returnFromGetFocus(),
//		underlayAttrs: attributes to set on underlay (when this widget is active)
// }
dijit._dialogStack = [
	{dialog: null, focus: null, underlayAttrs: null}	// entry for stuff at z-index: 0
];

}

if(!dojo._hasResource['epages.io.text']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.io.text'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.io.text');

epages.io.Text = function (/*String*/url) {
	// summary:
	//		Loads text data from url and set the received text data to the target object.
	// example:
	// 	  epages.io.Text('http://www.mydomain.de/header.text', $(header));
	if (url === undefined){
		return;
	}
	return this.load(url);
};

epages.io.Text.prototype = {
	load: function (/*String*/url) {
		// summary:
		//		Loads text data from url and set the received text data to the target object.
		// example:
		// 	  textLoader = new epages.io.Text();
		//		textLoader.load('http://www.mydomain.de/header.text', $(header));
		var targetObject = {};
	  dojo.xhrGet({
	    url:  url,
	    sync: true,
	    load: function(data, evt){
	      targetObject.text = data;
	    },
	    handleAs: "text"
	  });
	  return targetObject.text; //String
	},

	test: function(/*epages.Test*/eTest) {
		// summary:
		//		test this package
		// example:
		// 	  var package = new epages.io.Text();
		//		boolean = package.test(eTest);
		//		// returns true if all test are successfully
		eTest.setPlanned(2);
		eTest.ok(1, 'loaded');

		var text = this.load('htmlTest.inc');
		eTest.ok(text == 'Header loaded successfully.', 'load header');

		// closing async test
		return eTest.planned == eTest.correct ? true : false; //Boolean
	}
};

}

if(!dojo._hasResource["epages.widget.Button"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Button"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.widget.Button");




epages.widget.ButtonChangeForms = []; // global array of all buttons

dojo.declare(
	"epages.widget.Button",
	[dijit._Widget], {


		name:    '', // String - name of button
		button:  '', // String - execute|batch|confirm|submit
		'class': '', // String - additional class parameter for outer div element
		onclick: '', // function - execute this string on click
		value:   '', // String - label of button
		disabled:'', // String - disable button like submit
		active:  '', // String - enable active class on startup
		iconSrc: '', // String - path to any icon image
		submit:  '', // String - do submit on click
		triggerClass: '',
		disableOnClick: '',
		buttonContainerNode: undefined,// DomNode - always the original input element wich is wrapped by buttonContainerNode

		_returnFalse: "", // return false handle container

		_removeEventList: undefined,
		_onClickEvents: undefined,

		postCreate: function() {
			this.inherited('postCreate', arguments);

			var el = this.domNode;

			var type;
			var triggerClass = '';
			if (dojo.hasClass(el, 'RunButton')) {
				type = 'batch';
			}else if (dojo.hasClass(el, 'SaveButton')){
				type = 'submit';
			}else if (dojo.hasClass(el, 'DeleteButton')){
				type = 'confirm';
			}else if (dojo.hasClass(el, 'CancelButton')){
				type = 'confirm';
			}else if (dojo.hasClass(el, 'ExtraButton')){
				type = 'execute';
				triggerClass="ExtraButtonTrigger";
			}else if (dojo.hasClass(el, 'SearchButton')){
				type = 'execute';
			}else {
				type = 'confirm';
			}
			this.button = type;

			var submit = '';
			if (el.type == 'image' ||el.type == 'submit') {
				submit = 'true';
			}

			var disabled = '';
			/*if (el.disabled) {
				disabled = 'true';
			}*/
			if (el.getAttribute("triggerClass") != null && el.getAttribute("triggerClass") != '') {
				triggerClass = el.getAttribute("triggerClass");
			}

			this.triggerClass = triggerClass;
			this.disabled = disabled;
			this.submit = submit;

			//create outer element
			var buttonContainerNode = document.createElement("span");

			//export all classes to new button tag
			buttonContainerNode.setAttribute((document.all ? "className" : "class"), this["class"]);
			if (!dojo.hasClass(buttonContainerNode, 'Button')) {
				dojo.addClass(buttonContainerNode, 'Button');
			}
			dojo.addClass(buttonContainerNode, 'EnableHover');

			//insert button at the right place
			this.domNode.parentNode.insertBefore(buttonContainerNode, this.domNode);

			//transform old input into new button
			this.domNode.setAttribute((document.all ? "className" : "class"), "ButtonContainer");
			buttonContainerNode.appendChild(this.domNode);

			// is a submit button ?
			this.submit = this.submit != '' || this.button == 'submit';

			// disableOnClick - default settings for undefined
			if(this.disableOnClick == "" && (this.domNode.type == "submit" || this.domNode.href)){
				this.disableOnClick = true;
			}

			// disableOnClick - to bool
			this.disableOnClick = epages.string.toBoolean(this.disableOnClick);

			// is disabled ?
			//this.disabled = this.disabled != '' || this.button == 'submit';
			if (this.disabled) {
				this.domNode.disabled = true;
				this._returnFalse = dojo.connect(this.domNode, "click", this, function(){ return false; });
				dojo.addClass(buttonContainerNode, 'Disabled');
			}

			// is active on startup
			if (this.active!='') {
				dojo.addClass(buttonContainerNode, 'Active');
			}

			// insert icon if an image url exists
			if (this.iconSrc) {
				var buttonIconContainer = document.createElement("span");

				if(this.onclick) {
					buttonIconContainer.onclick = this.onclick;
				}
				if(this.onmousedown) {
					buttonIconContainer.onmousedown = this.onmousedown;
				}
				if(this.onmouseup) {
					buttonIconContainer.onmouseup = this.onmouseup;
				}
				if(this.onmouseover) {
					buttonIconContainer.onmouseover = this.onmouseover;
				}

				buttonIconContainer.form = this.domNode.form;
				buttonIconContainer.className = "ButtonIconContainer";
				//buttonIconContainer.style.background = "url(" + this.iconSrc + ") no-repeat center";

				buttonIconContainer.innerHTML = "<i class='Sprite " + this.iconSrc + "'></i>";

				buttonContainerNode.insertBefore(buttonIconContainer, this.domNode);
				dojo.addClass(this.domNode, "ButtonIconPadding");
			}

			// add events to trigger activation of buttons
			this.form = this.domNode.form;
			this._removeEventList = []; // remove events later if button is enabled
			this._onClickEvents = []; // event list for click, enable or disable

			if (this.button == 'execute' || this.button == 'submit' || this.button == 'batch' ) {
				var inputs = this.form.elements;
				// filter triggerClass or remove NoButtonTrigger
				if (this.triggerClass != '') {
					inputs = dojo.filter(inputs, function (el) { return dojo.hasClass(el, this.triggerClass); }, this);
				} else {
					inputs = dojo.filter(inputs, function (el) { return ( !dojo.hasClass(el, 'NoButtonTrigger') && !dojo.attr( el, 'formnovalidate' ) ) ? true : false; });
				}
				// filter BatchTrigger
				if (this.button == 'batch') {
					inputs = dojo.filter(inputs, function (el) { return dojo.hasClass(el, 'RunButtonTrigger'); });
				} else {
					inputs = dojo.filter(inputs, function (el) { return !dojo.hasClass(el, 'RunButtonTrigger'); });
				}

				// add change events to enable buttons
				this.registerInputs(inputs);
			}
			// buttonContainerNode as widget property
			this.buttonContainerNode = buttonContainerNode;

			// register on click
			if (!this.disabled) {
				this._registerEvents();
			}

			this.enable();
		},

		registerInput: function(el) {
			var it=el.type;
			if (it == "hidden" || it == "text" || it == "password" || it == "file" || it == "textarea") {
				this._removeEventList.push(dojo.connect(el, 'keydown', this, '_OnKeyPressInput')); // fastest activation
				this._removeEventList.push(dojo.connect(el, 'change', this, '_OnKeyPressInput')); // need for other javascripts
				this._removeEventList.push(dojo.connect(el, 'paste',  this, '_OnKeyPressInput')); // need for paste with mouse (right context menu)
				this._removeEventList.push(dojo.connect(el, 'blur', this, '_OnKeyPressInput')); // need for select old entry from browser history
			} else if (it == "checkbox" || it == "radio") {
				this._removeEventList.push(dojo.connect(el, 'click', this, '_OnKeyPressInput'));
				this._removeEventList.push(dojo.connect(el, 'keypress', this, '_OnKeyPressInput'));
				this._removeEventList.push(dojo.connect(el, 'change', this, '_OnKeyPressInput'));
			} else if (el.tagName == "SELECT") {
				this._removeEventList.push(dojo.connect(el, 'change', this, '_OnKeyPressInput'));
			}
		},

		registerInputs: function(inputs){
			dojo.forEach(inputs, function (el) {
				this.registerInput(el);
			}, this);
		},

		_OnKeyPressInput: function (evt) {
			if(!this.domNode.parentNode.className.match("Active")) {
				var t = evt.target;
				if(t.className.match("DialogError") || (evt.type =='blur' && (t.type == 'text' || t.type == 'textarea') && t.defaultValue === t.value)){
					return;
				}

				if(epages.vars.activeButton) {
					dojo.removeClass(epages.vars.activeButton, "Active");
				}
				epages.vars.activeButton = this.domNode.parentNode;

				dojo.addClass(this.domNode.parentNode, 'Active');
				dojo.removeClass(this.domNode.parentNode, 'Disabled');

				if (this.disabled){
					this.enable();
				}

				if (this.button == 'submit') {
					if (!document.title.match(/\*$/)){
						document.title+="*";
					}
					epages.widget.ButtonChangeForms.push(this.form);
				}
			}
		},

		_OnClick: function (evt) {
			if(!this.disabled && this.disableOnClick) {
				dojo.publish("interactionRestrictor/suspend", ["interactionRestrictorFor_" + this.id, this.domNode.parentNode, true]);
				/* prevent double click */
				setTimeout(dojo.hitch(this, function(){ this.disable(); }), 20);

/*				if( this.button != 'submit' && this.button != 'confirm' ){ */
					setTimeout(dojo.hitch(this, function() {
						this.enable();
						dojo.removeClass(this.domNode.parentNode, 'Active');
						dojo.publish("interactionRestrictor/permit", ["interactionRestrictorFor_" + this.id]);
					}), 2000);
/*				} */
			}
			if (this.button == 'confirm' || this.button == 'submit') {
				epages.widget.ButtonChangeForms = [];
			} else if (this.button != 'batch'){
				var formNode = this.form;
				epages.widget.ButtonChangeForms = dojo.filter(epages.widget.ButtonChangeForms, function (el) {
					return el != formNode;
				});
			}
		},


		_OnMouseDown: function() {
		  //summary: emulates the ":active" pseudoclass in the MSIE
			dojo.addClass(this.domNode.parentNode, 'ButtonClicked');
			dojo.addClass(this.domNode, 'ButtonContainerClicked');
		},

		_OnMouseUp: function() {
			dojo.removeClass(this.domNode.parentNode, 'ButtonClicked');
			dojo.removeClass(this.domNode, 'ButtonContainerClicked');
		},

		_registerEvents: function () {
			this._onClickEvents.push(dojo.connect(this.domNode,'click', this, '_OnClick'));
			this._onClickEvents.push(dojo.connect(this.domNode,'mousedown', this, '_OnMouseDown'));
			this._onClickEvents.push(dojo.connect(this.domNode,'mouseup', this, '_OnMouseUp'));
			this._onClickEvents.push(dojo.connect(this.domNode,'mouseout', this, '_OnMouseUp'));
		},

		enable: function () {
				this.disabled = false;
				this.domNode.disabled = false;
				dojo.disconnect(this._returnFalse);

				// switch classes
				dojo.addClass(this.domNode.parentNode, 'Active');
				dojo.removeClass(this.domNode.parentNode, 'Disabled');
				if(this._onClickEvents.length == 0) {
					this._registerEvents();
				}
		},

		disable: function () {
			this.disabled = true;
			this.domNode.disabled = true;

			dojo.disconnect(this._returnFalse);
			this._returnFalse = dojo.connect(this.domNode, "click", this, function(){ return false; });

			// switch classes
			dojo.removeClass(this.domNode.parentNode, 'Active');
			dojo.addClass(this.domNode.parentNode, 'Disabled');

			// unregister events
			dojo.forEach(this._onClickEvents, dojo.disconnect);
			this._onClickEvents = [];
		},

		disableIfEmpty: function (value) {
			if (value == ""){
				this.disable();
			}else{
				this.enable();
			}
		},

		hide: function() {
			dojo.addClass(this.buttonContainerNode, "HideElement");
		},

		show: function() {
			dojo.removeClass(this.buttonContainerNode, "HideElement");
		}
	}
);

epages.onUnloadFunctions.push(function() {
	return epages.widget.ButtonChangeForms.length > 0;
});

epages.widget.TransformButtons = function (domNode) {
	dojo.forEach(dojo.query('.Button', domNode), function (el) {
		if (el.tagName != 'INPUT' || el.type == 'hidden'){
			return;
		}

		var type;
		var triggerClass = '';
		if (dojo.hasClass(el, 'RunButton')) {
			type = 'batch';
		}else if (dojo.hasClass(el, 'SaveButton')){
			type = 'submit';
		}else if (dojo.hasClass(el, 'DeleteButton')){
			type = 'confirm';
		}else if (dojo.hasClass(el, 'CancelButton')){
			type = 'confirm';
		}else if (dojo.hasClass(el, 'ExtraButton')){
			type = 'execute';
			triggerClass="ExtraButtonTrigger";
		}else if (dojo.hasClass(el, 'SearchButton')){
			type = 'execute';
		}else {
			type = 'confirm';
		}


		var submit = '';
		if (el.type == 'image' ||el.type == 'submit') {
			submit = 'true';
		}
		var disabled = '';
		if (el.disabled) {
			disabled = 'true';
		}
		if (el.getAttribute("triggerClass") != null && el.getAttribute("triggerClass") != '') {
			triggerClass = el.getAttribute("triggerClass");
		}
		new epages.widget.Button({
			button:  type,
			name:    el.name,
			value:   el.value,
			'class': el.className,
			onclick: el.onclick,
			iconSrc: el.getAttribute("iconsrc"),
			submit:  submit,
			disabled: disabled,
			triggerClass: triggerClass
			 }, el);
	});
};

// convert old buttons
dojo.addOnLoad(function () {
	//epages.widget.TransformButtons(dojo.body());
});

}

if(!dojo._hasResource["epages.widget.Modaldialog"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Modaldialog"] = true;
dojo.provide("epages.widget.Modaldialog");





dojo["require"]('dijit.Dialog'); //change require syntax to keep it here after shrinksafe





dojo.declare(
	"epages.widget.Modaldialog",
	[dijit.Dialog, epages.widget.LocalizedWidget],
	{

		/**
		 * public properties
		 */
		buttons: undefined,
		options: undefined,
		duration: epages.Browser.engine=="MSIE" ? 10 : 150,
		title: '',
		'class' : '',
		/**
		 * private properties
		 */
		_contentWidget: null,
		_contentPane: null,
		_events: null,
		_tabEvents: null,
		_tabs: undefined,
		_currentTab: undefined,
		_iframe: null,
		_doc: null,

		/**
		 * dojo widget properties
		 */
		translationName       : dojo.moduleUrl('epages.widget', "templates/translation"),
		imagePath             : epages.themeUrl('images'),
		buttonTemplateString  : '<span class="Button EnableHover (%Class%)" (%buttonId%)><span class="ButtonContainer">(%Label%)</span></span>',
		tabTemplateString     : '<div class="Tab"><div>(%Label%)</div></div>',
		innerTemplatePath     : null,
		widgetsInTemplate     : true,
		templateString: dojo.cache("epages.widget", "templates/Modaldialog.html", "<div class=\"dijitDialog ModalDialog\" style=\"display:none\">\n  <div dojoAttachPoint=\"titleBar\" class=\"dijitDialogTitleBar\" tabindex=\"0\" waiRole=\"dialog\">\n    <span dojoAttachPoint=\"titleNode\" class=\"dijitDialogTitle\">${title}</span>\n    <span dojoAttachPoint=\"closeButtonNode\" class=\"dijitDialogCloseIcon EnableHover\" dojoAttachEvent=\"onclick: onCancel\">\n      <span dojoAttachPoint=\"closeText\" class=\"closeText\">x</span>\n    </span>\n  </div>\n  <div dojoAttachPoint=\"tabBarNode\" class=\"TabBar\" style=\"display:none\"></div>\n  <div dojoAttachPoint=\"layerContentNode\" class=\"LayerContent Border White\">\n    <div dojoAttachPoint=\"containerNode\" class=\"dijitDialogPaneContent ${options.containerClass}\"><!-- //innerTemplate// --></div>\n  </div>\n  <div dojoAttachPoint=\"innerButtonBarNode\" class=\"LayerInnerButtonBar\" style=\"display:none\"></div>\n  <div dojoAttachPoint=\"buttonBarNode\" class=\"LayerButtonBar\" style=\"display:none\"></div>\n</div>\n"),

		clearFloatNode        : undefined,

		buildRendering: function() {
			// summary:
			//    replaces the placeholder in the base template with the template from innerTemplateString,
			//    so this works like an include and you don't have to rewrite the whole template in sub-
			//    classes.
			if (this.innerTemplatePath != null) {
				this.templateString = dijit._Templated.getCachedTemplate(this.templatePath, this.templateString, true);
				var innerTemplateString = dijit._Templated.getCachedTemplate(this.innerTemplatePath, null, true);
				this.templateString = this.templateString.replace('<!-- //innerTemplate// -->', innerTemplateString);
				this.templatePath = '';
			}
			this.inherited("buildRendering", arguments);
		},

		postMixInProperties: function() {
			var options = {containerClass: ''};
			dojo.mixin(options, this.options);
			this.options = options;
			dijit.Dialog.prototype.postMixInProperties.apply(this, arguments);
			this.inherited("postMixInProperties", arguments);
		},

		postCreate: function() {
			this._doc = this.domNode.ownerDocument;
			//call postCreate of dijit.dialog because this.inherited only references to the last parent class
			dijit.Dialog.prototype.postCreate.apply(this, arguments);
			this.inherited("postCreate", arguments);
			if(this.buttons===undefined){
				this.buttons=[];
			}
			if(this.tabs===undefined){
				this.tabs=[];
			}
			if(this.options===undefined){
				this.options={};
			}
			this._createContent(this.options);
			this._createButtons(this.buttons);
			this._createTabs();
			dojo.addClass(this.domNode, this['class']);
			dojo.subscribe(this.id+"/executeAction",dojo.hitch(this,this.executeAction));
		},
		executeAction : function(/*String*/ functionName,/*anything...*/additionalParams){
			// summary: executes the specified function with the passed arguments
			// example: dojo.publish(id/executeAction,[disableButton,startButton])
			// functionName: function name to call and every following
			// additionalParams: parameters will be pushed as parameter to the called function
			if(this[functionName] && dojo.isFunction(this[functionName])){
				var params = [];
				dojo.forEach(arguments,function(el,i){
					if(i!=0){
						params.push(el);
					}
				});
				epages.lang.hitch(this,functionName,params)();
			}
		},

		destroyRendering: function() {
			this.hide();
			this.inherited("destroyRendering", arguments);
		},

		hide: function() {
			this.inherited("hide", arguments);
			if(epages.Browser.engine=="MSIE") { // layer display corrections
				this.domNode.style.width="auto";
			}
			dojo.publish(this.id+'/hide',[{dialog: this}]);
		},

		show: function() {
			this.inherited("show", arguments);
			if(epages.Browser.engine=="MSIE") { // layer display corrections
				this.domNode.style.width=this.domNode.offsetWidth+"px";
			}
			//set zIndex to epages.vars.ZIndex
			if(this.domNode && epages.zIndex){
				this.domNode.style.zIndex = epages.zIndex;
			}
			if(this._underlay){
				this._underlay.domNode.style.zIndex = this.domNode.style.zIndex-1;
			}
			if(epages.zIndex){
				epages.zIndex+=2;
			}
			//disconnect scrollevent from dialog, because there is no parameter in dojo dialog to achive this
			for(var i = 0, iLength = this._modalconnects.length; i < iLength; i++){
				var currentEventHandle = this._modalconnects[i];
				if( currentEventHandle.length && currentEventHandle[1] &&  currentEventHandle[1] == 'onscroll'){
					dojo.disconnect(currentEventHandle);
				}
			}
			//check if there is enough space to see the close button
			var popupTop = parseInt(this.domNode.style.top);
			var popupLeft = parseInt(this.domNode.style.left);
			if(popupTop < 0){
				this.domNode.style.top = "0px";
			}
			if(popupLeft < 0){
				this.domNode.style.left = "";
				this.domNode.style.right = "0px";
			}
			else {
				this.domNode.style.right = "";
			}
			//remove dragging
			if(this._moveable){
				this._moveable.destroy();
			}
			// manual focus handling : focus first input
			if(!this.autofocus) {
				var inputs = dojo.query('input', this.containerNode);
				if(inputs && inputs.length > 0) {
					inputs[0].focus();
				}
			}
			// trigger resize to adjust CKEditor dimensions
			jq(window).trigger('resize');

			dojo.publish(this.id+'/show',[{dialog: this}]);
		},

		close: function() {
			this.hide();
			window.setTimeout(dojo.hitch(this,function(){
				this._destroyContent();
				this._destroyButtons();
			}),this.duration);
		},

		setupContent: function(/*Object*/ opt) {
		// summary: setup new content (destorys old content contentarea, tabs, buttons)
		// opt: {
		//  content - string / domNode / widget object (strings may contain widgets e.g. <div dojoType="epages.widget.Tooltip"></div>)
		//  buttons - array with buttons e.g. [{label: 'Cancel',onclick: function() {this._modalDialogWidget.hide();}]}
		//  width - integer or string - width of content area
		//  height - integer or string - height of content area
		//  scroll - string - possible values: 'y', 'x', 'scroll', 'hidden'
		//  title - string - text in titlebar
		//  translationName - string (url) specify translation file to translate language tags in title attribute
		//  url - load content via url
		//  destroyWidgetOnClose - boolean - option to destroy widgets after closing the content widget (also after setting up new content)
		// }
			this._destroyTabs();
			this._destroyContent();
			this._destroyButtons();

			if (opt.buttons){
				this.setupButtons(opt.buttons);
			}
			this._createContent(opt);
			this._createTabs();
		},

		setupButtons: function (buttons) {
			this._destroyButtons();
			this._createButtons(buttons);
		},


		setTitle: function(title) {
			this.titleNode.innerHTML = title;
		},

/**
* widget button/ display functions
*/

		hideInnerButtonBar : function() {
			this.innerButtonBarNode.style.display ='none';
		},

		showInnerButtonBar : function() {
			this.innerButtonBarNode.style.display ='';
		},

		disableButton : function(/* string|DomNode*/ but) {
		// summary: disables specified button
			if(dojo.isString(but)){
				var buttons = dojo.query("[buttonid="+but+"]", this.domNode );
				if(buttons){
					buttons = buttons[0];
				}
			} else {
				var buttons = but;
			}
			if(buttons) {
				dojo.removeClass(buttons, "Active");
				dojo.addClass(buttons, "Disabled");
				buttons.disabled=true;
			}

			dojo.forEach(this._events, function(evtmap) {
				if(evtmap.button.domNode == buttons) {
					dojo.disconnect(evtmap.event);
				}
			});

		},

		enableButton : function(/* string */ buttonId) {
		// summary: enables specified button
			var buttonData = undefined;
			dojo.forEach(this.buttons, function (button) {
				if(button.buttonId == buttonId) {
					buttonData = button;
				}
			});

			if(buttonData && buttonData.domNode.disabled == true) {
				buttonData.domNode.disabled=false;
				if(buttonData.cssClass) {
					dojo.addClass(buttonData.domNode, buttonData.cssClass );
				}
				dojo.removeClass(buttonData.domNode, "Disabled");
				dojo.forEach(this._events, function(evtmap) {
					if(evtmap.button.buttonId == buttonId) {
						evtmap.event = dojo.connect(buttonData.domNode, "onclick", buttonData, "onclick");
					}
				});
			}
		},

		_createContent: function(/*Object*/ opt) {
			if(opt){
				dojo.mixin(this.options, opt);
			}

			var translation = undefined;
			if(this.options.translationName) {
				translation = new epages.io.Translation(this.options.translationName,"auto");
				if(this.options.title){
					this.options.title = translation.replaceLanguageTags(this.options.title);
				}
			}
			if (this.options.title){
				this.setTitle(this.options.title);
			}
			// set Layout
			switch(this.options.scroll){
				case "y":
					this.containerNode.style.overflowY='scroll';
					break;
				case "x":
					this.containerNode.style.overflowX='scroll';
					break;
				case "scroll":
					this.containerNode.style.overflow='scroll';
					break;
				case "hidden":
					this.containerNode.style.overflow='hidden';
					break;
				default:
					this.containerNode.style.overflow='auto';
					break;
			}
			if (this.options.width) {
				if (typeof this.options.width == 'number') {
					this.layerContentNode.style.width=this.options.width+"px";
				} else {
					this.layerContentNode.style.width=this.options.width;
				}
			} else {
				this.containerNode.style.width="auto";
				this.layerContentNode.style.width="auto";
			}
			if (this.options.height) {
				if (typeof this.options.height == 'number') {
					this.containerNode.style.height=this.options.height+"px";
				} else {
					this.containerNode.style.height=this.options.height;
				}
			} else {
				this.containerNode.style.height="auto";
			}
			if (this.options.url != null) {
				// url, use contentPane
				if (this._contentPane == null) {
					// contentPane does not exist -> create it
					this._contentPane = new dojox.layout.ContentPane({
						// url of content
						href: this.options.url,
						// wait for download to finish
						preload: true,
						// extract content from body tag
						extractContent: false,
						// adjust relative paths
						adjustPaths: true,
						// set content on download end to avoid resizing problem <-- does not work
						ioMethod: function(args) {
							var result = dojo.xhrGet(args);
							if(translation){
								result.addCallback(function(html){
										return translation.replaceLanguageTags(html);
								});
							}
							return result;
						},
						onLoad: dojo.hitch(this, function() {
							//Timeout necessary for IE
							window.setTimeout(dojo.hitch(this,function(){
							this.containerNode.appendChild(this._contentPane.domNode);
							// call event function
							if (this.options && this.options.onLoad && typeof this.options.onLoad == 'function'){
								this.options.onLoad();
							}
							this.layout();
							this.show();
							this._createTabs();
							dojo.publish(this.id+'/onLoadContentPane',[{dialog: this}]);
						}),10);
						})
					});
					this._contentPane.refresh();
				} else {
					this._contentPane.setHref(this.options.url);
				}
			} else {
				if(typeof this.options.content == "object") {
					// content, string, nodes or widgets
					if(this.options.content.domNode) { // widget
						this.containerNode.appendChild(this.options.content.domNode);
						this._contentWidget=this.options.content;
					} else {                           // dom node
						this.containerNode.appendChild(this.options.content);
					}
				} else if(typeof this.options.content == "string") {
					this.containerNode.innerHTML=this.options.content;  // html string
					var scripts = this.containerNode.getElementsByTagName('script');
					var win = this._doc.parentWindow ? this._doc.parentWindow : this._doc.defaultView;
					for( var i=0,iLength=scripts.length ; i<iLength ; i++ ) {
						if (scripts[i].childNodes.length > 0) {
							// Mozilla
							// Fix for bug https://bugzilla.mozilla.org/show_bug.cgi?id=194231: only 4K string in array element
							var evalString = "";
							for( var j=0,jLength=scripts[i].childNodes.length ; j<jLength ; j++ ) {
								evalString += scripts[i].childNodes[j].nodeValue;
							}
							win.eval(evalString);
						} else {
							// IE
							win.eval(scripts[i].innerHTML);
						}
					}
					win.dojo.parser.parse(this.containerNode); // build widgets
					//epages.widget.TransformButtons(this.containerNode);
				}
			}
			dojo.publish(this.id+'/change',[{dialog: this}]);
		},

		_destroyContent: function() {
			this.options.scroll=undefined;
			this.options.width=undefined;
			this.options.height=undefined;
			this.options.title=undefined;
			this.options.url=undefined;

			if(this.titleNode.firstChild){
				this.titleNode.firstChild.data=" ";
			}
			this.containerNode.style.overflow='auto';
			this.containerNode.style.overflowX='auto';
			this.containerNode.style.overflowY='auto';
			this.containerNode.style.width="auto";
			this.layerContentNode.style.width="auto";
			this.containerNode.style.height="auto";
			this.innerButtonBarNode.style.display="none";
			this.tabBarNode.style.display="none";

			// remove containerNode children

			epages.html.removeChildren(this.containerNode);

			if(typeof this.options.content == "object" && this.options.destroyWidgetOnClose){
				this.options.content.destroy();   // destroy widget
			}
			this._contentWidget = null;
			this.options.content = "";
		},

		_createButtons: function(/* Object[] */ buttons) {
		// summary: create modal dialog buttons
		// buttons:
		// [{
		//   label: '{Delete}',
		//   cssClass: 'Active',
		//   buttonId: 'delete',
		//   hideOnShow: 'false',
		//   isDisabled: 'false',
		//   onclick: function() {
		//     me.deleteNavigationElement();
		//     this._modalDialogWidget.hide();
		//   }
		//  },{
		//    label: '{Cancel}',
		//    onclick: function() { this._modalDialogWidget.hide(); }
		// }]
			if(buttons.length){
				this.innerButtonBarNode.style.display="";
			}
			this.buttons = [];
			this._events = [];
			dojo.forEach(buttons, function (button) {
				button.domNode=[];
				var tmplProcessor=new epages.Template({
					template: this.buttonTemplateString,
					vars    : {
						'Label': button.label,
						'Class': button.cssClass ? button.cssClass : '',
						'buttonId': (button.buttonId) ? 'buttonid='+button.buttonId+' ' : ''
					}
				});
				var buttonNode= this.createNodesFromText(tmplProcessor.generateOutput());
				this.innerButtonBarNode.appendChild(buttonNode);
				button.domNode=buttonNode;
				dojo.mixin(button, {_modalDialogWidget: this, _contentWidget: this._contentWidget});
				this._events.push({ event: dojo.connect(button.domNode, "onclick", button, "onclick"), button : button});
				this.buttons.push(button);
				if(button.isDisabled == 'true'){
					this.disableButton(buttonNode);
				}
			}, this);
			this.clearFloatNode = document.createElement("div");
			this.clearFloatNode.className="ClearBoth";
			this.innerButtonBarNode.appendChild(this.clearFloatNode);
		},

		_destroyButtons: function () {
			dojo.forEach(this._events, function(evtmap) {
				dojo.disconnect(evtmap.event);
			});
			dojo.forEach(this.buttons, function (button) {
				button.domNode.parentNode.removeChild(button.domNode);
				button.domNode = undefined;
			});
			this._events = null;
			delete this._events;			// delete var
			this.buttons=[];
			if(this.clearFloatNode !== undefined && this.clearFloatNode.parentNode != null) {
				this.clearFloatNode.parentNode.removeChild(this.clearFloatNode);
				this.clearFloatNode = undefined;
			}
		},

		_createTabs: function() {
		// summary: creates tabs by looking for dom nodes with css class "TabPage"
		// description: tab labels ar specified by attribute ep_label of the dom node
			var tabs = epages.html.getElementsByClassName('TabPage',this.containerNode);
			if(tabs.length && tabs.length > 1){
				this.tabBarNode.style.display="";
				dojo.addClass(this.tabBarNode, "Visible");
				this._tabs = [];
				this._tabEvents = [];
				dojo.forEach(tabs, function (domNode) {
					var tab = {
						domNode : [],
						changeNode: domNode
					};
					var tmplProcessor = new epages.Template({
						template: this.tabTemplateString,
						vars    : {
							'Label': domNode.getAttribute('ep_label')
						}
					});
					var tabNode = this.createNodesFromText(tmplProcessor.generateOutput());
					this.tabBarNode.appendChild(tabNode);
					tab.domNode = tabNode;
					//dojo.mixin(tab, {_modalDialogWidget: this, _contentWidget: this._contentWidget});
					this._tabEvents.push(dojo.connect(tab.domNode, "onclick", this, "_onTabClick"));
					tab.changeNode.style.display = 'none';
					this._tabs.push(tab);
				}, this);
				//activate first tab
				this._tabs[0].changeNode.style.display = '';
				dojo.addClass(this._tabs[0].domNode, 'Active');
				this._currentTab = this._tabs[0];
			} else {
				dojo.removeClass(this.tabBarNode, "Visible");
			}
		},

		_destroyTabs: function () {
			dojo.forEach(this._tabEvents, dojo.disconnect);
			dojo.forEach(this._tabs, function (tab) {
				tab.domNode.parentNode.removeChild(tab.domNode);
				tab.domNode = undefined;
				tab.changeNode = undefined;
			});
			this._tabs=[];
			this._currentTab = undefined;
		},

		_onTabClick: function(evt){
			var targetTab = evt.currentTarget;
			var tab = undefined;
			for( var i=0,iLength=this._tabs.length ; i<iLength ; i++ ){
				if(targetTab == this._tabs[i].domNode){
					tab = this._tabs[i];
				}
			}
			if(tab){
				if(this._currentTab){
					dojo.removeClass(this._currentTab.domNode,'Active');
					this._currentTab.changeNode.style.display = 'none';
				}
				tab.changeNode.style.display = '';
				dojo.addClass(tab.domNode, 'Active');
				this._currentTab = tab;
				dojo.publish(this.id+"/tabChange",[tab.changeNode]);
			}
		}
	}
);

}

if(!dojo._hasResource["epages.widget.Tooltip"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Tooltip"] = true;
/*
	Copyright (c) 2006-2010, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.widget.Tooltip");


dojo.declare("epages.widget.Tooltip", [dijit._Widget, dijit._Templated], {

		/**
		 * public properties
		 */
		disabledBodyClickHide : false,
		tooltipLayerFrame     : undefined,
		tooltipAreaId         : '',
		tooltipArea           : undefined,
		tooltipNode           : undefined,
		interactive           : '',	// String - Is the user able to use the content of the tooltip? i.e. if there's links in the tooltip text
		tooltipShowDelay      : 0,
		tooltipHideDelay      : 0,
		currentYPosition      : 0,
		currentXPosition      : 0,
		hideDelay             : null,
		fadeDelay             : null,
		showDelay             : null,
		bgcolor               : '',
		forceOrientation      : '',	// String - B - bottom, T - top , L - left, R - right (combinations are possible e.g BR)
		target                : "default",
		findAreaMethod        : "",

		/**
		 * private properties
		 */
		_findAreaMethodMapping: {
			'default'           : 'parentNode',
			'previous'          : 'previousSibling',
			'next'              : 'nextSibling'
		},													// Object - which node should be used to connect to the tooltip activation events (mouseover-area)
		_doc                  :	null,				// DomNode - owner document, i.e. to calculate the widget position
		_bodyConnect          : undefined,	// to store event connect to document's body, i.e. for hiding the tooltip when clicked somewhere else on the page
		_windowConnect        : undefined,	// to store event connect to the window for capturing keypress events

		/**
		 * dojo widget properties
		 */
		templateString        : '<div class="Tooltip"><div dojoAttachPoint="containerNode"></div></div>',


		/**
		 * dojo lifecycle methods
		 */
		postCreate: function() {
			// summary: widget lifecycle postCreate handler
			// description:
			//		Initializes widget parameters and find dom element for displaying the tooltip widget
			//		(see _findAreaMethodMapping values). Then create dom elements for the tooltip bubble
			//		and connect the keyboard/mouse event handlers.
			this.inherited("postCreate", arguments);
			this.tooltipNode = this.domNode;
			// catch tooltip area node
			var tooltipArea = undefined;
			if(this.tooltipArea) {
				tooltipArea = this.tooltipArea;
			}
			else if(this.tooltipAreaId!="") {
				tooltipArea= $(this.tooltipAreaId);
			}
			else {
				var findAreaMethod = this._findAreaMethodMapping[this.findAreaMethod || this.target];
				tooltipArea = this.domNode[findAreaMethod];
				if(tooltipArea.nodeType!= 1) {
					if(findAreaMethod == 'previousSibling') {
						tooltipArea=tooltipArea.previousSibling; // skip spaces
					}
					if(findAreaMethod == 'nextSibling') {
						tooltipArea=tooltipArea.nextSibling;     // skip spaces
					}
				}
			}

			if(this.bgcolor !=''){
				this.domNode.style.backgroundColor = this.bgcolor;
			}

			if(!tooltipArea || tooltipArea.nodeType!=1 ){
				console.warn('TooltipArea not found by using find method "'+this.findAreaMethod+'" in '+this.declaredClass);
			} else {
				this.tooltipArea = tooltipArea;
				this._doc = this.tooltipArea.ownerDocument;
				this.tooltipIsInteractive = epages.string.toBoolean(this.interactive);
				this.tooltipShowDelay = 600;
				this.tooltipHideDelay = this.tooltipIsInteractive ? 1400 : 400;
				this.tooltipLayerFrame = this._doc.createElement("div");
				this.tooltipShadow = this._doc.createElement("div");
				dojo.style(this.tooltipNode, "opacity", 0);

				this._bodyConnect = dojo.connect(dojo.body(),"onmouseup",this, "onBodyClick");
				this._windowConnect = dojo.connect(window,"onkeypress", this,"onKeypress");
				this.connect(this.tooltipArea, "onmousemove", "onElementMove");
				this.connect(this.tooltipArea, "onmouseover", "onElementOver");
				this.connect(this.tooltipArea, "onmouseout", "onElementOut");
				this.connect(this.tooltipArea, "onmousedown", "onElementClick");
				if(this.tooltipIsInteractive) {
					this.connect(this.tooltipNode, "onmouseover", "onTooltipOver");
					this.connect(this.tooltipNode, "onmouseout", "onTooltipOut");
				}
			}
		},

		destroy: function(){
			// summary: widget lifecycle destroy handler
			// description:
			//		Disconnect event handlers to body and window of the widget-containing document.
			this.inherited("destroy", arguments);
			dojo.disconnect(this._bodyConnect);
			dojo.disconnect(this._windowConnect);
		},


		/**
		 * public methods
		 */
		setContent: function(/* string */ html) {
			this.containerNode.innerHTML=html;
			this.setPosition();
		},

		isActive: function() {
			// summary: Is the tooltip dom node visible?
			// returns:  false if zero opacity, otherwise true
			return dojo.style(this.tooltipNode, "opacity") == 0? false : true;
		},

		setPosition: function() {
			// summary: Move the tooltip
			// description:
			//		Depending on the orientation mode set by the forceOrientation variable move the tooltip
			//		domNode to the position determined by currentYPosition and currentXPosition. This depends
			//		on the document parenting the tooltip node as well as possible window scroll bars.
			var forceRight  = (this.forceOrientation.match('R')) ? true : false;
			var forceLeft   = (this.forceOrientation.match('L')) ? true : false;
			var forceBottom = (this.forceOrientation.match('B')) ? true : false;
			var forceTop    = (this.forceOrientation.match('T')) ? true : false;

			// horizontal position
			var docWidth = epages.Browser.engine == "WebKit" ? this._doc.body.clientWidth : this._doc.documentElement.clientWidth;
			var rightSideX = this.tooltipNode.offsetWidth + this.currentXPosition + 16 + 3 - (this._doc.documentElement.scrollLeft || this._doc.body.scrollLeft);	// 16px = dist. from mouse ; 3px = shadow iframe
			if((rightSideX > docWidth && ! forceRight) || forceLeft) {
				var x = this.currentXPosition - this.tooltipNode.offsetWidth;
				if(forceLeft){
					x-=16;
				}
				if(x < 0){
					x=0;
				}
				this.tooltipNode.style.left = x + "px";			// layer > left align
			} else {
				var x = this.currentXPosition;
				if(forceRight){
					x+=16;
				}
				this.tooltipNode.style.left = x + "px";			// layer > right align
			}

			// vertical position
			var docHeight = epages.Browser.engine == "WebKit" ? this._doc.body.clientHeight : this._doc.documentElement.clientHeight;
			var bottomSideX = this.tooltipNode.offsetHeight + this.currentYPosition + 16 + 3 - (this._doc.documentElement.scrollTop || this._doc.body.scrollTop);
			if((bottomSideX > docHeight && ! forceBottom) || forceTop) { // 16px = dist. from mouse ; 3px = shadow iframe
				var y = this.currentYPosition - this.tooltipNode.offsetHeight - 16;
				if(y < 0){
					y=0;
				}
				this.tooltipNode.style.top =  y + "px";														// layer > top align
			}else{
				this.tooltipNode.style.top = this.currentYPosition + 16 + "px";		// layer > bottom align
			}
			this.tooltipLayerFrame.style.width = this.tooltipNode.offsetWidth + 2 + "px";
			this.tooltipLayerFrame.style.height = this.tooltipNode.offsetHeight + 2 + "px";
		},

		show: function(/* int */ x, /* int */ y) {
			// summary: Set position & display the Tooltip
			// description:
			//		Update the tooltip position and triggers the display of the tooltip.
			this.currentXPosition = x;
			this.currentYPosition = y;
			this.showTooltip();
		},

		showTooltip: function() {
			// summary: Display the Tooltip
			// description:
			//		Hide the tooltip dom node before changing it. Then attach the layout classes and move the
			//		tooltip frame to front. Finally attach the tooltip node to the dom tree and display it.
			dojo.addClass(this.tooltipNode, "HideElement");
			if(!this.rendered){
				dojo.addClass(this.tooltipNode, "Tooltip");
				dojo.addClass(this.tooltipShadow, "TooltipShadow");
				dojo.addClass(this.tooltipLayerFrame, "LayerIframe");
				if(!this.tooltipIsInteractive) {
					this.tooltipLayerFrame.style.zIndex = "1";
					this.tooltipNode.style.MozUserSelect = 'none';
				}
				this.tooltipNode.appendChild(this.tooltipLayerFrame); // overlay
				this.tooltipNode.appendChild(this.tooltipShadow);
				this._doc.getElementsByTagName("body")[0].appendChild(this.tooltipNode);
				this.rendered = true;
			}

			var _this = this;

			if( this.fadeAction ) {
				this.fadeAction.stop();
			}

			this.fadeAction = dojo.fadeIn({
				node: this.tooltipNode,
				duration:200,
				beforeBegin: function() {
					_this.tooltipNode.style.display = "block";
					_this.setPosition();
					dojo.removeClass(_this.tooltipNode, "HideElement");
				}
			});
			this.fadeAction.play();
		},

		hide: function() {
			// summary: Hide the Tooltip
			// description:
			//		After a fade, hide the tooltip.
			var _this = this;
			if( this.fadeAction ) {
				this.fadeAction.stop();
			}

			this.fadeAction = dojo.fadeOut({
				node:this.tooltipNode,
				duration: 200,
				onEnd: function() {
					_this.tooltipNode.style.display = "none";
				}
			});
			this.fadeAction.play();
		},


		/**
		 * Event handlers
		 */
		onElementMove: function(mouseEvent) {
			if(!mouseEvent){
				var mouseEvent = window.event;
			}
			this.currentYPosition = mouseEvent.clientY + (this._doc.documentElement.scrollTop || this._doc.body.scrollTop);
			this.currentXPosition = mouseEvent.clientX + (this._doc.documentElement.scrollLeft || this._doc.body.scrollLeft);
		},
		onElementOver: function() {
			this.disabledBodyClickHide = true;
			this._resetTimeouts();
			if(!this.isActive()) {
				this.showDelay = this._delayExec(this.showTooltip, this.tooltipShowDelay);
			}
		},
		onElementOut: function() {
			this._resetTimeouts();
			this.fadeDelay = this._delayExec(this.hide, this.tooltipHideDelay);
			this.disabledBodyClickHide = false;
		},
		onElementClick: function() {
			this.disabledBodyClickHide = true;
			if(!this.isActive()) {
				this._resetTimeouts();
				this.showTooltip();
			}
		},
		onTooltipOver: function() {
			this.disabledBodyClickHide = true;
			this._resetTimeouts();
		},
		onTooltipOut: function() {
			this.disabledBodyClickHide = false;
			this.onElementOut();
		},
		onBodyClick: function() {
			if(!this.disabledBodyClickHide && this.isActive()) {
				this._resetTimeouts();
				this.hide();
			}
		},
		onKeypress: function(evt) {
			if(evt.keyCode == dojo.keys.ESCAPE) {
				this._resetTimeouts();
				this.hide();
			}
		},


		/**
		 * private methods
		 */
		_delayExec: function(task, delay) {
			return setTimeout(dojo.hitch(this, task), delay);
		},
		_resetTimeouts: function() {
			clearTimeout(this.hideDelay);
			clearTimeout(this.fadeDelay);
			clearTimeout(this.showDelay);
		}

	}
);

}

if(!dojo._hasResource["epages.widget.Message"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Message"] = true;
dojo.provide("epages.widget.Message");




dojo.declare("epages.widget.Message",
	[dijit._Widget,dijit._Templated],
	{
		/**
		 * public properties
		 */
		headline: "",
		message: "",
		sizeClass: "Small",
		typeClass: "Info",
		borderClass: "",
		loderAniNode : undefined,

		/**
		 * dojo widget properties
		 */
		templateString:"<div class=\"Message ${sizeClass} ${typeClass} ${borderClass}\">\n  <div class=\"Headline\" dojoAttachPoint=\"headlineNode\">${headline}</div>\n  <div class=\"MessageDetails\" dojoAttachPoint=\"messageNode\">${message}</div>\n</div>\n",

		show: function() {
			this.domNode.style.display="block";
		},

		hide: function() {
			this.domNode.style.display="none";
		},

		postCreate: function() {
			this.inherited("postCreate", arguments);
			this.setupContent({
				headline: this.headline,
				message: this.message,
				sizeClass: this.sizeClass,
				typeClass: this.typeClass,
				borderClass: this.borderClass
			});
		},

		setupContent: function(/*Object*/opt) {
		// summary: set up new content / change content
		// opt: {
		//        headline - sting
		//        message - string
		//        sizeClass - string: Small, Medium, Large
		//        typeClass - string: Error, Warning, Notification, Question, Tip, Confirmation
		//        borderClass - string -> your css class
		//      }

			if(opt.headline !== undefined && opt.headline!="") {
				this.headline=opt.headline;
				this.headlineNode.innerHTML=opt.headline;
				this.headlineNode.style.display="";
			} else
				this.headlineNode.style.display="none";

			if(opt.message !== undefined && opt.message!="") {
				this.message=opt.message;
				this.messageNode.innerHTML=opt.message;
				this.messageNode.style.display="";
				dojo.parser.parse(this.messageNode);
			} else
				this.messageNode.style.display="none";

			if(opt.sizeClass !== undefined) {
				epages.html.replaceClass(this.domNode, opt.sizeClass, this.sizeClass);
				this.sizeClass = opt.sizeClass;
			}
			if(opt.typeClass !== undefined) {
				epages.html.replaceClass(this.domNode, opt.typeClass, this.typeClass);
				this.typeClass = opt.typeClass;

				if(this.loderAniNode !== undefined && opt.typeClass != "Loader") {
					epages.loaderani.destroy(this.loderAniNode);
				}
				if(opt.typeClass == "Loader") {
					var lani_options = {
						top: 14,
						left: 14,
						width: 24,
						height: 24
					}
					this.domNode.style.position="relative";
					this.loderAniNode = epages.loaderani.create(lani_options, this.domNode);
				}
			}

			if(opt.borderClass !== undefined) {
				epages.html.replaceClass(this.domNode, opt.borderClass, this.borderClass);
				this.borderClass = opt.borderClass;
			}
		}
	}
);

}

if(!dojo._hasResource["epages.widget.Bubble"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Bubble"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.widget.Bubble");



dojo.declare("epages.widget.Bubble", [dijit._Widget, dijit._Templated],	{
		optionsstring   : "",              // string - setup options as string
		options         : undefined,       // object - setup options (see setupContent for more)
		typeClass       : "",              // string - (Additional css class e.g. Wide)

		/* widget properties */
		templateString:"<div class=\"Bubble ${typeClass}\">\n  <div class=\"LayerOverIframe\" dojoAttachPoint=\"layerOverIframeNode\">\n    <div class=\"BubbleLayer\">\n      <div class=\"BubbleClose\" dojoAttachPoint=\"closeNode\"></div>\n      <div dojoAttachPoint=\"containerNode\"></div>\n    </div>\n    <div class=\"BubbleFoot\"></div>\n  </div>\n</div>\n",

		/* widget life cycle */
		postMixInProperties: function() {
			this.inherited("postMixInProperties", arguments);
			// prepare settings
			if(this.options===undefined){
				this.options = { content: '' };
			}

			var optFromString = (this.optionsstring != "" ) ? dojo.fromJson(this.optionsstring) : undefined;
			if(optFromString) {
				dojo.mixin(this.options, optFromString);
			}
		},

		postCreate: function() {
			this.inherited("postCreate", arguments);
			this.setupContent(this.options);
			// events
			this.connect(this.closeNode, 'onclick', 'hide');
			this.connect(window, "onkeypress", "onKeypress");
			this.connect(window, "onresize", "hide");
			this.connect(document.body, "onkeypress", "onKeypress");
		},

		/* public methods */

		setupContent: function(/*Object*/opt) {
			// summary: setup bubble content
			// opt:{
			//       content     - widget, string
			//       x           - integer
			//       y           - integer
			//       typeClass   - string (Additional css class e.g. Wide)
			//       orientation - string -> specifies the location of the bubble arrow (left right bottom top-right)
			//     }

			// mix in options
			if(opt) {
				dojo.mixin(this.options, opt);
			}

			// remove old nodes
			while(this.containerNode.firstChild){
				this.containerNode.removeChild(this.containerNode.firstChild);
			}

			// set content
			if(this.options.content) {
				if(typeof this.options.content == "object" && this.options.content.domNode != undefined) {
					// is widget
					this.containerNode.appendChild(this.options.content.domNode);
				} else if(typeof this.options.content == "string") {
					// is string
					this.containerNode.innerHTML = this.options.content;
				} else if (typeof this.options.content == "object" && this.options.content.nodeType){
					this.containerNode.appendChild(this.options.content);
				} else {
					console.warn('Bubble.setupContent needs a domnode a widget or a string as content.');
				}
			}

			var xOffset = 0;
			var yOffset = 0;

			if(this.options.orientation=="" || this.options.orientation=="top") {
				dojo.removeClass(this.domNode, "Left");
				dojo.removeClass(this.domNode, "Right");
				dojo.removeClass(this.domNode, "TopRight");
				dojo.removeClass(this.domNode, "Bottom");
			}

			if(this.options.orientation == "top-right") {
				var typeClass = this.options.typeClass;

				if(typeClass && typeClass.match("Wide")) {
					xOffset = -330;
				} else {
					xOffset = -230;
				}

				dojo.addClass(this.domNode, "TopRight");
				dojo.removeClass(this.domNode, "Left");
				dojo.removeClass(this.domNode, "Bottom");
				dojo.removeClass(this.domNode, "Right");
			}

			if(this.options.orientation == "right") {
				var typeClass = this.options.typeClass;

				if(typeClass && typeClass.match("Wide")) {
					xOffset = -380;
				} else {
					xOffset = -280;
				}

				yOffset = -24;
				dojo.addClass(this.domNode, "Right");
				dojo.removeClass(this.domNode, "Left");
				dojo.removeClass(this.domNode, "Bottom");
				dojo.removeClass(this.domNode, "TopRight");
			}

			if(this.options.orientation == "left") {
				yOffset = -24;
				dojo.addClass(this.domNode, "Left");
				dojo.removeClass(this.domNode, "Right");
				dojo.removeClass(this.domNode, "Bottom");
				dojo.removeClass(this.domNode, "TopRight");
			}

			if(this.options.orientation == "bottom" ) {
				dojo.addClass(this.domNode, "Bottom");
				dojo.removeClass(this.domNode, "Left");
				dojo.removeClass(this.domNode, "Right");
				dojo.removeClass(this.domNode, "TopRight");
			}

			// set position
			if(this.options.x !== undefined && this.options.y !== undefined) {
				$E(this.domNode).setCss({
					'left': 		(this.options.x + xOffset) + 'px',
					'top': 			(this.options.y + yOffset) + 'px',
					'zIndex': 	99998
				});
			}
			// replace css class
			if(this.options.typeClass !== undefined) {
				dojo.removeClass(this.domNode, this.typeClass);
				dojo.addClass(this.domNode, this.options.typeClass);
				this.typeClass = this.options.typeClass;
			}
		},

		show: function() {
		// summary: function to show the bubble
			if(this.options.orientation == "bottom") {
				this.domNode.style.visibility = 'hidden';
				this.domNode.style.display = 'block';
					var curHeight = this.layerOverIframeNode.offsetHeight || this.layerOverIframe.clientHeight;
					$E(this.domNode).setCss({
						'top': (this.options.y - curHeight) + 'px',
						visibility: 'visible'
					});
			} else {
				this.domNode.style.display = 'block';
			}
		},

		hide: function() {
		// summary: function to hide the bubble
			this.domNode.style.display = 'none';
		},

		/* events */
		onKeypress: function(evt) {
		// summary: keypress event controller
			if(evt.keyCode == dojo.keys.ESCAPE) {
				this.hide();
			}
		}
	}
);

}

if(!dojo._hasResource["epages.uimessagehandler"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.uimessagehandler"] = true;
dojo.provide("epages.uimessagehandler");








dojo.mixin( epages.uimessagehandler, {
	template :'<div id="busyMessageLayer" style="position: absolute; left:0px; top:0px; height: 100%; width: 100%; z-index: 100000; overflow: auto; display: none;">' +
						'<div id="busyMessageUnderlay" class="ui-widget-overlay"  style="position: absolute; left:0px; top:0px; height: 100%; width: 100%; z-index: 99999;" ></div>' +
						'<div id="busyMessageBox" style="position: relative; left:0px; top:300px; z-index: 100000; max-width: 200px; overflow: visible; margin: auto;">' +
						'<div class="Layer"><div id="busyMessagePropertyContainer" class="PropertyContainer" style="height:45px;padding-top:1px;"><div id="busyMessage"></div>' +
						'</div></div><div class="LayerFooter"><div class="PropertyContainer"></div></div></div></div>',
	fadeOutBusyLayer: function(duration) {

		dojo.fx.combine([
			dojo.fadeOut({
				node:$('busyMessageLayer'),
				onEnd: function() {
					$('busyMessageLayer').style.display='none';
					if(document.all) {
						dojo.body().parentNode.style.overflow = "auto";
					}
				},
				duration: duration ? duration : 1000
			})
		]).play();
	},
	rePositionBusy: function() {
		if($("busyMessageLayer")) {
			$("busyMessageLayer").style.top = (window.pageYOffset || document.getElementsByTagName("html")[0].scrollTop) + "px";
		}
	},
	errorsToString : function(errors) {
		var errorMessage = '';
		for(var el in errors) {
			if(errors[el].Message != "") {
				errorMessage += errors[el].Message+"<br />";
			} else {
				var t = epages.io.dictionary.get(errors[el].Reason);
				if(t === undefined){
					t=errors[el].Reason;
				}
				errorMessage += t+"<br />";
			}
		}
		return errorMessage;
	}
});

dojo.subscribe("uimessage/show", function(/* String */headline, /* String */message, /* String */ type, /* Object */ opt) {
/*
	headline -> string
	message  -> string
	type     -> string: Bubble, Dialog, Insert
	options  -> object

options type: Bubble
	* x          -> number
	* y	  	     -> number
	* typeClass  -> string: Error, Warning, Notification, Question, Tip
	* sizeClass  -> string: Large, Medium, Small
	* attachNode -> dom node (bubble will be attached as childnode) (optional)

options type: Insert
	* targetNode -> DOM object
	* typeClass  -> string: Error, Warning, Notification, Question, Tip, Confirmation
	* sizeClass  -> string: Large, Medium, Small

options type: Dialog
	* titleBar   -> string
	* typeClass  -> string: Error, Warning, Notification, Question, Tip, Confirmation
	* sizeClass  -> string: Large, Medium, Small
	* buttons    -> array: see ModalDialog widget
	* width      -> number: width of dialog
*/

	var sizeClass = (opt.sizeClass !== undefined) ? opt.sizeClass : "Large";
	var typeClass = (opt.typeClass !== undefined) ? opt.typeClass : "Warning";

	// hide old dialog / bubble
	if($$('uimessage_dialog')){ $$('uimessage_dialog').hide(); }
	if($$('uimessage_bubble')){ $$('uimessage_bubble').hide(); }

	var messageWidget = $$('uimessage_insert');

	if(messageWidget === undefined) {
		messageWidget = new epages.widget.Message({
			id: "uimessage_insert",
			headline: (headline !== undefined) ? headline : "",
			message:   message,
			sizeClass: sizeClass,
			typeClass: typeClass,
			borderClass: (type=='Insert') ? "WithBorder" : ""
		});
	} else {
		messageWidget.hide();
		messageWidget.setupContent({
			headline: headline,
			message: message,
			sizeClass: sizeClass,
			typeClass: typeClass,
			borderClass: (type=='Insert') ? "WithBorder" : ""
		});
	}
	messageWidget.show();
	switch(type) {
		case "Bubble":
			var bubbleWidget = $$('uimessage_bubble');
			var attachNode = opt.attachNode || document.body;
			// if not given, determine x and y by element
			if ((opt.x == null || opt.y == null) && opt.element != null) {
				var absPos = $E(opt.element).getAbsolutePosition(opt.baseNode);
				opt.x = opt.x || (absPos.x + opt.element.offsetWidth / 2);
				opt.y = opt.y || (absPos.y + opt.element.offsetHeight);
			}
			if(bubbleWidget === undefined) {
				
				bubbleWidget = new epages.widget.Bubble({
					id: "uimessage_bubble",
					options:{
						x : opt.x,
						y : opt.y,
						typeClass: typeClass,
						content: messageWidget,
						orientation: opt.orientation
					}
				});
				attachNode.appendChild(bubbleWidget.domNode);
			} else {
				bubbleWidget.setupContent({
					x : opt.x,
					y : opt.y,
					typeClass: typeClass,
					content: messageWidget,
					orientation: opt.orientation
				});
				attachNode.appendChild(bubbleWidget.domNode);
			}
			bubbleWidget.show();
			break;
		case "Insert":
			if(opt.targetNode !== undefined) {
				opt.targetNode.appendChild($$('uimessage_insert').domNode);
			} else {
				console.warn("uimessage/show: opt.targetNode is undefined");
			}
			break;
		default:
			var buttons = opt.buttons;
			if (buttons === undefined) {
					var translation = epages.io.dictionary.translation;
					buttons = typeClass == 'Confirmation' ?
					[{
						label: translation.get('Yes'),
						onclick: function() {
							this._modalDialogWidget.hide();
							if (typeof opt.onYes == 'function'){
								opt.onYes();
							}
						}
					},{
						label: translation.get('No'),
						onclick: function() {
							this._modalDialogWidget.hide();
							if (typeof opt.onNo == 'function'){
								opt.onNo();
							}
						}
					}] :
					[{
						label: translation.get('Close'),
						onclick: function() { this._modalDialogWidget.hide(); }
					}];
			}
			var title= opt.titleBar;
			if (title === undefined) {
				title = epages.io.dictionary.translation.get(typeClass);
			}

			var uid = $$('uimessage_dialog');
			if(uid === undefined) {
				
				uid = new epages.widget.Modaldialog({
					id: "uimessage_dialog",
					options:{
						title : title,
						width : (opt.width) ? opt.width : 450,
						content: messageWidget
					},
					buttons: buttons
				});
				document.body.appendChild(uid.domNode);
			} else {
				uid.containerNode.appendChild(messageWidget.domNode);
				uid.setupContent({
					title: title,
					width : 450,
					content: messageWidget,
					buttons: buttons
				});
			}
			uid.show();
			break;
	}
});

dojo.subscribe("uimessage/hide", function(opt) {
	if($$('uimessage_dialog')){ $$('uimessage_dialog').hide(); }
	if($$('uimessage_bubble')){ $$('uimessage_bubble').hide(); }
	if($$('uimessage_insert')){ $$('uimessage_insert').hide(); }
});

dojo.subscribe("uimessage/startBusy", function(/* * */ owner, /* ?HTML String */ message, /* ?url */ iconUrl) {

	epages.uimessagehandler.busyLayerOwner = owner;
	epages.vars.BusyLayerActive = true;
	if(message === undefined){
		var translation = epages.io.dictionary.translation;
		message = translation.get('PleaseWait');
	}

	var bodyNode = document.getElementsByTagName("body")[0];

	if(document.all) {
		bodyNode.parentNode.style.overflow = "hidden";
	}

	var busyUnderlay=$('busyMessageLayer');
	if(busyUnderlay == null) {
		busyUnderlay= document.createElement("div");
		busyUnderlay.innerHTML = epages.uimessagehandler.template;
		bodyNode.appendChild(busyUnderlay.firstChild);
		busyUnderlay=busyUnderlay.firstChild;
	}
	$('busyMessageLayer').style.display='';
	dojo.style($('busyMessageLayer'), "opacity", 1);

	if($('busyMessage').getElementsByTagName("div")[0]) {
		$('busyMessage').removeChild($('busyMessage').getElementsByTagName("div")[0]);
	}
	var container = document.createElement("div");
	container.innerHTML = message;
	$('busyMessage').appendChild(container);

	if(iconUrl) {
		$('busyMessage').style.backgroundImage="url(" + iconUrl + ")";
		if($('busyMessage').style.filter) {
		}
		$('busyMessage').style.backgroundRepeat="no-repeat";
		$('busyMessage').style.minHeight="40px";
		$("busyMessagePropertyContainer").style.height = "58px";
	}else {
		$("busyMessagePropertyContainer").style.height = "48px";
	}

	epages.uimessagehandler.rePositionBusy();


});

dojo.subscribe("uimessage/showErrors", function(/* String */headline, /* String */titlebar, /* Object */ errors) {
	var errorMessage = epages.uimessagehandler.errorsToString(errors);

	dojo.publish("uimessage/show", [headline, errorMessage, "Dialog" , {
		titleBar  : titlebar,
		typeClass : "Error"
	}]);
});

dojo.subscribe("uimessage/showErrorBubble", function(/* String */headline, /* String */attachNode, /* Object */ errors, /* string ?*/ typeClass) {
	var tc = (typeClass) ? typeClass : "Error";
	var errorMessage = epages.uimessagehandler.errorsToString(errors);
	var pos = $E(attachNode).getAbsolutePosition();
	dojo.publish("uimessage/show", [headline, errorMessage, "Bubble" , {
		typeClass : tc,
		sizeClass : "Small",
		x: pos.x,
		y: pos.y + attachNode.clientHeight + 4
	}]);
});

dojo.subscribe("uimessage/changeBusy", function(owner, message) {
	if(epages.uimessagehandler.busyLayerOwner == owner && top.$("busyMessage")) {
		if(epages.Browser.engine == "MSIE") {
			$('busyMessage').style.display = "inline-block";
		}
		if($('busyMessage').getElementsByTagName("div")[0]) {
			$('busyMessage').removeChild($('busyMessage').getElementsByTagName("div")[0]);
		}
		var container = document.createElement("div");
		container.innerHTML = message;
		$('busyMessage').appendChild(container);
		if(epages.Browser.engine == "MSIE") {
			$('busyMessage').style.display = "block";
		}
	}
});

dojo.subscribe("uimessage/stopBusy", function(owner, timeout, duration) {
	if(epages.uimessagehandler.busyLayerOwner == owner) {
		if(timeout) {
			window.setTimeout(function() {
				epages.vars.BusyLayerActive = false;
				epages.uimessagehandler.fadeOutBusyLayer(duration);
				}, timeout);
		}else {
			epages.vars.BusyLayerActive = false;
			epages.uimessagehandler.fadeOutBusyLayer(duration);
		}
	}
});

dojo.connect(window, "scroll", this, epages.uimessagehandler.rePositionBusy);

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.richtext"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.richtext"] = true;
dojo.provide("epages.cartridges.de_epages.presentation.richtext");




epages.cartridges.de_epages.presentation.richtext = {

	// reference to opened editor
	_editor: null,
	_translation: new epages.io.Translation(dojo.moduleUrl('epages.cartridges.de_epages.presentation', "templates/translation"), "auto"),

	_HEIGHT : 480,
	_WIDTH : 900,

	// stub for overloading
	getValue: function(value) {
		return value;
	},

	setValue: function(value){
		return value;
	},

	cleanUp: function(value, insertCompleteUrl) {
		if (insertCompleteUrl) {
			value = value.replace(/((?:src|href)\s*=\s*[\'\"])(.*?)([\'\"])/ig, function(match, beforeUrl, url, afterUrl) {
				if(url.match(/^mailto\:/i)){
					//ignore mailto:
					return beforeUrl + url + afterUrl;
				}
				// ignore attachments
				if (!url.match(/^cid\:/i)) {
					url = epages.lang.uri.parts(url);
					if (!url.host && !url.path && !url.query && url.anchor){
						return match;
					}
					var baseUrl = epages.lang.uri.parts(epages.vars.StoreFrontUrl);
					if (!url.host) {
						if (url.path.match(/^\//)) {
							return beforeUrl + baseUrl.protocol + '://' + baseUrl.host + url.href + afterUrl;
						} else {
							return beforeUrl + baseUrl.protocol + '://' + baseUrl.host + url.href + afterUrl;
						}
					}
					return beforeUrl + url.href + afterUrl;
				}
				return beforeUrl + url + afterUrl;
			});
		}
		return value;
	},

	openDialog: function(options){
		epages.require('ep_shop_tree','dijit.Tree');
		epages.require('ep_shop_preview','epages.cartridges.de_epages.presentation.objectupdater');
		if (options.value == null){
			options.value = $(options.name).value;
		}
		// value is a callback
		if (typeof value == 'function'){
			options.value = options.value($(options.name).value);
		}
		if (options.siteId == null){
			options.siteId = epages.vars.SiteID;
		}
		if (options.title == null){
			options.title = $E(options.name).getLabel();
		}
		if (options.title == undefined){
			options.title = '';
		}
		options.title = this._translation.get('EditText')+': '+options.title;
		if (options.getValueCallback == null){
			options.getValueCallback = dojo.hitch(epages.cartridges.de_epages.presentation.richtext,"getValue");
		}
		if (options.setValueCallback == null){
			options.setValueCallback = dojo.hitch(epages.cartridges.de_epages.presentation.richtext,"setValue");
		}
		var modalDialog = $$('epages.cartridges.de_epages.presentation.richtext.modalDialog');
		var buttons = [{
			cssClass: 'Active ep-button ep-button-apply',
			label: '{Apply}',
			onclick: function() {
				var rt = epages.cartridges.de_epages.presentation.richtext;
				var input = $(options.name);
				input.value = rt.cleanUp(options.getValueCallback(rt._editor.getContent()), options.insertCompleteUrl);
				if(options.savePage) {
					if (input.form.onsubmit){
						input.form.onsubmit();
					}
					input.form.submit();
				} else {
					epages.event.fire(input, "change");
				}
				this._modalDialogWidget.hide();
			}
		},{
			cssClass: 'ep-button ep-button-cancel',
			label: '{Cancel}',
			onclick: function() { this._modalDialogWidget.hide(); }
		}];
		if (modalDialog == null) {
			var div = document.createElement('div');
			document.getElementsByTagName('body')[0].appendChild(div);
			
			var json = new epages.io.Json();
			var openerId = epages.vars.currentSelectedObjectID ? epages.vars.currentSelectedObjectID : new Date().getTime();
			try {
				var snippet = json.loadSync('?', {
					'ObjectID':           parent.epages.vars.ObjectID,
					'TemplateAction':     parent.epages.vars.ViewAction,
					'TemplateLanguageID': parent.epages.vars.Locale.languageId,
					'TemplateName':       'INC-RichTextEditor',
					'ViewAction':         'JSONSnippet',
					'UseAbsolutePath':		options.useAbsolutePath ? '1' : '0',
					'OpenerID' : openerId
				}).data.snippet;
			} catch (e) {
				throw new Error('Could not load richtext snippet. Reason: ' + e.message);
			}
			
			modalDialog = new epages.widget.Modaldialog({
				id:             'epages.cartridges.de_epages.presentation.richtext.modalDialog',
				options: {
					content:        snippet,
					width:          this._WIDTH,
					height:         this._HEIGHT,
					containerClass: 'NoPadding',
					title:					options.title
				},
				buttons:          buttons
			}, div);
			if(epages.TinyMCELicenceText !== undefined) {
				var copyRightDiv = document.createElement("div");
				copyRightDiv.className="TinyMCELicenceText";
				copyRightDiv.innerHTML = epages.TinyMCELicenceText;
				var innerButtonBarNode = modalDialog.innerButtonBarNode;
				innerButtonBarNode.insertBefore(copyRightDiv, innerButtonBarNode.firstChild);
			}
			var tinyToolBar = $('TinyMCETools'+openerId);
			if(tinyToolBar !== undefined) {
				dojo.removeClass(tinyToolBar, 'NavBarInvisible');
			}

			var rte = $('RichTextEditor');
			rte.value = options.setValueCallback(options.value);
			var settings = dojo.mixin(tinyMCE.settings, {
				width: "100%",//this._WIDTH,
				height: (this._HEIGHT - epages.vars.Layout && epages.vars.Layout.toolBarHeight ? epages.vars.Layout.toolBarHeight : 0),
				body_class: 'ShowVisualAid mceShowContent'
			});

			var editor = new tinymce.Editor('RichTextEditor', settings);
			editor.render();
			epages.cartridges.de_epages.presentation.richtext._editor = editor;
		} else {
			epages.cartridges.de_epages.presentation.richtext._editor.setContent(options.setValueCallback(options.value));
			modalDialog.setupButtons(buttons);
			modalDialog.setTitle(options.title);
		}

		if(options.initCallback) {
			options.initCallback(modalDialog);
		}

		modalDialog.show();

	}

};

}

if(!dojo._hasResource['epages.widget.ContentList']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.widget.ContentList'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/

dojo.provide('epages.widget.ContentList');





/*
 add the class "NoRowSelector" to your element if you do not want to trigger the row selection for that specific element
 add the class "RowSelector" to your element if you explicitly want to trigger the row selection (even the element is an image / form element / whatever)
 add the class "NoSmallTableMode" to your table if the table is not meant to be displayed in this mode
*/
(function(dojo,undefined){

dojo.declare("epages.widget.ContentList", [dijit._Widget], {

	_getRelevantInputCell: function(tableRow) {
		var cellsInRow = tableRow.cells;
		for( var i=0,iLength=cellsInRow.length ; i<iLength ; i++ ) {
			var inputsInCell = cellsInRow[i].getElementsByTagName("input");
			for( var j=0,jLength=inputsInCell.length ; j<jLength ; j++ ) {
				if(inputsInCell[j] && inputsInCell[j].type != "hidden") {
					return cellsInRow[i];
				}
			}
		}
	},

	_calcCellWidth: function(cell) {
		if(cell.parentNode.parentNode.parentNode.className.match("ContentListForcedWidth")) {
			var tableHead = cell.parentNode.parentNode.parentNode.tHead.rows[0];
			var tableHeadCell = tableHead.cells[cell.cellIndex];
			if(!(tableHeadCell.className || "").match("Checkbox") && !(tableHeadCell.className || "").match("NoPadding") && tableHead.currentCellIndex != cell.cellIndex) {
				tableHead.currentCellIndex = cell.cellIndex;
				var parentWidth = tableHead.parentNode.parentNode.parentNode.offsetWidth;
				var tableWidth = tableHead.parentNode.parentNode.offsetWidth;
				tableWidth = ((parentWidth < tableWidth) ? parentWidth : tableWidth);
				var tableColumns = tableHead.cells.length;
				for(var i = 0; i < tableColumns; i++) {
					if(!(tableHead.cells[i].className || "").match("Checkbox")) {
						tableHead.cells[i].style.width = (tableWidth / tableColumns / 1.25) + "px";
					}
				}
				tableHeadCell.style.width = (tableWidth / tableColumns * 2) + "px";
			}
		}
	},

	_enableSmallTableMode: function(tableRows) {
		for( var i=0,iLength=tableRows.length ; i<iLength ; i++ ) {
			for( var j=0,jLength=tableRows[i].cells.length ; j<jLength ; j++ ) {
				this.connect(tableRows[i].cells[j], "mouseenter", function(evt) {
					this._calcCellWidth(evt.currentTarget);
				});
				this.connect(tableRows[i].cells[j], "mouseleave", function(evt) {
					var cell = evt.currentTarget;
					if(cell.parentNode.parentNode.parentNode.className.match("ContentListForcedWidth")) {
						var tableHead = cell.parentNode.parentNode.parentNode.tHead.rows[0];
						var tableHeadCell = tableHead.cells[cell.cellIndex];
						if(!(tableHeadCell.className || "").match("Checkbox") && !(tableHeadCell.className || "").match("NoPadding") && tableHead.currentCellIndex != cell.cellIndex) {
							tableHead.currentCellIndex = cell.cellIndex;
							for( var i=0,iLength=tableHead.cells.length ; i<iLength ; i++ ) {
								if(!(tableHead.cells[i].className || "").match("Checkbox")) {
									tableHead.cells[i].style.width = "auto";
								}
							}
						}
					}
				});
			}
		}
	},

	_setCheckTableMode: function() {
		var tRows = this.domNode.tBodies[0].rows;
		if(!this.domNode.className.match("NoSmallTableMode") && this.domNode.offsetWidth > this.domNode.parentNode.offsetWidth + 2) { //2px tolerance for the table border
			setTimeout(dojo.hitch(this, function() {
				if(!this.domNode.className.match("ContentListForcedWidth")) {
					this._enableSmallTableMode(this.domNode.rows);
					dojo.addClass(this.domNode, "ContentListForcedWidth");
				}
				if(tRows[1]) {
					var firstContentCell = tRows[1].cells[0].className.match("Checkbox") ? tRows[1].cells[1] : tRows[1].cells[0];
					this._calcCellWidth(firstContentCell);
				}
			}), 1);
		}
	},

	postCreate: function() {

		this.inherited("postCreate", arguments);

		this.domNode.className += " RowSelection" + (epages.Browser.engine == "MSIE" ? "" : " HideElement");

		this.connect(window, "resize", "_setCheckTableMode");
		dojo.subscribe("RightSidebar/afterShowSidebar", dojo.hitch(this, function() {
			setTimeout(dojo.hitch(this, function() {
				this._setCheckTableMode();
			}), 1);
		}));

		var tRows = this.domNode.tBodies[0].rows;

		for( var i=0,iLength=tRows.length ; i<iLength ; i++ ) {

			var relevantInputCell = this._getRelevantInputCell(tRows[i]);

			if(relevantInputCell) {
				// the listener does not know where to find the relevant inputs unless we mark the parent cell
				relevantInputCell.className += " RowSelectionInputCell";
				this.connect(tRows[i], "click", function(evt) {
					var currentTargetNode = evt.currentTarget;  // tr node
					var someThingSelected;
					if(document.selection && document.all) {
						someThingSelected = document.selection.createRange().text;
					}else {
						someThingSelected = window.getSelection.rangeCount;
					}
					var realTargetTag = evt.target.tagName.toLowerCase();
					// be sure that we don't override existing functionality
					if((evt.target.className.match("RowSelector") && !evt.target.className.match("NoRowSelector")) || (
							!someThingSelected &&
							realTargetTag != "a" &&
							realTargetTag != "input" &&
							realTargetTag != "select" &&
							realTargetTag != "option" &&
							realTargetTag != "textarea" &&
							realTargetTag != "img" &&
							realTargetTag != "label" &&
							!evt.target.className.match("NoRowSelector") &&
							!evt.target.className.match("Sprite"))
					) {
						var inputCell = null;
						if(realTargetTag == "td" && evt.target.getElementsByTagName("input").length > 0) {
							// the clicked element is a table cell and contains inputs
							// (although it is not our declarated cell)
							inputCell = evt.target;
						}else {
							// get the previous declarated cell (by class)
							var cells = currentTargetNode.getElementsByTagName("td");
							for( var i=0,iLength=cells.length ; i<iLength ; i++ ) {
								if(cells[i].className.match("RowSelectionInputCell")) {
									inputCell = cells[i];
									break;
								}
							}
						}
						var inputs = inputCell.getElementsByTagName("input");
						var radioInputs = 0;
						// precheck how many radio inputs given (for handling yes/no inputs)
						for( var i=0,iLength=inputs.length ; i<iLength ; i++ ) {
							if(inputs[i].className.match("Radio")) {
								radioInputs++;
							}
						}
						// now it's getting serious
						for( var i=0,iLength=inputs.length ; i<iLength ; i++ ) {
							if(!inputs[i].disabled && inputs[i].type != "hidden") {
								if(inputs[i].className.match("Radio")) {
									if(radioInputs > 1 && inputs[i].checked == false) {
										// it is a double radio input (yes/no)
										// (therefore we only activate the unchecked input)
										epages.event.fire(inputs[i], "click");
										break;
									}else {
										// it is a single radio input (content list selector)
										epages.event.fire(inputs[i], "click");
									}
								}else if(inputs[i].className.match("Checkbox")) {
									// it is a checkbox
									epages.event.fire(inputs[i], "click");
									if(!inputs[i].rowSelectEventSet) {
										inputs[i].rowSelectEventSet = true;
										this.connect(inputs[i], "click", function(evt) {
											if(evt.currentTarget.checked && epages.parentByTagName(evt.currentTarget,'td').cellIndex == 0) {
												dojo.addClass( epages.parentByTagName(evt.currentTarget,'tr'), "RowSelected");
											}else {
												dojo.removeClass( epages.parentByTagName(evt.currentTarget,'tr'), "RowSelected");
											}
										});
									}
								}else {
									// it is something else
									try {
										inputs[i].focus();
										inputs[i].select();
									}catch(e){}
									break;
								}
							}
						}
					}else if(!evt.target.rowSelectEventSet && realTargetTag == "input" && evt.target.className && evt.target.className.match("Checkbox")) {
						// we have to handle checkboxes even if the row never has been clicked before
						if(evt.target.checked && !epages.parentByTagName(evt.currentTarget,'td').cellIndex) {
							dojo.addClass( epages.parentByTagName(evt.currentTarget,'tr'), "RowSelected");
						}else {
							dojo.removeClass( epages.parentByTagName(evt.currentTarget,'tr'), "RowSelected");
						}
					}
				});
			}
		}
		setTimeout(dojo.hitch(this, function() {
			dojo.removeClass(this.domNode, "HideElement");
			this._setCheckTableMode();
		}), 1);
	}
});

})(dojo);

}

if(!dojo._hasResource['epages.validate.date']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.validate.date'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/

dojo.provide('epages.validate.date');




epages.validate.date.isTime = function(/*String*/timeString, /*String*/epagesPattern) {
	if (timeString == ''){
		return 'NO_VALUE';
	}
	var date;
	try {
		date = epages.string.toTime(timeString, epagesPattern);
	} catch (ex) {
		console.dir(ex);
		return 'INVALID_TIME';
	}
	// comment.translate:INVALID_TIME
	if (date === null){
		return 'INVALID_TIME';
	}
	return true;
};

epages.validate.date.isDate = function(/*String*/dateString, /*String*/epagesPattern) {
	if (dateString == ''){
		return 'NO_VALUE';
	}
	if (epagesPattern == null || epagesPattern.length == 0){
		epagesPattern = epages.vars.Locale.dateFormat;
	}
	var pattern = epages.localize.getDojoDateTimePattern(epagesPattern);
	try {
		var date = dojo.date.locale.parse(dateString, { selector: 'date', datePattern: pattern, timePattern: '' });
	} catch (ex) {
		return 'INVALID_DATE';
	}
	if (date === null){
		return 'INVALID_DATE';
	}
	return true;
};

epages.validate.date.isDateTime = function(/*String*/datetimeString, /*String*/epagesPattern) {
	if (datetimeString == ''){
		return 'NO_VALUE';
	}
	if (epagesPattern == null || epagesPattern.length == 0){
		epagesPattern = epages.vars.Locale.datetimeFormat;
	}
	var pattern = epages.localize.getDojoDateTimePattern(epagesPattern);
	try {
		var date = dojo.date.locale.parse(datetimeString, { selector: 'date', datePattern: pattern, timePattern: '' });
	} catch (ex) {
		return 'INVALID_DATETIME';
	}
	if (date === null){
		return 'INVALID_DATETIME';
	}
	return true;
};

}

if(!dojo._hasResource["epages.widget.Timespinner"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Timespinner"] = true;
dojo.provide("epages.widget.Timespinner");








dojo.declare(
	"epages.widget.Timespinner",
	[epages.widget.LocalizedWidget],
	{

		/**
		 * public properties
		 */
		templateString:"<span class=\"TimeSpinner EnableHover\">\n  <span class=\"Time\">\n    ${label} <input name=\"${name}\" type=\"text\" dojoAttachPoint=\"timeNode\" dojoAttachEvent=\"onkeyup:_onKeyUp, onchange:_onChange\" value=\"${value}\" />\n  </span>\n  <span class=\"ButtonWrapper\"><span class=\"TimeSpinnerButton\">\n      <span dojoAttachPoint=\"upNode\"   class=\"TimeSpinnerUpArrow EnableHover\"></span>\n      <span dojoAttachPoint=\"downNode\" class=\"TimeSpinnerDownArrow EnableHover\"></span>\n  </span></span>\n</span>\n",
		translationName : dojo.moduleUrl('epages', "translation"),

		delta:          5, // Integer - increment is 5 minutes by default
		value:          "",
		label:          "",
		name:           "",
		displayPattern: epages.vars.Locale.timeFormat     || "%H:%M", // String - epages time pattern
		emptyValueAllowed: true,
		initId: '',

		/**
		 * private
		 */
		_spinTimeout:           null, // timeout that holds the spinning function repetition (hold-down mouse key)
		_spinCounter:           0,    // counts the spins by the held-down mouse key to determine spinning speed
		_delta:                 0,    // this.delta in millisecs
		_spinIntervalFunction:  null, // function reference of the spinning function

		postMixInProperties: function() {
			if (typeof this.delta == 'string'){
				this.delta = new Number(this.delta);
			}
			if (this.delta<=0){
				this.delta = this.prototype.delta;
			}
			this._delta = this.delta * 60000; // calculate private delta, from mins to millisec
			this.emptyValueAllowed = epages.string.toBoolean(this.emptyValueAllowed);
		},

		postCreate: function() {
			// set initial value
			if (this.value != '') {
				var date = this.value;
				this.value = null;
				this.setValue(date);
			} else if (! this.emptyValueAllowed){
				// default is noon
				var date = new Date();
				date.setTime(43200000 + date.getTimezoneOffset() * 60000);
				this.value = null;
				this.setValue(date);
			} else {
				this.value = null;
			}

			this.connect(this.timeNode,   'focus', 'onFocus');
			this.connect(this.timeNode,   'blur', 'onBlur');

			// round time to closest possible position
			this.connect(this.upNode,   'mouseup', 'onMouseUp');
			this.connect(this.downNode, 'mouseup', 'onMouseUp');
			this.connect(this.upNode,   'mouseout', 'onMouseUp');
			this.connect(this.downNode, 'mouseout', 'onMouseUp');
			this.connect(this.upNode,   'mousedown', 'onMouseDown');
			this.connect(this.downNode, 'mousedown', 'onMouseDown');
		},

		onFocus: function() {
			dojo.addClass(this.domNode, "Focus");
		},

		onBlur: function() {
			dojo.removeClass(this.domNode, "Focus");
		},

		getValue: function() {
			// summary:
			//    returns the value as a date object, day is 1970-01-01
			return this.value;
		},

		setValue: function(/*Date*/date, /* booleab */ skipDisplay) {
			// summary:
			//    sets the time of Date into inputNode value and the internal property

			if (date === undefined){
				date = new Date();
			}
			else if (typeof date == "string") {
				date = epages.string.toTime(date, this.displayPattern);
				if(this.value) {	// fill up year, month, day
					date.setFullYear(this.value.getFullYear());
					date.setMonth(this.value.getMonth());
					date.setDate(this.value.getDate());
				}
			}
			if(!this.value || dojo.date.compare(date, this.value)){
				this.value = new Date(date);
				if(! skipDisplay){
					this.timeNode.value = epages.localize.formatDateTime(date, this.displayPattern);
				}
			}
			dojo.removeClass(this.timeNode, "DialogError");
			dojo.publish("uimessage/hide", []);
			dojo.publish(this.id + '/onChange', [date]);
		},

		onMouseDown: function(evt) {
			// summary:
			//    handle mousedowns on the spinner arrows
			var direction;
			if (evt.target == this.upNode) {
				direction = 1;
			} else if(evt.target == this.downNode) {
				direction = -1;
			} else {
				return;
			}
			this._spinIntervalFunction = dojo.hitch(this, function() {
				var speed = this._spinCounter > 5 ? this._spinCounter > 25 ? 25 : 55 : 200;
				this.spin(direction);
				this._spinCounter++;
				window.clearTimeout(this._spinTimeout);
				this._spinTimeout = undefined;
				this._spinTimeout = window.setTimeout(this._spinIntervalFunction, speed);
			});
			this._spinIntervalFunction();
		},

		onMouseUp: function() {
			// summary:
			//    stop spinning
			if(this._spinCounter){
				epages.event.fire(this.timeNode, 'change');
			}
			this._spinCounter = 0;
			window.clearTimeout(this._spinTimeout);
		},

		spin: function(direction) {
			// summary:
			//    spin the value by delta
			// direction: 
			//   | if > 0, spin up
			//   | if < 0, spin down
			//   | if = 0, do nothing

			// only spin, if date and direction are valid
			if (direction == 0){
				return;
			}
			var isValueChanged = false;

			if (this.value == null && this.timeNode.value != '') {
				var w = $$(this.initId);
				if (w) {
					this.value = w.value;
					isValueChanged = true;
				}
			}
			if (this.value == null && this.initId != '') {
				var w = $$(this.initId);
				if (w) {
					this.value = w.value;
					isValueChanged = true;
				}
			}
			if (this.value == null) {
				this.value = dojo.date.locale.parse('0', { selector: 'date', datePattern: 'HH', timePattern: '' });
				isValueChanged = true;
			}
			var date = new Date(this.value);
			if (isValueChanged){
				this.value=null;
			}else{ // set time via UTC in millisec - ensure that direction is either 1 or -1
				date.setTime(this.value.getTime() + this._delta * (direction / Math.abs(direction)));
			}

			this.setValue(date);
		},

		_onKeyUp: function(evt) {
			var newValue = evt.target.value;
			var isValid = epages.validate.date.isTime(newValue, this.displayPattern);
			if(isValid === true) {
				this.setValue(newValue, true);
			} else if(isValid == "NO_VALUE" && this.emptyValueAllowed) {
				dojo.removeClass(this.timeNode, "DialogError");
				dojo.publish("uimessage/hide", []);
				this.value = null;
			} else {
				dojo.addClass(this.timeNode, "DialogError");
			}
		},

		_onChange: function(evt) {
			//set 'px' as default-unit
			var newValue = evt.target.value;
			var isValid = epages.validate.date.isTime(newValue, this.displayPattern);

			var position=$E(this.timeNode).getRelativePosition();

			if(isValid != true && ! (isValid == "NO_VALUE" && this.emptyValueAllowed)) {
				//display Error-Box-Widget
				dojo.publish("uimessage/show", ["", this.translation.get(isValid), "Bubble", {
					typeClass: "Warning",
					sizeClass: "Small",
					x: position.x,
					y: position.y + this.timeNode.clientHeight + 4,
					attachNode: this.domNode.parentNode
				}]);
			}
		}
	}
);

}

if(!dojo._hasResource["dijit._HasDropDown"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._HasDropDown"] = true;
dojo.provide("dijit._HasDropDown");



dojo.declare("dijit._HasDropDown",
	null,
	{
		// summary:
		//		Mixin for widgets that need drop down ability.

		// _buttonNode: [protected] DomNode
		//		The button/icon/node to click to display the drop down.
		//		Can be set via a dojoAttachPoint assignment.
		//		If missing, then either focusNode or domNode (if focusNode is also missing) will be used.
		_buttonNode: null,

		// _arrowWrapperNode: [protected] DomNode
		//		Will set CSS class dijitUpArrow, dijitDownArrow, dijitRightArrow etc. on this node depending
		//		on where the drop down is set to be positioned.
		//		Can be set via a dojoAttachPoint assignment.
		//		If missing, then _buttonNode will be used.
		_arrowWrapperNode: null,

		// _popupStateNode: [protected] DomNode
		//		The node to set the popupActive class on.
		//		Can be set via a dojoAttachPoint assignment.
		//		If missing, then focusNode or _buttonNode (if focusNode is missing) will be used.
		_popupStateNode: null,

		// _aroundNode: [protected] DomNode
		//		The node to display the popup around.
		//		Can be set via a dojoAttachPoint assignment.
		//		If missing, then domNode will be used.
		_aroundNode: null,

		// dropDown: [protected] Widget
		//		The widget to display as a popup.  This widget *must* be
		//		defined before the startup function is called.
		dropDown: null,

		// autoWidth: [protected] Boolean
		//		Set to true to make the drop down at least as wide as this
		//		widget.  Set to false if the drop down should just be its
		//		default width
		autoWidth: true,

		// forceWidth: [protected] Boolean
		//		Set to true to make the drop down exactly as wide as this
		//		widget.  Overrides autoWidth.
		forceWidth: false,

		// maxHeight: [protected] Integer
		//		The max height for our dropdown.
		//		Any dropdown taller than this will have scrollbars.
		//		Set to 0 for no max height, or -1 to limit height to available space in viewport
		maxHeight: 0,

		// dropDownPosition: [const] String[]
		//		This variable controls the position of the drop down.
		//		It's an array of strings with the following values:
		//
		//			* before: places drop down to the left of the target node/widget, or to the right in
		//			  the case of RTL scripts like Hebrew and Arabic
		//			* after: places drop down to the right of the target node/widget, or to the left in
		//			  the case of RTL scripts like Hebrew and Arabic
		//			* above: drop down goes above target node
		//			* below: drop down goes below target node
		//
		//		The list is positions is tried, in order, until a position is found where the drop down fits
		//		within the viewport.
		//
		dropDownPosition: ["below","above"],

		// _stopClickEvents: Boolean
		//		When set to false, the click events will not be stopped, in
		//		case you want to use them in your subwidget
		_stopClickEvents: true,

		_onDropDownMouseDown: function(/*Event*/ e){
			// summary:
			//		Callback when the user mousedown's on the arrow icon

			if(this.disabled || this.readOnly){ return; }

			dojo.stopEvent(e);

			this._docHandler = this.connect(dojo.doc, "onmouseup", "_onDropDownMouseUp");

			this.toggleDropDown();
		},

		_onDropDownMouseUp: function(/*Event?*/ e){
			// summary:
			//		Callback when the user lifts their mouse after mouse down on the arrow icon.
			//		If the drop is a simple menu and the mouse is over the menu, we execute it, otherwise, we focus our
			//		dropDown node.  If the event is missing, then we are not
			//		a mouseup event.
			//
			//		This is useful for the common mouse movement pattern
			//		with native browser <select> nodes:
			//			1. mouse down on the select node (probably on the arrow)
			//			2. move mouse to a menu item while holding down the mouse button
			//			3. mouse up.  this selects the menu item as though the user had clicked it.
			if(e && this._docHandler){
				this.disconnect(this._docHandler);
			}
			var dropDown = this.dropDown, overMenu = false;

			if(e && this._opened){
				// This code deals with the corner-case when the drop down covers the original widget,
				// because it's so large.  In that case mouse-up shouldn't select a value from the menu.
				// Find out if our target is somewhere in our dropdown widget,
				// but not over our _buttonNode (the clickable node)
				var c = dojo.position(this._buttonNode, true);
				if(!(e.pageX >= c.x && e.pageX <= c.x + c.w) ||
					!(e.pageY >= c.y && e.pageY <= c.y + c.h)){
					var t = e.target;
					while(t && !overMenu){
						if(dojo.hasClass(t, "dijitPopup")){
							overMenu = true;
						}else{
							t = t.parentNode;
						}
					}
					if(overMenu){
						t = e.target;
						if(dropDown.onItemClick){
							var menuItem;
							while(t && !(menuItem = dijit.byNode(t))){
								t = t.parentNode;
							}
							if(menuItem && menuItem.onClick && menuItem.getParent){
								menuItem.getParent().onItemClick(menuItem, e);
							}
						}
						return;
					}
				}
			}
			if(this._opened && dropDown.focus && dropDown.autoFocus !== false){
				// Focus the dropdown widget - do it on a delay so that we
				// don't steal our own focus.
				window.setTimeout(dojo.hitch(dropDown, "focus"), 1);
			}
		},

		_onDropDownClick: function(/*Event*/ e){
			// the drop down was already opened on mousedown/keydown; just need to call stopEvent()
			if(this._stopClickEvents){
				dojo.stopEvent(e);
			}
		},

		buildRendering: function(){
			this.inherited(arguments);

			this._buttonNode = this._buttonNode || this.focusNode || this.domNode;
			this._popupStateNode = this._popupStateNode || this.focusNode || this._buttonNode;

			// Add a class to the "dijitDownArrowButton" type class to _buttonNode so theme can set direction of arrow
			// based on where drop down will normally appear
			var defaultPos = {
					"after" : this.isLeftToRight() ? "Right" : "Left",
					"before" : this.isLeftToRight() ? "Left" : "Right",
					"above" : "Up",
					"below" : "Down",
					"left" : "Left",
					"right" : "Right"
			}[this.dropDownPosition[0]] || this.dropDownPosition[0] || "Down";
			dojo.addClass(this._arrowWrapperNode || this._buttonNode, "dijit" + defaultPos + "ArrowButton");
		},

		postCreate: function(){
			// summary:
			//		set up nodes and connect our mouse and keypress events

			this.inherited(arguments);

			this.connect(this._buttonNode, "onmousedown", "_onDropDownMouseDown");
			this.connect(this._buttonNode, "onclick", "_onDropDownClick");
			this.connect(this.focusNode, "onkeypress", "_onKey");
			this.connect(this.focusNode, "onkeyup", "_onKeyUp");
		},

		destroy: function(){
			if(this.dropDown){
				// Destroy the drop down, unless it's already been destroyed.  This can happen because
				// the drop down is a direct child of <body> even though it's logically my child.
				if(!this.dropDown._destroyed){
					this.dropDown.destroyRecursive();
				}
				delete this.dropDown;
			}
			this.inherited(arguments);
		},

		_onKey: function(/*Event*/ e){
			// summary:
			//		Callback when the user presses a key while focused on the button node

			if(this.disabled || this.readOnly){ return; }

			var d = this.dropDown, target = e.target;
			if(d && this._opened && d.handleKey){
				if(d.handleKey(e) === false){
					/* false return code means that the drop down handled the key */
					dojo.stopEvent(e);
					return;
				}
			}
			if(d && this._opened && e.charOrCode == dojo.keys.ESCAPE){
				this.closeDropDown();
				dojo.stopEvent(e);
			}else if(!this._opened &&
					(e.charOrCode == dojo.keys.DOWN_ARROW ||
						( (e.charOrCode == dojo.keys.ENTER || e.charOrCode == " ") &&
						  //ignore enter and space if the event is for a text input
						  ((target.tagName || "").toLowerCase() !== 'input' ||
						     (target.type && target.type.toLowerCase() !== 'text'))))){
				// Toggle the drop down, but wait until keyup so that the drop down doesn't
				// get a stray keyup event, or in the case of key-repeat (because user held
				// down key for too long), stray keydown events
				this._toggleOnKeyUp = true;
				dojo.stopEvent(e);
			}
		},

		_onKeyUp: function(){
			if(this._toggleOnKeyUp){
				delete this._toggleOnKeyUp;
				this.toggleDropDown();
				var d = this.dropDown;	// drop down may not exist until toggleDropDown() call
				if(d && d.focus){
					setTimeout(dojo.hitch(d, "focus"), 1);
				}
			}
		},

		_onBlur: function(){
			// summary:
			//		Called magically when focus has shifted away from this widget and it's dropdown

			// Don't focus on button if the user has explicitly focused on something else (happens
			// when user clicks another control causing the current popup to close)..
			// But if focus is inside of the drop down then reset focus to me, because IE doesn't like
			// it when you display:none a node with focus.
			var focusMe = dijit._curFocus && this.dropDown && dojo.isDescendant(dijit._curFocus, this.dropDown.domNode);

			this.closeDropDown(focusMe);

			this.inherited(arguments);
		},

		isLoaded: function(){
			// summary:
			//		Returns whether or not the dropdown is loaded.  This can
			//		be overridden in order to force a call to loadDropDown().
			// tags:
			//		protected

			return true;
		},

		loadDropDown: function(/* Function */ loadCallback){
			// summary:
			//		Loads the data for the dropdown, and at some point, calls
			//		the given callback.   This is basically a callback when the
			//		user presses the down arrow button to open the drop down.
			// tags:
			//		protected

			loadCallback();
		},

		toggleDropDown: function(){
			// summary:
			//		Callback when the user presses the down arrow button or presses
			//		the down arrow key to open/close the drop down.
			//		Toggle the drop-down widget; if it is up, close it, if not, open it
			// tags:
			//		protected

			if(this.disabled || this.readOnly){ return; }
			if(!this._opened){
				// If we aren't loaded, load it first so there isn't a flicker
				if(!this.isLoaded()){
					this.loadDropDown(dojo.hitch(this, "openDropDown"));
					return;
				}else{
					this.openDropDown();
				}
			}else{
				this.closeDropDown();
			}
		},

		openDropDown: function(){
			// summary:
			//		Opens the dropdown for this widget.   To be called only when this.dropDown
			//		has been created and is ready to display (ie, it's data is loaded).
			// returns:
			//		return value of dijit.popup.open()
			// tags:
			//		protected

			var dropDown = this.dropDown,
				ddNode = dropDown.domNode,
				aroundNode = this._aroundNode || this.domNode,
				self = this;

			// Prepare our popup's height and honor maxHeight if it exists.

			// TODO: isn't maxHeight dependent on the return value from dijit.popup.open(),
			// ie, dependent on how much space is available (BK)

			if(!this._preparedNode){
				this._preparedNode = true;
				// Check if we have explicitly set width and height on the dropdown widget dom node
				if(ddNode.style.width){
					this._explicitDDWidth = true;
				}
				if(ddNode.style.height){
					this._explicitDDHeight = true;
				}
			}

			// Code for resizing dropdown (height limitation, or increasing width to match my width)
			if(this.maxHeight || this.forceWidth || this.autoWidth){
				var myStyle = {
					display: "",
					visibility: "hidden"
				};
				if(!this._explicitDDWidth){
					myStyle.width = "";
				}
				if(!this._explicitDDHeight){
					myStyle.height = "";
				}
				dojo.style(ddNode, myStyle);
				
				// Figure out maximum height allowed (if there is a height restriction)
				var maxHeight = this.maxHeight;
				if(maxHeight == -1){
					// limit height to space available in viewport either above or below my domNode
					// (whichever side has more room)
					var viewport = dojo.window.getBox(),
						position = dojo.position(aroundNode, false);
					maxHeight = Math.floor(Math.max(position.y, viewport.h - (position.y + position.h)));
				}

				// Attach dropDown to DOM and make make visibility:hidden rather than display:none
				// so we call startup() and also get the size
				if(dropDown.startup && !dropDown._started){
					dropDown.startup();
				}

				dijit.popup.moveOffScreen(dropDown);
				// Get size of drop down, and determine if vertical scroll bar needed
				var mb = dojo._getMarginSize(ddNode);
				var overHeight = (maxHeight && mb.h > maxHeight);
				dojo.style(ddNode, {
					overflowX: "hidden",
					overflowY: overHeight ? "auto" : "hidden"
				});
				if(overHeight){
					mb.h = maxHeight;
					if("w" in mb){
						mb.w += 16;	// room for vertical scrollbar
					}
				}else{
					delete mb.h;
				}

				// Adjust dropdown width to match or be larger than my width
				if(this.forceWidth){
					mb.w = aroundNode.offsetWidth;
				}else if(this.autoWidth){
					mb.w = Math.max(mb.w, aroundNode.offsetWidth);
				}else{
					delete mb.w;
				}
				
				// And finally, resize the dropdown to calculated height and width
				if(dojo.isFunction(dropDown.resize)){
					dropDown.resize(mb);
				}else{
					dojo.marginBox(ddNode, mb);
				}
			}

			var retVal = dijit.popup.open({
				parent: this,
				popup: dropDown,
				around: aroundNode,
				orient: dijit.getPopupAroundAlignment((this.dropDownPosition && this.dropDownPosition.length) ? this.dropDownPosition : ["below"],this.isLeftToRight()),
				onExecute: function(){
					self.closeDropDown(true);
				},
				onCancel: function(){
					self.closeDropDown(true);
				},
				onClose: function(){
					dojo.attr(self._popupStateNode, "popupActive", false);
					dojo.removeClass(self._popupStateNode, "dijitHasDropDownOpen");
					self._opened = false;
				}
			});
			dojo.attr(this._popupStateNode, "popupActive", "true");
			dojo.addClass(self._popupStateNode, "dijitHasDropDownOpen");
			this._opened=true;

			// TODO: set this.checked and call setStateClass(), to affect button look while drop down is shown
			return retVal;
		},

		closeDropDown: function(/*Boolean*/ focus){
			// summary:
			//		Closes the drop down on this widget
			// focus:
			//		If true, refocuses the button widget
			// tags:
			//		protected

			if(this._opened){
				if(focus){ this.focus(); }
				dijit.popup.close(this.dropDown);
				this._opened = false;
			}
		}

	}
);

}

if(!dojo._hasResource["dijit.form.Button"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form.Button"] = true;
dojo.provide("dijit.form.Button");





dojo.declare("dijit.form.Button",
	dijit.form._FormWidget,
	{
	// summary:
	//		Basically the same thing as a normal HTML button, but with special styling.
	// description:
	//		Buttons can display a label, an icon, or both.
	//		A label should always be specified (through innerHTML) or the label
	//		attribute.  It can be hidden via showLabel=false.
	// example:
	// |	<button dojoType="dijit.form.Button" onClick="...">Hello world</button>
	//
	// example:
	// |	var button1 = new dijit.form.Button({label: "hello world", onClick: foo});
	// |	dojo.body().appendChild(button1.domNode);

	// label: HTML String
	//		Text to display in button.
	//		If the label is hidden (showLabel=false) then and no title has
	//		been specified, then label is also set as title attribute of icon.
	label: "",

	// showLabel: Boolean
	//		Set this to true to hide the label text and display only the icon.
	//		(If showLabel=false then iconClass must be specified.)
	//		Especially useful for toolbars.
	//		If showLabel=true, the label will become the title (a.k.a. tooltip/hint) of the icon.
	//
	//		The exception case is for computers in high-contrast mode, where the label
	//		will still be displayed, since the icon doesn't appear.
	showLabel: true,

	// iconClass: String
	//		Class to apply to DOMNode in button to make it display an icon
	iconClass: "",

	// type: String
	//		Defines the type of button.  "button", "submit", or "reset".
	type: "button",

	baseClass: "dijitButton",

	templateString: dojo.cache("dijit.form", "templates/Button.html", "<span class=\"dijit dijitReset dijitInline\"\n\t><span class=\"dijitReset dijitInline dijitButtonNode\"\n\t\tdojoAttachEvent=\"ondijitclick:_onButtonClick\"\n\t\t><span class=\"dijitReset dijitStretch dijitButtonContents\"\n\t\t\tdojoAttachPoint=\"titleNode,focusNode\"\n\t\t\trole=\"button\" aria-labelledby=\"${id}_label\"\n\t\t\t><span class=\"dijitReset dijitInline dijitIcon\" dojoAttachPoint=\"iconNode\"></span\n\t\t\t><span class=\"dijitReset dijitToggleButtonIconChar\">&#x25CF;</span\n\t\t\t><span class=\"dijitReset dijitInline dijitButtonText\"\n\t\t\t\tid=\"${id}_label\"\n\t\t\t\tdojoAttachPoint=\"containerNode\"\n\t\t\t></span\n\t\t></span\n\t></span\n\t><input ${!nameAttrSetting} type=\"${type}\" value=\"${value}\" class=\"dijitOffScreen\" tabIndex=\"-1\"\n\t\tdojoAttachPoint=\"valueNode\"\n/></span>\n"),

	attributeMap: dojo.delegate(dijit.form._FormWidget.prototype.attributeMap, {
		value: "valueNode"
	}),

	_onClick: function(/*Event*/ e){
		// summary:
		//		Internal function to handle click actions
		if(this.disabled){
			return false;
		}
		this._clicked(); // widget click actions
		return this.onClick(e); // user click actions
	},

	_onButtonClick: function(/*Event*/ e){
		// summary:
		//		Handler when the user activates the button portion.
		if(this._onClick(e) === false){ // returning nothing is same as true
			e.preventDefault(); // needed for checkbox
		}else if(this.type == "submit" && !(this.valueNode||this.focusNode).form){ // see if a nonform widget needs to be signalled
			for(var node=this.domNode; node.parentNode/*#5935*/; node=node.parentNode){
				var widget=dijit.byNode(node);
				if(widget && typeof widget._onSubmit == "function"){
					widget._onSubmit(e);
					break;
				}
			}
		}else if(this.valueNode){
			this.valueNode.click();
			e.preventDefault(); // cancel BUTTON click and continue with hidden INPUT click
		}
	},

	buildRendering: function(){
		this.inherited(arguments);
		dojo.setSelectable(this.focusNode, false);
	},

	_fillContent: function(/*DomNode*/ source){
		// Overrides _Templated._fillContent().
		// If button label is specified as srcNodeRef.innerHTML rather than
		// this.params.label, handle it here.
		// TODO: remove the method in 2.0, parser will do it all for me
		if(source && (!this.params || !("label" in this.params))){
			this.set('label', source.innerHTML);
		}
	},

	_setShowLabelAttr: function(val){
		if(this.containerNode){
			dojo.toggleClass(this.containerNode, "dijitDisplayNone", !val);
		}
		this._set("showLabel", val);
	},

	onClick: function(/*Event*/ e){
		// summary:
		//		Callback for when button is clicked.
		//		If type="submit", return true to perform submit, or false to cancel it.
		// type:
		//		callback
		return true;		// Boolean
	},

	_clicked: function(/*Event*/ e){
		// summary:
		//		Internal overridable function for when the button is clicked
	},

	setLabel: function(/*String*/ content){
		// summary:
		//		Deprecated.  Use set('label', ...) instead.
		dojo.deprecated("dijit.form.Button.setLabel() is deprecated.  Use set('label', ...) instead.", "", "2.0");
		this.set("label", content);
	},

	_setLabelAttr: function(/*String*/ content){
		// summary:
		//		Hook for set('label', ...) to work.
		// description:
		//		Set the label (text) of the button; takes an HTML string.
		this._set("label", content);
		this.containerNode.innerHTML = content;
		if(this.showLabel == false && !this.params.title){
			this.titleNode.title = dojo.trim(this.containerNode.innerText || this.containerNode.textContent || '');
		}
	},

	_setIconClassAttr: function(/*String*/ val){
		// Custom method so that icon node is hidden when not in use, to avoid excess padding/margin
		// appearing around it (even if it's a 0x0 sized <img> node)

		var oldVal = this.iconClass || "dijitNoIcon",
			newVal = val || "dijitNoIcon";
		dojo.replaceClass(this.iconNode, newVal, oldVal);
		this._set("iconClass", val);
	}
});


dojo.declare("dijit.form.DropDownButton", [dijit.form.Button, dijit._Container, dijit._HasDropDown], {
	// summary:
	//		A button with a drop down
	//
	// example:
	// |	<button dojoType="dijit.form.DropDownButton" label="Hello world">
	// |		<div dojotype="dijit.Menu">...</div>
	// |	</button>
	//
	// example:
	// |	var button1 = new dijit.form.DropDownButton({ label: "hi", dropDown: new dijit.Menu(...) });
	// |	dojo.body().appendChild(button1);
	//

	baseClass : "dijitDropDownButton",

	templateString: dojo.cache("dijit.form", "templates/DropDownButton.html", "<span class=\"dijit dijitReset dijitInline\"\n\t><span class='dijitReset dijitInline dijitButtonNode'\n\t\tdojoAttachEvent=\"ondijitclick:_onButtonClick\" dojoAttachPoint=\"_buttonNode\"\n\t\t><span class=\"dijitReset dijitStretch dijitButtonContents\"\n\t\t\tdojoAttachPoint=\"focusNode,titleNode,_arrowWrapperNode\"\n\t\t\trole=\"button\" aria-haspopup=\"true\" aria-labelledby=\"${id}_label\"\n\t\t\t><span class=\"dijitReset dijitInline dijitIcon\"\n\t\t\t\tdojoAttachPoint=\"iconNode\"\n\t\t\t></span\n\t\t\t><span class=\"dijitReset dijitInline dijitButtonText\"\n\t\t\t\tdojoAttachPoint=\"containerNode,_popupStateNode\"\n\t\t\t\tid=\"${id}_label\"\n\t\t\t></span\n\t\t\t><span class=\"dijitReset dijitInline dijitArrowButtonInner\"></span\n\t\t\t><span class=\"dijitReset dijitInline dijitArrowButtonChar\">&#9660;</span\n\t\t></span\n\t></span\n\t><input ${!nameAttrSetting} type=\"${type}\" value=\"${value}\" class=\"dijitOffScreen\" tabIndex=\"-1\"\n\t\tdojoAttachPoint=\"valueNode\"\n/></span>\n"),

	_fillContent: function(){
		// Overrides Button._fillContent().
		//
		// My inner HTML contains both the button contents and a drop down widget, like
		// <DropDownButton>  <span>push me</span>  <Menu> ... </Menu> </DropDownButton>
		// The first node is assumed to be the button content. The widget is the popup.

		if(this.srcNodeRef){ // programatically created buttons might not define srcNodeRef
			//FIXME: figure out how to filter out the widget and use all remaining nodes as button
			//	content, not just nodes[0]
			var nodes = dojo.query("*", this.srcNodeRef);
			dijit.form.DropDownButton.superclass._fillContent.call(this, nodes[0]);

			// save pointer to srcNode so we can grab the drop down widget after it's instantiated
			this.dropDownContainer = this.srcNodeRef;
		}
	},

	startup: function(){
		if(this._started){ return; }

		// the child widget from srcNodeRef is the dropdown widget.  Insert it in the page DOM,
		// make it invisible, and store a reference to pass to the popup code.
		if(!this.dropDown && this.dropDownContainer){
			var dropDownNode = dojo.query("[widgetId]", this.dropDownContainer)[0];
			this.dropDown = dijit.byNode(dropDownNode);
			delete this.dropDownContainer;
		}
		if(this.dropDown){
			dijit.popup.hide(this.dropDown);
		}

		this.inherited(arguments);
	},

	isLoaded: function(){
		// Returns whether or not we are loaded - if our dropdown has an href,
		// then we want to check that.
		var dropDown = this.dropDown;
		return (!!dropDown && (!dropDown.href || dropDown.isLoaded));
	},

	loadDropDown: function(){
		// Loads our dropdown
		var dropDown = this.dropDown;
		if(!dropDown){ return; }
		if(!this.isLoaded()){
			var handler = dojo.connect(dropDown, "onLoad", this, function(){
				dojo.disconnect(handler);
				this.openDropDown();
			});
			dropDown.refresh();
		}else{
			this.openDropDown();
		}
	},

	isFocusable: function(){
		// Overridden so that focus is handled by the _HasDropDown mixin, not by
		// the _FormWidget mixin.
		return this.inherited(arguments) && !this._mouseDown;
	}
});

dojo.declare("dijit.form.ComboButton", dijit.form.DropDownButton, {
	// summary:
	//		A combination button and drop-down button.
	//		Users can click one side to "press" the button, or click an arrow
	//		icon to display the drop down.
	//
	// example:
	// |	<button dojoType="dijit.form.ComboButton" onClick="...">
	// |		<span>Hello world</span>
	// |		<div dojoType="dijit.Menu">...</div>
	// |	</button>
	//
	// example:
	// |	var button1 = new dijit.form.ComboButton({label: "hello world", onClick: foo, dropDown: "myMenu"});
	// |	dojo.body().appendChild(button1.domNode);
	//

	templateString: dojo.cache("dijit.form", "templates/ComboButton.html", "<table class=\"dijit dijitReset dijitInline dijitLeft\"\n\tcellspacing='0' cellpadding='0' role=\"presentation\"\n\t><tbody role=\"presentation\"><tr role=\"presentation\"\n\t\t><td class=\"dijitReset dijitStretch dijitButtonNode\" dojoAttachPoint=\"buttonNode\" dojoAttachEvent=\"ondijitclick:_onButtonClick,onkeypress:_onButtonKeyPress\"\n\t\t><div id=\"${id}_button\" class=\"dijitReset dijitButtonContents\"\n\t\t\tdojoAttachPoint=\"titleNode\"\n\t\t\trole=\"button\" aria-labelledby=\"${id}_label\"\n\t\t\t><div class=\"dijitReset dijitInline dijitIcon\" dojoAttachPoint=\"iconNode\" role=\"presentation\"></div\n\t\t\t><div class=\"dijitReset dijitInline dijitButtonText\" id=\"${id}_label\" dojoAttachPoint=\"containerNode\" role=\"presentation\"></div\n\t\t></div\n\t\t></td\n\t\t><td id=\"${id}_arrow\" class='dijitReset dijitRight dijitButtonNode dijitArrowButton'\n\t\t\tdojoAttachPoint=\"_popupStateNode,focusNode,_buttonNode\"\n\t\t\tdojoAttachEvent=\"onkeypress:_onArrowKeyPress\"\n\t\t\ttitle=\"${optionsTitle}\"\n\t\t\trole=\"button\" aria-haspopup=\"true\"\n\t\t\t><div class=\"dijitReset dijitArrowButtonInner\" role=\"presentation\"></div\n\t\t\t><div class=\"dijitReset dijitArrowButtonChar\" role=\"presentation\">&#9660;</div\n\t\t></td\n\t\t><td style=\"display:none !important;\"\n\t\t\t><input ${!nameAttrSetting} type=\"${type}\" value=\"${value}\" dojoAttachPoint=\"valueNode\"\n\t\t/></td></tr></tbody\n></table>\n"),

	attributeMap: dojo.mixin(dojo.clone(dijit.form.Button.prototype.attributeMap), {
		id: "",
		tabIndex: ["focusNode", "titleNode"],
		title: "titleNode"
	}),

	// optionsTitle: String
	//		Text that describes the options menu (accessibility)
	optionsTitle: "",

	baseClass: "dijitComboButton",

	// Set classes like dijitButtonContentsHover or dijitArrowButtonActive depending on
	// mouse action over specified node
	cssStateNodes: {
		"buttonNode": "dijitButtonNode",
		"titleNode": "dijitButtonContents",
		"_popupStateNode": "dijitDownArrowButton"
	},

	_focusedNode: null,

	_onButtonKeyPress: function(/*Event*/ evt){
		// summary:
		//		Handler for right arrow key when focus is on left part of button
		if(evt.charOrCode == dojo.keys[this.isLeftToRight() ? "RIGHT_ARROW" : "LEFT_ARROW"]){
			dijit.focus(this._popupStateNode);
			dojo.stopEvent(evt);
		}
	},

	_onArrowKeyPress: function(/*Event*/ evt){
		// summary:
		//		Handler for left arrow key when focus is on right part of button
		if(evt.charOrCode == dojo.keys[this.isLeftToRight() ? "LEFT_ARROW" : "RIGHT_ARROW"]){
			dijit.focus(this.titleNode);
			dojo.stopEvent(evt);
		}
	},
	
	focus: function(/*String*/ position){
		// summary:
		//		Focuses this widget to according to position, if specified,
		//		otherwise on arrow node
		// position:
		//		"start" or "end"
		if(!this.disabled){
			dijit.focus(position == "start" ? this.titleNode : this._popupStateNode);
		}
	}
});

dojo.declare("dijit.form.ToggleButton", dijit.form.Button, {
	// summary:
	//		A button that can be in two states (checked or not).
	//		Can be base class for things like tabs or checkbox or radio buttons

	baseClass: "dijitToggleButton",

	// checked: Boolean
	//		Corresponds to the native HTML <input> element's attribute.
	//		In markup, specified as "checked='checked'" or just "checked".
	//		True if the button is depressed, or the checkbox is checked,
	//		or the radio button is selected, etc.
	checked: false,

	attributeMap: dojo.mixin(dojo.clone(dijit.form.Button.prototype.attributeMap), {
		checked:"focusNode"
	}),

	_clicked: function(/*Event*/ evt){
		this.set('checked', !this.checked);
	},

	_setCheckedAttr: function(/*Boolean*/ value, /*Boolean?*/ priorityChange){
		this._set("checked", value);
		dojo.attr(this.focusNode || this.domNode, "checked", value);
		dijit.setWaiState(this.focusNode || this.domNode, "pressed", value);
		this._handleOnChange(value, priorityChange);
	},

	setChecked: function(/*Boolean*/ checked){
		// summary:
		//		Deprecated.  Use set('checked', true/false) instead.
		dojo.deprecated("setChecked("+checked+") is deprecated. Use set('checked',"+checked+") instead.", "", "2.0");
		this.set('checked', checked);
	},

	reset: function(){
		// summary:
		//		Reset the widget's value to what it was at initialization time

		this._hasBeenBlurred = false;

		// set checked state to original setting
		this.set('checked', this.params.checked || false);
	}
});

}

if(!dojo._hasResource["dijit.form.DropDownButton"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form.DropDownButton"] = true;
dojo.provide("dijit.form.DropDownButton");




}

if(!dojo._hasResource["dijit.Calendar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.Calendar"] = true;
dojo.provide("dijit.Calendar");









dojo.declare(
	"dijit.Calendar",
	[dijit._Widget, dijit._Templated, dijit._CssStateMixin],
	{
		// summary:
		//		A simple GUI for choosing a date in the context of a monthly calendar.
		//
		// description:
		//		A simple GUI for choosing a date in the context of a monthly calendar.
		//		This widget can't be used in a form because it doesn't serialize the date to an
		//		`<input>` field.  For a form element, use dijit.form.DateTextBox instead.
		//
		//		Note that the parser takes all dates attributes passed in the
		//		[RFC 3339 format](http://www.faqs.org/rfcs/rfc3339.html), e.g. `2005-06-30T08:05:00-07:00`
		//		so that they are serializable and locale-independent.
		//
		// example:
		//	|	var calendar = new dijit.Calendar({}, dojo.byId("calendarNode"));
		//
		// example:
		//	|	<div dojoType="dijit.Calendar"></div>

		templateString: dojo.cache("dijit", "templates/Calendar.html", "<table cellspacing=\"0\" cellpadding=\"0\" class=\"dijitCalendarContainer\" role=\"grid\" dojoAttachEvent=\"onkeypress: _onKeyPress\" aria-labelledby=\"${id}_year\">\n\t<thead>\n\t\t<tr class=\"dijitReset dijitCalendarMonthContainer\" valign=\"top\">\n\t\t\t<th class='dijitReset dijitCalendarArrow' dojoAttachPoint=\"decrementMonth\">\n\t\t\t\t<img src=\"${_blankGif}\" alt=\"\" class=\"dijitCalendarIncrementControl dijitCalendarDecrease\" role=\"presentation\"/>\n\t\t\t\t<span dojoAttachPoint=\"decreaseArrowNode\" class=\"dijitA11ySideArrow\">-</span>\n\t\t\t</th>\n\t\t\t<th class='dijitReset' colspan=\"5\">\n\t\t\t\t<div dojoType=\"dijit.form.DropDownButton\" dojoAttachPoint=\"monthDropDownButton\"\n\t\t\t\t\tid=\"${id}_mddb\" tabIndex=\"-1\">\n\t\t\t\t</div>\n\t\t\t</th>\n\t\t\t<th class='dijitReset dijitCalendarArrow' dojoAttachPoint=\"incrementMonth\">\n\t\t\t\t<img src=\"${_blankGif}\" alt=\"\" class=\"dijitCalendarIncrementControl dijitCalendarIncrease\" role=\"presentation\"/>\n\t\t\t\t<span dojoAttachPoint=\"increaseArrowNode\" class=\"dijitA11ySideArrow\">+</span>\n\t\t\t</th>\n\t\t</tr>\n\t\t<tr>\n\t\t\t<th class=\"dijitReset dijitCalendarDayLabelTemplate\" role=\"columnheader\"><span class=\"dijitCalendarDayLabel\"></span></th>\n\t\t</tr>\n\t</thead>\n\t<tbody dojoAttachEvent=\"onclick: _onDayClick, onmouseover: _onDayMouseOver, onmouseout: _onDayMouseOut, onmousedown: _onDayMouseDown, onmouseup: _onDayMouseUp\" class=\"dijitReset dijitCalendarBodyContainer\">\n\t\t<tr class=\"dijitReset dijitCalendarWeekTemplate\" role=\"row\">\n\t\t\t<td class=\"dijitReset dijitCalendarDateTemplate\" role=\"gridcell\"><span class=\"dijitCalendarDateLabel\"></span></td>\n\t\t</tr>\n\t</tbody>\n\t<tfoot class=\"dijitReset dijitCalendarYearContainer\">\n\t\t<tr>\n\t\t\t<td class='dijitReset' valign=\"top\" colspan=\"7\">\n\t\t\t\t<h3 class=\"dijitCalendarYearLabel\">\n\t\t\t\t\t<span dojoAttachPoint=\"previousYearLabelNode\" class=\"dijitInline dijitCalendarPreviousYear\"></span>\n\t\t\t\t\t<span dojoAttachPoint=\"currentYearLabelNode\" class=\"dijitInline dijitCalendarSelectedYear\" id=\"${id}_year\"></span>\n\t\t\t\t\t<span dojoAttachPoint=\"nextYearLabelNode\" class=\"dijitInline dijitCalendarNextYear\"></span>\n\t\t\t\t</h3>\n\t\t\t</td>\n\t\t</tr>\n\t</tfoot>\n</table>\n"),
		widgetsInTemplate: true,

		// value: Date
		//		The currently selected Date, initially set to invalid date to indicate no selection.
		value: new Date(""),
		// TODO: for 2.0 make this a string (ISO format) rather than a Date

		// datePackage: String
		//		JavaScript namespace to find Calendar routines.  Uses Gregorian Calendar routines
		//		at dojo.date by default.
		datePackage: "dojo.date",

		// dayWidth: String
		//		How to represent the days of the week in the calendar header. See dojo.date.locale
		dayWidth: "narrow",

		// tabIndex: Integer
		//		Order fields are traversed when user hits the tab key
		tabIndex: "0",

		// currentFocus: Date
		//		Date object containing the currently focused date, or the date which would be focused
		//		if the calendar itself was focused.   Also indicates which year and month to display,
		//		i.e. the current "page" the calendar is on.
		currentFocus: new Date(),

		baseClass:"dijitCalendar",

		// Set node classes for various mouse events, see dijit._CssStateMixin for more details
		cssStateNodes: {
			"decrementMonth": "dijitCalendarArrow",
			"incrementMonth": "dijitCalendarArrow",
			"previousYearLabelNode": "dijitCalendarPreviousYear",
			"nextYearLabelNode": "dijitCalendarNextYear"
		},

		_isValidDate: function(/*Date*/ value){
			// summary:
			//		Runs various tests on the value, checking that it's a valid date, rather
			//		than blank or NaN.
			// tags:
			//		private
			return value && !isNaN(value) && typeof value == "object" &&
				value.toString() != this.constructor.prototype.value.toString();
		},

		setValue: function(/*Date*/ value){
			// summary:
			//      Deprecated.   Use set('value', ...) instead.
			// tags:
			//      deprecated
			dojo.deprecated("dijit.Calendar:setValue() is deprecated.  Use set('value', ...) instead.", "", "2.0");
			this.set('value', value);
		},

		_getValueAttr: function(){
			// summary:
			//		Support get('value')

			// this.value is set to 1AM, but return midnight, local time for back-compat
			var value = new this.dateClassObj(this.value);
			value.setHours(0, 0, 0, 0);

			// If daylight savings pushes midnight to the previous date, fix the Date
			// object to point at 1am so it will represent the correct day. See #9366
			if(value.getDate() < this.value.getDate()){
				value = this.dateFuncObj.add(value, "hour", 1);
			}
			return value;
		},

		_setValueAttr: function(/*Date|Number*/ value, /*Boolean*/ priorityChange){
			// summary:
			//		Support set("value", ...)
			// description:
			// 		Set the current date and update the UI.  If the date is disabled, the value will
			//		not change, but the display will change to the corresponding month.
			// value:
			//		Either a Date or the number of seconds since 1970.
			// tags:
			//      protected
			if(value){
				// convert from Number to Date, or make copy of Date object so that setHours() call below
				// doesn't affect original value
				value = new this.dateClassObj(value);
			}
			if(this._isValidDate(value)){
				if(!this._isValidDate(this.value) || this.dateFuncObj.compare(value, this.value)){
					value.setHours(1, 0, 0, 0); // round to nearest day (1am to avoid issues when DST shift occurs at midnight, see #8521, #9366)

					if(!this.isDisabledDate(value, this.lang)){
						this._set("value", value);

						// Set focus cell to the new value.   Arguably this should only happen when there isn't a current
						// focus point.   This will also repopulate the grid, showing the new selected value (and possibly
						// new month/year).
						this.set("currentFocus", value);

						if(priorityChange || typeof priorityChange == "undefined"){
							this.onChange(this.get('value'));
							this.onValueSelected(this.get('value'));	// remove in 2.0
						}
					}
				}
			}else{
				// clear value, and repopulate grid (to deselect the previously selected day) without changing currentFocus
				this._set("value", null);
				this.set("currentFocus", this.currentFocus);
			}
		},

		_setText: function(node, text){
			// summary:
			//		This just sets the content of node to the specified text.
			//		Can't do "node.innerHTML=text" because of an IE bug w/tables, see #3434.
			// tags:
			//      private
			while(node.firstChild){
				node.removeChild(node.firstChild);
			}
			node.appendChild(dojo.doc.createTextNode(text));
		},

		_populateGrid: function(){
			// summary:
			//      Fills in the calendar grid with each day (1-31)
			// tags:
			//      private

			var month = new this.dateClassObj(this.currentFocus);
			month.setDate(1);

// EPAGES CHANGES - START
			this.displayMonth = month;
// EPAGES CHANGES - END

			var firstDay = month.getDay(),
				daysInMonth = this.dateFuncObj.getDaysInMonth(month),
				daysInPreviousMonth = this.dateFuncObj.getDaysInMonth(this.dateFuncObj.add(month, "month", -1)),
				today = new this.dateClassObj(),
				dayOffset = dojo.cldr.supplemental.getFirstDayOfWeek(this.lang);
			if(dayOffset > firstDay){ dayOffset -= 7; }

			// Iterate through dates in the calendar and fill in date numbers and style info
			dojo.query(".dijitCalendarDateTemplate", this.domNode).forEach(function(template, i){
				i += dayOffset;
				var date = new this.dateClassObj(month),
					number, clazz = "dijitCalendar", adj = 0;

				if(i < firstDay){
					number = daysInPreviousMonth - firstDay + i + 1;
					adj = -1;
					clazz += "Previous";
				}else if(i >= (firstDay + daysInMonth)){
					number = i - firstDay - daysInMonth + 1;
					adj = 1;
					clazz += "Next";
				}else{
					number = i - firstDay + 1;
					clazz += "Current";
				}

				if(adj){
					date = this.dateFuncObj.add(date, "month", adj);
				}
				date.setDate(number);

				if(!this.dateFuncObj.compare(date, today, "date")){
					clazz = "dijitCalendarCurrentDate " + clazz;
				}

				if(this._isSelectedDate(date, this.lang)){
					clazz = "dijitCalendarSelectedDate " + clazz;
				}

				if(this.isDisabledDate(date, this.lang)){
					clazz = "dijitCalendarDisabledDate " + clazz;
				}

				var clazz2 = this.getClassForDate(date, this.lang);
				if(clazz2){
					clazz = clazz2 + " " + clazz;
				}

				template.className = clazz + "Month dijitCalendarDateTemplate";
				template.dijitDateValue = date.valueOf();				// original code
				dojo.attr(template, "dijitDateValue", date.valueOf());	// so I can dojo.query() it
				var label = dojo.query(".dijitCalendarDateLabel", template)[0],
					text = date.getDateLocalized ? date.getDateLocalized(this.lang) : date.getDate();
				this._setText(label, text);
			}, this);

			// Repopulate month drop down list based on current year.
			// Need to do this to hide leap months in Hebrew calendar.
			var monthNames = this.dateLocaleModule.getNames('months', 'wide', 'standAlone', this.lang, month);
			this.monthDropDownButton.dropDown.set("months", monthNames);

			// Set name of current month and also fill in spacer element with all the month names
			// (invisible) so that the maximum width will affect layout.   But not on IE6 because then
			// the center <TH> overlaps the right <TH> (due to a browser bug).
			this.monthDropDownButton.containerNode.innerHTML =
				(dojo.isIE == 6 ? "" : "<div class='dijitSpacer'>" + this.monthDropDownButton.dropDown.domNode.innerHTML + "</div>") +
				"<div class='dijitCalendarMonthLabel dijitCalendarCurrentMonthLabel'>" +  monthNames[month.getMonth()] + "</div>";

			// Fill in localized prev/current/next years
			var y = month.getFullYear() - 1;
			var d = new this.dateClassObj();
			dojo.forEach(["previous", "current", "next"], function(name){
				d.setFullYear(y++);
				this._setText(this[name+"YearLabelNode"],
					this.dateLocaleModule.format(d, {selector:'year', locale:this.lang}));
			}, this);
		},

		goToToday: function(){
			// summary:
			//      Sets calendar's value to today's date
			this.set('value', new this.dateClassObj());
		},

		constructor: function(/*Object*/args){
			var dateClass = (args.datePackage && (args.datePackage != "dojo.date"))? args.datePackage + ".Date" : "Date";
			this.dateClassObj = dojo.getObject(dateClass, false);
			this.datePackage = args.datePackage || this.datePackage;
			this.dateFuncObj = dojo.getObject(this.datePackage, false);
			this.dateLocaleModule = dojo.getObject(this.datePackage + ".locale", false);
		},

		postMixInProperties: function(){
			// Parser.instantiate sometimes passes in NaN for IE.  Use default value in prototype instead.
			// TODO: remove this for 2.0 (thanks to #11511)
			if(isNaN(this.value)){ delete this.value; }

			this.inherited(arguments);
		},

		buildRendering: function(){
			this.inherited(arguments);
			dojo.setSelectable(this.domNode, false);

			var cloneClass = dojo.hitch(this, function(clazz, n){
				var template = dojo.query(clazz, this.domNode)[0];
	 			for(var i=0; i<n; i++){
					template.parentNode.appendChild(template.cloneNode(true));
				}
			});

			// clone the day label and calendar day templates 6 times to make 7 columns
			cloneClass(".dijitCalendarDayLabelTemplate", 6);
			cloneClass(".dijitCalendarDateTemplate", 6);

			// now make 6 week rows
			cloneClass(".dijitCalendarWeekTemplate", 5);

			// insert localized day names in the header
			var dayNames = this.dateLocaleModule.getNames('days', this.dayWidth, 'standAlone', this.lang);
			var dayOffset = dojo.cldr.supplemental.getFirstDayOfWeek(this.lang);
			dojo.query(".dijitCalendarDayLabel", this.domNode).forEach(function(label, i){
				this._setText(label, dayNames[(i + dayOffset) % 7]);
			}, this);

			var dateObj = new this.dateClassObj(this.currentFocus);

			this.monthDropDownButton.dropDown = new dijit.Calendar._MonthDropDown({
				id: this.id + "_mdd",
				onChange: dojo.hitch(this, "_onMonthSelect")
			});

			this.set('currentFocus', dateObj, false);	// draw the grid to the month specified by currentFocus

			// Set up repeating mouse behavior for increment/decrement of months/years
			var _this = this;
			var typematic = function(nodeProp, dateProp, adj){
				_this._connects.push(
// EPAGES CHANGES - START
					// this is how dojo did it before:
					// dijit.typematic.addMouseListener(_this[nodeProp], _this, function(count){
					// 	if(count >= 0){ _this._adjustDisplay(dateProp, adj); }
					// }, 0.5, 10)
					_this.connect(_this[nodeProp], "onmousedown", function(count){
						if(count >= 0){ _this._adjustDisplay(dateProp, adj); }
					})
// EPAGES CHANGES - END
				);
			};
			typematic("incrementMonth", "month", 1);
			typematic("decrementMonth", "month", -1);
			typematic("nextYearLabelNode", "year", 1);
			typematic("previousYearLabelNode", "year", -1);
		},

		_adjustDisplay: function(/*String*/ part, /*int*/ amount){
			// summary:
			//      Moves calendar forwards or backwards by months or years
			// part:
			//      "month" or "year"
			// amount:
			//      Number of months or years
			// tags:
			//      private
			this._setCurrentFocusAttr(this.dateFuncObj.add(this.currentFocus, part, amount));
		},

		_setCurrentFocusAttr: function(/*Date*/ date, /*Boolean*/ forceFocus){
			// summary:
			//		If the calendar currently has focus, then focuses specified date,
			//		changing the currently displayed month/year if necessary.
			//		If the calendar doesn't have focus, updates currently
			//		displayed month/year, and sets the cell that will get focus.
			// forceFocus:
			//		If true, will focus() the cell even if calendar itself doesn't have focus

			var oldFocus = this.currentFocus,
				oldCell = oldFocus ? dojo.query("[dijitDateValue=" + oldFocus.valueOf() + "]", this.domNode)[0] : null;

			// round specified value to nearest day (1am to avoid issues when DST shift occurs at midnight, see #8521, #9366)
			date = new this.dateClassObj(date);
			date.setHours(1, 0, 0, 0);

			this._set("currentFocus", date);

			// TODO: only re-populate grid when month/year has changed
			this._populateGrid();

			// set tabIndex=0 on new cell, and focus it (but only if Calendar itself is focused)
			var newCell = dojo.query("[dijitDateValue=" + date.valueOf() + "]", this.domNode)[0];
// EPAGES CHANGES - START
			if (newCell) {
				newCell.setAttribute("tabIndex", this.tabIndex);
				if(this._focused || forceFocus){
					newCell.focus();
				}
			}
// EPAGES CHANGES - END

			// set tabIndex=-1 on old focusable cell
			if(oldCell && oldCell != newCell){
				if(dojo.isWebKit){	// see #11064 about webkit bug
					oldCell.setAttribute("tabIndex", "-1");
				}else{
						oldCell.removeAttribute("tabIndex");
				}
			}
		},

		focus: function(){
			// summary:
			//		Focus the calendar by focusing one of the calendar cells
			this._setCurrentFocusAttr(this.currentFocus, true);
		},

		_onMonthSelect: function(/*Number*/ newMonth){
			// summary:
			//      Handler for when user selects a month from the drop down list
			// tags:
			//      protected

			// move to selected month, bounding by the number of days in the month
			// (ex: dec 31 --> jan 28, not jan 31)
			this.currentFocus = this.dateFuncObj.add(this.currentFocus, "month",
				newMonth - this.currentFocus.getMonth());
			this._populateGrid();
		},

		_onDayClick: function(/*Event*/ evt){
			// summary:
			//      Handler for day clicks, selects the date if appropriate
			// tags:
			//      protected
			dojo.stopEvent(evt);
			for(var node = evt.target; node && !node.dijitDateValue; node = node.parentNode);
			if(node && !dojo.hasClass(node, "dijitCalendarDisabledDate")){
				this.set('value', node.dijitDateValue);
			}
		},

		_onDayMouseOver: function(/*Event*/ evt){
			// summary:
			//      Handler for mouse over events on days, sets hovered style
			// tags:
			//      protected

			// event can occur on <td> or the <span> inside the td,
			// set node to the <td>.
			var node =
				dojo.hasClass(evt.target, "dijitCalendarDateLabel") ?
				evt.target.parentNode :
				evt.target;

			if(node && (node.dijitDateValue || node == this.previousYearLabelNode || node == this.nextYearLabelNode) ){
				dojo.addClass(node, "dijitCalendarHoveredDate");
				this._currentNode = node;
			}
		},

		_onDayMouseOut: function(/*Event*/ evt){
			// summary:
			//      Handler for mouse out events on days, clears hovered style
			// tags:
			//      protected

			if(!this._currentNode){ return; }

			// if mouse out occurs moving from <td> to <span> inside <td>, ignore it
			if(evt.relatedTarget && evt.relatedTarget.parentNode == this._currentNode){ return; }
			var cls = "dijitCalendarHoveredDate";
			if(dojo.hasClass(this._currentNode, "dijitCalendarActiveDate")) {
				cls += " dijitCalendarActiveDate";
			}
			dojo.removeClass(this._currentNode, cls);
			this._currentNode = null;
		},

		_onDayMouseDown: function(/*Event*/ evt){
			var node = evt.target.parentNode;
			if(node && node.dijitDateValue){
				dojo.addClass(node, "dijitCalendarActiveDate");
				this._currentNode = node;
			}
		},

		_onDayMouseUp: function(/*Event*/ evt){
			var node = evt.target.parentNode;
			if(node && node.dijitDateValue){
				dojo.removeClass(node, "dijitCalendarActiveDate");
			}
		},

//TODO: use typematic
		handleKey: function(/*Event*/ evt){
			// summary:
			//		Provides keyboard navigation of calendar.
			// description:
			//		Called from _onKeyPress() to handle keypress on a stand alone Calendar,
			//		and also from `dijit.form._DateTimeTextBox` to pass a keypress event
			//		from the `dijit.form.DateTextBox` to be handled in this widget
			// returns:
			//		False if the key was recognized as a navigation key,
			//		to indicate that the event was handled by Calendar and shouldn't be propogated
			// tags:
			//		protected
			var dk = dojo.keys,
				increment = -1,
				interval,
				newValue = this.currentFocus;
			switch(evt.keyCode){
				case dk.RIGHT_ARROW:
					increment = 1;
					//fallthrough...
				case dk.LEFT_ARROW:
					interval = "day";
					if(!this.isLeftToRight()){ increment *= -1; }
					break;
				case dk.DOWN_ARROW:
					increment = 1;
					//fallthrough...
				case dk.UP_ARROW:
					interval = "week";
					break;
				case dk.PAGE_DOWN:
					increment = 1;
					//fallthrough...
				case dk.PAGE_UP:
					interval = evt.ctrlKey || evt.altKey ? "year" : "month";
					break;
				case dk.END:
					// go to the next month
					newValue = this.dateFuncObj.add(newValue, "month", 1);
					// subtract a day from the result when we're done
					interval = "day";
					//fallthrough...
				case dk.HOME:
					newValue = new this.dateClassObj(newValue);
					newValue.setDate(1);
					break;
				case dk.ENTER:
				case dk.SPACE:
					this.set("value", this.currentFocus);
					break;
				default:
					return true;
			}

			if(interval){
				newValue = this.dateFuncObj.add(newValue, interval, increment);
			}

			this._setCurrentFocusAttr(newValue);

			return false;
		},

		_onKeyPress: function(/*Event*/ evt){
			// summary:
			//		For handling keypress events on a stand alone calendar
			if(!this.handleKey(evt)){
				dojo.stopEvent(evt);
			}
		},

		onValueSelected: function(/*Date*/ date){
			// summary:
			//		Notification that a date cell was selected.  It may be the same as the previous value.
			// description:
			//      Formerly used by `dijit.form._DateTimeTextBox` (and thus `dijit.form.DateTextBox`)
			//      to get notification when the user has clicked a date.  Now onExecute() (above) is used.
			// tags:
			//      protected
		},

		onChange: function(/*Date*/ date){
			// summary:
			//		Called only when the selected date has changed
		},

		_isSelectedDate: function(/*Date*/ dateObject, /*String?*/ locale){
			// summary:
			//		Extension point so developers can subclass Calendar to
			//		support multiple (concurrently) selected dates
			// tags:
			//		protected extension
			return this._isValidDate(this.value) && !this.dateFuncObj.compare(dateObject, this.value, "date")
		},

		isDisabledDate: function(/*Date*/ dateObject, /*String?*/ locale){
			// summary:
			//		May be overridden to disable certain dates in the calendar e.g. `isDisabledDate=dojo.date.locale.isWeekend`
			// tags:
			//      extension
/*=====
			return false; // Boolean
=====*/
		},

		getClassForDate: function(/*Date*/ dateObject, /*String?*/ locale){
			// summary:
			//		May be overridden to return CSS classes to associate with the date entry for the given dateObject,
			//		for example to indicate a holiday in specified locale.
			// tags:
			//      extension

/*=====
			return ""; // String
=====*/
		}
	}
);

dojo.declare("dijit.Calendar._MonthDropDown", [dijit._Widget, dijit._Templated], {
	// summary:
	//		The month drop down

	// months: String[]
	//		List of names of months, possibly w/some undefined entries for Hebrew leap months
	//		(ex: ["January", "February", undefined, "April", ...])
	months: [],

	templateString: "<div class='dijitCalendarMonthMenu dijitMenu' " +
		"dojoAttachEvent='onclick:_onClick,onmouseover:_onMenuHover,onmouseout:_onMenuHover'></div>",

	_setMonthsAttr: function(/*String[]*/ months){
		this.domNode.innerHTML = dojo.map(months, function(month, idx){
				return month ? "<div class='dijitCalendarMonthLabel' month='" + idx +"'>" + month + "</div>" : "";
			}).join("");
	},

	_onClick: function(/*Event*/ evt){
		this.onChange(dojo.attr(evt.target, "month"));
	},

	onChange: function(/*Number*/ month){
		// summary:
		//		Callback when month is selected from drop down
	},

	_onMenuHover: function(evt){
		dojo.toggleClass(evt.target, "dijitCalendarMonthLabelHover", evt.type == "mouseover");
	}
});

}

if(!dojo._hasResource["dijit._Calendar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._Calendar"] = true;
dojo.provide("dijit._Calendar");



dojo.deprecated("dijit._Calendar is deprecated", "dijit._Calendar moved to dijit.Calendar", 1.5);

// dijit._Calendar had an underscore all this time merely because it did
// not satisfy dijit's a11y policy.
dijit._Calendar = dijit.Calendar;

}

if(!dojo._hasResource['epages.lang.date']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.lang.date'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.lang.date');



epages.lang.date.getWeekOfYear = function(/*Date*/dateObject, /*Number*/firstDayOfWeek, /*Number*/minDaysFirstWeek){
	if(firstDayOfWeek   === undefined){ firstDayOfWeek   = epages.vars.Locale.firstDayOfWeek;   }
	if(minDaysFirstWeek === undefined){ minDaysFirstWeek = epages.vars.Locale.minDaysFirstWeek; }

	var calc = function(date) {
		var c = new Date(date.getFullYear(), 0, 1).getDay();
		if(c==0 && firstDayOfWeek == 1){
			c = 7;
		}

		// need number 7 on monday or sunday for first full week
		var week = Math.floor((dojo.date.locale._getDayOfYear(date) + c - 1 - firstDayOfWeek) / 7);
		if (minDaysFirstWeek == 1 || minDaysFirstWeek == 7 && c == firstDayOfWeek) {
			week++;
		}
		else if (minDaysFirstWeek == 4) {
			var g = c - firstDayOfWeek;
			if (g < 4) { week++; }
		}
		return week;
	};
	var result = calc(dateObject);
	if(result < 1) { // is last week of last year
		result = calc(new Date(dateObject.getFullYear() - 1, 11,31));
	}
	if(result >= 53) { // may be first week of next year
		var newyear = calc(new Date(dateObject.getFullYear() + 1, 0, 1));
		result = newyear == 0 ? result : newyear;
	}
	return result; // Number
};

}

if(!dojo._hasResource["epages.widget.Calendar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Calendar"] = true;
dojo.provide("epages.widget.Calendar");






dojo.declare("epages.widget.Calendar", [dijit.Calendar], {
		/**
		 * public properties
		 */
		firstAvailableDate : null,
		lastAvailableDate  : null,

		/**
		 * private properties
		 */
		templateType       : "default",
		defaultTemplateType: "default", // read-only!
		templateString:"<table cellspacing=\"0\" cellpadding=\"0\" class=\"dijitCalendarContainer\" role=\"grid\" dojoAttachEvent=\"onkeypress: _onKeyPress\">\n\t<thead>\n\t\t<tr class=\"dijitReset dijitCalendarMonthContainer\" valign=\"top\">\n\t\t\t<th class='dijitReset' dojoAttachPoint=\"decrementMonth\">\n\t\t\t\t<img src=\"${_blankGif}\" alt=\"\" class=\"dijitCalendarIncrementControl dijitCalendarDecrease\" waiRole=\"presentation\">\n\t\t\t\t<span dojoAttachPoint=\"decreaseArrowNode\" class=\"dijitA11ySideArrow\">-</span>\n\t\t\t</th>\n\t\t\t<th class='dijitReset' colspan=\"5\">\n\t\t\t\t<div class=\"dijitVisible\">\n\t\t\t\t\t<div class=\"dijitPopup dijitMenu dijitMenuPassive dijitHidden\" dojoAttachPoint=\"monthDropDown\" dojoAttachEvent=\"onmouseup: _onMonthSelect, onmouseover: _onMenuHover, onmouseout: _onMenuHover\">\n\t\t\t\t\t\t<div class=\"dijitCalendarMonthLabelTemplate dijitCalendarMonthLabel\"></div>\n\t\t\t\t\t</div>\n\t\t\t\t</div>\n\t\t\t\t<div dojoAttachPoint=\"monthLabelSpacer\" class=\"dijitSpacer\"></div>\n\t\t\t\t<div dojoAttachPoint=\"monthLabelNode\" class=\"dijitCalendarMonthLabel dijitInline dijitVisible\" dojoAttachEvent=\"onmousedown: _onMonthToggle\"></div>\n\t\t\t</th>\n\t\t\t<th class='dijitReset' dojoAttachPoint=\"incrementMonth\">\n\t\t\t\t<img src=\"${_blankGif}\" alt=\"\" class=\"dijitCalendarIncrementControl dijitCalendarIncrease\" waiRole=\"presentation\">\n\t\t\t\t<span dojoAttachPoint=\"increaseArrowNode\" class=\"dijitA11ySideArrow\">+</span>\n\t\t\t</th>\n\t\t</tr>\n\t\t<tr>\n\t\t\t<th class=\"dijitReset dijitCalendarDayLabelTemplate\" role=\"columnheader\"><span class=\"dijitCalendarDayLabel\"></span></th>\n\t\t</tr>\n\t</thead>\n\t<tbody dojoAttachEvent=\"onclick: _onDayClick, onmouseover: _onDayMouseOver, onmouseout: _onDayMouseOut\" class=\"dijitReset dijitCalendarBodyContainer\">\n\t\t<tr class=\"dijitReset dijitCalendarWeekTemplate\" role=\"row\">\n\t\t\t<td class=\"dijitReset dijitCalendarDateTemplate\" role=\"gridcell\"><span class=\"dijitCalendarDateLabel\"></span></td>\n\t\t</tr>\n\t</tbody>\n\t<tfoot class=\"dijitReset dijitCalendarYearContainer\">\n\t\t<tr>\n\t\t\t<td class='dijitReset' valign=\"top\" colspan=\"7\">\n\t\t\t\t<h3 class=\"dijitCalendarYearLabel\">\n\t\t\t\t\t<span dojoAttachPoint=\"previousYearLabelNode\" class=\"dijitInline dijitCalendarPreviousYear\"></span>\n\t\t\t\t\t<span dojoAttachPoint=\"currentYearLabelNode\" class=\"dijitInline dijitCalendarSelectedYear\"></span>\n\t\t\t\t\t<span dojoAttachPoint=\"nextYearLabelNode\" class=\"dijitInline dijitCalendarNextYear\"></span>\n\t\t\t\t</h3>\n\t\t\t\t<div class=\"HideElement\" dojoType=\"dijit.form.DropDownButton\" dojoAttachPoint=\"monthDropDownButton\" id=\"${id}_mddb\" tabIndex=\"-1\"></div>\n\t\t\t</td>\n\t\t</tr>\n\t</tfoot>\n</table>\n", // need template for weeknumber
		_templateDirectory : dojo.moduleUrl("epages.widget", "templates"),
		widgetsInTemplate : true,
		_templateMapping : {
			'default' : {templateString:"<table cellspacing=\"0\" cellpadding=\"0\" class=\"dijitCalendarContainer\" role=\"grid\" dojoAttachEvent=\"onkeypress: _onKeyPress\">\n\t<thead>\n\t\t<tr class=\"dijitReset dijitCalendarMonthContainer\" valign=\"top\">\n\t\t\t<th class='dijitReset' dojoAttachPoint=\"decrementMonth\">\n\t\t\t\t<img src=\"${_blankGif}\" alt=\"\" class=\"dijitCalendarIncrementControl dijitCalendarDecrease\" waiRole=\"presentation\">\n\t\t\t\t<span dojoAttachPoint=\"decreaseArrowNode\" class=\"dijitA11ySideArrow\">-</span>\n\t\t\t</th>\n\t\t\t<th class='dijitReset' colspan=\"5\">\n\t\t\t\t<div class=\"dijitVisible\">\n\t\t\t\t\t<div class=\"dijitPopup dijitMenu dijitMenuPassive dijitHidden\" dojoAttachPoint=\"monthDropDown\" dojoAttachEvent=\"onmouseup: _onMonthSelect, onmouseover: _onMenuHover, onmouseout: _onMenuHover\">\n\t\t\t\t\t\t<div class=\"dijitCalendarMonthLabelTemplate dijitCalendarMonthLabel\"></div>\n\t\t\t\t\t</div>\n\t\t\t\t</div>\n\t\t\t\t<div dojoAttachPoint=\"monthLabelSpacer\" class=\"dijitSpacer\"></div>\n\t\t\t\t<div dojoAttachPoint=\"monthLabelNode\" class=\"dijitCalendarMonthLabel dijitInline dijitVisible\" dojoAttachEvent=\"onmousedown: _onMonthToggle\"></div>\n\t\t\t</th>\n\t\t\t<th class='dijitReset' dojoAttachPoint=\"incrementMonth\">\n\t\t\t\t<img src=\"${_blankGif}\" alt=\"\" class=\"dijitCalendarIncrementControl dijitCalendarIncrease\" waiRole=\"presentation\">\n\t\t\t\t<span dojoAttachPoint=\"increaseArrowNode\" class=\"dijitA11ySideArrow\">+</span>\n\t\t\t</th>\n\t\t</tr>\n\t\t<tr>\n\t\t\t<th class=\"dijitReset dijitCalendarDayLabelTemplate\" role=\"columnheader\"><span class=\"dijitCalendarDayLabel\"></span></th>\n\t\t</tr>\n\t</thead>\n\t<tbody dojoAttachEvent=\"onclick: _onDayClick, onmouseover: _onDayMouseOver, onmouseout: _onDayMouseOut\" class=\"dijitReset dijitCalendarBodyContainer\">\n\t\t<tr class=\"dijitReset dijitCalendarWeekTemplate\" role=\"row\">\n\t\t\t<td class=\"dijitReset dijitCalendarDateTemplate\" role=\"gridcell\"><span class=\"dijitCalendarDateLabel\"></span></td>\n\t\t</tr>\n\t</tbody>\n\t<tfoot class=\"dijitReset dijitCalendarYearContainer\">\n\t\t<tr>\n\t\t\t<td class='dijitReset' valign=\"top\" colspan=\"7\">\n\t\t\t\t<h3 class=\"dijitCalendarYearLabel\">\n\t\t\t\t\t<span dojoAttachPoint=\"previousYearLabelNode\" class=\"dijitInline dijitCalendarPreviousYear\"></span>\n\t\t\t\t\t<span dojoAttachPoint=\"currentYearLabelNode\" class=\"dijitInline dijitCalendarSelectedYear\"></span>\n\t\t\t\t\t<span dojoAttachPoint=\"nextYearLabelNode\" class=\"dijitInline dijitCalendarNextYear\"></span>\n\t\t\t\t</h3>\n\t\t\t\t<div class=\"HideElement\" dojoType=\"dijit.form.DropDownButton\" dojoAttachPoint=\"monthDropDownButton\" id=\"${id}_mddb\" tabIndex=\"-1\"></div>\n\t\t\t</td>\n\t\t</tr>\n\t</tfoot>\n</table>\n"},
			'flat'    : {templateString:"<div class=\"Calendar Flat dijitCalendarContainer\"><div class=\"InnerContainer\">\n\t<div>\n\t\t<div class=\"dijitReset dijitCalendarMonthContainer\"><div class=\"MonthSelection\">\n\t\t\t<div class='dijitReset' dojoAttachPoint=\"decrementMonth\">\n\t\t\t\t<span class=\"dijitInline dijitCalendarIncrementControl dijitCalendarDecrease\"><span dojoAttachPoint=\"decreaseArrowNode\" class=\"dijitA11ySideArrow dijitCalendarIncrementControl dijitCalendarDecreaseInner\">-</span></span>\n\t\t\t</div>\n\t\t\t<div class='dijitReset'>\n\t\t\t\t<div dojoAttachPoint=\"monthLabelSpacer\" class=\"dijitCalendarMonthLabelSpacer\"></div>\n\t\t\t\t<div dojoAttachPoint=\"monthLabelNode\" class=\"dijitCalendarMonth\"></div>\n\t\t\t</div>\n\t\t\t<div class='dijitReset' dojoAttachPoint=\"incrementMonth\">\n\t\t\t\t<div class=\"dijitInline dijitCalendarIncrementControl dijitCalendarIncrease\"><span dojoAttachPoint=\"increaseArrowNode\" class=\"dijitA11ySideArrow dijitCalendarIncrementControl dijitCalendarIncreaseInner\">+</span></div>\n\t\t\t</div>\n\t\t</div></div>\n\t\t<div class=\"DayLabelHead\">\n\t\t\t<div class=\"dijitReset dijitCalendarWeekLabelTemplate\"><span class=\"dijitCalendarWeekLabel\"></span></div>\n\t\t\t<div class=\"dijitReset dijitCalendarDayLabelTemplate\"><span class=\"dijitCalendarDayLabel\"></span></div>\n\t\t</div>\n\t</div>\n\t<div dojoAttachEvent=\"onclick: _onDayClick\" class=\"dijitReset dijitCalendarBodyContainer\">\n\t\t<div class=\"dijitReset dijitCalendarWeekTemplate\">\n\t\t\t<div class=\"dijitReset dijitCalendarWeekTemplate\"><span class=\"dijitCalendarWeekLabel\"></span></div>\n\t\t\t<div class=\"dijitReset dijitCalendarDateTemplate\"><span class=\"dijitCalendarDateLabel\"></span></div>\n\t\t</div>\n\t</div>\n\t<div class=\"dijitReset dijitCalendarYearContainer\">\n\t\t<div>\n\t\t\t<div class='dijitReset' >\n\t\t\t\t<h3 class=\"dijitCalendarYearLabel\">\n\t\t\t\t\t<span dojoAttachPoint=\"previousYearLabelNode\" class=\"dijitInline dijitCalendarPreviousYear\"></span>\n\t\t\t\t\t<span dojoAttachPoint=\"currentYearLabelNode\" class=\"dijitInline dijitCalendarSelectedYear\"></span>\n\t\t\t\t\t<span dojoAttachPoint=\"nextYearLabelNode\" class=\"dijitInline dijitCalendarNextYear\"></span>\n\t\t\t\t</h3>\n\t\t\t</div>\n\t\t</div>\n\t</div>\n\t<div class=\"HideElement dijitCalendarMonthLabelTemplate\"></div>\n\t<div class=\"HideElement\" dojoType=\"dijit.form.DropDownButton\" dojoAttachPoint=\"monthDropDownButton\" id=\"${id}_mddb\" tabIndex=\"-1\"></div>\n\t<div class=\"Bottom\"></div>\n</div></div>\n\n"}
		},
		_yearTip: '',

		postMixInProperties: function() {
			this.inherited("postMixInProperties", arguments);
			if (this._templateMapping !== undefined &&  this.templateType !== undefined &&  this._templateDirectory !== undefined) {
				if(this._templateMapping[this.templateType]!==undefined) {
					// check if set to widget's default using its prototype value
					if(this.templateType != this.defaultTemplateType) {
						var tempPath = '';

							// load templates from json object..
							if(typeof this._templateMapping[this.templateType] == 'object'){
								var TempObj = this._templateMapping[this.templateType];

								// ..from shrinksafed packages
								if(TempObj.templateString){
										this.templatePath   = null;
										this.templateString = TempObj.templateString;
								}

								// ..from sources
								else if(TempObj.templatePath){
									var TempTemplateString;
									dojo.xhrGet({
										url: TempObj.templatePath,
										sync: true,
										load: function(data){
											TempTemplateString = data;
										}
									});
									this.templatePath   = null;
									this.templateString = TempTemplateString;
								} else {
										console.warn('Template type: "'+ this.templateType +'" could not be loaded from json object! Use properties templatePath or templateString to declare its template file!');
								}
							}

					}
				} else {
					console.warn('Template type: "'+ this.templateType +'" does not exist in this widget - use default. ('+this.declaredClass+')');
				}
			}
			this._dictionary = new epages.io.Translation(dojo.moduleUrl('epages.widget', "templates/translation"), "auto");
			this._yearTip = this._dictionary.get('YearTip');


		},

		postCreate: function() {
			var d = this.value;
			this.inherited("postCreate", arguments);
			this.attr('value',null);
			this.attr('value',d);

		},

		_populateGrid: function(){
			epages.widget.Calendar.superclass._populateGrid.apply(this);
			dojo.query(".dijitCalendarWeekLabel", this.domNode).forEach(function(label, i) {
				if (i) {
					var node = label.parentNode.nextSibling;
					while (node != null && node.nodeName == '#text'){
						node = node.nextSibling;
					}
					this._setText(label, epages.lang.date.getWeekOfYear(new Date(node.dijitDateValue), dojo.cldr.supplemental.getFirstDayOfWeek(this.lang)));
				}
			}, this);
		},

		_dateNode: function (node) {
			while(node && !node.dijitDateValue){ node = node.parentNode; }
			return node;
		},

		// disallow clicks on calendar weeks
		_onDayClick: function(/*Event*/evt){
			var node = evt.target;
			if(dojo.hasClass(node, "dijitCalendarDateLabel")) {
				epages.widget.Calendar.superclass._onDayClick.apply(this, arguments);
			} else {
				dojo.stopEvent(evt);
			}
		},

		isDisabledDate: function(/*Date*/ date, /*String?*/ locale) {
			date.setHours(0,0,0,0);
			// check if a date is between a the available period
			return (this.lastAvailableDate && date > this.lastAvailableDate) ||
						 (this.firstAvailableDate && date < this.firstAvailableDate);
		},

		_onMenuHover: function(e){
			dojo.stopEvent(e);
			dojo.toggleClass(e.target, "dijitMenuItemHover");
		},

		_onMonthToggle: function(/*Event*/ evt){
			// summary:
			//      Handler for when user triggers or dismisses the month list
			// tags:
			//      protected
			dojo.stopEvent(evt);

			if(evt.type == "mousedown"){
				var coords = dojo.position(this.monthLabelNode);
//				coords.y -= dojo.position(this.domNode, true).y;
				// Size the dropdown's width to match the label in the widget
				// so that they are horizontally aligned
				var dim = {
					width: coords.w + "px",
					top: -this.displayMonth.getMonth() * coords.h + "px"
				};
				if((dojo.isIE && dojo.isQuirks) || dojo.isIE < 7){
					dim.left = -coords.w/2 + "px";
				}
				dojo.style(this.monthDropDown, dim);
				this._popupHandler = this.connect(document, "onmouseup", "_onMonthToggle");
			}else{
				this.disconnect(this._popupHandler);
				delete this._popupHandler;
			}

			dojo.toggleClass(this.monthDropDown, "dijitHidden");
			dojo.toggleClass(this.monthLabelNode, "dijitVisible");
		}
});

}

if(!dojo._hasResource["epages.widget.Datetimeinput"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Datetimeinput"] = true;
dojo.provide("epages.widget.Datetimeinput");








dojo.declare(
	"epages.widget.Datetimeinput",
	[dijit._Widget, dijit._Templated],
	{
		templateString:"<span style=\"white-space:nowrap\" class=\"Datetimeinput\" >\n  <input type=\"text\" dojoAttachPoint=\"textBoxNode\" class=\"${class}\" style=\"${style}\" name=\"${name}\" autocomplete=\"off\" />\n  <img class=\"ButtonNode\" dojoAttachPoint=\"buttonNode\"\n        alt=\"${title}\" title=\"${title}\"\n        src=\"${image}\" />\n  <div style=\"display:none\" dojoAttachPoint=\"popupNode\" class=\"CalendarAndTimer\">\n    <div class=\"Layer\">\n      <div class=\"LayerTitleBar\">\n        <div class=\"LayerCloseButton EnableHover\" dojoAttachEvent=\"onclick: closePopup\"></div>\n      </div>\n      <div class=\"ContentContainer\">\n        <div class=\"CalendarNode\" dojoAttachPoint=\"calendarNode\"></div>\n        <div class=\"TimerWrapper\" dojoAttachPoint=\"timerNode\"></div>\n        <div style=\"clear:both\"></div>\n      </div>\n    </div>\n  </div>\n </span>\n",
		dojoPattern:        '',
		pattern:            '',
		popupclass:         '',
		'style':            '',
		name:               '',
		textId:             '', // String - id for text node
		value:              '',
		selector:           'date',// String - can be: "date", "time" or "datetime"
		calendar:           null, // dojo._Widjet - insert other calender as parameter
		timer:              null, // dojo._Widjet - insert other time selector as parameter
		hideOnBlur:         true, // Boolean - hide calendar/time on cick outside
		imagePath:          epages.themeUrl('images'),
		image:              '',
		title:              '',
		onchange:           'void(0)',
		firstAvailableDate: '',
		lastAvailableDate:  '',
		disabled:           '',
		textBoxWidget:      undefined, // epages.widget.FormElement -
		textBoxNode:        undefined, // DomNode - dom node of textBoxWidget

		_isChangeInput: 		false, // Boolean - dont not change input field if user makes on input
		// assign selectors to formats
		_formats: {
			'date':     			'dateFormat',
			'time':     			'timeFormat',
			'datetime': 			'datetimeFormat',
			'iso':						'iso'
		},
		_titles: {
			'date':     			'SelectDate',
			'time':     			'SelectTime',
			'datetime': 			'SelectDatetime'
		},
		_formatError: false,
		_ep_connects: undefined, // [] - saved connections


		/* widget life cycle */

		postMixInProperties: function() {
			this.inherited("postMixInProperties", arguments);

			this._ep_connects =[];
			
			// save the original value
			this.originalValue = this.value;

			if(this._formats[this.selector] == 'iso'){
				this.value = epages.localize.parseDateTime(this.value, '%y-%m-%d');
				this.pattern = this.pattern || epages.vars.Locale[this._formats['dateFormat']];
			}
			else{
				this.pattern = this.pattern || epages.vars.Locale[this._formats[this.selector]];
			}
			
			var parsedValue = null;
			if (typeof(this.value) == "string" && this.value != ''){
				parsedValue = epages.localize.parseDateTime(this.value, this.pattern);
			}
			else{
				this.value = null;
			}
			if( parsedValue==null && this.originalValue ){
				this._formatError = true;
			}
			else{
				this.value = parsedValue;
			}
			//if (typeof(this.value) == "string") this.value = this.value == '' ? null : epages.localize.parseDateTime(this.value, this.pattern);
			var fileType = (epages.Browser.engine == "MSIE" && epages.Browser.version=="6" ) ? "gif" : "png";
			if (this.image == ''){
				this.image = this.imagePath + (this.selector == 'time' ? '/ico_s_clock.'+fileType : '/ico_s_calendar.'+fileType);
			}
			if (this.title == ''){
				this.title = epages.io.dictionary.get(this._titles[this.selector]);
			}
			if (this.firstAvailableDate){
				this.firstAvailableDate = epages.localize.parseDateTime(this.firstAvailableDate, this.pattern);
			}
			if (this.lastAvailableDate){
				this.lastAvailableDate = epages.localize.parseDateTime(this.lastAvailableDate, this.pattern);
			}

			this.disabled = this.disabled.toLowerCase();
			this.disabled = (this.disabled =="true" || this.disabled =="disabled" || this.disabled == "1") ? true : false;

		},

		postCreate: function() {
			this.inherited("postCreate", arguments);

			// parse date value and provide to text box and calendar

			this.textBoxWidget = new epages.widget.FormElement({}, this.textBoxNode);
			this.textBoxWidget.attr('pattern', epages.localize.getPattern(this.selector||'datetime'));
			this.textBoxNode = this.textBoxWidget.elementNode;
			if(this.disabled) {
				this.disable();
			}

			this.textBoxNode.value = this.textBoxNode.defaultValue = this.originalValue;
			
			if( this._formatError ){
				// turn red if not empty and formaterror
				dojo.addClass(this.textBoxNode, 'DialogError');
			}
			if (this.textId != ''){
				this.textBoxNode.id = this.textId;
			}
			this._ep_connects.push(dojo.connect(this.buttonNode,  "click",  this, 'toggleCalendar'));
			this._ep_connects.push(dojo.connect(this.textBoxNode, "keyup",  this, "onValueInput"));
			this._ep_connects.push(dojo.connect(this.textBoxNode, "change", this, "onValueInput"));
			this.textBoxNode.onchange = dojo.hitch(this, function() { eval(this.onchange); });
		},

		destroy : function() {
			// detach events
			var connects = this._ep_connects;
			for(var c in connects) {
				dojo.disconnect(connects[c]);
				delete this._ep_connects[c];
			}

			// destroy inner widgets
			if(this.timer) {
				this.timer.destroy();
			}
			if(this.calendar) {
				this.calendar.destroy();
			}
			if(this.popup) {
				this.popup.destroy();
			}
			if(this.textBoxWidget) {
				this.textBoxWidget.destroy();
			}
			this.inherited("destroy", arguments);
		},

		/* public: setter / getter */

		setValueInBox: function(date, startupUpdate) {
			if (date) {
				this.value = new Date(date);
				if (!this._isChangeInput) {
					this.textBoxNode.value = epages.localize.formatDateTime(date, this.pattern);
					if(startupUpdate) {
						this.textBoxNode.startupValue = this.textBoxNode.value;
					}
					dojo.removeClass(this.textBoxNode, 'DialogError');
				}
			} else {
				this.value = undefined;
				this.textBoxNode.value = '';
			}
			dojo.publish(this.id + '/change', [this.value, this.textBoxNode.value]);
			// inform search/submit button
			if(!this._isChangeInput){
				epages.event.fire(this.textBoxNode,'change');
			}
		},

		setValue: function(date) {
			if(date === undefined || date === null || date == ''){
				this.setValueInBox(undefined);
			}else{
				this.value = typeof(date) == 'string' ? epages.localize.parseDateTime(date, this.pattern) :  new Date(date);
				this.onTimeChange(this.value);
			}
		},

		disable: function() {
		// summary: disable inputfield and button
			this.textBoxNode.disabled="disabled";
			dojo.addClass(this.buttonNode , "Opacity30");
			this.disabled = true;
		},

		enable: function() {
		// summary: enable inputfield and button
			this.textBoxNode.disabled="";
			dojo.removeClass(this.buttonNode , "Opacity30");
			this.disabled = false;
		},

		/* private */

		_createCalendar: function() {
			// summary: create calendar widget
			if( this.value == null ){
				this.value = this.firstStartDate ? this.firstStartDate : new Date();
				if(this.calendar && this.calendar.value && dojo.date.compare(this.calendar.value, this.value, "date")){
					this.value = this.calendar.value;
				}
			}
			if(this.selector != 'date') {
				if (this.timer == null) {
					
					this.timer = new epages.widget.Timespinner({ value: this.value }, this.timerNode);
					if(this.selector != "datetime") {
						this.timer.domNode.style.border = "0";
					}
				} else {
					this.timer.setValue(this.value);
					this.timerNode.parentNode.replaceChild(this.timer.domNode, this.timerNode);
				}
				dojo.subscribe(this.timer.id + '/onChange', this, 'onTimeChange');
			}
			if(this.selector != 'time') {
				if (this.calendar == null) {
					
					this.calendar = new epages.widget.Calendar({
						value: this.value,
						timer: this.timer,
						firstAvailableDate: this.firstAvailableDate,
						lastAvailableDate: this.lastAvailableDate
					}, this.calendarNode);
				} else {
					if (this.calendar.setValue === undefined && typeof this.calendar == 'function') {
						this.calendar = this.calendar();
					}
					this.calendar.attr('value',this.value);
					this.calendarNode.parentNode.replaceChild(this.calendar.domNode, this.calendarNode);
				}
				this.calendar.onValueSelected = dojo.hitch(this, 'onCalendarChange');
			}
			this.popup = new epages.widget.Popup({
				parent:     this.buttonNode,
				around:     this.buttonNode,
				hideOnBlur: this.hideOnBlur,
				'class':    this['popupclass']
			}, this.popupNode);
			this.attr('value',this.value);
		},

		/* event functions */

		toggleCalendar: function() {
			if(!this.disabled) {
				if (this.popup == null){
					this._createCalendar();
				}
				if (this.value === undefined) {
					// set calendar to current date, but dont change input field
					this._isChangeInput = true;
					var newDate = this.firstStartDate ? this.firstStartDate : new Date();
					this.calendar.attr('value',newDate);
					this._isChangeInput = false;
				}
				this.popup.toggle();
			}
		},

		onCalendarChange: function(date) {
			if(this.value === undefined){
				var newDate = this.firstStartDate ? this.firstStartDate : new Date();
				this.value = newDate;
			}
			date.setHours(this.value.getHours(),this.value.getMinutes(),this.value.getSeconds());
			if (this.timer != null){
				this.timer.attr('value',date);
				this.setValueInBox(this.timer.getValue());
			}
			else{
				this.setValueInBox(date);
			}
			if (this.selector == 'date'){
				this.popup.hide();
			}
			this.textBoxWidget.validate();
		},

		onTimeChange: function(date) {
			//var date = new Date(this.value.getFullYear(), this.value.getMonth(), this.value.getDate(), date.getHours(),date.getMinutes(),date.getSeconds());
			if (this.calendar != null) {
				this.value = new Date(date); // set time for onCalendarChange
				if (typeof this.calendar.setValue == 'function') { // calendar loaded
					this.onCalendarChange(date);
					//this.calendar.attr('value',date); // calls onCalendarChange
				} else {
						this.setValueInBox(date);
				}
			} else {
				this.setValueInBox(date);
			}
		},

		onValueInput: function(evt) {
			this._isChangeInput = true;
			var value = this.textBoxNode.value;
			var date = value =='' ? null : epages.localize.parseDateTime(value, this.pattern);
			if (value =='' ||  date != null ) {
				this.attr('value',date);
				dojo.removeClass(this.textBoxNode, 'DialogError');
			} else {
				dojo.addClass(this.textBoxNode, 'DialogError');
			}
			this._isChangeInput = false;
		},

		closePopup: function() {
			this.popup.hide();
		}
	}
);

}

if(!dojo._hasResource["dijit._KeyNavContainer"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._KeyNavContainer"] = true;
dojo.provide("dijit._KeyNavContainer");



dojo.declare("dijit._KeyNavContainer",
	dijit._Container,
	{

		// summary:
		//		A _Container with keyboard navigation of its children.
		// description:
		//		To use this mixin, call connectKeyNavHandlers() in
		//		postCreate() and call startupKeyNavChildren() in startup().
		//		It provides normalized keyboard and focusing code for Container
		//		widgets.
/*=====
		// focusedChild: [protected] Widget
		//		The currently focused child widget, or null if there isn't one
		focusedChild: null,
=====*/

		// tabIndex: Integer
		//		Tab index of the container; same as HTML tabIndex attribute.
		//		Note then when user tabs into the container, focus is immediately
		//		moved to the first item in the container.
		tabIndex: "0",

		_keyNavCodes: {},

		connectKeyNavHandlers: function(/*dojo.keys[]*/ prevKeyCodes, /*dojo.keys[]*/ nextKeyCodes){
			// summary:
			//		Call in postCreate() to attach the keyboard handlers
			//		to the container.
			// preKeyCodes: dojo.keys[]
			//		Key codes for navigating to the previous child.
			// nextKeyCodes: dojo.keys[]
			//		Key codes for navigating to the next child.
			// tags:
			//		protected

			var keyCodes = (this._keyNavCodes = {});
			var prev = dojo.hitch(this, this.focusPrev);
			var next = dojo.hitch(this, this.focusNext);
			dojo.forEach(prevKeyCodes, function(code){ keyCodes[code] = prev; });
			dojo.forEach(nextKeyCodes, function(code){ keyCodes[code] = next; });
			keyCodes[dojo.keys.HOME] = dojo.hitch(this, "focusFirstChild");
			keyCodes[dojo.keys.END] = dojo.hitch(this, "focusLastChild");
			this.connect(this.domNode, "onkeypress", "_onContainerKeypress");
			this.connect(this.domNode, "onfocus", "_onContainerFocus");
		},

		startupKeyNavChildren: function(){
			// summary:
			//		Call in startup() to set child tabindexes to -1
			// tags:
			//		protected
			dojo.forEach(this.getChildren(), dojo.hitch(this, "_startupChild"));
		},

		addChild: function(/*dijit._Widget*/ widget, /*int?*/ insertIndex){
			// summary:
			//		Add a child to our _Container
			dijit._KeyNavContainer.superclass.addChild.apply(this, arguments);
			this._startupChild(widget);
		},

		focus: function(){
			// summary:
			//		Default focus() implementation: focus the first child.
			this.focusFirstChild();
		},

		focusFirstChild: function(){
			// summary:
			//		Focus the first focusable child in the container.
			// tags:
			//		protected
			var child = this._getFirstFocusableChild();
			if(child){ // edge case: Menu could be empty or hidden
				this.focusChild(child);
			}
		},

		focusLastChild: function(){
			// summary:
			//		Focus the last focusable child in the container.
			// tags:
			//		protected
			var child = this._getLastFocusableChild();
			if(child){ // edge case: Menu could be empty or hidden
				this.focusChild(child);
			}
		},

		focusNext: function(){
			// summary:
			//		Focus the next widget
			// tags:
			//		protected
			var child = this._getNextFocusableChild(this.focusedChild, 1);
			this.focusChild(child);
		},

		focusPrev: function(){
			// summary:
			//		Focus the last focusable node in the previous widget
			//		(ex: go to the ComboButton icon section rather than button section)
			// tags:
			//		protected
			var child = this._getNextFocusableChild(this.focusedChild, -1);
			this.focusChild(child, true);
		},

		focusChild: function(/*dijit._Widget*/ widget, /*Boolean*/ last){
			// summary:
			//		Focus widget.
			// widget:
			//		Reference to container's child widget
			// last:
			//		If true and if widget has multiple focusable nodes, focus the
			//		last one instead of the first one
			// tags:
			//		protected
			
			if(this.focusedChild && widget !== this.focusedChild){
				this._onChildBlur(this.focusedChild);
			}
			widget.set("tabIndex", this.tabIndex);	// for IE focus outline to appear, must set tabIndex before focs
			widget.focus(last ? "end" : "start");
			this._set("focusedChild", widget);
		},

		_startupChild: function(/*dijit._Widget*/ widget){
			// summary:
			//		Setup for each child widget
			// description:
			//		Sets tabIndex=-1 on each child, so that the tab key will
			//		leave the container rather than visiting each child.
			// tags:
			//		private
			
			widget.set("tabIndex", "-1");
			
			this.connect(widget, "_onFocus", function(){
				// Set valid tabIndex so tabbing away from widget goes to right place, see #10272
				widget.set("tabIndex", this.tabIndex);
			});
			this.connect(widget, "_onBlur", function(){
				widget.set("tabIndex", "-1");
			});
		},

		_onContainerFocus: function(evt){
			// summary:
			//		Handler for when the container gets focus
			// description:
			//		Initially the container itself has a tabIndex, but when it gets
			//		focus, switch focus to first child...
			// tags:
			//		private

			// Note that we can't use _onFocus() because switching focus from the
			// _onFocus() handler confuses the focus.js code
			// (because it causes _onFocusNode() to be called recursively)

			// focus bubbles on Firefox,
			// so just make sure that focus has really gone to the container
			if(evt.target !== this.domNode){ return; }

			this.focusFirstChild();

			// and then set the container's tabIndex to -1,
			// (don't remove as that breaks Safari 4)
			// so that tab or shift-tab will go to the fields after/before
			// the container, rather than the container itself
			dojo.attr(this.domNode, "tabIndex", "-1");
		},

		_onBlur: function(evt){
			// When focus is moved away the container, and its descendant (popup) widgets,
			// then restore the container's tabIndex so that user can tab to it again.
			// Note that using _onBlur() so that this doesn't happen when focus is shifted
			// to one of my child widgets (typically a popup)
			if(this.tabIndex){
				dojo.attr(this.domNode, "tabIndex", this.tabIndex);
			}
			this.inherited(arguments);
		},

		_onContainerKeypress: function(evt){
			// summary:
			//		When a key is pressed, if it's an arrow key etc. then
			//		it's handled here.
			// tags:
			//		private
			if(evt.ctrlKey || evt.altKey){ return; }
			var func = this._keyNavCodes[evt.charOrCode];
			if(func){
				func();
				dojo.stopEvent(evt);
			}
		},

		_onChildBlur: function(/*dijit._Widget*/ widget){
			// summary:
			//		Called when focus leaves a child widget to go
			//		to a sibling widget.
			// tags:
			//		protected
		},

		_getFirstFocusableChild: function(){
			// summary:
			//		Returns first child that can be focused
			return this._getNextFocusableChild(null, 1);	// dijit._Widget
		},

		_getLastFocusableChild: function(){
			// summary:
			//		Returns last child that can be focused
			return this._getNextFocusableChild(null, -1);	// dijit._Widget
		},

		_getNextFocusableChild: function(child, dir){
			// summary:
			//		Returns the next or previous focusable child, compared
			//		to "child"
			// child: Widget
			//		The current widget
			// dir: Integer
			//		* 1 = after
			//		* -1 = before
			if(child){
				child = this._getSiblingOfChild(child, dir);
			}
			var children = this.getChildren();
			for(var i=0; i < children.length; i++){
				if(!child){
					child = children[(dir>0) ? 0 : (children.length-1)];
				}
				if(child.isFocusable()){
					return child;	// dijit._Widget
				}
				child = this._getSiblingOfChild(child, dir);
			}
			// no focusable child found
			return null;	// dijit._Widget
		}
	}
);

}

if(!dojo._hasResource["dijit.MenuItem"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.MenuItem"] = true;
dojo.provide("dijit.MenuItem");






dojo.declare("dijit.MenuItem",
		[dijit._Widget, dijit._Templated, dijit._Contained, dijit._CssStateMixin],
		{
		// summary:
		//		A line item in a Menu Widget

		// Make 3 columns
		// icon, label, and expand arrow (BiDi-dependent) indicating sub-menu
		templateString: dojo.cache("dijit", "templates/MenuItem.html", "<tr class=\"dijitReset dijitMenuItem\" dojoAttachPoint=\"focusNode\" role=\"menuitem\" tabIndex=\"-1\"\n\t\tdojoAttachEvent=\"onmouseenter:_onHover,onmouseleave:_onUnhover,ondijitclick:_onClick\">\n\t<td class=\"dijitReset dijitMenuItemIconCell\" role=\"presentation\">\n\t\t<img src=\"${_blankGif}\" alt=\"\" class=\"dijitIcon dijitMenuItemIcon\" dojoAttachPoint=\"iconNode\"/>\n\t</td>\n\t<td class=\"dijitReset dijitMenuItemLabel\" colspan=\"2\" dojoAttachPoint=\"containerNode\"></td>\n\t<td class=\"dijitReset dijitMenuItemAccelKey\" style=\"display: none\" dojoAttachPoint=\"accelKeyNode\"></td>\n\t<td class=\"dijitReset dijitMenuArrowCell\" role=\"presentation\">\n\t\t<div dojoAttachPoint=\"arrowWrapper\" style=\"visibility: hidden\">\n\t\t\t<img src=\"${_blankGif}\" alt=\"\" class=\"dijitMenuExpand\"/>\n\t\t\t<span class=\"dijitMenuExpandA11y\">+</span>\n\t\t</div>\n\t</td>\n</tr>\n"),

		attributeMap: dojo.delegate(dijit._Widget.prototype.attributeMap, {
			label: { node: "containerNode", type: "innerHTML" },
			iconClass: { node: "iconNode", type: "class" }
		}),

		baseClass: "dijitMenuItem",

		// label: String
		//		Menu text
		label: '',

		// iconClass: String
		//		Class to apply to DOMNode to make it display an icon.
		iconClass: "",

		// accelKey: String
		//		Text for the accelerator (shortcut) key combination.
		//		Note that although Menu can display accelerator keys there
		//		is no infrastructure to actually catch and execute these
		//		accelerators.
		accelKey: "",

		// disabled: Boolean
		//		If true, the menu item is disabled.
		//		If false, the menu item is enabled.
		disabled: false,

		_fillContent: function(/*DomNode*/ source){
			// If button label is specified as srcNodeRef.innerHTML rather than
			// this.params.label, handle it here.
			if(source && !("label" in this.params)){
				this.set('label', source.innerHTML);
			}
		},

		buildRendering: function(){
			this.inherited(arguments);
			var label = this.id+"_text";
			dojo.attr(this.containerNode, "id", label);
			if(this.accelKeyNode){
				dojo.attr(this.accelKeyNode, "id", this.id + "_accel");
				label += " " + this.id + "_accel";
			}
			dijit.setWaiState(this.domNode, "labelledby", label);
			dojo.setSelectable(this.domNode, false);
		},

		_onHover: function(){
			// summary:
			//		Handler when mouse is moved onto menu item
			// tags:
			//		protected
			this.getParent().onItemHover(this);
		},

		_onUnhover: function(){
			// summary:
			//		Handler when mouse is moved off of menu item,
			//		possibly to a child menu, or maybe to a sibling
			//		menuitem or somewhere else entirely.
			// tags:
			//		protected

			// if we are unhovering the currently selected item
			// then unselect it
			this.getParent().onItemUnhover(this);

			// When menu is hidden (collapsed) due to clicking a MenuItem and having it execute,
			// FF and IE don't generate an onmouseout event for the MenuItem.
			// So, help out _CssStateMixin in this case.
			this._set("hovering", false);
		},

		_onClick: function(evt){
			// summary:
			//		Internal handler for click events on MenuItem.
			// tags:
			//		private
			this.getParent().onItemClick(this, evt);
			dojo.stopEvent(evt);
		},

		onClick: function(/*Event*/ evt){
			// summary:
			//		User defined function to handle clicks
			// tags:
			//		callback
		},

		focus: function(){
			// summary:
			//		Focus on this MenuItem
			try{
				if(dojo.isIE == 8){
					// needed for IE8 which won't scroll TR tags into view on focus yet calling scrollIntoView creates flicker (#10275)
					this.containerNode.focus();
				}
				dijit.focus(this.focusNode);
			}catch(e){
				// this throws on IE (at least) in some scenarios
			}
		},

		_onFocus: function(){
			// summary:
			//		This is called by the focus manager when focus
			//		goes to this MenuItem or a child menu.
			// tags:
			//		protected
			this._setSelected(true);
			this.getParent()._onItemFocus(this);

			this.inherited(arguments);
		},

		_setSelected: function(selected){
			// summary:
			//		Indicate that this node is the currently selected one
			// tags:
			//		private

			/***
			 * TODO: remove this method and calls to it, when _onBlur() is working for MenuItem.
			 * Currently _onBlur() gets called when focus is moved from the MenuItem to a child menu.
			 * That's not supposed to happen, but the problem is:
			 * In order to allow dijit.popup's getTopPopup() to work,a sub menu's popupParent
			 * points to the parent Menu, bypassing the parent MenuItem... thus the
			 * MenuItem is not in the chain of active widgets and gets a premature call to
			 * _onBlur()
			 */

			dojo.toggleClass(this.domNode, "dijitMenuItemSelected", selected);
		},

		setLabel: function(/*String*/ content){
			// summary:
			//		Deprecated.   Use set('label', ...) instead.
			// tags:
			//		deprecated
			dojo.deprecated("dijit.MenuItem.setLabel() is deprecated.  Use set('label', ...) instead.", "", "2.0");
			this.set("label", content);
		},

		setDisabled: function(/*Boolean*/ disabled){
			// summary:
			//		Deprecated.   Use set('disabled', bool) instead.
			// tags:
			//		deprecated
			dojo.deprecated("dijit.Menu.setDisabled() is deprecated.  Use set('disabled', bool) instead.", "", "2.0");
			this.set('disabled', disabled);
		},
		_setDisabledAttr: function(/*Boolean*/ value){
			// summary:
			//		Hook for attr('disabled', ...) to work.
			//		Enable or disable this menu item.

			dijit.setWaiState(this.focusNode, 'disabled', value ? 'true' : 'false');
			this._set("disabled", value);
		},
		_setAccelKeyAttr: function(/*String*/ value){
			// summary:
			//		Hook for attr('accelKey', ...) to work.
			//		Set accelKey on this menu item.

			this.accelKeyNode.style.display=value?"":"none";
			this.accelKeyNode.innerHTML=value;
			//have to use colSpan to make it work in IE
			dojo.attr(this.containerNode,'colSpan',value?"1":"2");
			
			this._set("accelKey", value);
		}
	});

}

if(!dojo._hasResource["dijit.PopupMenuItem"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.PopupMenuItem"] = true;
dojo.provide("dijit.PopupMenuItem");



dojo.declare("dijit.PopupMenuItem",
		dijit.MenuItem,
		{
		_fillContent: function(){
			// summary:
			//		When Menu is declared in markup, this code gets the menu label and
			//		the popup widget from the srcNodeRef.
			// description:
			//		srcNodeRefinnerHTML contains both the menu item text and a popup widget
			//		The first part holds the menu item text and the second part is the popup
			// example:
			// |	<div dojoType="dijit.PopupMenuItem">
			// |		<span>pick me</span>
			// |		<popup> ... </popup>
			// |	</div>
			// tags:
			//		protected

			if(this.srcNodeRef){
				var nodes = dojo.query("*", this.srcNodeRef);
				dijit.PopupMenuItem.superclass._fillContent.call(this, nodes[0]);

				// save pointer to srcNode so we can grab the drop down widget after it's instantiated
				this.dropDownContainer = this.srcNodeRef;
			}
		},

		startup: function(){
			if(this._started){ return; }
			this.inherited(arguments);

			// we didn't copy the dropdown widget from the this.srcNodeRef, so it's in no-man's
			// land now.  move it to dojo.doc.body.
			if(!this.popup){
				var node = dojo.query("[widgetId]", this.dropDownContainer)[0];
				this.popup = dijit.byNode(node);
			}
			dojo.body().appendChild(this.popup.domNode);
			this.popup.startup();

			this.popup.domNode.style.display="none";
			if(this.arrowWrapper){
				dojo.style(this.arrowWrapper, "visibility", "");
			}
			dijit.setWaiState(this.focusNode, "haspopup", "true");
		},

		destroyDescendants: function(){
			if(this.popup){
				// Destroy the popup, unless it's already been destroyed.  This can happen because
				// the popup is a direct child of <body> even though it's logically my child.
				if(!this.popup._destroyed){
					this.popup.destroyRecursive();
				}
				delete this.popup;
			}
			this.inherited(arguments);
		}
	});

}

if(!dojo._hasResource["dijit.CheckedMenuItem"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.CheckedMenuItem"] = true;
dojo.provide("dijit.CheckedMenuItem");



dojo.declare("dijit.CheckedMenuItem",
		dijit.MenuItem,
		{
		// summary:
		//		A checkbox-like menu item for toggling on and off

		templateString: dojo.cache("dijit", "templates/CheckedMenuItem.html", "<tr class=\"dijitReset dijitMenuItem\" dojoAttachPoint=\"focusNode\" role=\"menuitemcheckbox\" tabIndex=\"-1\"\n\t\tdojoAttachEvent=\"onmouseenter:_onHover,onmouseleave:_onUnhover,ondijitclick:_onClick\">\n\t<td class=\"dijitReset dijitMenuItemIconCell\" role=\"presentation\">\n\t\t<img src=\"${_blankGif}\" alt=\"\" class=\"dijitMenuItemIcon dijitCheckedMenuItemIcon\" dojoAttachPoint=\"iconNode\"/>\n\t\t<span class=\"dijitCheckedMenuItemIconChar\">&#10003;</span>\n\t</td>\n\t<td class=\"dijitReset dijitMenuItemLabel\" colspan=\"2\" dojoAttachPoint=\"containerNode,labelNode\"></td>\n\t<td class=\"dijitReset dijitMenuItemAccelKey\" style=\"display: none\" dojoAttachPoint=\"accelKeyNode\"></td>\n\t<td class=\"dijitReset dijitMenuArrowCell\" role=\"presentation\">&nbsp;</td>\n</tr>\n"),

		// checked: Boolean
		//		Our checked state
		checked: false,
		_setCheckedAttr: function(/*Boolean*/ checked){
			// summary:
			//		Hook so attr('checked', bool) works.
			//		Sets the class and state for the check box.
			dojo.toggleClass(this.domNode, "dijitCheckedMenuItemChecked", checked);
			dijit.setWaiState(this.domNode, "checked", checked);
			this._set("checked", checked);
		},

		onChange: function(/*Boolean*/ checked){
			// summary:
			//		User defined function to handle check/uncheck events
			// tags:
			//		callback
		},

		_onClick: function(/*Event*/ e){
			// summary:
			//		Clicking this item just toggles its state
			// tags:
			//		private
			if(!this.disabled){
				this.set("checked", !this.checked);
				this.onChange(this.checked);
			}
			this.inherited(arguments);
		}
	});

}

if(!dojo._hasResource["dijit.MenuSeparator"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.MenuSeparator"] = true;
dojo.provide("dijit.MenuSeparator");





dojo.declare("dijit.MenuSeparator",
		[dijit._Widget, dijit._Templated, dijit._Contained],
		{
		// summary:
		//		A line between two menu items

		templateString: dojo.cache("dijit", "templates/MenuSeparator.html", "<tr class=\"dijitMenuSeparator\">\n\t<td class=\"dijitMenuSeparatorIconCell\">\n\t\t<div class=\"dijitMenuSeparatorTop\"></div>\n\t\t<div class=\"dijitMenuSeparatorBottom\"></div>\n\t</td>\n\t<td colspan=\"3\" class=\"dijitMenuSeparatorLabelCell\">\n\t\t<div class=\"dijitMenuSeparatorTop dijitMenuSeparatorLabel\"></div>\n\t\t<div class=\"dijitMenuSeparatorBottom\"></div>\n\t</td>\n</tr>\n"),

		buildRendering: function(){
			this.inherited(arguments);
			dojo.setSelectable(this.domNode, false);
		},

		isFocusable: function(){
			// summary:
			//		Override to always return false
			// tags:
			//		protected

			return false; // Boolean
		}
	});

}

if(!dojo._hasResource["dijit.Menu"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.Menu"] = true;
dojo.provide("dijit.Menu");










// "dijit/MenuItem", "dijit/PopupMenuItem", "dijit/CheckedMenuItem", "dijit/MenuSeparator" for Back-compat (TODO: remove in 2.0)

dojo.declare("dijit._MenuBase",
	[dijit._Widget, dijit._Templated, dijit._KeyNavContainer],
{
	// summary:
	//		Base class for Menu and MenuBar

	// parentMenu: [readonly] Widget
	//		pointer to menu that displayed me
	parentMenu: null,

	// popupDelay: Integer
	//		number of milliseconds before hovering (without clicking) causes the popup to automatically open.
	popupDelay: 500,

	startup: function(){
		if(this._started){ return; }

		dojo.forEach(this.getChildren(), function(child){ child.startup(); });
		this.startupKeyNavChildren();

		this.inherited(arguments);
	},

	onExecute: function(){
		// summary:
		//		Attach point for notification about when a menu item has been executed.
		//		This is an internal mechanism used for Menus to signal to their parent to
		//		close them, because they are about to execute the onClick handler.   In
		//		general developers should not attach to or override this method.
		// tags:
		//		protected
	},

	onCancel: function(/*Boolean*/ closeAll){
		// summary:
		//		Attach point for notification about when the user cancels the current menu
		//		This is an internal mechanism used for Menus to signal to their parent to
		//		close them.  In general developers should not attach to or override this method.
		// tags:
		//		protected
	},

	_moveToPopup: function(/*Event*/ evt){
		// summary:
		//		This handles the right arrow key (left arrow key on RTL systems),
		//		which will either open a submenu, or move to the next item in the
		//		ancestor MenuBar
		// tags:
		//		private

		if(this.focusedChild && this.focusedChild.popup && !this.focusedChild.disabled){
			this.focusedChild._onClick(evt);
		}else{
			var topMenu = this._getTopMenu();
			if(topMenu && topMenu._isMenuBar){
				topMenu.focusNext();
			}
		}
	},

	_onPopupHover: function(/*Event*/ evt){
		// summary:
		//		This handler is called when the mouse moves over the popup.
		// tags:
		//		private

		// if the mouse hovers over a menu popup that is in pending-close state,
		// then stop the close operation.
		// This can't be done in onItemHover since some popup targets don't have MenuItems (e.g. ColorPicker)
		if(this.currentPopup && this.currentPopup._pendingClose_timer){
			var parentMenu = this.currentPopup.parentMenu;
			// highlight the parent menu item pointing to this popup
			if(parentMenu.focusedChild){
				parentMenu.focusedChild._setSelected(false);
			}
			parentMenu.focusedChild = this.currentPopup.from_item;
			parentMenu.focusedChild._setSelected(true);
			// cancel the pending close
			this._stopPendingCloseTimer(this.currentPopup);
		}
	},

	onItemHover: function(/*MenuItem*/ item){
		// summary:
		//		Called when cursor is over a MenuItem.
		// tags:
		//		protected

		// Don't do anything unless user has "activated" the menu by:
		//		1) clicking it
		//		2) opening it from a parent menu (which automatically focuses it)
		if(this.isActive){
			this.focusChild(item);
			if(this.focusedChild.popup && !this.focusedChild.disabled && !this.hover_timer){
				this.hover_timer = setTimeout(dojo.hitch(this, "_openPopup"), this.popupDelay);
			}
		}
		// if the user is mixing mouse and keyboard navigation,
		// then the menu may not be active but a menu item has focus,
		// but it's not the item that the mouse just hovered over.
		// To avoid both keyboard and mouse selections, use the latest.
		if(this.focusedChild){
			this.focusChild(item);
		}
		this._hoveredChild = item;
	},

	_onChildBlur: function(item){
		// summary:
		//		Called when a child MenuItem becomes inactive because focus
		//		has been removed from the MenuItem *and* it's descendant menus.
		// tags:
		//		private
		this._stopPopupTimer();
		item._setSelected(false);
		// Close all popups that are open and descendants of this menu
		var itemPopup = item.popup;
		if(itemPopup){
			this._stopPendingCloseTimer(itemPopup);
			itemPopup._pendingClose_timer = setTimeout(function(){
				itemPopup._pendingClose_timer = null;
				if(itemPopup.parentMenu){
					itemPopup.parentMenu.currentPopup = null;
				}
				dijit.popup.close(itemPopup); // this calls onClose
			}, this.popupDelay);
		}
	},

	onItemUnhover: function(/*MenuItem*/ item){
		// summary:
		//		Callback fires when mouse exits a MenuItem
		// tags:
		//		protected

		if(this.isActive){
			this._stopPopupTimer();
		}
		if(this._hoveredChild == item){ this._hoveredChild = null; }
	},

	_stopPopupTimer: function(){
		// summary:
		//		Cancels the popup timer because the user has stop hovering
		//		on the MenuItem, etc.
		// tags:
		//		private
		if(this.hover_timer){
			clearTimeout(this.hover_timer);
			this.hover_timer = null;
		}
	},

	_stopPendingCloseTimer: function(/*dijit._Widget*/ popup){
		// summary:
		//		Cancels the pending-close timer because the close has been preempted
		// tags:
		//		private
		if(popup._pendingClose_timer){
			clearTimeout(popup._pendingClose_timer);
			popup._pendingClose_timer = null;
		}
	},

	_stopFocusTimer: function(){
		// summary:
		//		Cancels the pending-focus timer because the menu was closed before focus occured
		// tags:
		//		private
		if(this._focus_timer){
			clearTimeout(this._focus_timer);
			this._focus_timer = null;
		}
	},

	_getTopMenu: function(){
		// summary:
		//		Returns the top menu in this chain of Menus
		// tags:
		//		private
		for(var top=this; top.parentMenu; top=top.parentMenu);
		return top;
	},

	onItemClick: function(/*dijit._Widget*/ item, /*Event*/ evt){
		// summary:
		//		Handle clicks on an item.
		// tags:
		//		private

		// this can't be done in _onFocus since the _onFocus events occurs asynchronously
		if(typeof this.isShowingNow == 'undefined'){ // non-popup menu
			this._markActive();
		}

		this.focusChild(item);

		if(item.disabled){ return false; }

		if(item.popup){
			this._openPopup();
		}else{
			// before calling user defined handler, close hierarchy of menus
			// and restore focus to place it was when menu was opened
			this.onExecute();

			// user defined handler for click
			item.onClick(evt);
		}
	},

	_openPopup: function(){
		// summary:
		//		Open the popup to the side of/underneath the current menu item
		// tags:
		//		protected

		this._stopPopupTimer();
		var from_item = this.focusedChild;
		if(!from_item){ return; } // the focused child lost focus since the timer was started
		var popup = from_item.popup;
		if(popup.isShowingNow){ return; }
		if(this.currentPopup){
			this._stopPendingCloseTimer(this.currentPopup);
			dijit.popup.close(this.currentPopup);
		}
		popup.parentMenu = this;
		popup.from_item = from_item; // helps finding the parent item that should be focused for this popup
		var self = this;
		dijit.popup.open({
			parent: this,
			popup: popup,
			around: from_item.domNode,
			orient: this._orient || (this.isLeftToRight() ?
									{'TR': 'TL', 'TL': 'TR', 'BR': 'BL', 'BL': 'BR'} :
									{'TL': 'TR', 'TR': 'TL', 'BL': 'BR', 'BR': 'BL'}),
			onCancel: function(){ // called when the child menu is canceled
				// set isActive=false (_closeChild vs _cleanUp) so that subsequent hovering will NOT open child menus
				// which seems aligned with the UX of most applications (e.g. notepad, wordpad, paint shop pro)
				self.focusChild(from_item);	// put focus back on my node
				self._cleanUp();			// close the submenu (be sure this is done _after_ focus is moved)
				from_item._setSelected(true); // oops, _cleanUp() deselected the item
				self.focusedChild = from_item;	// and unset focusedChild
			},
			onExecute: dojo.hitch(this, "_cleanUp")
		});

		this.currentPopup = popup;
		// detect mouseovers to handle lazy mouse movements that temporarily focus other menu items
		popup.connect(popup.domNode, "onmouseenter", dojo.hitch(self, "_onPopupHover")); // cleaned up when the popped-up widget is destroyed on close

		if(popup.focus){
			// If user is opening the popup via keyboard (right arrow, or down arrow for MenuBar),
			// if the cursor happens to collide with the popup, it will generate an onmouseover event
			// even though the mouse wasn't moved.   Use a setTimeout() to call popup.focus so that
			// our focus() call overrides the onmouseover event, rather than vice-versa.  (#8742)
			popup._focus_timer = setTimeout(dojo.hitch(popup, function(){
				this._focus_timer = null;
				this.focus();
			}), 0);
		}
	},

	_markActive: function(){
		// summary:
		//              Mark this menu's state as active.
		//		Called when this Menu gets focus from:
		//			1) clicking it (mouse or via space/arrow key)
		//			2) being opened by a parent menu.
		//		This is not called just from mouse hover.
		//		Focusing a menu via TAB does NOT automatically set isActive
		//		since TAB is a navigation operation and not a selection one.
		//		For Windows apps, pressing the ALT key focuses the menubar
		//		menus (similar to TAB navigation) but the menu is not active
		//		(ie no dropdown) until an item is clicked.
		this.isActive = true;
		dojo.replaceClass(this.domNode, "dijitMenuActive", "dijitMenuPassive");
	},

	onOpen: function(/*Event*/ e){
		// summary:
		//		Callback when this menu is opened.
		//		This is called by the popup manager as notification that the menu
		//		was opened.
		// tags:
		//		private

		this.isShowingNow = true;
		this._markActive();
	},

	_markInactive: function(){
		// summary:
		//		Mark this menu's state as inactive.
		this.isActive = false; // don't do this in _onBlur since the state is pending-close until we get here
		dojo.replaceClass(this.domNode, "dijitMenuPassive", "dijitMenuActive");
	},

	onClose: function(){
		// summary:
		//		Callback when this menu is closed.
		//		This is called by the popup manager as notification that the menu
		//		was closed.
		// tags:
		//		private

		this._stopFocusTimer();
		this._markInactive();
		this.isShowingNow = false;
		this.parentMenu = null;
	},

	_closeChild: function(){
		// summary:
		//		Called when submenu is clicked or focus is lost.  Close hierarchy of menus.
		// tags:
		//		private
		this._stopPopupTimer();

		var fromItem = this.focusedChild && this.focusedChild.from_item;

		if(this.currentPopup){
			// If focus is on my child menu then move focus to me,
			// because IE doesn't like it when you display:none a node with focus
			if(dijit._curFocus && dojo.isDescendant(dijit._curFocus, this.currentPopup.domNode)){
				this.focusedChild.focusNode.focus();
			}
			// Close all popups that are open and descendants of this menu
			dijit.popup.close(this.currentPopup);
			this.currentPopup = null;
		}

		if(this.focusedChild){ // unhighlight the focused item
			this.focusedChild._setSelected(false);
			this.focusedChild._onUnhover();
			this.focusedChild = null;
		}
	},

	_onItemFocus: function(/*MenuItem*/ item){
		// summary:
		//		Called when child of this Menu gets focus from:
		//			1) clicking it
		//			2) tabbing into it
		//			3) being opened by a parent menu.
		//		This is not called just from mouse hover.
		if(this._hoveredChild && this._hoveredChild != item){
			this._hoveredChild._onUnhover(); // any previous mouse movement is trumped by focus selection
		}
	},

	_onBlur: function(){
		// summary:
		//		Called when focus is moved away from this Menu and it's submenus.
		// tags:
		//		protected
		this._cleanUp();
		this.inherited(arguments);
	},

	_cleanUp: function(){
		// summary:
		//		Called when the user is done with this menu.  Closes hierarchy of menus.
		// tags:
		//		private

		this._closeChild(); // don't call this.onClose since that's incorrect for MenuBar's that never close
		if(typeof this.isShowingNow == 'undefined'){ // non-popup menu doesn't call onClose
			this._markInactive();
		}
	}
});

dojo.declare("dijit.Menu",
	dijit._MenuBase,
	{
	// summary
	//		A context menu you can assign to multiple elements

	// TODO: most of the code in here is just for context menu (right-click menu)
	// support.  In retrospect that should have been a separate class (dijit.ContextMenu).
	// Split them for 2.0

	constructor: function(){
		this._bindings = [];
	},

	templateString: dojo.cache("dijit", "templates/Menu.html", "<table class=\"dijit dijitMenu dijitMenuPassive dijitReset dijitMenuTable\" role=\"menu\" tabIndex=\"${tabIndex}\" dojoAttachEvent=\"onkeypress:_onKeyPress\" cellspacing=\"0\">\n\t<tbody class=\"dijitReset\" dojoAttachPoint=\"containerNode\"></tbody>\n</table>\n"),

	baseClass: "dijitMenu",

	// targetNodeIds: [const] String[]
	//		Array of dom node ids of nodes to attach to.
	//		Fill this with nodeIds upon widget creation and it becomes context menu for those nodes.
	targetNodeIds: [],

	// contextMenuForWindow: [const] Boolean
	//		If true, right clicking anywhere on the window will cause this context menu to open.
	//		If false, must specify targetNodeIds.
	contextMenuForWindow: false,

	// leftClickToOpen: [const] Boolean
	//		If true, menu will open on left click instead of right click, similiar to a file menu.
	leftClickToOpen: false,

	// refocus: Boolean
	// 		When this menu closes, re-focus the element which had focus before it was opened.
	refocus: true,

	postCreate: function(){
		if(this.contextMenuForWindow){
			this.bindDomNode(dojo.body());
		}else{
			// TODO: should have _setTargetNodeIds() method to handle initialization and a possible
			// later set('targetNodeIds', ...) call.   There's also a problem that targetNodeIds[]
			// gets stale after calls to bindDomNode()/unBindDomNode() as it still is just the original list (see #9610)
			dojo.forEach(this.targetNodeIds, this.bindDomNode, this);
		}
		var k = dojo.keys, l = this.isLeftToRight();
		this._openSubMenuKey = l ? k.RIGHT_ARROW : k.LEFT_ARROW;
		this._closeSubMenuKey = l ? k.LEFT_ARROW : k.RIGHT_ARROW;
		this.connectKeyNavHandlers([k.UP_ARROW], [k.DOWN_ARROW]);
	},

	_onKeyPress: function(/*Event*/ evt){
		// summary:
		//		Handle keyboard based menu navigation.
		// tags:
		//		protected

		if(evt.ctrlKey || evt.altKey){ return; }

		switch(evt.charOrCode){
			case this._openSubMenuKey:
				this._moveToPopup(evt);
				dojo.stopEvent(evt);
				break;
			case this._closeSubMenuKey:
				if(this.parentMenu){
					if(this.parentMenu._isMenuBar){
						this.parentMenu.focusPrev();
					}else{
						this.onCancel(false);
					}
				}else{
					dojo.stopEvent(evt);
				}
				break;
		}
	},

	// thanks burstlib!
	_iframeContentWindow: function(/* HTMLIFrameElement */iframe_el){
		// summary:
		//		Returns the window reference of the passed iframe
		// tags:
		//		private
		var win = dojo.window.get(this._iframeContentDocument(iframe_el)) ||
			// Moz. TODO: is this available when defaultView isn't?
			this._iframeContentDocument(iframe_el)['__parent__'] ||
			(iframe_el.name && dojo.doc.frames[iframe_el.name]) || null;
		return win;	//	Window
	},

	_iframeContentDocument: function(/* HTMLIFrameElement */iframe_el){
		// summary:
		//		Returns a reference to the document object inside iframe_el
		// tags:
		//		protected
		var doc = iframe_el.contentDocument // W3
			|| (iframe_el.contentWindow && iframe_el.contentWindow.document) // IE
			|| (iframe_el.name && dojo.doc.frames[iframe_el.name] && dojo.doc.frames[iframe_el.name].document)
			|| null;
		return doc;	//	HTMLDocument
	},

	bindDomNode: function(/*String|DomNode*/ node){
		// summary:
		//		Attach menu to given node
		node = dojo.byId(node);

		var cn;	// Connect node

		// Support context menus on iframes.   Rather than binding to the iframe itself we need
		// to bind to the <body> node inside the iframe.
		if(node.tagName.toLowerCase() == "iframe"){
			var iframe = node,
				win = this._iframeContentWindow(iframe);
			cn = dojo.withGlobal(win, dojo.body);
		}else{
			
			// To capture these events at the top level, attach to <html>, not <body>.
			// Otherwise right-click context menu just doesn't work.
			cn = (node == dojo.body() ? dojo.doc.documentElement : node);
		}


		// "binding" is the object to track our connection to the node (ie, the parameter to bindDomNode())
		var binding = {
			node: node,
			iframe: iframe
		};

		// Save info about binding in _bindings[], and make node itself record index(+1) into
		// _bindings[] array.   Prefix w/_dijitMenu to avoid setting an attribute that may
		// start with a number, which fails on FF/safari.
		dojo.attr(node, "_dijitMenu" + this.id, this._bindings.push(binding));

		// Setup the connections to monitor click etc., unless we are connecting to an iframe which hasn't finished
		// loading yet, in which case we need to wait for the onload event first, and then connect
		// On linux Shift-F10 produces the oncontextmenu event, but on Windows it doesn't, so
		// we need to monitor keyboard events in addition to the oncontextmenu event.
		var doConnects = dojo.hitch(this, function(cn){
			return [
				// TODO: when leftClickToOpen is true then shouldn't space/enter key trigger the menu,
				// rather than shift-F10?
				dojo.connect(cn, this.leftClickToOpen ? "onclick" : "oncontextmenu", this, function(evt){
					// Schedule context menu to be opened unless it's already been scheduled from onkeydown handler
					dojo.stopEvent(evt);
					this._scheduleOpen(evt.target, iframe, {x: evt.pageX, y: evt.pageY});
				}),
				dojo.connect(cn, "onkeydown", this, function(evt){
					if(evt.shiftKey && evt.keyCode == dojo.keys.F10){
						dojo.stopEvent(evt);
						this._scheduleOpen(evt.target, iframe);	// no coords - open near target node
					}
				})
			];
		});
		binding.connects = cn ? doConnects(cn) : [];

		if(iframe){
			// Setup handler to [re]bind to the iframe when the contents are initially loaded,
			// and every time the contents change.
			// Need to do this b/c we are actually binding to the iframe's <body> node.
			// Note: can't use dojo.connect(), see #9609.

			binding.onloadHandler = dojo.hitch(this, function(){
				// want to remove old connections, but IE throws exceptions when trying to
				// access the <body> node because it's already gone, or at least in a state of limbo

				var win = this._iframeContentWindow(iframe);
					cn = dojo.withGlobal(win, dojo.body);
				binding.connects = doConnects(cn);
			});
			if(iframe.addEventListener){
				iframe.addEventListener("load", binding.onloadHandler, false);
			}else{
				iframe.attachEvent("onload", binding.onloadHandler);
			}
		}
	},

	unBindDomNode: function(/*String|DomNode*/ nodeName){
		// summary:
		//		Detach menu from given node

		var node;
		try{
			node = dojo.byId(nodeName);
		}catch(e){
			// On IE the dojo.byId() call will get an exception if the attach point was
			// the <body> node of an <iframe> that has since been reloaded (and thus the
			// <body> node is in a limbo state of destruction.
			return;
		}

		// node["_dijitMenu" + this.id] contains index(+1) into my _bindings[] array
		var attrName = "_dijitMenu" + this.id;
		if(node && dojo.hasAttr(node, attrName)){
			var bid = dojo.attr(node, attrName)-1, b = this._bindings[bid];
			dojo.forEach(b.connects, dojo.disconnect);

			// Remove listener for iframe onload events
			var iframe = b.iframe;
			if(iframe){
				if(iframe.removeEventListener){
					iframe.removeEventListener("load", b.onloadHandler, false);
				}else{
					iframe.detachEvent("onload", b.onloadHandler);
				}
			}

			dojo.removeAttr(node, attrName);
			delete this._bindings[bid];
		}
	},

	_scheduleOpen: function(/*DomNode?*/ target, /*DomNode?*/ iframe, /*Object?*/ coords){
		// summary:
		//		Set timer to display myself.  Using a timer rather than displaying immediately solves
		//		two problems:
		//
		//		1. IE: without the delay, focus work in "open" causes the system
		//		context menu to appear in spite of stopEvent.
		//
		//		2. Avoid double-shows on linux, where shift-F10 generates an oncontextmenu event
		//		even after a dojo.stopEvent(e).  (Shift-F10 on windows doesn't generate the
		//		oncontextmenu event.)

		if(!this._openTimer){
			this._openTimer = setTimeout(dojo.hitch(this, function(){
				delete this._openTimer;
				this._openMyself({
					target: target,
					iframe: iframe,
					coords: coords
				});
			}), 1);
		}
	},

	_openMyself: function(args){
		// summary:
		//		Internal function for opening myself when the user does a right-click or something similar.
		// args:
		//		This is an Object containing:
		//		* target:
		//			The node that is being clicked
		//		* iframe:
		//			If an <iframe> is being clicked, iframe points to that iframe
		//		* coords:
		//			Put menu at specified x/y position in viewport, or if iframe is
		//			specified, then relative to iframe.
		//
		//		_openMyself() formerly took the event object, and since various code references
		//		evt.target (after connecting to _openMyself()), using an Object for parameters
		//		(so that old code still works).

		var target = args.target,
			iframe = args.iframe,
			coords = args.coords;

		// Get coordinates to open menu, either at specified (mouse) position or (if triggered via keyboard)
		// then near the node the menu is assigned to.
		if(coords){
			if(iframe){
				// Specified coordinates are on <body> node of an <iframe>, convert to match main document
				var od = target.ownerDocument,
					ifc = dojo.position(iframe, true),
					win = this._iframeContentWindow(iframe),
					scroll = dojo.withGlobal(win, "_docScroll", dojo);
	
				var cs = dojo.getComputedStyle(iframe),
					tp = dojo._toPixelValue,
					left = (dojo.isIE && dojo.isQuirks ? 0 : tp(iframe, cs.paddingLeft)) + (dojo.isIE && dojo.isQuirks ? tp(iframe, cs.borderLeftWidth) : 0),
					top = (dojo.isIE && dojo.isQuirks ? 0 : tp(iframe, cs.paddingTop)) + (dojo.isIE && dojo.isQuirks ? tp(iframe, cs.borderTopWidth) : 0);

				coords.x += ifc.x + left - scroll.x;
				coords.y += ifc.y + top - scroll.y;
			}
		}else{
			coords = dojo.position(target, true);
			coords.x += 10;
			coords.y += 10;
		}

		var self=this;
		var savedFocus = dijit.getFocus(this);
		function closeAndRestoreFocus(){
			// user has clicked on a menu or popup
			if(self.refocus){
				dijit.focus(savedFocus);
			}
			dijit.popup.close(self);
		}
		dijit.popup.open({
			popup: this,
			x: coords.x,
			y: coords.y,
			onExecute: closeAndRestoreFocus,
			onCancel: closeAndRestoreFocus,
			orient: this.isLeftToRight() ? 'L' : 'R'
		});
		this.focus();

		this._onBlur = function(){
			this.inherited('_onBlur', arguments);
			// Usually the parent closes the child widget but if this is a context
			// menu then there is no parent
			dijit.popup.close(this);
			// don't try to restore focus; user has clicked another part of the screen
			// and set focus there
		};
	},

	uninitialize: function(){
 		dojo.forEach(this._bindings, function(b){ if(b){ this.unBindDomNode(b.node); } }, this);
 		this.inherited(arguments);
	}
}
);

}

if(!dojo._hasResource["epages.widget.Menu"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Menu"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.widget.Menu");



dojo.declare(
	"epages.widget.Menu",
	[dijit.Menu], {
		templateString:
			'<div class="Menu" ><div class="Layer"><div class="PropertyContainer">' +
				'<table class="dijit dijitMenu dijitReset dijitMenuTable" waiRole="menu" dojoAttachEvent="onkeypress:_onKeyPress" cellspacing="0">' +
					'<tbody class="dijitReset" dojoAttachPoint="containerNode"></tbody>'+
				'</table>'+
			'</div></div>' +
			'<div class="LayerFooter"><div class="PropertyContainer"></div></div></div>'
	}
);

}

if(!dojo._hasResource["epages.widget.Elementlistitem"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Elementlistitem"] = true;
dojo.provide("epages.widget.Elementlistitem");



dojo.declare("epages.widget.Elementlistitem", [epages.widget.LocalizedWidget, dijit._Contained],  {
		/**
		 * public properties
		 */
		templateString:     '<div class="${itemClassName}">${title}</div>',
		itemClassName:      'ElementListItem',
		hoverClassName:     'Hover',
		selectClassName:    'Selected',
		isSelected:         false,
		objectId:           '',
		title:              'item',
		parent:             undefined,
		translationName:    dojo.moduleUrl('epages','translation'),
		selectOn:           'onclick',
		disabled:           false,
		/**
		 * public methods
		 */
		postCreate: function() {
			epages.widget.Elementlistitem.superclass.postCreate.apply(this, arguments);

			// connect events
			this.connect(this.domNode, "onmouseover", '_onMouseOver');
			this.connect(this.domNode, "onmouseout",  '_onMouseOut');
			this.connect(this.domNode, this.selectOn, '_onClick');
			this.parent = this.getParent();
		},

		select: function () {
			this.isSelected = true;
			dojo.addClass(this.domNode, this.selectClassName);
		},

		deselect: function () {
			this.isSelected = false;
			dojo.removeClass(this.domNode, this.selectClassName);
		},

		/**
		 * private methods
		 */
		_onMouseOver: function() {
			dojo.addClass(this.domNode, this.hoverClassName);
		},

		_onMouseOut: function() {
			dojo.removeClass(this.domNode, this.hoverClassName);
		},

		_onClick: function(evt) {
			if (this.getParent()) {
				this.getParent().doSelectItem(this, this.isSelected, evt);
			} else {
				this.isSelected ? this.deselect() : this.select();
				dojo.publish(this.id+'/onClick', [{ widget: this, node: this.domNode, objectId: this.objectId }]);
			}
		}
	}
);

}

if(!dojo._hasResource["epages.widget.Elementlist"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Elementlist"] = true;
dojo.provide("epages.widget.Elementlist");




dojo.declare("epages.widget.Elementlist", [dijit._Widget,dijit._Templated,dijit._Container], {

		/**
		 * public properties
		 */
		templateString:"<div>\n\t<div class=\"${listClassName}\" dojoAttachPoint=\"containerNode\"></div>\n\t<div dojoAttachPoint=\"PaggerButtons\" class=\"HideElement AlignCenter LinkImage ClearBoth\">\n\t\t<i dojoAttachPoint=\"PageDownNode\" class=\"\" title=\"\">&lt;</i>\n\t\t<span dojoAttachPoint=\"PageButtonsContainer\"></span>\n\t\t<i dojoAttachPoint=\"PageUpNode\" class=\"\" title=\"\">&gt;</i>\n\t</div>\n\t<span dojoAttachPoint=\"PageButtonNode\">\n  </span>\n</div>\n",
		listClassName:      'ElementList',
		widgetElementType:  "epages.widget.Elementlistitem",
		multiSelect:        'false',
		objectId:           '',
		onselect:           '',
		children:           [],
		store:              undefined,
		pagging:            false,
		paggingQuantity:    20,

		eventNames:         undefined,
		eventNamesDefault: {
			afterListCreate:  'afterListCreate',
			afterSetChildren: 'afterSetChildren',
			select:           'select',
			deselect:         'deselect'
		},

		selectTypes:{
			SINGLE: 'SINGLE', // no modification key
			ADD:    'ADD',    // CTRL key
			LIST:   'LIST'    // SHIFT key
		},

		/**
		 * private properties
		 */
		_lastSelectedItem:   undefined,
		_allChildren: [],
		_pagger: {
			currentVisibleChildren : [],
			currentPage : 0,
			maxPage: 0
		},

		postMixInProperties: function(){
			this.pagging = epages.string.toBoolean(this.pagging);
		},

		adjustEventNames: function() {
			// summary: add id of widget to event names
			this.eventNames = {};
			for(var name in this.eventNamesDefault) {
				if (this.eventNames[name] === undefined) {
					this.eventNames[name] = this.id + "/" + this.eventNamesDefault[name];
				}
			}
		},

		initialize: function () {
			// summary: clear last selected item, when the list gets new content
			this._lastSelectedItem = undefined;
		},

		postCreate: function() {
			// summary: only add pagging events is pagging is activated
			this.inherited("postCreate", arguments);
			this.adjustEventNames();
			if(this.pagging){
				this.connect(this.PageDownNode, "onclick", 'pageDown');
				this.connect(this.PageUpNode, "onclick", 'pageUp');
			}

		},

		startup: function(){
			// summary: collect children that are inside the main dom node and put them inside array for later use
			this.children = this.getChildren();
			dojo.publish(this.eventNames.afterListCreate, [this]);
		},

		pageUp:function(){
			// summary: changes the visible elemnts by pagging one page down
			if(this._pagger.currentPage+1 != this._pagger.maxPage){
				var page = this._pagger.currentPage + 1;
				this._createVisibleChildren(this._allChildren,page);
			}
		},

		pageDown:function(){
			// summary: changes the visible elemnts by pagging one page up
			if(this._pagger.currentPage > 0){
				var page = this._pagger.currentPage - 1;
				this._createVisibleChildren(this._allChildren,page);
			}
		},

		pageTo: function(page){
			// summary: changes the visible elemnts by pagging to given page
			if(page >= 0 && page < this._pagger.maxPage){
				this._createVisibleChildren(this._allChildren,page);
			}
		},

		_setPagerButtons: function(startId, endId){
			// summary: creates pager buttons if needed and sets status of page up / down node
			dojo.removeClass(this.PaggerButtons,'HideElement');
			if(endId > this._allChildren.length){
				dojo.addClass(this.PageUpNode,'Disabled');
			}
			else{
				dojo.removeClass(this.PageUpNode,'Disabled');
			}
			if(startId == 0){
				dojo.addClass(this.PageDownNode,'Disabled');
			}
			else{
				dojo.removeClass(this.PageDownNode,'Disabled');
			}
			//create array of pages and fill them until current page is inside
			//remove first element if array is larger than 10 and current page are not inside
			//end if all pages are in or current page is at right position
			var pageIdArray = [];
			for(var i = 0; i < this._pagger.maxPage; i++){
				var pageId = i;
				pageIdArray.push(pageId);
				if(pageIdArray.length == 10){
					if($A(pageIdArray).exists(this._pagger.currentPage)){
						if($A(pageIdArray).find(this._pagger.currentPage) <= 5){
							break;
						}
						else{
							pageIdArray.shift();
						}
					}
					else{
						pageIdArray.shift();
					}
				}
			}
			//create spans for pager entrys, attach page events and highlight current page
			this.PageButtonsContainer.innerHTML = '';
			for( var j=0,jLength=pageIdArray.length ; j<jLength ; j++ ){
				currentPage = pageIdArray[j];
				//use PageButtonNode as prototype for page buttons
				var newPageButtonNode = this.PageButtonNode.cloneNode(true);
				this.PageButtonsContainer.appendChild(newPageButtonNode);
				this.connect(newPageButtonNode, 'onclick', epages.lang.hitch(this,this.pageTo, [currentPage]));
				if(currentPage == this._pagger.currentPage){
					dojo.addClass(newPageButtonNode,'Selected');
					newPageButtonNode.innerHTML = '<b> '+(currentPage+1)+' </b>';
				}
				else{
					newPageButtonNode.innerHTML = ' '+(currentPage+1)+' ';
				}
			}
		},

		_createVisibleChildren: function(elements,page){
			// summary: creates widgets for the current on this page of list visible children
			// creates all children if there is only one page
			//save Children and destroy old visible Children

			//remove old content
			this._allChildren = elements;
			this.destroyDescendants();
			this.initialize();
			//check pagger and display buttons if needed
			this._pagger.currentPage = page;
			if(this.pagging && this._pagger.maxPage > 1){
				var startId = page * this.paggingQuantity;
				var endId = startId + this.paggingQuantity;
				this._setPagerButtons(startId, endId);
			}
			else{
				var startId = 0;
				var endId = elements.length;
				dojo.addClass(this.PaggerButtons,'HideElement');
			}

			//createVisible Children
			for (var i = startId; i < endId; i++) {
				//could be possible that endId is greater than number of children
				if(i > this._allChildren.length){
					break;
				}
				var elm = this._allChildren[i];
				if(elm){
					elm.parentId = this.id;
					elm.store = this.store;
					var item = new (eval(this.widgetElementType))(elm);
					item.data = elm;
					this.addChild(item);
					item.startup();
					this._pagger.currentVisibleChildren.push(item);
				}
			}
			this.children = this.getChildren();
			dojo.publish(this.eventNames.afterSetChildren, [{ source: this, length: this.children.length }] );
		},

		setChildren: function(/*array*/ elements) {
			// summary: set children elements for list and show first page
			this._pagger.maxPage = Math.ceil(elements.length / this.paggingQuantity);
			this._createVisibleChildren(elements,0);
		},

		selectedNodes: function () {
			// summary: return current selected nodes of list can be more than one if multiSelect is enabled
			if (this.multiSelect != 'true') {
				if (this._lastSelectedItem === undefined){
					return []; // Array
				}
				return [this._lastSelectedItem]; // Array
			}
			// get selected widgets
			var nodes = dojo.filter(this.getChildren(), function (el) {
				return (typeof (el.isSelected) == 'boolean' && el.isSelected);
			});
			return nodes; // Array
		},

		selectedItems: function () {
			// summary: returns array of objectIds of current selected items
			var nodes = this.selectedNodes();
			var objectIds = dojo.map(nodes, function (el) {
				return el.objectId;
			});
			return objectIds; // Array
		},

		select: function(/*Elementlistitem*/ item) {
			if (this._lastSelectedItem !== undefined && this.multiSelect != 'true') {
				// deselect old selected item
				this._lastSelectedItem.deselect();
			}
			item.select();
			this._lastSelectedItem = item;
			// fire events
			dojo.publish(this.eventNames.select, [item]);
			if (this.onselect != ''){
				eval(this.onselect);
			}
		},

		deselect: function(/*Elementlistitem*/ item) {
			this._lastSelectedItem = undefined;
			item.deselect();
			// fire events
			dojo.publish(this.eventNames.deselect, [item]);
			if (this.ondeselect != ''){
				eval(this.ondeselect);
			}
		},

		deselectAll: function() {
			var items = this.selectedNodes();
			for( var i=0,iLength=items.length ; i<iLength ; i++ ) {
				var item = items[i];
				this.deselect(item);
			}
		},

		_childById: function (objectId) {
			for( var i=0,iLength=this.children.length ; i<iLength ; i++ ) {
				if (this.children[i].objectId == objectId){
					return this.children[i];
				}
			}
			return;
		},

		doSelectItem: function(/*Elementlistitem*/item, /*boolean?*/isSelected, evt) {
			// cannot select item if it's disabled
			if(item.disabled) {
				return;
			}

			if (typeof(item) == 'string' || typeof(item) == 'number') {
				item = this._childById(item);
			}
			var type = this.selectTypes.SINGLE;
			if (this.multiSelect == 'true' && evt != undefined) {
				if (evt.ctrlKey) {
					type = this.selectTypes.ADD;
				} else if (evt.shiftKey) {
					type = this.selectTypes.LIST;
				}
			}
			switch (type) {
				case this.selectTypes.LIST:
					var select = false;
					var lastSelectedItem = this._lastSelectedItem;
					// use first selected item in list, if exists
					if (lastSelectedItem == undefined && this.selectedNodes().length > 0) {
						lastSelectedItem = (this.selectedNodes())[0];
					}
					for( var i=0,iLength=this.children.length ; i<iLength ; i++ ) {
						var child = this.children[i];
						if (!select &&
								(child.objectId == item.objectId ||
								 (lastSelectedItem == undefined || child.objectId == lastSelectedItem.objectId))) {
							select = true;
						}
						else if (select &&
										 (child.objectId == item.objectId ||
											(lastSelectedItem != undefined && child.objectId == lastSelectedItem.objectId))) {
							this.select(child);
							break;
						}
						if (select){
							this.select(child);
						}
					}
					break;
				case this.selectTypes.ADD:
					if (isSelected) {
						this.deselect(item);
					} else {
						this.select(item);
					}
					break;
				default:
				case this.selectTypes.SINGLE:
					this.deselectAll();
					this.select(item);
					break;
			}
			// set focus to avoid text selection
			this.domNode.focus();
		},

		getItemByIdentity : function(/* String */identifierName, identity) {
			for(var el in this.children) {
				if(this.children[el][identifierName] == identity){
					return this.children[el];
				}
			}
		}
	}
);

}

if(!dojo._hasResource["dojo.data.util.sorter"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.data.util.sorter"] = true;
dojo.provide("dojo.data.util.sorter");

dojo.getObject("data.util.sorter", true, dojo);

dojo.data.util.sorter.basicComparator = function(	/*anything*/ a,
													/*anything*/ b){
	//	summary:
	//		Basic comparision function that compares if an item is greater or less than another item
	//	description:
	//		returns 1 if a > b, -1 if a < b, 0 if equal.
	//		'null' values (null, undefined) are treated as larger values so that they're pushed to the end of the list.
	//		And compared to each other, null is equivalent to undefined.
	
	//null is a problematic compare, so if null, we set to undefined.
	//Makes the check logic simple, compact, and consistent
	//And (null == undefined) === true, so the check later against null
	//works for undefined and is less bytes.
	var r = -1;
	if(a === null){
		a = undefined;
	}
	if(b === null){
		b = undefined;
	}
	if(a == b){
		r = 0;
	}else if(a > b || a == null){
		r = 1;
	}
	return r; //int {-1,0,1}
};

dojo.data.util.sorter.createSortFunction = function(	/* attributes array */sortSpec,
														/*dojo.data.core.Read*/ store){
	//	summary:
	//		Helper function to generate the sorting function based off the list of sort attributes.
	//	description:
	//		The sort function creation will look for a property on the store called 'comparatorMap'.  If it exists
	//		it will look in the mapping for comparisons function for the attributes.  If one is found, it will
	//		use it instead of the basic comparator, which is typically used for strings, ints, booleans, and dates.
	//		Returns the sorting function for this particular list of attributes and sorting directions.
	//
	//	sortSpec: array
	//		A JS object that array that defines out what attribute names to sort on and whether it should be descenting or asending.
	//		The objects should be formatted as follows:
	//		{
	//			attribute: "attributeName-string" || attribute,
	//			descending: true|false;   // Default is false.
	//		}
	//	store: object
	//		The datastore object to look up item values from.
	//
	var sortFunctions=[];

	function createSortFunction(attr, dir, comp, s){
		//Passing in comp and s (comparator and store), makes this
		//function much faster.
		return function(itemA, itemB){
			var a = s.getValue(itemA, attr);
			var b = s.getValue(itemB, attr);
			return dir * comp(a,b); //int
		};
	}
	var sortAttribute;
	var map = store.comparatorMap;
	var bc = dojo.data.util.sorter.basicComparator;
	for(var i = 0; i < sortSpec.length; i++){
		sortAttribute = sortSpec[i];
		var attr = sortAttribute.attribute;
		if(attr){
			var dir = (sortAttribute.descending) ? -1 : 1;
			var comp = bc;
			if(map){
				if(typeof attr !== "string" && ("toString" in attr)){
					 attr = attr.toString();
				}
				comp = map[attr] || bc;
			}
			sortFunctions.push(createSortFunction(attr,
				dir, comp, store));
		}
	}
	return function(rowA, rowB){
		var i=0;
		while(i < sortFunctions.length){
			var ret = sortFunctions[i++](rowA, rowB);
			if(ret !== 0){
				return ret;//int
			}
		}
		return 0; //int
	}; // Function
};

}

if(!dojo._hasResource["dojo.data.util.simpleFetch"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.data.util.simpleFetch"] = true;
dojo.provide("dojo.data.util.simpleFetch");


dojo.getObject("data.util.simpleFetch", true, dojo);

dojo.data.util.simpleFetch.fetch = function(/* Object? */ request){
	//	summary:
	//		The simpleFetch mixin is designed to serve as a set of function(s) that can
	//		be mixed into other datastore implementations to accelerate their development.
	//		The simpleFetch mixin should work well for any datastore that can respond to a _fetchItems()
	//		call by returning an array of all the found items that matched the query.  The simpleFetch mixin
	//		is not designed to work for datastores that respond to a fetch() call by incrementally
	//		loading items, or sequentially loading partial batches of the result
	//		set.  For datastores that mixin simpleFetch, simpleFetch
	//		implements a fetch method that automatically handles eight of the fetch()
	//		arguments -- onBegin, onItem, onComplete, onError, start, count, sort and scope
	//		The class mixing in simpleFetch should not implement fetch(),
	//		but should instead implement a _fetchItems() method.  The _fetchItems()
	//		method takes three arguments, the keywordArgs object that was passed
	//		to fetch(), a callback function to be called when the result array is
	//		available, and an error callback to be called if something goes wrong.
	//		The _fetchItems() method should ignore any keywordArgs parameters for
	//		start, count, onBegin, onItem, onComplete, onError, sort, and scope.
	//		The _fetchItems() method needs to correctly handle any other keywordArgs
	//		parameters, including the query parameter and any optional parameters
	//		(such as includeChildren).  The _fetchItems() method should create an array of
	//		result items and pass it to the fetchHandler along with the original request object
	//		-- or, the _fetchItems() method may, if it wants to, create an new request object
	//		with other specifics about the request that are specific to the datastore and pass
	//		that as the request object to the handler.
	//
	//		For more information on this specific function, see dojo.data.api.Read.fetch()
	request = request || {};
	if(!request.store){
		request.store = this;
	}
	var self = this;

	var _errorHandler = function(errorData, requestObject){
		if(requestObject.onError){
			var scope = requestObject.scope || dojo.global;
			requestObject.onError.call(scope, errorData, requestObject);
		}
	};

	var _fetchHandler = function(items, requestObject){
		var oldAbortFunction = requestObject.abort || null;
		var aborted = false;

		var startIndex = requestObject.start?requestObject.start:0;
		var endIndex = (requestObject.count && (requestObject.count !== Infinity))?(startIndex + requestObject.count):items.length;

		requestObject.abort = function(){
			aborted = true;
			if(oldAbortFunction){
				oldAbortFunction.call(requestObject);
			}
		};

		var scope = requestObject.scope || dojo.global;
		if(!requestObject.store){
			requestObject.store = self;
		}
		if(requestObject.onBegin){
			requestObject.onBegin.call(scope, items.length, requestObject);
		}
		if(requestObject.sort){
			items.sort(dojo.data.util.sorter.createSortFunction(requestObject.sort, self));
		}
		if(requestObject.onItem){
			for(var i = startIndex; (i < items.length) && (i < endIndex); ++i){
				var item = items[i];
				if(!aborted){
					requestObject.onItem.call(scope, item, requestObject);
				}
			}
		}
		if(requestObject.onComplete && !aborted){
			var subset = null;
			if(!requestObject.onItem){
				subset = items.slice(startIndex, endIndex);
			}
			requestObject.onComplete.call(scope, subset, requestObject);
		}
	};
	this._fetchItems(request, _fetchHandler, _errorHandler);
	return request;	// Object
};

}

if(!dojo._hasResource["epages.widget.DeleteFileOnServer"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.DeleteFileOnServer"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.widget.DeleteFileOnServer");





dojo.declare(
	"epages.widget.DeleteFileOnServer",
	[ dijit._Widget, dijit._Templated ],
	{
		_fileSizeText: '',
		
		fileName:  '',
		fileSize:  '',
		filePath :  '',
		confirm :  'true',
		url:       '?',
		newWindowFeature: 'PopUp',
		displayfileName: '',
		headlineConfirm: epages.io.dictionary.get('HeadLineDeleteFile'), // 'Moechten Sie diese Datei wirklich loeschen?',
		messageConfirm:  epages.io.dictionary.get('File')+(':'), // 'Datei',
		titleConfirm:    epages.io.dictionary.get('TitleDeleteFile'), // 'Datei loeschen',
		altDelete:   epages.io.dictionary.get('TitleDeleteFile'), //'Datei loeschen',
		altView:     epages.io.dictionary.get('TitleViewFile'), //'Datei anzeigen',

		objectId:      epages.vars.ObjectID || '',
		changeAction:  'DeleteFile',
		fileAttribute: '',
		languageId:    '',
		onSuccess:     '',
		onPreview:     '',

		imagePath: epages.themeUrl('images'),
		templateString: '<span><i dojoAttachEvent="onclick:onConfirm" class="ClickIcon ico_s_delete Sprite" title="${altDelete}"></i> <a dojoAttachEvent="onclick:onConfirm" href="#">${altDelete}</a>${_fileSizeText}</span>',

		postMixInProperties: function () {
			this.inherited("postMixInProperties", arguments);
			this.confirm = epages.string.toBoolean(this.confirm);
			if (this.fileSize != ''){
				this._fileSizeText = ' (' + this.fileSize +')';
			}
			this.displayfileName=epages.format.scrunch(this.fileName,35);
			
			if( !this.altDelete ){
				this.altDelete = epages.io.dictionary.get('TitleDeleteFile');
			}
		},

		onExecution: function (response) {
			if (response.error == null) {
				// EPG-10737 dirty cache
				if(typeof(window.pc_active) != "undefined" && window.pc_active == true) {
					pageCache_SetStatus(true);
				}
				if (typeof this.onSuccess == 'function') {
					this.onSuccess();
				} else {
					eval(this.onSuccess);
				}
			}
			this.domNode.style.display = 'none';
		},

		onExecute: function () {
			
			var json = new epages.io.Json();
			json.loadAsync(this.url, dojo.hitch(this, 'onExecution'), {
				'ObjectID': this.objectId,
				'ChangeAction': this.changeAction,
				'File': this.fileAttribute,
				'DeleteLanguageID': this.languageId,
				'ACCEPT': this.confirm ? 1 : 0
			});
		},

		onConfirm: function (evt) {
			dojo.stopEvent(evt);
			if(this.confirm) {
				
				dojo.publish("uimessage/show", [
					this.headlineConfirm,
					this.messageConfirm + ' ' + this.fileName, 'Dialog', {
						titleBar:  this.titleConfirm,
						sizeClass: 'Large',
						typeClass: 'Confirmation',
						onYes:     dojo.hitch(this, 'onExecute')
					}]);
			} else {
				this.onExecute();
			}
		}
	}
);

}

if(!dojo._hasResource["epages.widget.DeleteFileAttributesOnServer"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.DeleteFileAttributesOnServer"] = true;
/*
	Copyright (c) 2006-2010, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.widget.DeleteFileAttributesOnServer");


dojo.declare(
	"epages.widget.DeleteFileAttributesOnServer",
	[ epages.widget.DeleteFileOnServer ],
	{
		onExecute: function () {
			

			var params = {
				'ObjectID': this.objectId,
				'DeleteLanguageID': this.languageId,
				'ACCEPT': this.confirm ? 1 : 0,
				'ChangeAction' : this.changeAction,
				'Files' : this.fileAttribute		// comma seperated list
			};
			var json = new epages.io.Json();
			json.loadAsync(this.url, dojo.hitch(this, 'onExecution'), params);
		}
	}
);

}

if(!dojo._hasResource["dojo.number"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.number"] = true;
dojo.provide("dojo.number");





dojo.getObject("number", true, dojo);

/*=====
dojo.number = {
	// summary: localized formatting and parsing routines for Number
}

dojo.number.__FormatOptions = function(){
	//	pattern: String?
	//		override [formatting pattern](http://www.unicode.org/reports/tr35/#Number_Format_Patterns)
	//		with this string.  Default value is based on locale.  Overriding this property will defeat
	//		localization.  Literal characters in patterns are not supported.
	//	type: String?
	//		choose a format type based on the locale from the following:
	//		decimal, scientific (not yet supported), percent, currency. decimal by default.
	//	places: Number?
	//		fixed number of decimal places to show.  This overrides any
	//		information in the provided pattern.
	//	round: Number?
	//		5 rounds to nearest .5; 0 rounds to nearest whole (default). -1
	//		means do not round.
	//	locale: String?
	//		override the locale used to determine formatting rules
	//	fractional: Boolean?
	//		If false, show no decimal places, overriding places and pattern settings.
	this.pattern = pattern;
	this.type = type;
	this.places = places;
	this.round = round;
	this.locale = locale;
	this.fractional = fractional;
}
=====*/

dojo.number.format = function(/*Number*/value, /*dojo.number.__FormatOptions?*/options){
	// summary:
	//		Format a Number as a String, using locale-specific settings
	// description:
	//		Create a string from a Number using a known localized pattern.
	//		Formatting patterns appropriate to the locale are chosen from the
	//		[Common Locale Data Repository](http://unicode.org/cldr) as well as the appropriate symbols and
	//		delimiters.
	//		If value is Infinity, -Infinity, or is not a valid JavaScript number, return null.
	// value:
	//		the number to be formatted

	options = dojo.mixin({}, options || {});
	var locale = dojo.i18n.normalizeLocale(options.locale),
		bundle = dojo.i18n.getLocalization("dojo.cldr", "number", locale);
	options.customs = bundle;
	var pattern = options.pattern || bundle[(options.type || "decimal") + "Format"];
	if(isNaN(value) || Math.abs(value) == Infinity){ return null; } // null
	return dojo.number._applyPattern(value, pattern, options); // String
};

//dojo.number._numberPatternRE = /(?:[#0]*,?)*[#0](?:\.0*#*)?/; // not precise, but good enough
dojo.number._numberPatternRE = /[#0,]*[#0](?:\.0*#*)?/; // not precise, but good enough

dojo.number._applyPattern = function(/*Number*/value, /*String*/pattern, /*dojo.number.__FormatOptions?*/options){
	// summary:
	//		Apply pattern to format value as a string using options. Gives no
	//		consideration to local customs.
	// value:
	//		the number to be formatted.
	// pattern:
	//		a pattern string as described by
	//		[unicode.org TR35](http://www.unicode.org/reports/tr35/#Number_Format_Patterns)
	// options: dojo.number.__FormatOptions?
	//		_applyPattern is usually called via `dojo.number.format()` which
	//		populates an extra property in the options parameter, "customs".
	//		The customs object specifies group and decimal parameters if set.

	//TODO: support escapes
	options = options || {};
	var group = options.customs.group,
		decimal = options.customs.decimal,
		patternList = pattern.split(';'),
		positivePattern = patternList[0];
	pattern = patternList[(value < 0) ? 1 : 0] || ("-" + positivePattern);

	//TODO: only test against unescaped
	if(pattern.indexOf('%') != -1){
		value *= 100;
	}else if(pattern.indexOf('\u2030') != -1){
		value *= 1000; // per mille
	}else if(pattern.indexOf('\u00a4') != -1){
		group = options.customs.currencyGroup || group;//mixins instead?
		decimal = options.customs.currencyDecimal || decimal;// Should these be mixins instead?
		pattern = pattern.replace(/\u00a4{1,3}/, function(match){
			var prop = ["symbol", "currency", "displayName"][match.length-1];
			return options[prop] || options.currency || "";
		});
	}else if(pattern.indexOf('E') != -1){
		throw new Error("exponential notation not supported");
	}
	
	//TODO: support @ sig figs?
	var numberPatternRE = dojo.number._numberPatternRE;
	var numberPattern = positivePattern.match(numberPatternRE);
	if(!numberPattern){
		throw new Error("unable to find a number expression in pattern: "+pattern);
	}
	if(options.fractional === false){ options.places = 0; }
	return pattern.replace(numberPatternRE,
		dojo.number._formatAbsolute(value, numberPattern[0], {decimal: decimal, group: group, places: options.places, round: options.round}));
};

dojo.number.round = function(/*Number*/value, /*Number?*/places, /*Number?*/increment){
	//	summary:
	//		Rounds to the nearest value with the given number of decimal places, away from zero
	//	description:
	//		Rounds to the nearest value with the given number of decimal places, away from zero if equal.
	//		Similar to Number.toFixed(), but compensates for browser quirks. Rounding can be done by
	//		fractional increments also, such as the nearest quarter.
	//		NOTE: Subject to floating point errors.  See dojox.math.round for experimental workaround.
	//	value:
	//		The number to round
	//	places:
	//		The number of decimal places where rounding takes place.  Defaults to 0 for whole rounding.
	//		Must be non-negative.
	//	increment:
	//		Rounds next place to nearest value of increment/10.  10 by default.
	//	example:
	//		>>> dojo.number.round(-0.5)
	//		-1
	//		>>> dojo.number.round(162.295, 2)
	//		162.29  // note floating point error.  Should be 162.3
	//		>>> dojo.number.round(10.71, 0, 2.5)
	//		10.75
	var factor = 10 / (increment || 10);
	return (factor * +value).toFixed(places) / factor; // Number
};

if((0.9).toFixed() == 0){
	// (isIE) toFixed() bug workaround: Rounding fails on IE when most significant digit
	// is just after the rounding place and is >=5
	(function(){
		var round = dojo.number.round;
		dojo.number.round = function(v, p, m){
			var d = Math.pow(10, -p || 0), a = Math.abs(v);
			if(!v || a >= d || a * Math.pow(10, p + 1) < 5){
				d = 0;
			}
			return round(v, p, m) + (v > 0 ? d : -d);
		};
	})();
}

/*=====
dojo.number.__FormatAbsoluteOptions = function(){
	//	decimal: String?
	//		the decimal separator
	//	group: String?
	//		the group separator
	//	places: Number?|String?
	//		number of decimal places.  the range "n,m" will format to m places.
	//	round: Number?
	//		5 rounds to nearest .5; 0 rounds to nearest whole (default). -1
	//		means don't round.
	this.decimal = decimal;
	this.group = group;
	this.places = places;
	this.round = round;
}
=====*/

dojo.number._formatAbsolute = function(/*Number*/value, /*String*/pattern, /*dojo.number.__FormatAbsoluteOptions?*/options){
	// summary:
	//		Apply numeric pattern to absolute value using options. Gives no
	//		consideration to local customs.
	// value:
	//		the number to be formatted, ignores sign
	// pattern:
	//		the number portion of a pattern (e.g. `#,##0.00`)
	options = options || {};
	if(options.places === true){options.places=0;}
	if(options.places === Infinity){options.places=6;} // avoid a loop; pick a limit

	var patternParts = pattern.split("."),
		comma = typeof options.places == "string" && options.places.indexOf(","),
		maxPlaces = options.places;
	if(comma){
		maxPlaces = options.places.substring(comma + 1);
	}else if(!(maxPlaces >= 0)){
		maxPlaces = (patternParts[1] || []).length;
	}
	if(!(options.round < 0)){
		value = dojo.number.round(value, maxPlaces, options.round);
	}

	var valueParts = String(Math.abs(value)).split("."),
		fractional = valueParts[1] || "";
	if(patternParts[1] || options.places){
		if(comma){
			options.places = options.places.substring(0, comma);
		}
		// Pad fractional with trailing zeros
		var pad = options.places !== undefined ? options.places : (patternParts[1] && patternParts[1].lastIndexOf("0") + 1);
		if(pad > fractional.length){
			valueParts[1] = dojo.string.pad(fractional, pad, '0', true);
		}

		// Truncate fractional
		if(maxPlaces < fractional.length){
			valueParts[1] = fractional.substr(0, maxPlaces);
		}
	}else{
		if(valueParts[1]){ valueParts.pop(); }
	}

	// Pad whole with leading zeros
	var patternDigits = patternParts[0].replace(',', '');
	pad = patternDigits.indexOf("0");
	if(pad != -1){
		pad = patternDigits.length - pad;
		if(pad > valueParts[0].length){
			valueParts[0] = dojo.string.pad(valueParts[0], pad);
		}

		// Truncate whole
		if(patternDigits.indexOf("#") == -1){
			valueParts[0] = valueParts[0].substr(valueParts[0].length - pad);
		}
	}

	// Add group separators
	var index = patternParts[0].lastIndexOf(','),
		groupSize, groupSize2;
	if(index != -1){
		groupSize = patternParts[0].length - index - 1;
		var remainder = patternParts[0].substr(0, index);
		index = remainder.lastIndexOf(',');
		if(index != -1){
			groupSize2 = remainder.length - index - 1;
		}
	}
	var pieces = [];
	for(var whole = valueParts[0]; whole;){
		var off = whole.length - groupSize;
		pieces.push((off > 0) ? whole.substr(off) : whole);
		whole = (off > 0) ? whole.slice(0, off) : "";
		if(groupSize2){
			groupSize = groupSize2;
			delete groupSize2;
		}
	}
	valueParts[0] = pieces.reverse().join(options.group || ",");

	return valueParts.join(options.decimal || ".");
};

/*=====
dojo.number.__RegexpOptions = function(){
	//	pattern: String?
	//		override [formatting pattern](http://www.unicode.org/reports/tr35/#Number_Format_Patterns)
	//		with this string.  Default value is based on locale.  Overriding this property will defeat
	//		localization.
	//	type: String?
	//		choose a format type based on the locale from the following:
	//		decimal, scientific (not yet supported), percent, currency. decimal by default.
	//	locale: String?
	//		override the locale used to determine formatting rules
	//	strict: Boolean?
	//		strict parsing, false by default.  Strict parsing requires input as produced by the format() method.
	//		Non-strict is more permissive, e.g. flexible on white space, omitting thousands separators
	//	places: Number|String?
	//		number of decimal places to accept: Infinity, a positive number, or
	//		a range "n,m".  Defined by pattern or Infinity if pattern not provided.
	this.pattern = pattern;
	this.type = type;
	this.locale = locale;
	this.strict = strict;
	this.places = places;
}
=====*/
dojo.number.regexp = function(/*dojo.number.__RegexpOptions?*/options){
	//	summary:
	//		Builds the regular needed to parse a number
	//	description:
	//		Returns regular expression with positive and negative match, group
	//		and decimal separators
	return dojo.number._parseInfo(options).regexp; // String
};

dojo.number._parseInfo = function(/*Object?*/options){
	options = options || {};
	var locale = dojo.i18n.normalizeLocale(options.locale),
		bundle = dojo.i18n.getLocalization("dojo.cldr", "number", locale),
		pattern = options.pattern || bundle[(options.type || "decimal") + "Format"],
//TODO: memoize?
		group = bundle.group,
		decimal = bundle.decimal,
		factor = 1;

	if(pattern.indexOf('%') != -1){
		factor /= 100;
	}else if(pattern.indexOf('\u2030') != -1){
		factor /= 1000; // per mille
	}else{
		var isCurrency = pattern.indexOf('\u00a4') != -1;
		if(isCurrency){
			group = bundle.currencyGroup || group;
			decimal = bundle.currencyDecimal || decimal;
		}
	}

	//TODO: handle quoted escapes
	var patternList = pattern.split(';');
	if(patternList.length == 1){
		patternList.push("-" + patternList[0]);
	}

	var re = dojo.regexp.buildGroupRE(patternList, function(pattern){
		pattern = "(?:"+dojo.regexp.escapeString(pattern, '.')+")";
		return pattern.replace(dojo.number._numberPatternRE, function(format){
			var flags = {
				signed: false,
				separator: options.strict ? group : [group,""],
				fractional: options.fractional,
				decimal: decimal,
				exponent: false
				},

				parts = format.split('.'),
				places = options.places;

			// special condition for percent (factor != 1)
			// allow decimal places even if not specified in pattern
			if(parts.length == 1 && factor != 1){
			    parts[1] = "###";
			}
			if(parts.length == 1 || places === 0){
				flags.fractional = false;
			}else{
				if(places === undefined){ places = options.pattern ? parts[1].lastIndexOf('0') + 1 : Infinity; }
				if(places && options.fractional == undefined){flags.fractional = true;} // required fractional, unless otherwise specified
				if(!options.places && (places < parts[1].length)){ places += "," + parts[1].length; }
				flags.places = places;
			}
			var groups = parts[0].split(',');
			if(groups.length > 1){
				flags.groupSize = groups.pop().length;
				if(groups.length > 1){
					flags.groupSize2 = groups.pop().length;
				}
			}
			return "("+dojo.number._realNumberRegexp(flags)+")";
		});
	}, true);

	if(isCurrency){
		// substitute the currency symbol for the placeholder in the pattern
		re = re.replace(/([\s\xa0]*)(\u00a4{1,3})([\s\xa0]*)/g, function(match, before, target, after){
			var prop = ["symbol", "currency", "displayName"][target.length-1],
				symbol = dojo.regexp.escapeString(options[prop] || options.currency || "");
			before = before ? "[\\s\\xa0]" : "";
			after = after ? "[\\s\\xa0]" : "";
			if(!options.strict){
				if(before){before += "*";}
				if(after){after += "*";}
				return "(?:"+before+symbol+after+")?";
			}
			return before+symbol+after;
		});
	}

//TODO: substitute localized sign/percent/permille/etc.?

	// normalize whitespace and return
	return {regexp: re.replace(/[\xa0 ]/g, "[\\s\\xa0]"), group: group, decimal: decimal, factor: factor}; // Object
};

/*=====
dojo.number.__ParseOptions = function(){
	//	pattern: String?
	//		override [formatting pattern](http://www.unicode.org/reports/tr35/#Number_Format_Patterns)
	//		with this string.  Default value is based on locale.  Overriding this property will defeat
	//		localization.  Literal characters in patterns are not supported.
	//	type: String?
	//		choose a format type based on the locale from the following:
	//		decimal, scientific (not yet supported), percent, currency. decimal by default.
	//	locale: String?
	//		override the locale used to determine formatting rules
	//	strict: Boolean?
	//		strict parsing, false by default.  Strict parsing requires input as produced by the format() method.
	//		Non-strict is more permissive, e.g. flexible on white space, omitting thousands separators
	//	fractional: Boolean?|Array?
	//		Whether to include the fractional portion, where the number of decimal places are implied by pattern
	//		or explicit 'places' parameter.  The value [true,false] makes the fractional portion optional.
	this.pattern = pattern;
	this.type = type;
	this.locale = locale;
	this.strict = strict;
	this.fractional = fractional;
}
=====*/
dojo.number.parse = function(/*String*/expression, /*dojo.number.__ParseOptions?*/options){
	// summary:
	//		Convert a properly formatted string to a primitive Number, using
	//		locale-specific settings.
	// description:
	//		Create a Number from a string using a known localized pattern.
	//		Formatting patterns are chosen appropriate to the locale
	//		and follow the syntax described by
	//		[unicode.org TR35](http://www.unicode.org/reports/tr35/#Number_Format_Patterns)
    	//		Note that literal characters in patterns are not supported.
	// expression:
	//		A string representation of a Number
	var info = dojo.number._parseInfo(options),
		results = (new RegExp("^"+info.regexp+"$")).exec(expression);
	if(!results){
		return NaN; //NaN
	}
	var absoluteMatch = results[1]; // match for the positive expression
	if(!results[1]){
		if(!results[2]){
			return NaN; //NaN
		}
		// matched the negative pattern
		absoluteMatch =results[2];
		info.factor *= -1;
	}

	// Transform it to something Javascript can parse as a number.  Normalize
	// decimal point and strip out group separators or alternate forms of whitespace
	absoluteMatch = absoluteMatch.
		replace(new RegExp("["+info.group + "\\s\\xa0"+"]", "g"), "").
		replace(info.decimal, ".");
	// Adjust for negative sign, percent, etc. as necessary
	return absoluteMatch * info.factor; //Number
};

/*=====
dojo.number.__RealNumberRegexpFlags = function(){
	//	places: Number?
	//		The integer number of decimal places or a range given as "n,m".  If
	//		not given, the decimal part is optional and the number of places is
	//		unlimited.
	//	decimal: String?
	//		A string for the character used as the decimal point.  Default
	//		is ".".
	//	fractional: Boolean?|Array?
	//		Whether decimal places are used.  Can be true, false, or [true,
	//		false].  Default is [true, false] which means optional.
	//	exponent: Boolean?|Array?
	//		Express in exponential notation.  Can be true, false, or [true,
	//		false]. Default is [true, false], (i.e. will match if the
	//		exponential part is present are not).
	//	eSigned: Boolean?|Array?
	//		The leading plus-or-minus sign on the exponent.  Can be true,
	//		false, or [true, false].  Default is [true, false], (i.e. will
	//		match if it is signed or unsigned).  flags in regexp.integer can be
	//		applied.
	this.places = places;
	this.decimal = decimal;
	this.fractional = fractional;
	this.exponent = exponent;
	this.eSigned = eSigned;
}
=====*/

dojo.number._realNumberRegexp = function(/*dojo.number.__RealNumberRegexpFlags?*/flags){
	// summary:
	//		Builds a regular expression to match a real number in exponential
	//		notation

	// assign default values to missing parameters
	flags = flags || {};
	//TODO: use mixin instead?
	if(!("places" in flags)){ flags.places = Infinity; }
	if(typeof flags.decimal != "string"){ flags.decimal = "."; }
	if(!("fractional" in flags) || /^0/.test(flags.places)){ flags.fractional = [true, false]; }
	if(!("exponent" in flags)){ flags.exponent = [true, false]; }
	if(!("eSigned" in flags)){ flags.eSigned = [true, false]; }

	var integerRE = dojo.number._integerRegexp(flags),
		decimalRE = dojo.regexp.buildGroupRE(flags.fractional,
		function(q){
			var re = "";
			if(q && (flags.places!==0)){
				re = "\\" + flags.decimal;
				if(flags.places == Infinity){
					re = "(?:" + re + "\\d+)?";
				}else{
					re += "\\d{" + flags.places + "}";
				}
			}
			return re;
		},
		true
	);

	var exponentRE = dojo.regexp.buildGroupRE(flags.exponent,
		function(q){
			if(q){ return "([eE]" + dojo.number._integerRegexp({ signed: flags.eSigned}) + ")"; }
			return "";
		}
	);

	var realRE = integerRE + decimalRE;
	// allow for decimals without integers, e.g. .25
	if(decimalRE){realRE = "(?:(?:"+ realRE + ")|(?:" + decimalRE + "))";}
	return realRE + exponentRE; // String
};

/*=====
dojo.number.__IntegerRegexpFlags = function(){
	//	signed: Boolean?
	//		The leading plus-or-minus sign. Can be true, false, or `[true,false]`.
	//		Default is `[true, false]`, (i.e. will match if it is signed
	//		or unsigned).
	//	separator: String?
	//		The character used as the thousands separator. Default is no
	//		separator. For more than one symbol use an array, e.g. `[",", ""]`,
	//		makes ',' optional.
	//	groupSize: Number?
	//		group size between separators
	//	groupSize2: Number?
	//		second grouping, where separators 2..n have a different interval than the first separator (for India)
	this.signed = signed;
	this.separator = separator;
	this.groupSize = groupSize;
	this.groupSize2 = groupSize2;
}
=====*/

dojo.number._integerRegexp = function(/*dojo.number.__IntegerRegexpFlags?*/flags){
	// summary:
	//		Builds a regular expression that matches an integer

	// assign default values to missing parameters
	flags = flags || {};
	if(!("signed" in flags)){ flags.signed = [true, false]; }
	if(!("separator" in flags)){
		flags.separator = "";
	}else if(!("groupSize" in flags)){
		flags.groupSize = 3;
	}

	var signRE = dojo.regexp.buildGroupRE(flags.signed,
		function(q){ return q ? "[-+]" : ""; },
		true
	);

	var numberRE = dojo.regexp.buildGroupRE(flags.separator,
		function(sep){
			if(!sep){
				return "(?:\\d+)";
			}

			sep = dojo.regexp.escapeString(sep);
			if(sep == " "){ sep = "\\s"; }
			else if(sep == "\xa0"){ sep = "\\s\\xa0"; }

			var grp = flags.groupSize, grp2 = flags.groupSize2;
			//TODO: should we continue to enforce that numbers with separators begin with 1-9?  See #6933
			if(grp2){
				var grp2RE = "(?:0|[1-9]\\d{0," + (grp2-1) + "}(?:[" + sep + "]\\d{" + grp2 + "})*[" + sep + "]\\d{" + grp + "})";
				return ((grp-grp2) > 0) ? "(?:" + grp2RE + "|(?:0|[1-9]\\d{0," + (grp-1) + "}))" : grp2RE;
			}
			return "(?:0|[1-9]\\d{0," + (grp-1) + "}(?:[" + sep + "]\\d{" + grp + "})*)";
		},
		true
	);

	return signRE + numberRE; // String
};

}

if(!dojo._hasResource["epages.widget.ProgressBar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.ProgressBar"] = true;
/*
	Copyright (c) 2006-2010, ePages GmbH
	All Rights Reserved.

	 *	+---------------------------------------+
	 *	|@@@@@@@@@@@@@@@@@@@                    |
	 *	+---------------------------------------+
	 *	{preStatusString}: {progress} / {maximum}

*/
dojo.provide("epages.widget.ProgressBar");



dojo.declare(
	"epages.widget.ProgressBar",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 *
		 */
		maximum 						: 0.0,
		progress 						: 0.0,
		preStatusString 		: "",
		disableStatusString : false,

		/**
		 * widget properties
		 */
		percentageClass        : 'PercentageNormal',
		templateString:"<span>\n  <div class=\"ProgressBar\">\n     <div class=\"InnerProgressBar\" dojoAttachPoint=\"innerProgressBar\">\n        <div dojoAttachPoint=\"progressBar\" style=\"width: 0%;\" class=\"PercentageNormal\" title=\"0%\"></div>\n     </div>\n  </div>\n  <div dojoAttachPoint=\"progressText\"><br /></div>\n</span>\n",
		translationName        : dojo.moduleUrl('epages.widget','templates/translation'),

		postCreate: function() {
			this.inherited("postCreate", arguments);
			dojo.subscribe(this.id+'/updateProgress', this, 'updateProgress');
			dojo.subscribe(this.id+'/setMaximum', this, 'setMaximum');
		},

		updateData : function(/* Object */ usageData) {
		 // summary: Write current data to class members and update widget.
		 	dojo.mixin(this,usageData);
			this._updateWidget();
		},

		setMaximum : function(/* Integer */ maximum) {
		 // summary: Write current data to class members and update widget.
			this.maximum = parseFloat(maximum);
			this._updateWidget();
		},

		updateProgress : function (/* Integer */ progress) {
		 // summary: Change the current progress and update the widget.
			this.progress = parseFloat(progress);
			this._updateWidget();
		},

		_updateWidget : function() {
		 // summary: Compose strings with usage percentage, maximum and progress
		 //   and update the widget's template attach points.
			var percentage = 100 * parseFloat(this.progress) / parseFloat(this.maximum);
			var displayPercentageTwoDec = dojo.number.round(percentage, 2).toString() + '%';
			var displayPercentageNoDec = dojo.number.round(percentage, 0).toString() + '%';
			dojo.attr(this.progressBar, 'style', 'width:' + displayPercentageNoDec);
			this.progressBar.title = displayPercentageTwoDec + ' : '+ this.progress + ' ' + this.translate('of') + ' ' + this.maximum;

			if(!this.disableStatusString){
					// Display format: "preStatusString : progress of maximum"
					this.progressText.style.display = "";
					if(this.preStatusString!=""){
						this.progressText.innerHTML = this.preStatusString + ": ";
					} else {
						this.progressText.innerHTML = "";
					}
					this.progressText.innerHTML += this.progress + ' / ' + this.maximum;
			} else {
					this.progressText.style.display = "none";
			}
		}
});

}

if(!dojo._hasResource["dojo.data.util.filter"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.data.util.filter"] = true;
dojo.provide("dojo.data.util.filter");

dojo.getObject("data.util.filter", true, dojo);

dojo.data.util.filter.patternToRegExp = function(/*String*/pattern, /*boolean?*/ ignoreCase){
	//	summary:
	//		Helper function to convert a simple pattern to a regular expression for matching.
	//	description:
	//		Returns a regular expression object that conforms to the defined conversion rules.
	//		For example:
	//			ca*   -> /^ca.*$/
	//			*ca*  -> /^.*ca.*$/
	//			*c\*a*  -> /^.*c\*a.*$/
	//			*c\*a?*  -> /^.*c\*a..*$/
	//			and so on.
	//
	//	pattern: string
	//		A simple matching pattern to convert that follows basic rules:
	//			* Means match anything, so ca* means match anything starting with ca
	//			? Means match single character.  So, b?b will match to bob and bab, and so on.
	//      	\ is an escape character.  So for example, \* means do not treat * as a match, but literal character *.
	//				To use a \ as a character in the string, it must be escaped.  So in the pattern it should be
	//				represented by \\ to be treated as an ordinary \ character instead of an escape.
	//
	//	ignoreCase:
	//		An optional flag to indicate if the pattern matching should be treated as case-sensitive or not when comparing
	//		By default, it is assumed case sensitive.

	var rxp = "^";
	var c = null;
	for(var i = 0; i < pattern.length; i++){
		c = pattern.charAt(i);
		switch(c){
			case '\\':
				rxp += c;
				i++;
				rxp += pattern.charAt(i);
				break;
			case '*':
				rxp += ".*"; break;
			case '?':
				rxp += "."; break;
			case '$':
			case '^':
			case '/':
			case '+':
			case '.':
			case '|':
			case '(':
			case ')':
			case '{':
			case '}':
			case '[':
			case ']':
				rxp += "\\"; //fallthrough
			default:
				rxp += c;
		}
	}
	rxp += "$";
	if(ignoreCase){
		return new RegExp(rxp,"mi"); //RegExp
	}else{
		return new RegExp(rxp,"m"); //RegExp
	}
	
};

}

if(!dojo._hasResource["dijit.form.TextBox"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form.TextBox"] = true;
dojo.provide("dijit.form.TextBox");



dojo.declare(
	"dijit.form.TextBox",
	dijit.form._FormValueWidget,
	{
		// summary:
		//		A base class for textbox form inputs

		// trim: Boolean
		//		Removes leading and trailing whitespace if true.  Default is false.
		trim: false,

		// uppercase: Boolean
		//		Converts all characters to uppercase if true.  Default is false.
		uppercase: false,

		// lowercase: Boolean
		//		Converts all characters to lowercase if true.  Default is false.
		lowercase: false,

		// propercase: Boolean
		//		Converts the first character of each word to uppercase if true.
		propercase: false,

		// maxLength: String
		//		HTML INPUT tag maxLength declaration.
		maxLength: "",

		// selectOnClick: [const] Boolean
		//		If true, all text will be selected when focused with mouse
		selectOnClick: false,

		// placeHolder: String
		//		Defines a hint to help users fill out the input field (as defined in HTML 5).
		//		This should only contain plain text (no html markup).
		placeHolder: "",
		
		templateString: dojo.cache("dijit.form", "templates/TextBox.html", "<div class=\"dijit dijitReset dijitInline dijitLeft\" id=\"widget_${id}\" role=\"presentation\"\n\t><div class=\"dijitReset dijitInputField dijitInputContainer\"\n\t\t><input class=\"dijitReset dijitInputInner\" dojoAttachPoint='textbox,focusNode' autocomplete=\"off\"\n\t\t\t${!nameAttrSetting} type='${type}'\n\t/></div\n></div>\n"),
		_singleNodeTemplate: '<input class="dijit dijitReset dijitLeft dijitInputField" dojoAttachPoint="textbox,focusNode" autocomplete="off" type="${type}" ${!nameAttrSetting} />',

		_buttonInputDisabled: dojo.isIE ? "disabled" : "", // allows IE to disallow focus, but Firefox cannot be disabled for mousedown events

		baseClass: "dijitTextBox",

		attributeMap: dojo.delegate(dijit.form._FormValueWidget.prototype.attributeMap, {
			maxLength: "focusNode"
		}),
		
		postMixInProperties: function(){
			var type = this.type.toLowerCase();
			if(this.templateString && this.templateString.toLowerCase() == "input" || ((type == "hidden" || type == "file") && this.templateString == dijit.form.TextBox.prototype.templateString)){
				this.templateString = this._singleNodeTemplate;
			}
			this.inherited(arguments);
		},

		_setPlaceHolderAttr: function(v){
			this._set("placeHolder", v);
			if(!this._phspan){
				this._attachPoints.push('_phspan');
				/* dijitInputField class gives placeHolder same padding as the input field
				 * parent node already has dijitInputField class but it doesn't affect this <span>
				 * since it's position: absolute.
				 */
				this._phspan = dojo.create('span',{className:'dijitPlaceHolder dijitInputField'},this.textbox,'after');
			}
			this._phspan.innerHTML="";
			this._phspan.appendChild(document.createTextNode(v));
			
			this._updatePlaceHolder();
		},
		
		_updatePlaceHolder: function(){
			if(this._phspan){
				this._phspan.style.display=(this.placeHolder&&!this._focused&&!this.textbox.value)?"":"none";
			}
		},

		_getValueAttr: function(){
			// summary:
			//		Hook so get('value') works as we like.
			// description:
			//		For `dijit.form.TextBox` this basically returns the value of the <input>.
			//
			//		For `dijit.form.MappedTextBox` subclasses, which have both
			//		a "displayed value" and a separate "submit value",
			//		This treats the "displayed value" as the master value, computing the
			//		submit value from it via this.parse().
			return this.parse(this.get('displayedValue'), this.constraints);
		},

		_setValueAttr: function(value, /*Boolean?*/ priorityChange, /*String?*/ formattedValue){
			// summary:
			//		Hook so set('value', ...) works.
			//
			// description:
			//		Sets the value of the widget to "value" which can be of
			//		any type as determined by the widget.
			//
			// value:
			//		The visual element value is also set to a corresponding,
			//		but not necessarily the same, value.
			//
			// formattedValue:
			//		If specified, used to set the visual element value,
			//		otherwise a computed visual value is used.
			//
			// priorityChange:
			//		If true, an onChange event is fired immediately instead of
			//		waiting for the next blur event.

			var filteredValue;
			if(value !== undefined){
				// TODO: this is calling filter() on both the display value and the actual value.
				// I added a comment to the filter() definition about this, but it should be changed.
				filteredValue = this.filter(value);
				if(typeof formattedValue != "string"){
					if(filteredValue !== null && ((typeof filteredValue != "number") || !isNaN(filteredValue))){
						formattedValue = this.filter(this.format(filteredValue, this.constraints));
					}else{ formattedValue = ''; }
				}
			}
			if(formattedValue != null && formattedValue != undefined && ((typeof formattedValue) != "number" || !isNaN(formattedValue)) && this.textbox.value != formattedValue){
				this.textbox.value = formattedValue;
				this._set("displayedValue", this.get("displayedValue"));
			}

			this._updatePlaceHolder();

			this.inherited(arguments, [filteredValue, priorityChange]);
		},

		// displayedValue: String
		//		For subclasses like ComboBox where the displayed value
		//		(ex: Kentucky) and the serialized value (ex: KY) are different,
		//		this represents the displayed value.
		//
		//		Setting 'displayedValue' through set('displayedValue', ...)
		//		updates 'value', and vice-versa.  Otherwise 'value' is updated
		//		from 'displayedValue' periodically, like onBlur etc.
		//
		//		TODO: move declaration to MappedTextBox?
		//		Problem is that ComboBox references displayedValue,
		//		for benefit of FilteringSelect.
		displayedValue: "",

		getDisplayedValue: function(){
			// summary:
			//		Deprecated.  Use get('displayedValue') instead.
			// tags:
			//		deprecated
			dojo.deprecated(this.declaredClass+"::getDisplayedValue() is deprecated. Use set('displayedValue') instead.", "", "2.0");
			return this.get('displayedValue');
		},

		_getDisplayedValueAttr: function(){
			// summary:
			//		Hook so get('displayedValue') works.
			// description:
			//		Returns the displayed value (what the user sees on the screen),
			// 		after filtering (ie, trimming spaces etc.).
			//
			//		For some subclasses of TextBox (like ComboBox), the displayed value
			//		is different from the serialized value that's actually
			//		sent to the server (see dijit.form.ValidationTextBox.serialize)

			// TODO: maybe we should update this.displayedValue on every keystroke so that we don't need
			// this method
			// TODO: this isn't really the displayed value when the user is typing
			return this.filter(this.textbox.value);
		},

		setDisplayedValue: function(/*String*/ value){
			// summary:
			//		Deprecated.  Use set('displayedValue', ...) instead.
			// tags:
			//		deprecated
			dojo.deprecated(this.declaredClass+"::setDisplayedValue() is deprecated. Use set('displayedValue', ...) instead.", "", "2.0");
			this.set('displayedValue', value);
		},

		_setDisplayedValueAttr: function(/*String*/ value){
			// summary:
			//		Hook so set('displayedValue', ...) works.
			// description:
			//		Sets the value of the visual element to the string "value".
			//		The widget value is also set to a corresponding,
			//		but not necessarily the same, value.

			if(value === null || value === undefined){ value = '' }
			else if(typeof value != "string"){ value = String(value) }

			this.textbox.value = value;

			// sets the serialized value to something corresponding to specified displayedValue
			// (if possible), and also updates the textbox.value, for example converting "123"
			// to "123.00"
			this._setValueAttr(this.get('value'), undefined);

			this._set("displayedValue", this.get('displayedValue'));
		},

		format: function(/*String*/ value, /*Object*/ constraints){
			// summary:
			//		Replacable function to convert a value to a properly formatted string.
			// tags:
			//		protected extension
			return ((value == null || value == undefined) ? "" : (value.toString ? value.toString() : value));
		},

		parse: function(/*String*/ value, /*Object*/ constraints){
			// summary:
			//		Replacable function to convert a formatted string to a value
			// tags:
			//		protected extension

			return value;	// String
		},

		_refreshState: function(){
			// summary:
			//		After the user types some characters, etc., this method is
			//		called to check the field for validity etc.  The base method
			//		in `dijit.form.TextBox` does nothing, but subclasses override.
			// tags:
			//		protected
		},

		_onInput: function(e){
			if(e && e.type && /key/i.test(e.type) && e.keyCode){
				switch(e.keyCode){
					case dojo.keys.SHIFT:
					case dojo.keys.ALT:
					case dojo.keys.CTRL:
					case dojo.keys.TAB:
						return;
				}
			}
			if(this.intermediateChanges){
				var _this = this;
				// the setTimeout allows the key to post to the widget input box
				setTimeout(function(){ _this._handleOnChange(_this.get('value'), false); }, 0);
			}
			this._refreshState();

			// In case someone is watch()'ing for changes to displayedValue
			this._set("displayedValue", this.get("displayedValue"));
		},

		postCreate: function(){
			if(dojo.isIE){ // IE INPUT tag fontFamily has to be set directly using STYLE
				// the setTimeout gives IE a chance to render the TextBox and to deal with font inheritance
				setTimeout(dojo.hitch(this, function(){
				var s = dojo.getComputedStyle(this.domNode);
				if(s){
					var ff = s.fontFamily;
					if(ff){
						var inputs = this.domNode.getElementsByTagName("INPUT");
						if(inputs){
							for(var i=0; i < inputs.length; i++){
								inputs[i].style.fontFamily = ff;
							}
						}
					}
				}
				}), 0);
			}

			// setting the value here is needed since value="" in the template causes "undefined"
			// and setting in the DOM (instead of the JS object) helps with form reset actions
			this.textbox.setAttribute("value", this.textbox.value); // DOM and JS values should be the same

			this.inherited(arguments);

			if(dojo.isMoz || dojo.isOpera){
				this.connect(this.textbox, "oninput", "_onInput");
			}else{
				this.connect(this.textbox, "onkeydown", "_onInput");
				this.connect(this.textbox, "onkeyup", "_onInput");
				this.connect(this.textbox, "onpaste", "_onInput");
				this.connect(this.textbox, "oncut", "_onInput");
			}
		},

		_blankValue: '', // if the textbox is blank, what value should be reported
		filter: function(val){
			// summary:
			//		Auto-corrections (such as trimming) that are applied to textbox
			//		value on blur or form submit.
			// description:
			//		For MappedTextBox subclasses, this is called twice
			// 			- once with the display value
			//			- once the value as set/returned by set('value', ...)
			//		and get('value'), ex: a Number for NumberTextBox.
			//
			//		In the latter case it does corrections like converting null to NaN.  In
			//		the former case the NumberTextBox.filter() method calls this.inherited()
			//		to execute standard trimming code in TextBox.filter().
			//
			//		TODO: break this into two methods in 2.0
			//
			// tags:
			//		protected extension
			if(val === null){ return this._blankValue; }
			if(typeof val != "string"){ return val; }
			if(this.trim){
				val = dojo.trim(val);
			}
			if(this.uppercase){
				val = val.toUpperCase();
			}
			if(this.lowercase){
				val = val.toLowerCase();
			}
			if(this.propercase){
				val = val.replace(/[^\s]+/g, function(word){
					return word.substring(0,1).toUpperCase() + word.substring(1);
				});
			}
			return val;
		},

		_setBlurValue: function(){
			this._setValueAttr(this.get('value'), true);
		},

		_onBlur: function(e){
			if(this.disabled){ return; }
			this._setBlurValue();
			this.inherited(arguments);

			if(this._selectOnClickHandle){
				this.disconnect(this._selectOnClickHandle);
			}
			if(this.selectOnClick && dojo.isMoz){
				this.textbox.selectionStart = this.textbox.selectionEnd = undefined; // clear selection so that the next mouse click doesn't reselect
			}
			
			this._updatePlaceHolder();
		},

		_onFocus: function(/*String*/ by){
			if(this.disabled || this.readOnly){ return; }

			// Select all text on focus via click if nothing already selected.
			// Since mouse-up will clear the selection need to defer selection until after mouse-up.
			// Don't do anything on focus by tabbing into the widget since there's no associated mouse-up event.
			if(this.selectOnClick && by == "mouse"){
				this._selectOnClickHandle = this.connect(this.domNode, "onmouseup", function(){
					// Only select all text on first click; otherwise users would have no way to clear
					// the selection.
					this.disconnect(this._selectOnClickHandle);

					// Check if the user selected some text manually (mouse-down, mouse-move, mouse-up)
					// and if not, then select all the text
					var textIsNotSelected;
					if(dojo.isIE){
						var range = dojo.doc.selection.createRange();
						var parent = range.parentElement();
						textIsNotSelected = parent == this.textbox && range.text.length == 0;
					}else{
						textIsNotSelected = this.textbox.selectionStart == this.textbox.selectionEnd;
					}
					if(textIsNotSelected){
						dijit.selectInputText(this.textbox);
					}
				});
			}

			this._updatePlaceHolder();
			
			// call this.inherited() before refreshState(), since this.inherited() will possibly scroll the viewport
			// (to scroll the TextBox into view), which will affect how _refreshState() positions the tooltip
			this.inherited(arguments);

			this._refreshState();
		},

		reset: function(){
			// Overrides dijit._FormWidget.reset().
			// Additionally resets the displayed textbox value to ''
			this.textbox.value = '';
			this.inherited(arguments);
		}
	}
);

dijit.selectInputText = function(/*DomNode*/ element, /*Number?*/ start, /*Number?*/ stop){
	// summary:
	//		Select text in the input element argument, from start (default 0), to stop (default end).

	// TODO: use functions in _editor/selection.js?
	var _window = dojo.global;
	var _document = dojo.doc;
	element = dojo.byId(element);
	if(isNaN(start)){ start = 0; }
	if(isNaN(stop)){ stop = element.value ? element.value.length : 0; }
	dijit.focus(element);
	if(_document["selection"] && dojo.body()["createTextRange"]){ // IE
		if(element.createTextRange){
			var r = element.createTextRange();
			r.collapse(true);
			r.moveStart("character", -99999); // move to 0
			r.moveStart("character", start); // delta from 0 is the correct position
			r.moveEnd("character", stop-start);
			r.select();
		}
	}else if(_window["getSelection"]){
		if(element.setSelectionRange){
			element.setSelectionRange(start, stop);
		}
	}
};

}

if(!dojo._hasResource["dijit.Tooltip"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.Tooltip"] = true;
dojo.provide("dijit.Tooltip");




dojo.declare(
	"dijit._MasterTooltip",
	[dijit._Widget, dijit._Templated],
	{
		// summary:
		//		Internal widget that holds the actual tooltip markup,
		//		which occurs once per page.
		//		Called by Tooltip widgets which are just containers to hold
		//		the markup
		// tags:
		//		protected

		// duration: Integer
		//		Milliseconds to fade in/fade out
		duration: dijit.defaultDuration,

		templateString: dojo.cache("dijit", "templates/Tooltip.html", "<div class=\"dijitTooltip dijitTooltipLeft\" id=\"dojoTooltip\"\n\t><div class=\"dijitTooltipContainer dijitTooltipContents\" dojoAttachPoint=\"containerNode\" role='alert'></div\n\t><div class=\"dijitTooltipConnector\" dojoAttachPoint=\"connectorNode\"></div\n></div>\n"),

		postCreate: function(){
			dojo.body().appendChild(this.domNode);

			this.bgIframe = new dijit.BackgroundIframe(this.domNode);

			// Setup fade-in and fade-out functions.
			this.fadeIn = dojo.fadeIn({ node: this.domNode, duration: this.duration, onEnd: dojo.hitch(this, "_onShow") });
			this.fadeOut = dojo.fadeOut({ node: this.domNode, duration: this.duration, onEnd: dojo.hitch(this, "_onHide") });
		},

		show: function(/*String*/ innerHTML, /*DomNode*/ aroundNode, /*String[]?*/ position, /*Boolean*/ rtl){
			// summary:
			//		Display tooltip w/specified contents to right of specified node
			//		(To left if there's no space on the right, or if rtl == true)

			if(this.aroundNode && this.aroundNode === aroundNode){
				return;
			}

			// reset width; it may have been set by orient() on a previous tooltip show()
			this.domNode.width = "auto";

			if(this.fadeOut.status() == "playing"){
				// previous tooltip is being hidden; wait until the hide completes then show new one
				this._onDeck=arguments;
				return;
			}
			this.containerNode.innerHTML=innerHTML;

			var pos = dijit.placeOnScreenAroundElement(this.domNode, aroundNode, dijit.getPopupAroundAlignment((position && position.length) ? position : dijit.Tooltip.defaultPosition, !rtl), dojo.hitch(this, "orient"));

			// show it
			dojo.style(this.domNode, "opacity", 0);
			this.fadeIn.play();
			this.isShowingNow = true;
			this.aroundNode = aroundNode;
		},

		orient: function(/*DomNode*/ node, /*String*/ aroundCorner, /*String*/ tooltipCorner, /*Object*/ spaceAvailable, /*Object*/ aroundNodeCoords){
			// summary:
			//		Private function to set CSS for tooltip node based on which position it's in.
			//		This is called by the dijit popup code.   It will also reduce the tooltip's
			//		width to whatever width is available
			// tags:
			//		protected
			this.connectorNode.style.top = ""; //reset to default
			
			//Adjust the spaceAvailable width, without changing the spaceAvailable object
			var tooltipSpaceAvaliableWidth = spaceAvailable.w - this.connectorNode.offsetWidth;

			node.className = "dijitTooltip " +
				{
					"BL-TL": "dijitTooltipBelow dijitTooltipABLeft",
					"TL-BL": "dijitTooltipAbove dijitTooltipABLeft",
					"BR-TR": "dijitTooltipBelow dijitTooltipABRight",
					"TR-BR": "dijitTooltipAbove dijitTooltipABRight",
					"BR-BL": "dijitTooltipRight",
					"BL-BR": "dijitTooltipLeft"
				}[aroundCorner + "-" + tooltipCorner];
				
			// reduce tooltip's width to the amount of width available, so that it doesn't overflow screen
			this.domNode.style.width = "auto";
			var size = dojo.contentBox(this.domNode);
			
			var width = Math.min((Math.max(tooltipSpaceAvaliableWidth,1)), size.w);
			var widthWasReduced = width < size.w;
			
			this.domNode.style.width = width+"px";
						
			//Adjust width for tooltips that have a really long word or a nowrap setting
			if(widthWasReduced){
				this.containerNode.style.overflow = "auto"; //temp change to overflow to detect if our tooltip needs to be wider to support the content
				var scrollWidth = this.containerNode.scrollWidth;
				this.containerNode.style.overflow = "visible"; //change it back
				if(scrollWidth > width){
					scrollWidth = scrollWidth + dojo.style(this.domNode,"paddingLeft") + dojo.style(this.domNode,"paddingRight");
					this.domNode.style.width = scrollWidth + "px";
				}
			}
			
			// Reposition the tooltip connector.
			if(tooltipCorner.charAt(0) == 'B' && aroundCorner.charAt(0) == 'B'){
				var mb = dojo.marginBox(node);
				var tooltipConnectorHeight = this.connectorNode.offsetHeight;
				if(mb.h > spaceAvailable.h){
					// The tooltip starts at the top of the page and will extend past the aroundNode
					var aroundNodePlacement = spaceAvailable.h - (aroundNodeCoords.h / 2) - (tooltipConnectorHeight / 2);
					this.connectorNode.style.top = aroundNodePlacement + "px";
					this.connectorNode.style.bottom = "";
				}else{
					// Align center of connector with center of aroundNode, except don't let bottom
					// of connector extend below bottom of tooltip content, or top of connector
					// extend past top of tooltip content
					this.connectorNode.style.bottom = Math.min(
						Math.max(aroundNodeCoords.h/2 - tooltipConnectorHeight/2, 0),
						mb.h - tooltipConnectorHeight) + "px";
					this.connectorNode.style.top = "";
				}
			}else{
				// reset the tooltip back to the defaults
				this.connectorNode.style.top = "";
				this.connectorNode.style.bottom = "";
			}
			
			return Math.max(0, size.w - tooltipSpaceAvaliableWidth);
		},

		_onShow: function(){
			// summary:
			//		Called at end of fade-in operation
			// tags:
			//		protected
			if(dojo.isIE){
				// the arrow won't show up on a node w/an opacity filter
				this.domNode.style.filter="";
			}
		},

		hide: function(aroundNode){
			// summary:
			//		Hide the tooltip

			if(this._onDeck && this._onDeck[1] == aroundNode){
				// this hide request is for a show() that hasn't even started yet;
				// just cancel the pending show()
				this._onDeck=null;
			}else if(this.aroundNode === aroundNode){
				// this hide request is for the currently displayed tooltip
				this.fadeIn.stop();
				this.isShowingNow = false;
				this.aroundNode = null;
				this.fadeOut.play();
			}else{
				// just ignore the call, it's for a tooltip that has already been erased
			}
		},

		_onHide: function(){
			// summary:
			//		Called at end of fade-out operation
			// tags:
			//		protected

			this.domNode.style.cssText="";	// to position offscreen again
			this.containerNode.innerHTML="";
			if(this._onDeck){
				// a show request has been queued up; do it now
				this.show.apply(this, this._onDeck);
				this._onDeck=null;
			}
		}

	}
);

dijit.showTooltip = function(/*String*/ innerHTML, /*DomNode*/ aroundNode, /*String[]?*/ position, /*Boolean*/ rtl){
	// summary:
	//		Display tooltip w/specified contents in specified position.
	//		See description of dijit.Tooltip.defaultPosition for details on position parameter.
	//		If position is not specified then dijit.Tooltip.defaultPosition is used.
	if(!dijit._masterTT){ dijit._masterTT = new dijit._MasterTooltip(); }
	return dijit._masterTT.show(innerHTML, aroundNode, position, rtl);
};

dijit.hideTooltip = function(aroundNode){
	// summary:
	//		Hide the tooltip
	if(!dijit._masterTT){ dijit._masterTT = new dijit._MasterTooltip(); }
	return dijit._masterTT.hide(aroundNode);
};

dojo.declare(
	"dijit.Tooltip",
	dijit._Widget,
	{
		// summary:
		//		Pops up a tooltip (a help message) when you hover over a node.

		// label: String
		//		Text to display in the tooltip.
		//		Specified as innerHTML when creating the widget from markup.
		label: "",

		// showDelay: Integer
		//		Number of milliseconds to wait after hovering over/focusing on the object, before
		//		the tooltip is displayed.
		showDelay: 400,

		// connectId: String|String[]
		//		Id of domNode(s) to attach the tooltip to.
		//		When user hovers over specified dom node, the tooltip will appear.
		connectId: [],

		// position: String[]
		//		See description of `dijit.Tooltip.defaultPosition` for details on position parameter.
		position: [],

		_setConnectIdAttr: function(/*String*/ newId){
			// summary:
			//		Connect to node(s) (specified by id)

			// Remove connections to old nodes (if there are any)
			dojo.forEach(this._connections || [], function(nested){
				dojo.forEach(nested, dojo.hitch(this, "disconnect"));
			}, this);

			// Make connections to nodes in newIds.
			var ary = dojo.isArrayLike(newId) ? newId : (newId ? [newId] : []);
			this._connections = dojo.map(ary, function(id){
				var node = dojo.byId(id);
				return node ? [
					this.connect(node, "onmouseenter", "_onTargetMouseEnter"),
					this.connect(node, "onmouseleave", "_onTargetMouseLeave"),
					this.connect(node, "onfocus", "_onTargetFocus"),
					this.connect(node, "onblur", "_onTargetBlur")
				] : [];
			}, this);
	
			this._set("connectId", newId);

			this._connectIds = ary;	// save as array
		},

		addTarget: function(/*DOMNODE || String*/ node){
			// summary:
			//		Attach tooltip to specified node if it's not already connected

			// TODO: remove in 2.0 and just use set("connectId", ...) interface

			var id = node.id || node;
			if(dojo.indexOf(this._connectIds, id) == -1){
				this.set("connectId", this._connectIds.concat(id));
			}
		},

		removeTarget: function(/*DOMNODE || String*/ node){
			// summary:
			//		Detach tooltip from specified node

			// TODO: remove in 2.0 and just use set("connectId", ...) interface
			
			var id = node.id || node,	// map from DOMNode back to plain id string
				idx = dojo.indexOf(this._connectIds, id);
			if(idx >= 0){
				// remove id (modifies original this._connectIds but that's OK in this case)
				this._connectIds.splice(idx, 1);
				this.set("connectId", this._connectIds);
			}
		},

		buildRendering: function(){
			this.inherited(arguments);
			dojo.addClass(this.domNode,"dijitTooltipData");
		},

		startup: function(){
			this.inherited(arguments);

			// If this tooltip was created in a template, or for some other reason the specified connectId[s]
			// didn't exist during the widget's initialization, then connect now.
			var ids = this.connectId;
			dojo.forEach(dojo.isArrayLike(ids) ? ids : [ids], this.addTarget, this);
		},

		_onTargetMouseEnter: function(/*Event*/ e){
			// summary:
			//		Handler for mouseenter event on the target node
			// tags:
			//		private
			this._onHover(e);
		},

		_onTargetMouseLeave: function(/*Event*/ e){
			// summary:
			//		Handler for mouseleave event on the target node
			// tags:
			//		private
			this._onUnHover(e);
		},

		_onTargetFocus: function(/*Event*/ e){
			// summary:
			//		Handler for focus event on the target node
			// tags:
			//		private

			this._focus = true;
			this._onHover(e);
		},

		_onTargetBlur: function(/*Event*/ e){
			// summary:
			//		Handler for blur event on the target node
			// tags:
			//		private

			this._focus = false;
			this._onUnHover(e);
		},

		_onHover: function(/*Event*/ e){
			// summary:
			//		Despite the name of this method, it actually handles both hover and focus
			//		events on the target node, setting a timer to show the tooltip.
			// tags:
			//		private
			if(!this._showTimer){
				var target = e.target;
				this._showTimer = setTimeout(dojo.hitch(this, function(){this.open(target)}), this.showDelay);
			}
		},

		_onUnHover: function(/*Event*/ e){
			// summary:
			//		Despite the name of this method, it actually handles both mouseleave and blur
			//		events on the target node, hiding the tooltip.
			// tags:
			//		private

			// keep a tooltip open if the associated element still has focus (even though the
			// mouse moved away)
			if(this._focus){ return; }

			if(this._showTimer){
				clearTimeout(this._showTimer);
				delete this._showTimer;
			}
			this.close();
		},

		open: function(/*DomNode*/ target){
 			// summary:
			//		Display the tooltip; usually not called directly.
			// tags:
			//		private

			if(this._showTimer){
				clearTimeout(this._showTimer);
				delete this._showTimer;
			}
			dijit.showTooltip(this.label || this.domNode.innerHTML, target, this.position, !this.isLeftToRight());

			this._connectNode = target;
			this.onShow(target, this.position);
		},

		close: function(){
			// summary:
			//		Hide the tooltip or cancel timer for show of tooltip
			// tags:
			//		private

			if(this._connectNode){
				// if tooltip is currently shown
				dijit.hideTooltip(this._connectNode);
				delete this._connectNode;
				this.onHide();
			}
			if(this._showTimer){
				// if tooltip is scheduled to be shown (after a brief delay)
				clearTimeout(this._showTimer);
				delete this._showTimer;
			}
		},

		onShow: function(target, position){
			// summary:
			//		Called when the tooltip is shown
			// tags:
			//		callback
		},

		onHide: function(){
			// summary:
			//		Called when the tooltip is hidden
			// tags:
			//		callback
		},

		uninitialize: function(){
			this.close();
			this.inherited(arguments);
		}
	}
);

// dijit.Tooltip.defaultPosition: String[]
//		This variable controls the position of tooltips, if the position is not specified to
//		the Tooltip widget or *TextBox widget itself.  It's an array of strings with the following values:
//
//			* before: places tooltip to the left of the target node/widget, or to the right in
//			  the case of RTL scripts like Hebrew and Arabic
//			* after: places tooltip to the right of the target node/widget, or to the left in
//			  the case of RTL scripts like Hebrew and Arabic
//			* above: tooltip goes above target node
//			* below: tooltip goes below target node
//
//		The list is positions is tried, in order, until a position is found where the tooltip fits
//		within the viewport.
//
//		Be careful setting this parameter.  A value of "above" may work fine until the user scrolls
//		the screen so that there's no room above the target node.   Nodes with drop downs, like
//		DropDownButton or FilteringSelect, are especially problematic, in that you need to be sure
//		that the drop down and tooltip don't overlap, even when the viewport is scrolled so that there
//		is only room below (or above) the target node, but not both.
dijit.Tooltip.defaultPosition = ["after", "before"];

}

if(!dojo._hasResource["dijit.form.ValidationTextBox"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form.ValidationTextBox"] = true;
dojo.provide("dijit.form.ValidationTextBox");






/*=====
	dijit.form.ValidationTextBox.__Constraints = function(){
		// locale: String
		//		locale used for validation, picks up value from this widget's lang attribute
		// _flags_: anything
		//		various flags passed to regExpGen function
		this.locale = "";
		this._flags_ = "";
	}
=====*/

dojo.declare(
	"dijit.form.ValidationTextBox",
	dijit.form.TextBox,
	{
		// summary:
		//		Base class for textbox widgets with the ability to validate content of various types and provide user feedback.
		// tags:
		//		protected

		templateString: dojo.cache("dijit.form", "templates/ValidationTextBox.html", "<div class=\"dijit dijitReset dijitInlineTable dijitLeft\"\n\tid=\"widget_${id}\" role=\"presentation\"\n\t><div class='dijitReset dijitValidationContainer'\n\t\t><input class=\"dijitReset dijitInputField dijitValidationIcon dijitValidationInner\" value=\"&#935; \" type=\"text\" tabIndex=\"-1\" readonly=\"readonly\" role=\"presentation\"\n\t/></div\n\t><div class=\"dijitReset dijitInputField dijitInputContainer\"\n\t\t><input class=\"dijitReset dijitInputInner\" dojoAttachPoint='textbox,focusNode' autocomplete=\"off\"\n\t\t\t${!nameAttrSetting} type='${type}'\n\t/></div\n></div>\n"),
		baseClass: "dijitTextBox dijitValidationTextBox",

		// required: Boolean
		//		User is required to enter data into this field.
		required: false,

		// promptMessage: String
		//		If defined, display this hint string immediately on focus to the textbox, if empty.
		//		Also displays if the textbox value is Incomplete (not yet valid but will be with additional input).
		//		Think of this like a tooltip that tells the user what to do, not an error message
		//		that tells the user what they've done wrong.
		//
		//		Message disappears when user starts typing.
		promptMessage: "",

		// invalidMessage: String
		// 		The message to display if value is invalid.
		//		The translated string value is read from the message file by default.
		// 		Set to "" to use the promptMessage instead.
		invalidMessage: "$_unset_$",

		// missingMessage: String
		// 		The message to display if value is empty and the field is required.
		//		The translated string value is read from the message file by default.
		// 		Set to "" to use the invalidMessage instead.
		missingMessage: "$_unset_$",

		// message: String
		//		Currently error/prompt message.
		//		When using the default tooltip implementation, this will only be
		//		displayed when the field is focused.
		message: "",

		// constraints: dijit.form.ValidationTextBox.__Constraints
		//		user-defined object needed to pass parameters to the validator functions
		constraints: {},

		// regExp: [extension protected] String
		//		regular expression string used to validate the input
		//		Do not specify both regExp and regExpGen
		regExp: ".*",

		regExpGen: function(/*dijit.form.ValidationTextBox.__Constraints*/ constraints){
			// summary:
			//		Overridable function used to generate regExp when dependent on constraints.
			//		Do not specify both regExp and regExpGen.
			// tags:
			//		extension protected
			return this.regExp; // String
		},

		// state: [readonly] String
		//		Shows current state (ie, validation result) of input (""=Normal, Incomplete, or Error)
		state: "",

		// tooltipPosition: String[]
		//		See description of `dijit.Tooltip.defaultPosition` for details on this parameter.
		tooltipPosition: [],

		_setValueAttr: function(){
			// summary:
			//		Hook so set('value', ...) works.
			this.inherited(arguments);
			this.validate(this._focused);
		},

		validator: function(/*anything*/ value, /*dijit.form.ValidationTextBox.__Constraints*/ constraints){
			// summary:
			//		Overridable function used to validate the text input against the regular expression.
			// tags:
			//		protected
			return (new RegExp("^(?:" + this.regExpGen(constraints) + ")"+(this.required?"":"?")+"$")).test(value) &&
				(!this.required || !this._isEmpty(value)) &&
				(this._isEmpty(value) || this.parse(value, constraints) !== undefined); // Boolean
		},

		_isValidSubset: function(){
			// summary:
			//		Returns true if the value is either already valid or could be made valid by appending characters.
			//		This is used for validation while the user [may be] still typing.
			return this.textbox.value.search(this._partialre) == 0;
		},

		isValid: function(/*Boolean*/ isFocused){
			// summary:
			//		Tests if value is valid.
			//		Can override with your own routine in a subclass.
			// tags:
			//		protected
			return this.validator(this.textbox.value, this.constraints);
		},

		_isEmpty: function(value){
			// summary:
			//		Checks for whitespace
			return (this.trim ? /^\s*$/ : /^$/).test(value); // Boolean
		},

		getErrorMessage: function(/*Boolean*/ isFocused){
			// summary:
			//		Return an error message to show if appropriate
			// tags:
			//		protected
			return (this.required && this._isEmpty(this.textbox.value)) ? this.missingMessage : this.invalidMessage; // String
		},

		getPromptMessage: function(/*Boolean*/ isFocused){
			// summary:
			//		Return a hint message to show when widget is first focused
			// tags:
			//		protected
			return this.promptMessage; // String
		},

		_maskValidSubsetError: true,
		validate: function(/*Boolean*/ isFocused){
			// summary:
			//		Called by oninit, onblur, and onkeypress.
			// description:
			//		Show missing or invalid messages if appropriate, and highlight textbox field.
			// tags:
			//		protected
			var message = "";
			var isValid = this.disabled || this.isValid(isFocused);
			if(isValid){ this._maskValidSubsetError = true; }
			var isEmpty = this._isEmpty(this.textbox.value);
			var isValidSubset = !isValid && isFocused && this._isValidSubset();
			this._set("state", isValid ? "" : (((((!this._hasBeenBlurred || isFocused) && isEmpty) || isValidSubset) && this._maskValidSubsetError) ? "Incomplete" : "Error"));
			dijit.setWaiState(this.focusNode, "invalid", isValid ? "false" : "true");

			if(this.state == "Error"){
				this._maskValidSubsetError = isFocused && isValidSubset; // we want the error to show up after a blur and refocus
				message = this.getErrorMessage(isFocused);
			}else if(this.state == "Incomplete"){
				message = this.getPromptMessage(isFocused); // show the prompt whenever the value is not yet complete
				this._maskValidSubsetError = !this._hasBeenBlurred || isFocused; // no Incomplete warnings while focused
			}else if(isEmpty){
				message = this.getPromptMessage(isFocused); // show the prompt whenever there's no error and no text
			}
			this.set("message", message);

			return isValid;
		},

		displayMessage: function(/*String*/ message){
			// summary:
			//		Overridable method to display validation errors/hints.
			//		By default uses a tooltip.
			// tags:
			//		extension
			dijit.hideTooltip(this.domNode);
			if(message && this._focused){
				dijit.showTooltip(message, this.domNode, this.tooltipPosition, !this.isLeftToRight());
			}
		},

		_refreshState: function(){
			// Overrides TextBox._refreshState()
			this.validate(this._focused);
			this.inherited(arguments);
		},

		//////////// INITIALIZATION METHODS ///////////////////////////////////////

		constructor: function(){
			this.constraints = {};
		},

		_setConstraintsAttr: function(/*Object*/ constraints){
			if(!constraints.locale && this.lang){
				constraints.locale = this.lang;
			}
			this._set("constraints", constraints);
			this._computePartialRE();
		},

		_computePartialRE: function(){
			var p = this.regExpGen(this.constraints);
			this.regExp = p;
			var partialre = "";
			// parse the regexp and produce a new regexp that matches valid subsets
			// if the regexp is .* then there's no use in matching subsets since everything is valid
			if(p != ".*"){ this.regExp.replace(/\\.|\[\]|\[.*?[^\\]{1}\]|\{.*?\}|\(\?[=:!]|./g,
				function (re){
					switch(re.charAt(0)){
						case '{':
						case '+':
						case '?':
						case '*':
						case '^':
						case '$':
						case '|':
						case '(':
							partialre += re;
							break;
						case ")":
							partialre += "|$)";
							break;
						 default:
							partialre += "(?:"+re+"|$)";
							break;
					}
				}
			);}
			try{ // this is needed for now since the above regexp parsing needs more test verification
				"".search(partialre);
			}catch(e){ // should never be here unless the original RE is bad or the parsing is bad
				partialre = this.regExp;
				console.warn('RegExp error in ' + this.declaredClass + ': ' + this.regExp);
			} // should never be here unless the original RE is bad or the parsing is bad
			this._partialre = "^(?:" + partialre + ")$";
		},

		postMixInProperties: function(){
			this.inherited(arguments);
			this.messages = dojo.i18n.getLocalization("dijit.form", "validate", this.lang);
			if(this.invalidMessage == "$_unset_$"){ this.invalidMessage = this.messages.invalidMessage; }
			if(!this.invalidMessage){ this.invalidMessage = this.promptMessage; }
			if(this.missingMessage == "$_unset_$"){ this.missingMessage = this.messages.missingMessage; }
			if(!this.missingMessage){ this.missingMessage = this.invalidMessage; }
			this._setConstraintsAttr(this.constraints); // this needs to happen now (and later) due to codependency on _set*Attr calls attachPoints
		},

		_setDisabledAttr: function(/*Boolean*/ value){
			this.inherited(arguments);	// call FormValueWidget._setDisabledAttr()
			this._refreshState();
		},

		_setRequiredAttr: function(/*Boolean*/ value){
			this._set("required", value);
			dijit.setWaiState(this.focusNode, "required", value);
			this._refreshState();
		},

		_setMessageAttr: function(/*String*/ message){
			this._set("message", message);
			this.displayMessage(message);
		},

		reset:function(){
			// Overrides dijit.form.TextBox.reset() by also
			// hiding errors about partial matches
			this._maskValidSubsetError = true;
			this.inherited(arguments);
		},

		_onBlur: function(){
			// the message still exists but for back-compat, and to erase the tooltip
			// (if the message is being displayed as a tooltip), call displayMessage('')
			this.displayMessage('');

			this.inherited(arguments);
		}
	}
);

dojo.declare(
	"dijit.form.MappedTextBox",
	dijit.form.ValidationTextBox,
	{
		// summary:
		//		A dijit.form.ValidationTextBox subclass which provides a base class for widgets that have
		//		a visible formatted display value, and a serializable
		//		value in a hidden input field which is actually sent to the server.
		// description:
		//		The visible display may
		//		be locale-dependent and interactive.  The value sent to the server is stored in a hidden
		//		input field which uses the `name` attribute declared by the original widget.  That value sent
		//		to the server is defined by the dijit.form.MappedTextBox.serialize method and is typically
		//		locale-neutral.
		// tags:
		//		protected

		postMixInProperties: function(){
			this.inherited(arguments);

			// we want the name attribute to go to the hidden <input>, not the displayed <input>,
			// so override _FormWidget.postMixInProperties() setting of nameAttrSetting
			this.nameAttrSetting = "";
		},

		serialize: function(/*anything*/ val, /*Object?*/ options){
			// summary:
			//		Overridable function used to convert the get('value') result to a canonical
			//		(non-localized) string.  For example, will print dates in ISO format, and
			//		numbers the same way as they are represented in javascript.
			// tags:
			//		protected extension
			return val.toString ? val.toString() : ""; // String
		},

		toString: function(){
			// summary:
			//		Returns widget as a printable string using the widget's value
			// tags:
			//		protected
			var val = this.filter(this.get('value')); // call filter in case value is nonstring and filter has been customized
			return val != null ? (typeof val == "string" ? val : this.serialize(val, this.constraints)) : ""; // String
		},

		validate: function(){
			// Overrides `dijit.form.TextBox.validate`
			this.valueNode.value = this.toString();
			return this.inherited(arguments);
		},

		buildRendering: function(){
			// Overrides `dijit._Templated.buildRendering`

			this.inherited(arguments);

			// Create a hidden <input> node with the serialized value used for submit
			// (as opposed to the displayed value).
			// Passing in name as markup rather than calling dojo.create() with an attrs argument
			// to make dojo.query(input[name=...]) work on IE. (see #8660)
			this.valueNode = dojo.place("<input type='hidden'" + (this.name ? " name='" + this.name.replace(/'/g, "&quot;") + "'" : "") + "/>", this.textbox, "after");
		},

		reset: function(){
			// Overrides `dijit.form.ValidationTextBox.reset` to
			// reset the hidden textbox value to ''
			this.valueNode.value = '';
			this.inherited(arguments);
		}
	}
);

/*=====
	dijit.form.RangeBoundTextBox.__Constraints = function(){
		// min: Number
		//		Minimum signed value.  Default is -Infinity
		// max: Number
		//		Maximum signed value.  Default is +Infinity
		this.min = min;
		this.max = max;
	}
=====*/

dojo.declare(
	"dijit.form.RangeBoundTextBox",
	dijit.form.MappedTextBox,
	{
		// summary:
		//		Base class for textbox form widgets which defines a range of valid values.

		// rangeMessage: String
		//		The message to display if value is out-of-range
		rangeMessage: "",

		/*=====
		// constraints: dijit.form.RangeBoundTextBox.__Constraints
		constraints: {},
		======*/

		rangeCheck: function(/*Number*/ primitive, /*dijit.form.RangeBoundTextBox.__Constraints*/ constraints){
			// summary:
			//		Overridable function used to validate the range of the numeric input value.
			// tags:
			//		protected
			return	("min" in constraints? (this.compare(primitive,constraints.min) >= 0) : true) &&
				("max" in constraints? (this.compare(primitive,constraints.max) <= 0) : true); // Boolean
		},

		isInRange: function(/*Boolean*/ isFocused){
			// summary:
			//		Tests if the value is in the min/max range specified in constraints
			// tags:
			//		protected
			return this.rangeCheck(this.get('value'), this.constraints);
		},

		_isDefinitelyOutOfRange: function(){
			// summary:
			//		Returns true if the value is out of range and will remain
			//		out of range even if the user types more characters
			var val = this.get('value');
			var isTooLittle = false;
			var isTooMuch = false;
			if("min" in this.constraints){
				var min = this.constraints.min;
				min = this.compare(val, ((typeof min == "number") && min >= 0 && val !=0) ? 0 : min);
				isTooLittle = (typeof min == "number") && min < 0;
			}
			if("max" in this.constraints){
				var max = this.constraints.max;
				max = this.compare(val, ((typeof max != "number") || max > 0) ? max : 0);
				isTooMuch = (typeof max == "number") && max > 0;
			}
			return isTooLittle || isTooMuch;
		},

		_isValidSubset: function(){
			// summary:
			//		Overrides `dijit.form.ValidationTextBox._isValidSubset`.
			//		Returns true if the input is syntactically valid, and either within
			//		range or could be made in range by more typing.
			return this.inherited(arguments) && !this._isDefinitelyOutOfRange();
		},

		isValid: function(/*Boolean*/ isFocused){
			// Overrides dijit.form.ValidationTextBox.isValid to check that the value is also in range.
			return this.inherited(arguments) &&
				((this._isEmpty(this.textbox.value) && !this.required) || this.isInRange(isFocused)); // Boolean
		},

		getErrorMessage: function(/*Boolean*/ isFocused){
			// Overrides dijit.form.ValidationTextBox.getErrorMessage to print "out of range" message if appropriate
			var v = this.get('value');
			if(v !== null && v !== '' && v !== undefined && (typeof v != "number" || !isNaN(v)) && !this.isInRange(isFocused)){ // don't check isInRange w/o a real value
				return this.rangeMessage; // String
			}
			return this.inherited(arguments);
		},

		postMixInProperties: function(){
			this.inherited(arguments);
			if(!this.rangeMessage){
				this.messages = dojo.i18n.getLocalization("dijit.form", "validate", this.lang);
				this.rangeMessage = this.messages.rangeMessage;
			}
		},

		_setConstraintsAttr: function(/*Object*/ constraints){
			this.inherited(arguments);
			if(this.focusNode){ // not set when called from postMixInProperties
				if(this.constraints.min !== undefined){
					dijit.setWaiState(this.focusNode, "valuemin", this.constraints.min);
				}else{
					dijit.removeWaiState(this.focusNode, "valuemin");
				}
				if(this.constraints.max !== undefined){
					dijit.setWaiState(this.focusNode, "valuemax", this.constraints.max);
				}else{
					dijit.removeWaiState(this.focusNode, "valuemax");
				}
			}
		},

		_setValueAttr: function(/*Number*/ value, /*Boolean?*/ priorityChange){
			// summary:
			//		Hook so set('value', ...) works.

			dijit.setWaiState(this.focusNode, "valuenow", value);
			this.inherited(arguments);
		}
	}
);

}

if(!dojo._hasResource["dijit.form.ComboBox"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form.ComboBox"] = true;
dojo.provide("dijit.form.ComboBox");











dojo.declare(
	"dijit.form.ComboBoxMixin",
	dijit._HasDropDown,
	{
		// summary:
		//		Implements the base functionality for `dijit.form.ComboBox`/`dijit.form.FilteringSelect`
		// description:
		//		All widgets that mix in dijit.form.ComboBoxMixin must extend `dijit.form._FormValueWidget`.
		// tags:
		//		protected

		// item: Object
		//		This is the item returned by the dojo.data.store implementation that
		//		provides the data for this ComboBox, it's the currently selected item.
		item: null,

		// pageSize: Integer
		//		Argument to data provider.
		//		Specifies number of search results per page (before hitting "next" button)
		pageSize: Infinity,

		// store: [const] Object
		//		Reference to data provider object used by this ComboBox
		store: null,

		// fetchProperties: Object
		//		Mixin to the dojo.data store's fetch.
		//		For example, to set the sort order of the ComboBox menu, pass:
		//	|	{ sort: [{attribute:"name",descending: true}] }
		//		To override the default queryOptions so that deep=false, do:
		//	|	{ queryOptions: {ignoreCase: true, deep: false} }
		fetchProperties:{},

		// query: Object
		//		A query that can be passed to 'store' to initially filter the items,
		//		before doing further filtering based on `searchAttr` and the key.
		//		Any reference to the `searchAttr` is ignored.
		query: {},

		// autoComplete: Boolean
		//		If user types in a partial string, and then tab out of the `<input>` box,
		//		automatically copy the first entry displayed in the drop down list to
		//		the `<input>` field
		autoComplete: true,

		// highlightMatch: String
		// 		One of: "first", "all" or "none".
		//
		//		If the ComboBox/FilteringSelect opens with the search results and the searched
		//		string can be found, it will be highlighted.  If set to "all"
		//		then will probably want to change `queryExpr` parameter to '*${0}*'
		//
		//		Highlighting is only performed when `labelType` is "text", so as to not
		//		interfere with any HTML markup an HTML label might contain.
		highlightMatch: "first",

		// searchDelay: Integer
		//		Delay in milliseconds between when user types something and we start
		//		searching based on that value
		searchDelay: 100,

		// searchAttr: String
		//		Search for items in the data store where this attribute (in the item)
		//		matches what the user typed
		searchAttr: "name",

		// labelAttr: String?
		//		The entries in the drop down list come from this attribute in the
		//		dojo.data items.
		//		If not specified, the searchAttr attribute is used instead.
		labelAttr: "",

		// labelType: String
		//		Specifies how to interpret the labelAttr in the data store items.
		//		Can be "html" or "text".
		labelType: "text",

		// queryExpr: String
		//		This specifies what query ComboBox/FilteringSelect sends to the data store,
		//		based on what the user has typed.  Changing this expression will modify
		//		whether the drop down shows only exact matches, a "starting with" match,
		//		etc.  Use it in conjunction with highlightMatch.
		//		dojo.data query expression pattern.
		//		`${0}` will be substituted for the user text.
		//		`*` is used for wildcards.
		//		`${0}*` means "starts with", `*${0}*` means "contains", `${0}` means "is"
		queryExpr: "${0}*",

		// ignoreCase: Boolean
		//		Set true if the ComboBox/FilteringSelect should ignore case when matching possible items
		ignoreCase: true,

		// hasDownArrow: Boolean
		//		Set this textbox to have a down arrow button, to display the drop down list.
		//		Defaults to true.
		hasDownArrow: true,

		templateString: dojo.cache("dijit.form", "templates/DropDownBox.html", "<div class=\"dijit dijitReset dijitInlineTable dijitLeft\"\n\tid=\"widget_${id}\"\n\trole=\"combobox\"\n\t><div class='dijitReset dijitRight dijitButtonNode dijitArrowButton dijitDownArrowButton dijitArrowButtonContainer'\n\t\tdojoAttachPoint=\"_buttonNode, _popupStateNode\" role=\"presentation\"\n\t\t><input class=\"dijitReset dijitInputField dijitArrowButtonInner\" value=\"&#9660; \" type=\"text\" tabIndex=\"-1\" readonly=\"readonly\" role=\"presentation\"\n\t\t\t${_buttonInputDisabled}\n\t/></div\n\t><div class='dijitReset dijitValidationContainer'\n\t\t><input class=\"dijitReset dijitInputField dijitValidationIcon dijitValidationInner\" value=\"&#935; \" type=\"text\" tabIndex=\"-1\" readonly=\"readonly\" role=\"presentation\"\n\t/></div\n\t><div class=\"dijitReset dijitInputField dijitInputContainer\"\n\t\t><input class='dijitReset dijitInputInner' ${!nameAttrSetting} type=\"text\" autocomplete=\"off\"\n\t\t\tdojoAttachPoint=\"textbox,focusNode\" role=\"textbox\" aria-haspopup=\"true\"\n\t/></div\n></div>\n"),

		baseClass: "dijitTextBox dijitComboBox",

		// dropDownClass: [protected extension] String
		//		Name of the dropdown widget class used to select a date/time.
		//		Subclasses should specify this.
		dropDownClass: "dijit.form._ComboBoxMenu",

		// Set classes like dijitDownArrowButtonHover depending on
		// mouse action over button node
		cssStateNodes: {
			"_buttonNode": "dijitDownArrowButton"
		},

		// Flags to _HasDropDown to limit height of drop down to make it fit in viewport
		maxHeight: -1,

		// For backwards compatibility let onClick events propagate, even clicks on the down arrow button
		_stopClickEvents: false,

		_getCaretPos: function(/*DomNode*/ element){
			// khtml 3.5.2 has selection* methods as does webkit nightlies from 2005-06-22
			var pos = 0;
			if(typeof(element.selectionStart) == "number"){
				// FIXME: this is totally borked on Moz < 1.3. Any recourse?
				pos = element.selectionStart;
			}else if(dojo.isIE){
				// in the case of a mouse click in a popup being handled,
				// then the dojo.doc.selection is not the textarea, but the popup
				// var r = dojo.doc.selection.createRange();
				// hack to get IE 6 to play nice. What a POS browser.
				var tr = dojo.doc.selection.createRange().duplicate();
				var ntr = element.createTextRange();
				tr.move("character",0);
				ntr.move("character",0);
				try{
					// If control doesn't have focus, you get an exception.
					// Seems to happen on reverse-tab, but can also happen on tab (seems to be a race condition - only happens sometimes).
					// There appears to be no workaround for this - googled for quite a while.
					ntr.setEndPoint("EndToEnd", tr);
					pos = String(ntr.text).replace(/\r/g,"").length;
				}catch(e){
					// If focus has shifted, 0 is fine for caret pos.
				}
			}
			return pos;
		},

		_setCaretPos: function(/*DomNode*/ element, /*Number*/ location){
			location = parseInt(location);
			dijit.selectInputText(element, location, location);
		},

		_setDisabledAttr: function(/*Boolean*/ value){
			// Additional code to set disabled state of ComboBox node.
			// Overrides _FormValueWidget._setDisabledAttr() or ValidationTextBox._setDisabledAttr().
			this.inherited(arguments);
			dijit.setWaiState(this.domNode, "disabled", value);
		},

		_abortQuery: function(){
			// stop in-progress query
			if(this.searchTimer){
				clearTimeout(this.searchTimer);
				this.searchTimer = null;
			}
			if(this._fetchHandle){
				if(this._fetchHandle.abort){ this._fetchHandle.abort(); }
				this._fetchHandle = null;
			}
		},

		_onInput: function(/*Event*/ evt){
			// summary:
			//		Handles paste events
			if(!this.searchTimer && (evt.type == 'paste'/*IE|WebKit*/ || evt.type == 'input'/*Firefox*/) && this._lastInput != this.textbox.value){
				this.searchTimer = setTimeout(dojo.hitch(this, function(){
					this._onKey({charOrCode: 229}); // fake IME key to cause a search
				}), 100); // long delay that will probably be preempted by keyboard input
			}
			this.inherited(arguments);
		},

		_onKey: function(/*Event*/ evt){
			// summary:
			//		Handles keyboard events

			var key = evt.charOrCode;

			// except for cutting/pasting case - ctrl + x/v
			if(evt.altKey || ((evt.ctrlKey || evt.metaKey) && (key != 'x' && key != 'v')) || key == dojo.keys.SHIFT){
				return; // throw out weird key combinations and spurious events
			}
			
			var doSearch = false;
			var pw = this.dropDown;
			var dk = dojo.keys;
			var highlighted = null;
			this._prev_key_backspace = false;
			this._abortQuery();

			// _HasDropDown will do some of the work:
			//		1. when drop down is not yet shown:
			//			- if user presses the down arrow key, call loadDropDown()
			//		2. when drop down is already displayed:
			//			- on ESC key, call closeDropDown()
			//			- otherwise, call dropDown.handleKey() to process the keystroke
			this.inherited(arguments);

			if(this._opened){
				highlighted = pw.getHighlightedOption();
			}
			switch(key){
				case dk.PAGE_DOWN:
				case dk.DOWN_ARROW:
				case dk.PAGE_UP:
				case dk.UP_ARROW:
					// Keystroke caused ComboBox_menu to move to a different item.
					// Copy new item to <input> box.
					if(this._opened){
						this._announceOption(highlighted);
					}
					dojo.stopEvent(evt);
					break;

				case dk.ENTER:
					// prevent submitting form if user presses enter. Also
					// prevent accepting the value if either Next or Previous
					// are selected
					if(highlighted){
						// only stop event on prev/next
						if(highlighted == pw.nextButton){
							this._nextSearch(1);
							dojo.stopEvent(evt);
							break;
						}else if(highlighted == pw.previousButton){
							this._nextSearch(-1);
							dojo.stopEvent(evt);
							break;
						}
					}else{
						// Update 'value' (ex: KY) according to currently displayed text
						this._setBlurValue(); // set value if needed
						this._setCaretPos(this.focusNode, this.focusNode.value.length); // move cursor to end and cancel highlighting
					}
					// default case:
					// if enter pressed while drop down is open, or for FilteringSelect,
					// if we are in the middle of a query to convert a directly typed in value to an item,
					// prevent submit, but allow event to bubble
					if(this._opened || this._fetchHandle){
					evt.preventDefault();
					}
					// fall through

				case dk.TAB:
					var newvalue = this.get('displayedValue');
					//	if the user had More Choices selected fall into the
					//	_onBlur handler
					if(pw && (
						newvalue == pw._messages["previousMessage"] ||
						newvalue == pw._messages["nextMessage"])
					){
						break;
					}
					if(highlighted){
						this._selectOption();
					}
					if(this._opened){
						this._lastQuery = null; // in case results come back later
						this.closeDropDown();
					}
					break;

				case ' ':
					if(highlighted){
						// user is effectively clicking a choice in the drop down menu
						dojo.stopEvent(evt);
						this._selectOption();
						this.closeDropDown();
					}else{
						// user typed a space into the input box, treat as normal character
						doSearch = true;
					}
					break;

				case dk.DELETE:
				case dk.BACKSPACE:
					this._prev_key_backspace = true;
					doSearch = true;
					break;

				default:
					// Non char keys (F1-F12 etc..)  shouldn't open list.
					// Ascii characters and IME input (Chinese, Japanese etc.) should.
					//IME input produces keycode == 229.
					doSearch = typeof key == 'string' || key == 229;
			}
			if(doSearch){
				// need to wait a tad before start search so that the event
				// bubbles through DOM and we have value visible
				this.item = undefined; // undefined means item needs to be set
				this.searchTimer = setTimeout(dojo.hitch(this, "_startSearchFromInput"),1);
			}
		},

		_autoCompleteText: function(/*String*/ text){
			// summary:
			// 		Fill in the textbox with the first item from the drop down
			// 		list, and highlight the characters that were
			// 		auto-completed. For example, if user typed "CA" and the
			// 		drop down list appeared, the textbox would be changed to
			// 		"California" and "ifornia" would be highlighted.

			var fn = this.focusNode;

			// IE7: clear selection so next highlight works all the time
			dijit.selectInputText(fn, fn.value.length);
			// does text autoComplete the value in the textbox?
			var caseFilter = this.ignoreCase? 'toLowerCase' : 'substr';
			if(text[caseFilter](0).indexOf(this.focusNode.value[caseFilter](0)) == 0){
				var cpos = this._getCaretPos(fn);
				// only try to extend if we added the last character at the end of the input
				if((cpos+1) > fn.value.length){
					// only add to input node as we would overwrite Capitalisation of chars
					// actually, that is ok
					fn.value = text;//.substr(cpos);
					// visually highlight the autocompleted characters
					dijit.selectInputText(fn, cpos);
				}
			}else{
				// text does not autoComplete; replace the whole value and highlight
				fn.value = text;
				dijit.selectInputText(fn);
			}
		},

		_openResultList: function(/*Object*/ results, /*Object*/ dataObject){
			// summary:
			//		Callback when a search completes.
			// description:
			//		1. generates drop-down list and calls _showResultList() to display it
			//		2. if this result list is from user pressing "more choices"/"previous choices"
			//			then tell screen reader to announce new option
			this._fetchHandle = null;
			if(	this.disabled ||
				this.readOnly ||
				(dataObject.query[this.searchAttr] != this._lastQuery)
			){
				return;
			}
			var wasSelected = this.dropDown._highlighted_option && dojo.hasClass(this.dropDown._highlighted_option, "dijitMenuItemSelected");
			this.dropDown.clearResultList();
			if(!results.length && !this._maxOptions){ // if no results and not just the previous choices button
				this.closeDropDown();
				return;
			}

			// Fill in the textbox with the first item from the drop down list,
			// and highlight the characters that were auto-completed. For
			// example, if user typed "CA" and the drop down list appeared, the
			// textbox would be changed to "California" and "ifornia" would be
			// highlighted.

			dataObject._maxOptions = this._maxOptions;
			var nodes = this.dropDown.createOptions(
				results,
				dataObject,
				dojo.hitch(this, "_getMenuLabelFromItem")
			);

			// show our list (only if we have content, else nothing)
			this._showResultList();

			// #4091:
			//		tell the screen reader that the paging callback finished by
			//		shouting the next choice
			if(dataObject.direction){
				if(1 == dataObject.direction){
					this.dropDown.highlightFirstOption();
				}else if(-1 == dataObject.direction){
					this.dropDown.highlightLastOption();
				}
				if(wasSelected){
					this._announceOption(this.dropDown.getHighlightedOption());
				}
			}else if(this.autoComplete && !this._prev_key_backspace
				// when the user clicks the arrow button to show the full list,
				// startSearch looks for "*".
				// it does not make sense to autocomplete
				// if they are just previewing the options available.
				&& !/^[*]+$/.test(dataObject.query[this.searchAttr])){
					this._announceOption(nodes[1]); // 1st real item
			}
		},

		_showResultList: function(){
			// summary:
			//		Display the drop down if not already displayed, or if it is displayed, then
			//		reposition it if necessary (reposition may be necessary if drop down's height changed).

			this.closeDropDown(true);

			// hide the tooltip
			this.displayMessage("");

			this.openDropDown();

			dijit.setWaiState(this.domNode, "expanded", "true");
		},

		loadDropDown: function(/*Function*/ callback){
			// Overrides _HasDropDown.loadDropDown().
			// This is called when user has pressed button icon or pressed the down arrow key
			// to open the drop down.
			
			this._startSearchAll();
		},

		isLoaded: function(){
			// signal to _HasDropDown that it needs to call loadDropDown() to load the
			// drop down asynchronously before displaying it
			return false;
		},

		closeDropDown: function(){
			// Overrides _HasDropDown.closeDropDown().  Closes the drop down (assuming that it's open).
			// This method is the callback when the user types ESC or clicking
			// the button icon while the drop down is open.  It's also called by other code.
			this._abortQuery();
			if(this._opened){
				this.inherited(arguments);
				dijit.setWaiState(this.domNode, "expanded", "false");
				dijit.removeWaiState(this.focusNode,"activedescendant");
			}
		},

		_setBlurValue: function(){
			// if the user clicks away from the textbox OR tabs away, set the
			// value to the textbox value
			// #4617:
			//		if value is now more choices or previous choices, revert
			//		the value
			var newvalue = this.get('displayedValue');
			var pw = this.dropDown;
			if(pw && (
				newvalue == pw._messages["previousMessage"] ||
				newvalue == pw._messages["nextMessage"]
				)
			){
				this._setValueAttr(this._lastValueReported, true);
			}else if(typeof this.item == "undefined"){
				// Update 'value' (ex: KY) according to currently displayed text
				this.item = null;
				this.set('displayedValue', newvalue);
			}else{
				if(this.value != this._lastValueReported){
					dijit.form._FormValueWidget.prototype._setValueAttr.call(this, this.value, true);
				}
				this._refreshState();
			}
		},

		_onBlur: function(){
			// summary:
			//		Called magically when focus has shifted away from this widget and it's drop down
			this.closeDropDown();
			this.inherited(arguments);
		},

		_setItemAttr: function(/*item*/ item, /*Boolean?*/ priorityChange, /*String?*/ displayedValue){
			// summary:
			//		Set the displayed valued in the input box, and the hidden value
			//		that gets submitted, based on a dojo.data store item.
			// description:
			//		Users shouldn't call this function; they should be calling
			//		set('item', value)
			// tags:
			//		private
			if(!displayedValue){
				displayedValue = this.store.getValue(item, this.searchAttr);
			}
			var value = this._getValueField() != this.searchAttr? this.store.getIdentity(item) : displayedValue;
			this._set("item", item);
			dijit.form.ComboBox.superclass._setValueAttr.call(this, value, priorityChange, displayedValue);
		},

		_announceOption: function(/*Node*/ node){
			// summary:
			//		a11y code that puts the highlighted option in the textbox.
			//		This way screen readers will know what is happening in the
			//		menu.

			if(!node){
				return;
			}
			// pull the text value from the item attached to the DOM node
			var newValue;
			if(node == this.dropDown.nextButton ||
				node == this.dropDown.previousButton){
				newValue = node.innerHTML;
				this.item = undefined;
				this.value = '';
			}else{
				newValue = this.store.getValue(node.item, this.searchAttr).toString();
				this.set('item', node.item, false, newValue);
			}
			// get the text that the user manually entered (cut off autocompleted text)
			this.focusNode.value = this.focusNode.value.substring(0, this._lastInput.length);
			// set up ARIA activedescendant
			dijit.setWaiState(this.focusNode, "activedescendant", dojo.attr(node, "id"));
			// autocomplete the rest of the option to announce change
			this._autoCompleteText(newValue);
		},

		_selectOption: function(/*Event*/ evt){
			// summary:
			//		Menu callback function, called when an item in the menu is selected.
			if(evt){
				this._announceOption(evt.target);
			}
			this.closeDropDown();
			this._setCaretPos(this.focusNode, this.focusNode.value.length);
			dijit.form._FormValueWidget.prototype._setValueAttr.call(this, this.value, true); // set this.value and fire onChange
		},

		_startSearchAll: function(){
			this._startSearch('');
		},

		_startSearchFromInput: function(){
			this._startSearch(this.focusNode.value.replace(/([\\\*\?])/g, "\\$1"));
		},

		_getQueryString: function(/*String*/ text){
			return dojo.string.substitute(this.queryExpr, [text]);
		},

		_startSearch: function(/*String*/ key){
			// summary:
			//		Starts a search for elements matching key (key=="" means to return all items),
			//		and calls _openResultList() when the search completes, to display the results.
			if(!this.dropDown){
				var popupId = this.id + "_popup",
				dropDownConstructor = dojo.getObject(this.dropDownClass, false);
				this.dropDown = new dropDownConstructor({
					onChange: dojo.hitch(this, this._selectOption),
					id: popupId,
					dir: this.dir
				});
				dijit.removeWaiState(this.focusNode,"activedescendant");
				dijit.setWaiState(this.textbox,"owns",popupId); // associate popup with textbox
			}
			// create a new query to prevent accidentally querying for a hidden
			// value from FilteringSelect's keyField
			var query = dojo.clone(this.query); // #5970
			this._lastInput = key; // Store exactly what was entered by the user.
			this._lastQuery = query[this.searchAttr] = this._getQueryString(key);
			// #5970: set _lastQuery, *then* start the timeout
			// otherwise, if the user types and the last query returns before the timeout,
			// _lastQuery won't be set and their input gets rewritten
			this.searchTimer=setTimeout(dojo.hitch(this, function(query, _this){
				this.searchTimer = null;
				var fetch = {
					queryOptions: {
						ignoreCase: this.ignoreCase,
						deep: true
					},
					query: query,
					onBegin: dojo.hitch(this, "_setMaxOptions"),
					onComplete: dojo.hitch(this, "_openResultList"),
					onError: function(errText){
						_this._fetchHandle = null;
						console.error('dijit.form.ComboBox: ' + errText);
						_this.closeDropDown();
					},
					start: 0,
					count: this.pageSize
				};
				dojo.mixin(fetch, _this.fetchProperties);
				this._fetchHandle = _this.store.fetch(fetch);

				var nextSearch = function(dataObject, direction){
					dataObject.start += dataObject.count*direction;
					// #4091:
					//		tell callback the direction of the paging so the screen
					//		reader knows which menu option to shout
					dataObject.direction = direction;
					this._fetchHandle = this.store.fetch(dataObject);
					this.focus();
				};
				this._nextSearch = this.dropDown.onPage = dojo.hitch(this, nextSearch, this._fetchHandle);
			}, query, this), this.searchDelay);
		},

		_setMaxOptions: function(size, request){
			 this._maxOptions = size;
		},

		_getValueField: function(){
			// summary:
			//		Helper for postMixInProperties() to set this.value based on data inlined into the markup.
			//		Returns the attribute name in the item (in dijit.form._ComboBoxDataStore) to use as the value.
			return this.searchAttr;
		},

		//////////// INITIALIZATION METHODS ///////////////////////////////////////

		constructor: function(){
			this.query={};
			this.fetchProperties={};
		},

		postMixInProperties: function(){
			if(!this.store){
				var srcNodeRef = this.srcNodeRef;

				// if user didn't specify store, then assume there are option tags
				this.store = new dijit.form._ComboBoxDataStore(srcNodeRef);

				// if there is no value set and there is an option list, set
				// the value to the first value to be consistent with native
				// Select

				// Firefox and Safari set value
				// IE6 and Opera set selectedIndex, which is automatically set
				// by the selected attribute of an option tag
				// IE6 does not set value, Opera sets value = selectedIndex
				if(!("value" in this.params)){
					var item = (this.item = this.store.fetchSelectedItem());
					if(item){
						var valueField = this._getValueField();
						this.value = this.store.getValue(item, valueField);
					}
				}
			}

			this.inherited(arguments);
		},

		postCreate: function(){
			// summary:
			//		Subclasses must call this method from their postCreate() methods
			// tags:
			//		protected

			// find any associated label element and add to ComboBox node.
			var label=dojo.query('label[for="'+this.id+'"]');
			if(label.length){
				label[0].id = (this.id+"_label");
				dijit.setWaiState(this.domNode, "labelledby", label[0].id);

			}
			this.inherited(arguments);
		},

		_setHasDownArrowAttr: function(val){
			this.hasDownArrow = val;
			this._buttonNode.style.display = val ? "" : "none";
		},

		_getMenuLabelFromItem: function(/*Item*/ item){
			var label = this.labelFunc(item, this.store),
				labelType = this.labelType;
			// If labelType is not "text" we don't want to screw any markup ot whatever.
			if(this.highlightMatch != "none" && this.labelType == "text" && this._lastInput){
				label = this.doHighlight(label, this._escapeHtml(this._lastInput));
				labelType = "html";
			}
			return {html: labelType == "html", label: label};
		},

		doHighlight: function(/*String*/ label, /*String*/ find){
			// summary:
			//		Highlights the string entered by the user in the menu.  By default this
			//		highlights the first occurrence found. Override this method
			//		to implement your custom highlighting.
			// tags:
			//		protected

			var
				// Add (g)lobal modifier when this.highlightMatch == "all" and (i)gnorecase when this.ignoreCase == true
				modifiers = (this.ignoreCase ? "i" : "") + (this.highlightMatch == "all" ? "g" : ""),
				i = this.queryExpr.indexOf("${0}");
			find = dojo.regexp.escapeString(find); // escape regexp special chars
			return this._escapeHtml(label).replace(
				// prepend ^ when this.queryExpr == "${0}*" and append $ when this.queryExpr == "*${0}"
				new RegExp((i == 0 ? "^" : "") + "("+ find +")" + (i == (this.queryExpr.length - 4) ? "$" : ""), modifiers),
				'<span class="dijitComboBoxHighlightMatch">$1</span>'
			); // returns String, (almost) valid HTML (entities encoded)
		},

		_escapeHtml: function(/*String*/ str){
			// TODO Should become dojo.html.entities(), when exists use instead
			// summary:
			//		Adds escape sequences for special characters in XML: &<>"'
			str = String(str).replace(/&/gm, "&amp;").replace(/</gm, "&lt;")
				.replace(/>/gm, "&gt;").replace(/"/gm, "&quot;");
			return str; // string
		},

		reset: function(){
			// Overrides the _FormWidget.reset().
			// Additionally reset the .item (to clean up).
			this.item = null;
			this.inherited(arguments);
		},

		labelFunc: function(/*item*/ item, /*dojo.data.store*/ store){
			// summary:
			//		Computes the label to display based on the dojo.data store item.
			// returns:
			//		The label that the ComboBox should display
			// tags:
			//		private

			// Use toString() because XMLStore returns an XMLItem whereas this
			// method is expected to return a String (#9354)
			return store.getValue(item, this.labelAttr || this.searchAttr).toString(); // String
		}
	}
);

dojo.declare(
	"dijit.form._ComboBoxMenu",
	[dijit._Widget, dijit._Templated, dijit._CssStateMixin],
	{
		// summary:
		//		Focus-less menu for internal use in `dijit.form.ComboBox`
		// tags:
		//		private

		templateString: "<ul class='dijitReset dijitMenu' dojoAttachEvent='onmousedown:_onMouseDown,onmouseup:_onMouseUp,onmouseover:_onMouseOver,onmouseout:_onMouseOut' style='overflow: \"auto\"; overflow-x: \"hidden\";'>"
				+"<li class='dijitMenuItem dijitMenuPreviousButton' dojoAttachPoint='previousButton' role='option'></li>"
				+"<li class='dijitMenuItem dijitMenuNextButton' dojoAttachPoint='nextButton' role='option'></li>"
			+"</ul>",

		// _messages: Object
		//		Holds "next" and "previous" text for paging buttons on drop down
		_messages: null,
		
		baseClass: "dijitComboBoxMenu",

		postMixInProperties: function(){
			this.inherited(arguments);
			this._messages = dojo.i18n.getLocalization("dijit.form", "ComboBox", this.lang);
		},

		buildRendering: function(){
			this.inherited(arguments);

			// fill in template with i18n messages
			this.previousButton.innerHTML = this._messages["previousMessage"];
			this.nextButton.innerHTML = this._messages["nextMessage"];
		},

		_setValueAttr: function(/*Object*/ value){
			this.value = value;
			this.onChange(value);
		},

		// stubs
		onChange: function(/*Object*/ value){
			// summary:
			//		Notifies ComboBox/FilteringSelect that user clicked an option in the drop down menu.
			//		Probably should be called onSelect.
			// tags:
			//		callback
		},
		onPage: function(/*Number*/ direction){
			// summary:
			//		Notifies ComboBox/FilteringSelect that user clicked to advance to next/previous page.
			// tags:
			//		callback
		},

		onClose: function(){
			// summary:
			//		Callback from dijit.popup code to this widget, notifying it that it closed
			// tags:
			//		private
			this._blurOptionNode();
		},

		_createOption: function(/*Object*/ item, labelFunc){
			// summary:
			//		Creates an option to appear on the popup menu subclassed by
			//		`dijit.form.FilteringSelect`.

			var menuitem = dojo.create("li", {
				"class": "dijitReset dijitMenuItem" +(this.isLeftToRight() ? "" : " dijitMenuItemRtl"),
				role: "option"
			});
			var labelObject = labelFunc(item);
			if(labelObject.html){
				menuitem.innerHTML = labelObject.label;
			}else{
				menuitem.appendChild(
					dojo.doc.createTextNode(labelObject.label)
				);
			}
			// #3250: in blank options, assign a normal height
			if(menuitem.innerHTML == ""){
				menuitem.innerHTML = "&nbsp;";
			}
			menuitem.item=item;
			return menuitem;
		},

		createOptions: function(results, dataObject, labelFunc){
			// summary:
			//		Fills in the items in the drop down list
			// results:
			//		Array of dojo.data items
			// dataObject:
			//		dojo.data store
			// labelFunc:
			//		Function to produce a label in the drop down list from a dojo.data item

			//this._dataObject=dataObject;
			//this._dataObject.onComplete=dojo.hitch(comboBox, comboBox._openResultList);
			// display "Previous . . ." button
			this.previousButton.style.display = (dataObject.start == 0) ? "none" : "";
			dojo.attr(this.previousButton, "id", this.id + "_prev");
			// create options using _createOption function defined by parent
			// ComboBox (or FilteringSelect) class
			// #2309:
			//		iterate over cache nondestructively
			dojo.forEach(results, function(item, i){
				var menuitem = this._createOption(item, labelFunc);
				dojo.attr(menuitem, "id", this.id + i);
				this.domNode.insertBefore(menuitem, this.nextButton);
			}, this);
			// display "Next . . ." button
			var displayMore = false;
			//Try to determine if we should show 'more'...
			if(dataObject._maxOptions && dataObject._maxOptions != -1){
				if((dataObject.start + dataObject.count) < dataObject._maxOptions){
					displayMore = true;
				}else if((dataObject.start + dataObject.count) > dataObject._maxOptions && dataObject.count == results.length){
					//Weird return from a datastore, where a start + count > maxOptions
					// implies maxOptions isn't really valid and we have to go into faking it.
					//And more or less assume more if count == results.length
					displayMore = true;
				}
			}else if(dataObject.count == results.length){
				//Don't know the size, so we do the best we can based off count alone.
				//So, if we have an exact match to count, assume more.
				displayMore = true;
			}

			this.nextButton.style.display = displayMore ? "" : "none";
			dojo.attr(this.nextButton,"id", this.id + "_next");
			return this.domNode.childNodes;
		},

		clearResultList: function(){
			// summary:
			//		Clears the entries in the drop down list, but of course keeps the previous and next buttons.
			while(this.domNode.childNodes.length>2){
				this.domNode.removeChild(this.domNode.childNodes[this.domNode.childNodes.length-2]);
			}
			this._blurOptionNode();
		},

		_onMouseDown: function(/*Event*/ evt){
			dojo.stopEvent(evt);
		},

		_onMouseUp: function(/*Event*/ evt){
			if(evt.target === this.domNode || !this._highlighted_option){
				// !this._highlighted_option check to prevent immediate selection when menu appears on top
				// of <input>, see #9898.  Note that _HasDropDown also has code to prevent this.
				return;
			}else if(evt.target == this.previousButton){
				this._blurOptionNode();
				this.onPage(-1);
			}else if(evt.target == this.nextButton){
				this._blurOptionNode();
				this.onPage(1);
			}else{
				var tgt = evt.target;
				// while the clicked node is inside the div
				while(!tgt.item){
					// recurse to the top
					tgt = tgt.parentNode;
				}
				this._setValueAttr({ target: tgt }, true);
			}
		},

		_onMouseOver: function(/*Event*/ evt){
			if(evt.target === this.domNode){ return; }
			var tgt = evt.target;
			if(!(tgt == this.previousButton || tgt == this.nextButton)){
				// while the clicked node is inside the div
				while(!tgt.item){
					// recurse to the top
					tgt = tgt.parentNode;
				}
			}
			this._focusOptionNode(tgt);
		},

		_onMouseOut: function(/*Event*/ evt){
			if(evt.target === this.domNode){ return; }
			this._blurOptionNode();
		},

		_focusOptionNode: function(/*DomNode*/ node){
			// summary:
			//		Does the actual highlight.
			if(this._highlighted_option != node){
				this._blurOptionNode();
				this._highlighted_option = node;
				dojo.addClass(this._highlighted_option, "dijitMenuItemSelected");
			}
		},

		_blurOptionNode: function(){
			// summary:
			//		Removes highlight on highlighted option.
			if(this._highlighted_option){
				dojo.removeClass(this._highlighted_option, "dijitMenuItemSelected");
				this._highlighted_option = null;
			}
		},

		_highlightNextOption: function(){
			// summary:
			// 		Highlight the item just below the current selection.
			// 		If nothing selected, highlight first option.

			// because each press of a button clears the menu,
			// the highlighted option sometimes becomes detached from the menu!
			// test to see if the option has a parent to see if this is the case.
			if(!this.getHighlightedOption()){
				var fc = this.domNode.firstChild;
				this._focusOptionNode(fc.style.display == "none" ? fc.nextSibling : fc);
			}else{
				var ns = this._highlighted_option.nextSibling;
				if(ns && ns.style.display != "none"){
					this._focusOptionNode(ns);
				}else{
					this.highlightFirstOption();
				}
			}
			// scrollIntoView is called outside of _focusOptionNode because in IE putting it inside causes the menu to scroll up on mouseover
			dojo.window.scrollIntoView(this._highlighted_option);
		},

		highlightFirstOption: function(){
			// summary:
			// 		Highlight the first real item in the list (not Previous Choices).
			var first = this.domNode.firstChild;
			var second = first.nextSibling;
			this._focusOptionNode(second.style.display == "none" ? first : second); // remotely possible that Previous Choices is the only thing in the list
			dojo.window.scrollIntoView(this._highlighted_option);
		},

		highlightLastOption: function(){
			// summary:
			// 		Highlight the last real item in the list (not More Choices).
			this._focusOptionNode(this.domNode.lastChild.previousSibling);
			dojo.window.scrollIntoView(this._highlighted_option);
		},

		_highlightPrevOption: function(){
			// summary:
			// 		Highlight the item just above the current selection.
			// 		If nothing selected, highlight last option (if
			// 		you select Previous and try to keep scrolling up the list).
			if(!this.getHighlightedOption()){
				var lc = this.domNode.lastChild;
				this._focusOptionNode(lc.style.display == "none" ? lc.previousSibling : lc);
			}else{
				var ps = this._highlighted_option.previousSibling;
				if(ps && ps.style.display != "none"){
					this._focusOptionNode(ps);
				}else{
					this.highlightLastOption();
				}
			}
			dojo.window.scrollIntoView(this._highlighted_option);
		},

		_page: function(/*Boolean*/ up){
			// summary:
			//		Handles page-up and page-down keypresses

			var scrollamount = 0;
			var oldscroll = this.domNode.scrollTop;
			var height = dojo.style(this.domNode, "height");
			// if no item is highlighted, highlight the first option
			if(!this.getHighlightedOption()){
				this._highlightNextOption();
			}
			while(scrollamount<height){
				if(up){
					// stop at option 1
					if(!this.getHighlightedOption().previousSibling ||
						this._highlighted_option.previousSibling.style.display == "none"){
						break;
					}
					this._highlightPrevOption();
				}else{
					// stop at last option
					if(!this.getHighlightedOption().nextSibling ||
						this._highlighted_option.nextSibling.style.display == "none"){
						break;
					}
					this._highlightNextOption();
				}
				// going backwards
				var newscroll=this.domNode.scrollTop;
				scrollamount+=(newscroll-oldscroll)*(up ? -1:1);
				oldscroll=newscroll;
			}
		},

		pageUp: function(){
			// summary:
			//		Handles pageup keypress.
			//		TODO: just call _page directly from handleKey().
			// tags:
			//		private
			this._page(true);
		},

		pageDown: function(){
			// summary:
			//		Handles pagedown keypress.
			//		TODO: just call _page directly from handleKey().
			// tags:
			//		private
			this._page(false);
		},

		getHighlightedOption: function(){
			// summary:
			//		Returns the highlighted option.
			var ho = this._highlighted_option;
			return (ho && ho.parentNode) ? ho : null;
		},

		handleKey: function(evt){
			// summary:
			//		Handle keystroke event forwarded from ComboBox, returning false if it's
			//		a keystroke I recognize and process, true otherwise.
			switch(evt.charOrCode){
				case dojo.keys.DOWN_ARROW:
					this._highlightNextOption();
					return false;
				case dojo.keys.PAGE_DOWN:
					this.pageDown();
					return false;
				case dojo.keys.UP_ARROW:
					this._highlightPrevOption();
					return false;
				case dojo.keys.PAGE_UP:
					this.pageUp();
					return false;
				default:
					return true;
			}
		}
	}
);

dojo.declare(
	"dijit.form.ComboBox",
	[dijit.form.ValidationTextBox, dijit.form.ComboBoxMixin],
	{
		// summary:
		//		Auto-completing text box, and base class for dijit.form.FilteringSelect.
		//
		// description:
		//		The drop down box's values are populated from an class called
		//		a data provider, which returns a list of values based on the characters
		//		that the user has typed into the input box.
		//		If OPTION tags are used as the data provider via markup,
		//		then the OPTION tag's child text node is used as the widget value
		//		when selected.  The OPTION tag's value attribute is ignored.
		//		To set the default value when using OPTION tags, specify the selected
		//		attribute on 1 of the child OPTION tags.
		//
		//		Some of the options to the ComboBox are actually arguments to the data
		//		provider.

		_setValueAttr: function(/*String*/ value, /*Boolean?*/ priorityChange, /*String?*/ displayedValue){
			// summary:
			//		Hook so set('value', value) works.
			// description:
			//		Sets the value of the select.
			this._set("item", null); // value not looked up in store
			if(!value){ value = ''; } // null translates to blank
			dijit.form.ValidationTextBox.prototype._setValueAttr.call(this, value, priorityChange, displayedValue);
		}
	}
);

dojo.declare("dijit.form._ComboBoxDataStore", null, {
	// summary:
	//		Inefficient but small data store specialized for inlined `dijit.form.ComboBox` data
	//
	// description:
	//		Provides a store for inlined data like:
	//
	//	|	<select>
	//	|		<option value="AL">Alabama</option>
	//	|		...
	//
	//		Actually. just implements the subset of dojo.data.Read/Notification
	//		needed for ComboBox and FilteringSelect to work.
	//
	//		Note that an item is just a pointer to the <option> DomNode.

	constructor: function( /*DomNode*/ root){
		this.root = root;
		if(root.tagName != "SELECT" && root.firstChild){
			root = dojo.query("select", root);
			if(root.length > 0){ // SELECT is a child of srcNodeRef
				root = root[0];
			}else{ // no select, so create 1 to parent the option tags to define selectedIndex
				this.root.innerHTML = "<SELECT>"+this.root.innerHTML+"</SELECT>";
				root = this.root.firstChild;
			}
			this.root = root;
		}
		dojo.query("> option", root).forEach(function(node){
			//	TODO: this was added in #3858 but unclear why/if it's needed;  doesn't seem to be.
			//	If it is needed then can we just hide the select itself instead?
			//node.style.display="none";
			node.innerHTML = dojo.trim(node.innerHTML);
		});

	},

	getValue: function(	/*item*/ item,
						/*attribute-name-string*/ attribute,
						/*value?*/ defaultValue){
		return (attribute == "value") ? item.value : (item.innerText || item.textContent || '');
	},

	isItemLoaded: function(/*anything*/ something){
		return true;
	},

	getFeatures: function(){
		return {"dojo.data.api.Read": true, "dojo.data.api.Identity": true};
	},

	_fetchItems: function(	/*Object*/ args,
							/*Function*/ findCallback,
							/*Function*/ errorCallback){
		// summary:
		//		See dojo.data.util.simpleFetch.fetch()
		if(!args.query){ args.query = {}; }
		if(!args.query.name){ args.query.name = ""; }
		if(!args.queryOptions){ args.queryOptions = {}; }
		var matcher = dojo.data.util.filter.patternToRegExp(args.query.name, args.queryOptions.ignoreCase),
			items = dojo.query("> option", this.root).filter(function(option){
				return (option.innerText || option.textContent || '').match(matcher);
			} );
		if(args.sort){
			items.sort(dojo.data.util.sorter.createSortFunction(args.sort, this));
		}
		findCallback(items, args);
	},

	close: function(/*dojo.data.api.Request || args || null*/ request){
		return;
	},

	getLabel: function(/*item*/ item){
		return item.innerHTML;
	},

	getIdentity: function(/*item*/ item){
		return dojo.attr(item, "value");
	},

	fetchItemByIdentity: function(/*Object*/ args){
		// summary:
		//		Given the identity of an item, this method returns the item that has
		//		that identity through the onItem callback.
		//		Refer to dojo.data.api.Identity.fetchItemByIdentity() for more details.
		//
		// description:
		//		Given arguments like:
		//
		//	|		{identity: "CA", onItem: function(item){...}
		//
		//		Call `onItem()` with the DOM node `<option value="CA">California</option>`
		var item = dojo.query("> option[value='" + args.identity + "']", this.root)[0];
		args.onItem(item);
	},

	fetchSelectedItem: function(){
		// summary:
		//		Get the option marked as selected, like `<option selected>`.
		//		Not part of dojo.data API.
		var root = this.root,
			si = root.selectedIndex;
		return typeof si == "number"
			? dojo.query("> option:nth-child(" + (si != -1 ? si+1 : 1) + ")", root)[0]
			: null;	// dojo.data.Item
	}
});
//Mix in the simple fetch implementation to this class.
dojo.extend(dijit.form._ComboBoxDataStore,dojo.data.util.simpleFetch);

}

if(!dojo._hasResource["epages.widget.ComboBox"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.ComboBox"] = true;
dojo.provide("epages.widget.ComboBox");


dojo.declare(
	"epages.widget._ComboBoxMenu",
	dijit.form._ComboBoxMenu,
	{
		templateString: "<ul class='dijitReset dijitMenu dijitTagEditor' style='background-color:#FFF;' dojoAttachEvent='onmousedown:_onMouseDown,onmouseup:_onMouseUp,onmouseover:_onMouseOver,onmouseout:_onMouseOut' tabIndex='-1' style='overflow: \"auto\"; overflow-x: \"hidden\";z-index:200000000;'>"
			+"<li class='dijitMenuPreviousButton' dojoAttachPoint='previousButton' waiRole='option'></li>"
			+"<li class='dijitMenuNextButton' dojoAttachPoint='nextButton' waiRole='option'></li>"
		+"</ul>"
	}
);
dojo.declare(
	"epages.widget.ComboBox",
	[dijit.form.ComboBox],
	{
    // summary:
		//		Auto-completing text box, and base class for dijit.form.FilteringSelect.
		//
		// description:
		//		The drop down box's values are populated from an class called
		//		a data provider, which returns a list of values based on the characters
		//		that the user has typed into the input box.
		//		If OPTION tags are used as the data provider via markup,
		//		then the OPTION tag's child text node is used as the widget value
		//		when selected.  The OPTION tag's value attribute is ignored.
		//		To set the default value when using OPTION tags, specify the selected
		//		attribute on 1 of the child OPTION tags.
		//
		//		Some of the options to the ComboBox are actually arguments to the data
		//		provider.

		// autoComplete: Boolean
		//		If user types in a partial string, and then tab out of the `<input>` box,
		//		automatically copy the first entry displayed in the drop down list to
		//		the `<input>` field
		autoComplete: true,

		// highlightMatch: String
		// 		One of: "first", "all" or "none".
		//
		//		If the ComboBox/FilteringSelect opens with the search results and the searched
		//		string can be found, it will be highlighted.  If set to "all"
		//		then will probably want to change `queryExpr` parameter to '*${0}*'
		//
		//		Highlighting is only performed when `labelType` is "text", so as to not
		//		interfere with any HTML markup an HTML label might contain.
		highlightMatch: "none",

		// ignoreCase: Boolean
		//		Set true if the ComboBox/FilteringSelect should ignore case when matching possible items
		ignoreCase: true,

		// hasDownArrow: [const] Boolean
		//		Set this textbox to have a down arrow button, to display the drop down list.
		//		Defaults to true.
		hasDownArrow: true,

		templateString: dojo.cache("epages.widget", "templates/ComboBox.html", "<div id=\"widget_${id}\" style=\"${style};\"\n\tdojoAttachEvent=\"onmouseenter:_onMouse,onmouseleave:_onMouse,onmousedown:_onMouse\" dojoAttachPoint=\"comboNode\" waiRole=\"combobox\" tabIndex=\"-1\"\n\t><div style=\"overflow:hidden;\"\n\t\t><div class='dijitReset dijitRight dijitButtonNode dijitArrowButton dijitDownArrowButton'\n\t\t\tdojoAttachPoint=\"downArrowNode\" waiRole=\"presentation\"\n\t\t\tdojoAttachEvent=\"onmousedown:_onArrowMouseDown,onmouseup:_onMouse,onmouseenter:_onMouse,onmouseleave:_onMouse\"\n\t\t\t><div class=\"dijitButtonCombobox\">&#9660;</div\n\t\t></div\n\t\t><div class=\"dijitReset dijitInputField\"\n\t\t\t><input ${nameAttrSetting} dojoType=\"epages.widget.FormElement\"  type=\"text\" autocomplete=\"off\" class='dijitReset'\n\t\t\tdojoAttachEvent=\"onkeypress:_onKeyPress,compositionend\"\n\t\t\tdojoAttachPoint=\"textbox,focusNode\" waiRole=\"textbox\" waiState=\"haspopup-true,autocomplete-list\"\n\t\t/></div\n\t></div\n></div>\n"),
	
		baseClass : "",

		_setValueAttr: function(/*String*/ value, /*Boolean?*/ priorityChange, /*String?*/ displayedValue){
			// summary:
			//		Hook so attr('value', value) works.
			// description:
			//		Sets the value of the select.
			this.item = null; // value not looked up in store
			if(!value){ value = ''; } // null translates to blank
			dijit.form.ValidationTextBox.prototype._setValueAttr.call(this, value, priorityChange, displayedValue);
		},
		
		_startSearch: function(/*String*/ key){
			if(!this._popupWidget){
				var popupId = this.id + "_popup";
				this._popupWidget = new epages.widget._ComboBoxMenu({
					onChange: dojo.hitch(this, this._selectOption),
					id: popupId
				});
				dijit.removeWaiState(this.focusNode,"activedescendant");
				dijit.setWaiState(this.textbox,"owns",popupId); // associate popup with textbox
			}
			this.inherited("_startSearch", arguments);
		},
		open: function(){
			// summary:
			//		Opens the drop down menu.  TODO: rename to _open.
			// tags:
			//		private
			this._isShowingNow=true;
			var best = dijit.popup.open({
				popup: this._popupWidget,
				around: this.domNode,
				orient: {'BL':'TL', 'BR':'TR', 'TL':'BL', 'TR':'BR'},
				parent: this
			});
			if(epages.zIndex) {
				this._popupWidget.domNode.parentNode.style.zIndex=epages.zIndex;	// set z-index of wrapper div
				epages.zIndex+=1;
			}
			return best;
		}
	}
);

}

if(!dojo._hasResource["epages.widget.InfoText"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.InfoText"] = true;
dojo.provide("epages.widget.InfoText");



dojo.declare("epages.widget.InfoText",
	[dijit._Widget],
	{
		/**
		 * public properties
		 */
		readMoreText  : "",							// read more link text
		length        : "",							// number of chars to be displayed as widget param

		/**
		 * nodes
		 */
		 readMoreNode : undefined,

		/**
		 * private properties
		 */
		_textContent   : undefined,			// original text content
		_htmlContent   : undefined,			// original html Content
		_DEFAULT_LENGTH: 130,						// max number of chars to be displayed

		/**
		 * widget life cycle
		 */
		postCreate: function() {
			var length = parseInt(this.length) || this._DEFAULT_LENGTH;

			// save original text content
			this._htmlContent = this.domNode.innerHTML;
			this._textContent = (this.domNode.textContent) ? this.domNode.textContent : this.domNode.innerText;
			this.domNode.className = "InfoText";
			if(this._textContent.length - Math.round(length / 4) < length) {
				// we don't need the "read more" link if there are only some chars about to be sliced
				this.expand();
			}else {
				this.domNode.innerHTML = epages.format.slice(this._textContent, length, false)+"<br />";
				this.readMoreNode = document.createElement("A");
				this.readMoreNode.innerHTML = this.readMoreText;
				this.readMoreNode.className="NormalFontWeight";
				this.domNode.appendChild(this.readMoreNode);

				this.connect(this.readMoreNode, "click" , "expand");
			}
		},

		expand: function() {
		//summary: show the complete text
			this.domNode.innerHTML = this._htmlContent;
		}
});

}

if(!dojo._hasResource["epages.widget.WizardController"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.WizardController"] = true;
/*
	Copyright (c) 2006-2010, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.widget.WizardController");









dojo.declare("epages.widget.WizardController",[epages.widget.LocalizedWidget],{
		/**
		* public properties
		*/
		currentLanguageId : undefined,   // integer - id of current language
		controllerName    : '',          // string - name of controller
		url               : '?',         // string - request url
		saveOnNext        : false,       // boolean - flag that indicates weather the wizards saves after every step or not
		showQuickFinish   : false,       // boolean - flag that indicates weather the show link to finish page will be displayed or not
		debugMode         : false,       // boolean - flag to run the wizard in debug mode
		finishButtonLabel : "",          // string - label of finish button node
		finishRedirectURL : "",          // string - this url is called after the finish step
		cancelRedirectURL : "",          // string - this url is called after clicking the cancel button

		/**
		* private properties
		*/
		_steps                  : undefined,  // array - array with step data objects
		_objects                : undefined,  // hash - contains epages objects: <objectId> : { saveValues: [], saveNames: [], changeActions: []) }
		_jsonHandler            : undefined,  // epages.io.Json - communication
		_initialized            : undefined,  // boolean - you can not add steps after the wizard is initialized
		_activeStep             : undefined,  // integer - index of current step
		_stepNavigation         : undefined,  // array - array with navigation  { node : stepNode, bubbleNode : bubbleNode, stepNumber : i }
		_defaultChangeAction    : 'Save',     // string - default save action for objects (_objects)
		_stepStates             : [
			'Active','Disabled','Done'
		],                                    // array - navigation states (css classes)
		_hideBubbleTimeout      : undefined,  // timeout reference
		HIDEBUBBLE_TIMEOUT      : 800,        // integer - navigation bubble timeout value in ms

		/**
		* dojo widget properties
		*/
		templateString:"<div class=\"WizardController\">\n  <div class=\"Overlay\"></div>\n  <div class=\"SpaceContainer\">\n    <div>\n      <div class=\"BorderRadius12Box\">\n        <div class=\"Assistant\">\n          <form name=\"WizzardControllerForm\">\n              <div class=\"dijitDialog ModalDialog\">\n                <div class=\"dijitDialogTitleBar\">\n                  <span dojoAttachPoint=\"closeButtonNode\" dojoAttachEvent=\"onclick: _onCancel\"style=\"display:none\"class=\"dijitDialogCloseIcon\">\n                    <span class=\"closeText\">close</span>\n                  </span>\n                  <div class=\"StepNavigation EnableHover\" dojoAttachPoint=\"StepNavigationNode\">\n                    <a dojoAttachPoint=\"QuickFinish\" class=\"DialogAction Bold\">{QuickFinish}</a> | <span>{Step}</span>\n                  </div>\n                  <div dojoAttachPoint=\"StepNavigationBubble\"  dojoType=\"epages.widget.Bubble\"></div>\n                </div>\n                <div dojoAttachPoint=\"ContainerNode\" class=\"AssistantContainer ShowAllSteps\">\n                  <div dojoAttachPoint=\"ContentPlaceHolder\" style=\"height:450px;\"></div>\n                </div>\n                <div dojoAttachPoint=\"ButtonBarNode\" class=\"ButtonBar LayerButtonBar\">\n                  <div dojoAttachPoint=\"BackButton\" dojotype=\"epages.widget.Button\" name=\"Back\" class=\"FloatLeft HideElement\">{Back}</div>\n                  <div dojoAttachPoint=\"NextButton\" dojotype=\"epages.widget.Button\" name=\"Next\" class=\"FloatRight\">{Next}</div>\n                  <div dojoAttachPoint=\"SaveButton\" dojotype=\"epages.widget.Button\" name=\"Save\" class=\"FloatRight HideElement\">${finishButtonLabel}</div>\n                  <div class=\"ClearBoth\"></div>\n                </div>\n              </div>\n          </form>\n        </div>\n        <div class=\"HideElement\" dojoAttachPoint=\"BubbleContentNode\"></div>\n      </div>\n    </div>\n  </div>\n</div>\n",
		translationName  : dojo.moduleUrl('epages.widget','templates/translation'),
		widgetsInTemplate:true,

		postMixInProperties: function(){
			//summary: initialize all necessary objects and arrays, convert flags to real boolean
			this.inherited("postMixInProperties", arguments);
			if(this.finishButtonLabel == "") {
				this.finishButtonLabel = this.translate("Finish");
			}
			this._jsonHandler = new epages.io.Json();
			this._steps = [];
			this._objects = undefined;
			this._stepNavigation = [];
			this._initialized = false;
			this.showQuickFinish = epages.string.toBoolean(this.showQuickFinish);
			this.saveOnNext = epages.string.toBoolean(this.saveOnNext);
			//if(epages.vars.DebugLevel && epages.vars.DebugLevel != 0){
				this.debugMode = true;
			//}
			if(epages.Browser.engine == "MSIE") {
				var htmlTag = document.getElementsByTagName("html")[0];
				htmlTag.style.overflow="visible";
			}
		},

		postCreate: function(){
			this.inherited("postCreate", arguments);
			if(this.cancelRedirectURL) {
				this.closeButtonNode.style.display="";
			}
		},

		startup: function(){
			//summary: make all event connects and connect to Switch to Edit Mode topic
			this.inherited("startup", arguments);

			dojo.body().appendChild(this.domNode);

			//attach events
			//catch all events that happen inside the domNode
			this.connect(this.domNode,'onclick', '_onDomNodeEvent');
			this.connect(this.domNode,'onkeyup', '_onDomNodeEvent');
			this.connect(this.domNode,'onchange', '_onDomNodeEvent');
			//connect all buttons
			this.connect(this.NextButton.domNode,'onclick', '_onNextButtonClick');
			this.connect(this.BackButton.domNode,'onclick', '_onBackButtonClick');
			this.connect(this.SaveButton.domNode,'onclick', '_onSaveButtonClick');

			// bubble events
			this.connect(this.StepNavigationBubble.domNode,'onmouseleave', '_hideStepNavigationBubble');      //hide stepNavigationBubble on mouse leave of the bubble
			this.connect(this.StepNavigationNode, 'onmouseleave', '_hideStepNavigationBubble');               //hide stepNavigationBubble on mouse leave of the bubble
			this.connect(this.StepNavigationBubble.domNode,'onmouseenter', '_dontHideStepNavigationBubble');  //clear timeout

			if(this.showQuickFinish){
				this.connect(this.QuickFinish,'onclick', '_onQuickFinishClick');
			}
			else{
				dojo.addClass(this.QuickFinish,'HideElement');
			}
			//do subscribes
			dojo.subscribe(this.id+'/SwitchToEditMode',this,'_onSwitchToEditMode');
			dojo.subscribe(this.id+'/switchToStep',this,'_onSwitchToStep');


		},

		start: function(){
			//summary: this function has to be called when all steps are added with publishthe add steps method
			//this function starts the wizard and shows the first step
			//steps inside the _steps Array are processed in there normal order
			this._toggleLoaderOverlay(true);
			this._initialized = true;
			this._activeStep = 0;
			this._initialize();
			//load template of fist step
			this._loadStep(0);
		},

		addStep: function(stepData){
			//summary: add step to wizard with this function is only working before wizard is started
			//example:
			//	|myWizard.addStep({
			//	|		Name            : '{Video}',     - required
			//	|		ViewAction      : 'JSONSnippet', - required
			//	|		TemplateAction  : 'MBO-ViewBookingsystemWizardSteps', - required
			//	|		TemplateName    : 'Content-Video', - required
			//	|		ObjectID        : '#Shop.ID', - required
			//	|		NotInNavigation : true, - optional
			//	|		NoPreload       : true - optional
			//	|		NoButtons       : true, - optional
			//	|		ShowAllStepsOnFinish : true, - optional
			//	|		IsFinishStep    : false - optional
			//	|});
			if(stepData){
				if(this._initialized){
					console.warn(this.id,'unable to add step wizard is already started');
					return;
				}
				//every step is disabled on start
				stepData.state = "Disabled";
				this._steps.push(stepData);
			}
		},

		_preloadSteps:function(){
			//summary: load template of every defined step only loads one step at the same time no multiple simultan loading
			//checks if step is loaded, step is loaded when template is set
			//load next step where template is not defined
			for( var i=0,iLength=this._steps.length ; i<iLength ; i++ ){
				var stepData = this._steps[i];
				if(stepData.template == undefined && !stepData.errorOnLoad){
					this._loadStep(i);
					break;
				}
			}
		},

		_loadStep: function(stepNumber){
			//summary: load data of step defined by given stepNumber with async json request
			//when step is loaded call redStepResponse with given data
			//loads given step asynchronous from server
			var stepData = this._steps[stepNumber];
			stepData.TemplateLanguageID = this.currentLanguageId;
			if(epages.vars[this.id+'TemplateObjectID']) {
				stepData.TemplateObjectID = epages.vars[this.id+'TemplateObjectID'];
			}
			if(stepData && stepData.ObjectID) {
				this._jsonHandler.loadAsync(this.url,dojo.hitch(this,function(response){
					this._readStepResponse(response,stepNumber);
				}),stepData);
			} else {
				this._showErrorMessage(this.translate('WizardStepError'),this.translate('WizardStepErrorDesciption'));
			}
		},

		_loadStepSync: function(stepNumber){
			//summary: loads given step synchronous from server
			//is needed when preloading is disabled and next step has to be loaded on next Button click
			//checks if epages.vars[this.id+'TemplateObjectID'] is defined and adds it to request is
			//neccassary if steps are influenced by each other
			var stepData = this._steps[stepNumber];
			stepData.TemplateLanguageID = this.currentLanguageId;
			if(epages.vars[this.id+'TemplateObjectID']) {
				stepData.TemplateObjectID = epages.vars[this.id+'TemplateObjectID'];
			}
			if(stepData && stepData.ObjectID) {
				var response = this._jsonHandler.loadSync(this.url,stepData);
				this._readStepResponse(response,stepNumber);
			}
		},

		_readStepResponse: function(response,stepNumber){
			//summary: read response from server and load next step if preloading is enabled
			var stepData = this._steps[stepNumber];
			//check if step response is okay
			if(response && response.data && response.data.snippet){
				stepData.template = response.data.snippet;

				if(stepNumber == this._activeStep){
					//build step and step navigation if activeStep was loaded, happens on first step
					stepData.state = 'Active';
					this._changeNavigationNodeState(stepNumber,'Active');
					this._buildStep(stepNumber);
				}
			}
			else{
				//set step on error to avoid preload step from loading it again and again
				stepData.errorOnLoad = true;
			}
			if(stepData){
				//is preload is enabled load next step
				if(!stepData.NoPreload){
					this._preloadSteps();
				}
			}
		},

		_buildStep: function(stepNumber){
			//summary: build template of given step and add it to the container
			//step with flag IsFinishStep is added as first element on container for summary mode of this step
			var stepData = this._steps[stepNumber];
			//check if template ist loaded if not load template
			if(stepData.template && stepData.templateNode == undefined){
				//dojo.addClass(this.ContainerNode, "HideElement");
				//create step node and insert loaded template
				var stepNode = document.createElement('div');
				dojo.addClass(stepNode,"Step");
				dojo.addClass(stepNode,"HideElement");
				stepNode.id = stepData.TemplateName;

				stepData.template = stepData.template.replace(/<!--.*-->/g, "");		// remove comments from pagetype
				stepNode.innerHTML = stepData.template;

				//finish step has to be first step in container for design reasons
				if(stepData.IsFinishStep){
					this.ContainerNode.insertBefore(stepNode,this.ContainerNode.firstChild);
				}
				else{
					this.ContainerNode.appendChild(stepNode);
				}
				// no need for extra eval of the script tags on Fx, but on all other browsers
				if(epages.Browser.engine != "Gecko" || (epages.Browser.engine == "Gecko" && epages.Browser.version >= 4)) {
					//evalute script-tags inside content
					var scripts = stepNode.getElementsByTagName('script');
					for( var i=0,iLength=scripts.length ; i<iLength ; i++ ) {
						window.eval(scripts[i].innerHTML);
					}
				}

				//start dojo parser to parse all dojo widgets inside the template
				dojo.parser.parse(stepNode);
				stepData.templateNode = stepNode;
				//dojo.removeClass(this.ContainerNode, "HideElement");
			}
			//show all steps in SummaryMode if FinishStep is shown
			dojo.addClass(this.ContentPlaceHolder,"HideElement");
			// unshow any visible loader overlay
			this._toggleLoaderOverlay(false);
			for( var i=0,iLength=this._steps.length ; i<iLength ; i++ ){
				var currentStep = this._steps[i];
				if(stepData.IsFinishStep && (stepData.ShowAllStepsOnFinish === undefined || stepData.ShowAllStepsOnFinish)){
					if(currentStep && currentStep.templateNode && currentStep != stepData){
						dojo.addClass(currentStep.templateNode,'SummaryMode');
						dojo.removeClass(currentStep.templateNode,"HideElement");
					}
				}
				else{
					if(currentStep.templateNode){
						dojo.removeClass(currentStep.templateNode,'SummaryMode');
						dojo.addClass(currentStep.templateNode,"HideElement");
					}
				}
			}
			if(stepData.template && stepData.templateNode){
				dojo.removeClass(stepData.templateNode,"HideElement");
			}
		},

		_closeLastInlineTinyMCE:function(){
			//summary: close last instance of inline tinyMCE
			//Inline tinyMCE is still not working correct
			//TODO: still in progress
			if(epages.vars.currentInlineTinyMCE){
				tinyMCE.execCommand('mceRemoveControl', true,epages.vars.currentInlineTinyMCE);
			}
		},

		_getSaveData:function(stepNumber){
			//summary: this function collects all data from the given step template which has to be send to the server
			//input for saving must have a name attribute like name="ObjectId:attributeAlias:LanguageId"
			//languageId ist optional
			//this function although collects hidden inputs with ChangeActions they must have name="ObjectId:ChangeAction"
			var node;
			if(typeof stepNumber != "undefined"){
				if(!this._steps[stepNumber] && !this._steps[stepNumber].templateNode){
					return;
				}
				node = this._steps[stepNumber].templateNode;

				// possibility to add a hidden input to the step template which tells the wizard NOT to perform a save action for the step
				var doNotSaveOnNextNode = $("DoNotSaveOnNext_" + this._steps[stepNumber].TemplateName);
				if(doNotSaveOnNextNode && doNotSaveOnNextNode.value == "true") {
					return;
				}
			}
			else{
				node = this.ContainerNode;
			}
			//get all named elemnts with name like ObjectId:attributeAlias:LanguageId or ObjectId:attributeAlias
			var allNamedElements = dojo.query("[name*=':']", node);
			if(!this._objects) {
				this._objects = {};
			}
			for( var i=0,iLength=allNamedElements.length ; i<iLength ; i++ ){
				var elm = allNamedElements[i];
				//ignore disabled inputs
				if(elm.disabled && elm.disabled == true){
					continue;
				}
				//special treatment for radio buttons
				if( elm.checked === false && (elm.type.toLowerCase() === 'radio' || dojo.hasClass(elm, 'Radio')) ){
					continue;
				}
				//split name into objectId, atrributeAlias and LanguageID - optional
				if(elm.name){
					var nameValues = elm.name.split(':');
				}
				else if(elm.id){
					var nameValues = elm.id.split(':');
				}
				else{
					return;
				}

				var objectId = nameValues[0];
				if(isNaN(objectId)) {
					// only perform object ids ..
					continue;
				}

				var attributeAlias = nameValues[1];
				var languageId = nameValues[2];
				var languageFieldName = nameValues[3];

				var currentValue = this._objects[objectId] ? this._objects[objectId] : {};
				if(!currentValue.saveNames){
					currentValue.saveNames = [];
				}
				if(!currentValue.saveValues){
					currentValue.saveValues = [];
				}
				if(objectId && attributeAlias){
					// hack for multiple select: if elm is a widget of class type dijit.form.MultiSelect
					if(dijit.registry.byId(elm.id) && $$(elm.id).declaredClass == "dijit.form.MultiSelect") {
						var multiSelectValues = $$(elm.id).attr('value');
						// add all selected values seperately
						if(multiSelectValues && multiSelectValues.length > 0) {
							for( var j=0,jLength=multiSelectValues.length ; j<jLength ; j++ ) {
								currentValue.saveNames.push(attributeAlias);
								currentValue.saveValues.push(multiSelectValues[j]);
							}
						}
					}
					else if(elm.innerHTML && !elm.value){
						currentValue.saveNames.push(attributeAlias);
						currentValue.saveValues.push(elm.innerHTML);
						if(languageId){
							//if object has languages we need other methode to write them
							currentValue.saveNames.push(languageFieldName ? languageFieldName : 'LanguageID');
							currentValue.saveValues.push(languageId);
						}
					}
					else {
						currentValue.saveNames.push(attributeAlias);
						currentValue.saveValues.push(elm.value);
						if(languageId){
							//if object has languages we need other methode to write them
							currentValue.saveNames.push(languageFieldName ? languageFieldName : 'LanguageID');
							currentValue.saveValues.push(languageId);
						}
					}
				}
				this._objects[objectId] = currentValue;
			}
			//get all inputs with name ChangeAction, they must have objectId in name and changeAction name in value
			var allChangeActions = dojo.query("[name='ChangeAction']", node);
			for( var j=0,jLength=allChangeActions.length ; j<jLength ; j++ ){
				var currentAction = allChangeActions[j];
				var splitValues = currentAction.value.split(':');
				if(splitValues.length > 0){
					objectId = splitValues[0];
					var actionName = splitValues[1];
					currentValue = this._objects[objectId] ? this._objects[objectId] : {};
					if(!currentValue.changeActions){
						currentValue.changeActions = [];
					}
					currentValue.changeActions.push(actionName);
				}
				this._objects[objectId] = currentValue;
			}
		},

		saveData:function(){
			//summary: save all data that is inside _objects to the server
			//after successfull save _objects get cleared to allow override of data if user goes back to an already saved step
			//when debugMode is true than saveData sends every object in a own request to the server
			if(!this._objects) {
				return true;
			}
			var result;
			if(!this.debugMode){
				var params = {};
				params['ViewAction'] = 'JSONViewResponse';
				params['ObjectID'] = [];
				params['Value'] = [];
				params['ChangeAction'] = [];
			}
			//add parameters of every object to json request
			for(var key in this._objects){
				if(isNaN(dojo.number.parse(key))) {
					// only valid objectids..
					continue;
				}
				if(this.debugMode){
					var params = {};
					params['ViewAction'] = 'JSONViewResponse';
					params['ObjectID'] = [];
					params['Value'] = [];
					params['ChangeAction'] = [];
				}
				var currentObject = this._objects[key];
				if(!currentObject.saveNames){
					continue;
				}
				for( var j=0,jLength=currentObject.saveNames.length ; j<jLength ; j++ ){
					if(!params[currentObject.saveNames[j]]){
						params[currentObject.saveNames[j]] = [];
					}
					params[currentObject.saveNames[j]].push(currentObject.saveValues[j]);
				}
				//add changeActions for Object
				if(currentObject.changeActions){
					for( var i=0,iLength=currentObject.changeActions.length ; i<iLength ; i++ ){
						params['ObjectID'].push(key);
						params['ChangeAction'].push(currentObject.changeActions[i]);
					}
				}
				else{
					params['ObjectID'].push(key);
					params['ChangeAction'].push(this._defaultChangeAction);
				}
				if(this.debugMode){
					result = this._jsonHandler.loadSync(this.url,params);
				}
			}
			if(!this.debugMode){
				result = this._jsonHandler.loadSync(this.url,params);
			}
			//clear _objects on error to but show error to customer so that he can correct it and save again
			if(result && result.error && result.error.data){
				console.warn("error in wizardcontroller saveData, result=", result);
				this._showErrors(result.error.data.Errors);
				this._objects = undefined;
				return false;
			}
			else{
				//if everything was saved we can clear the saveData object
				if(result && result.data){
					dojo.publish(this.id+'/saveFinished', [ result.data ]);
				}
				else{
					dojo.publish(this.id+'/saveFinished', []);
				}
				this._objects = undefined;
				return true;
			}
		},

		_showErrors:function(errors){
			//summary: show given errors to customer with an error message
			for( var i=0,iLength=errors.length ; i<iLength ; i++ ){
				var currentError = errors[i];
				if(currentError.LoopName && currentError.Index && currentError.Name){
					var errorClass = currentError.LoopName + currentError.Index;
					for( var j=0,jLength=this._steps.length ; j<jLength ; j++ ){
						var stepData = this._steps[j];
						if(stepData.templateNode){
							var errorNodeContainer = dojo.query("."+errorClass, stepData.templateNode);
							if(errorNodeContainer && errorNodeContainer.length == 1){
								errorNodeContainer = errorNodeContainer[0];
								var errorNode = dojo.query("[name*="+currentError.Name+"]", errorNodeContainer);
								if(errorNode && errorNode.length == 1){
									dojo.addClass(errorNode[0],'DialogError');
									if(this._steps[this._activeStep].IsFinishStep){
										dojo.removeClass(stepData.templateNode, "SummaryMode");
										dojo.addClass(stepData.templateNode, "EditMode");
									}
									this._showErrorMessage(this.translate('WizardSaveError'),this.translate('WizardSaveErrorDesciption'));
								}
							}
						}
					}
				}
				else if(currentError.Reason && currentError.Reason == 'FeatureMaxValueReached'){
					var me = this;
					dojo.publish("uimessage/show", [ "", 'The maximum number of services for this website type has been reached.', 'Dialog', {
					titleBar: this._steps[this._activeStep].Name,
					typeClass: 'Warning',
					buttons: [{
						cssClass: 'Active ep-button ep-button-cta',
						label: '{Close}',
						onclick: function() {
							me._closeWizard();
							this._modalDialogWidget.hide();
						}
					}]
				}
				]);
				}
				else if(currentError.Reason && currentError.Reason == 'OBJECT_EXISTS'){
					dojo.publish("uimessage/show", [ "", this.translate('ServiceNoExists'), 'Dialog', {
						titleBar: this._steps[this._activeStep].Name,
						typeClass: 'Warning'
					}]);
				}
				else if(currentError.Reason && currentError.Message){
					dojo.publish("uimessage/show", [ "", currentError.Message, 'Dialog', {
						titleBar: this._steps[this._activeStep].Name,
						typeClass: 'Warning'
					}]);
				}
				else if(currentError.Name){
					for( var j=0,jLength=this._steps.length ; j<jLength ; j++ ){
						var stepData = this._steps[j];
						if(stepData.templateNode){
								var errorNode = dojo.query("[name*="+currentError.Name+"]", stepData.templateNode);
								if(errorNode && errorNode.length == 1){
									dojo.addClass(errorNode[0],'DialogError');
									if(this._steps[this._activeStep].IsFinishStep){
										dojo.removeClass(stepData.templateNode, "SummaryMode");
										dojo.addClass(stepData.templateNode, "EditMode");
									}
								}
							}
						}
				}
			}
			// remove any loader overlays
			this._toggleLoaderOverlay(false);
		},

		activateStep: function(nextStepNumber){
			//summary: activate given step
			//change to next step is only possible if next step is already loaded
			var nextStepData = this._steps[nextStepNumber];
			if(nextStepData){
				//check if next step is loaded, if not load it sync to avoid error while user have to wait
				if(!nextStepData.template){
					this._loadStepSync(nextStepNumber);
				}
				//update stepNavigation
				this._changeNavigationNodeState(this._activeStep,'Done');
				this._changeNavigationNodeState(nextStepNumber,'Active');
				nextStepData.state = 'Active';
				this._activeStep = nextStepNumber;
				//check if there is a step before the step we now want to activeate
				//disable all buttons if NoButtons flag is set used for last step
				if(nextStepData.NoButtons){
					dojo.addClass(this.ButtonBarNode,'HideElement');
					dojo.addClass(this.StepNavigationNode,'HideElement');
					dojo.addClass(this.QuickFinish,'HideElement');
				}
				else{
					dojo.removeClass(this.ButtonBarNode,'HideElement');
					dojo.removeClass(this.StepNavigationNode,'HideElement');
					if(this.showQuickFinish){
						dojo.removeClass(this.QuickFinish,'HideElement');
					}
				}
				//on IsFinishStep we need the save button not the next button
				if(nextStepData.IsFinishStep){
					this.NextButton.hide();
					this.SaveButton.show();
					dojo.addClass(this.QuickFinish,'HideElement');
				}
				else{
					this.NextButton.show();
					this.SaveButton.hide();
					if(this.showQuickFinish){
						dojo.removeClass(this.QuickFinish,'HideElement');
					}
				}
				//hide BackButton if next step is first step
				if(nextStepNumber == 0){
					this.BackButton.hide();
				}
				else{
					this.BackButton.show();
				}

				var stepdata = this._steps[this._activeStep];
				var templateName= stepdata['TemplateName'];

				//start building next step
				this._buildStep(nextStepNumber);

				// publish step message by templateName
				dojo.publish(this.id+'/stepActivated/'+templateName, []);

				//publish general step change message
				dojo.publish(this.id+'/activateStep', [ {
						'stepNumber' : this._activeStep,
						'stepData' : this._steps[this._activeStep]
				}]);

				if(epages.Browser.engine == "MSIE") {
					var domNode = this.domNode;
					dojo.removeClass(domNode, "WizardController");
					window.setTimeout(function() {
						dojo.addClass(domNode, "WizardController");
					}, 1);
				}

			}
			else{
				//show error to user if we had problems
				this._showErrorMessage(this.translate('WizardStepError'),this.translate('WizardStepErrorDesciption'));
			}
		},

		_calculateRestrictorOverlay : function(){
			var suspendPosition = new epages.html.Element(this.ContainerNode).getAbsolutePosition(dojo.body());
			var aw  = dojo.style(this.ContainerNode,"marginLeft");
					aw += dojo.style(this.ContainerNode,"paddingLeft");
			var l = suspendPosition.x - aw;
					aw += dojo.style(this.ContainerNode,"marginRight");
					aw += dojo.style(this.ContainerNode,"paddingRight");
			var w = this.ContainerNode.offsetWidth + aw;

			var ah = dojo.style(this.ContainerNode,"marginTop");
					ah += dojo.style(this.ContainerNode,"paddingTop");
			var t = suspendPosition.y - ah;
					ah += dojo.style(this.ContainerNode,"marginBottom");
					ah += dojo.style(this.ContainerNode,"paddingBottom");
			var h = this.ContainerNode.offsetHeight + ah;

			return {
				Width  : w,
				Height : h,
				Left   : l,
				Top    : t
			};
		},
		_toggleLoaderOverlay : function(/*boolean*/toggleState){
			if(toggleState){
				dojo.publish("interactionRestrictor/suspend", ["ContainerNodeLoading", this.ContainerNode,false,this._calculateRestrictorOverlay()]);
			} else {
				dojo.publish("interactionRestrictor/permit", ["ContainerNodeLoading"]);
			}
		},
		_onNextButtonClick: function(){
			//summary: got to next step and save if saveOnNext is defined
			dojo.publish(this.id+'/nextButtonClick', []);
			this._toggleLoaderOverlay(true);
			this._closeLastInlineTinyMCE();
			if(this.saveOnNext){
			this._getSaveData(this._activeStep);
				if(!this.saveData()) {
					return;
				}
			}
			this.activateStep(this._activeStep + 1);
		},

		_onBackButtonClick: function(){
			//summary: go to prevoius step
			this._toggleLoaderOverlay(true);
			this.activateStep(this._activeStep - 1);
		},

		_onSaveButtonClick:function(){
			//summary: collect save data and send it to the server
			//go to last step this is always the quickStart step
			this._closeLastInlineTinyMCE();
			if(this.saveOnNext) {
				this._getSaveData(this._activeStep);
			} else {
				this._getSaveData();
			}
			if(this.saveData()){
				var stepdata = this._steps[this._activeStep];
				if(this.finishRedirectURL && stepdata.IsFinishStep) {
					epages.locationHref(this.finishRedirectURL);
				} else {
					this.activateStep(this._steps.length - 1);
				}
			}
		},
		_onQuickFinishClick:function(){
			//summary: save data and go to last step
			this._toggleLoaderOverlay(true);
			this._closeLastInlineTinyMCE();
			this._getSaveData();
			if(this.saveData()){
				this.activateStep(this._steps.length - 1);
			}
		},

		_activateNextButton: function(){
			//summary: activate the next Button
			dojo.addClass(this.NextButton, 'Active');
		},

		_disableNextButton: function(){
			//summary: disable the next Button
			dojo.addClass(this.NextButton, 'Disabled');
		},

		_closeWizard:function(){
			//summary: activates the last step without saving necessary for errors
			location.href = epages.vars.BaseUrl;
		},

		_changeNavigationNodeState: function(stepNumber,state){
			//summary: change states of nextNavigationNodes
			//only steps with state done can be clicked
			var stepNavigationNode;
			for( var j=0,jLength=this._stepNavigation.length ; j<jLength ; j++ ){
				var currentNode = this._stepNavigation[j];
				if(stepNumber == currentNode.stepNumber){
					stepNavigationNode = currentNode;
				}
			}
			//change stepNavigationNode to active and remove all other states on this step only no multiple states possible
			if(stepNavigationNode){
				for( var i=0,iLength=this._stepStates.length ; i<iLength ; i++ ){
					var currentState = this._stepStates[i];
					if(state == currentState){
						dojo.addClass(stepNavigationNode.node,currentState);
						dojo.addClass(stepNavigationNode.bubbleNode,currentState);
					}
					else{
						dojo.removeClass(stepNavigationNode.node,currentState);
						dojo.removeClass(stepNavigationNode.bubbleNode,currentState);
					}
				}
			}
		},

		checkChanges:function(){
			//TODO: diese funktion soll �berpr�fen, ob es noch ungespeicherte �nderungen gibt und bei Bedarf warnen
			/*this._getSaveData();
			console.debug('check changes',this._objects);
			var unsavedData = false;
			for(var key in this._objects){
				if(this._objects[key]){
					unsavedData = true;
					break;
				}
			}
			if(unsavedData){
				return true;
			}
			else{
				return false;
			}*/
			return false;
		},

		_initialize: function(){
			//summary:make necessary first values to start wizard
			//show step jump list
			//register on onbeforeunload
			epages.onUnloadFunctions.push(dojo.hitch(this,function() {
				return this.checkChanges();
			}));
			this._buildStepNavigation();
			this.BackButton.hide();
			this.SaveButton.hide();
		},

		_buildStepNavigation: function(){
			//summary: build step navigation and stepNavigation Bubble
			this.BubbleContentNode.innerHTML='<div class="Headline">'+this.controllerName+'</div>';

			var visibleStepNumber = 1;
			for( var i=0,iLength=this._steps.length ; i<iLength ; i++ ){
				var stepData = this._steps[i];
				if(stepData.NotInNavigation){
					continue;
				}

				// create step node
				var stepNode = document.createElement('a');
				stepNode.innerHTML = visibleStepNumber;
				dojo.addClass(stepNode, "Step");
				dojo.addClass(stepNode, stepData.state);
				this.connect(stepNode,'onclick', '_onStepNumberClick');
				this.connect(stepNode,'onmouseover', '_onStepNumberHover');
				this.StepNavigationNode.appendChild(stepNode);

				// create step node in bubble
				var bubbleNode = document.createElement('div');
				bubbleNode.innerHTML = visibleStepNumber+'. '+stepData.Name;
				dojo.addClass(bubbleNode, stepData.state);
				dojo.addClass(bubbleNode, "Step");
				this.connect(bubbleNode,'onclick', '_onStepNumberClick');
				this.BubbleContentNode.appendChild(bubbleNode);

				// register nodes
				var stepNavigationNode = {
					node : stepNode,
					bubbleNode : bubbleNode,
					stepNumber : i
				};
				this._stepNavigation.push(stepNavigationNode);

				visibleStepNumber++;
			}

			// fill in bubble
			this.StepNavigationBubble.setupContent({
				content: this.BubbleContentNode,
				orientation : 'top-right'
			});
			// show bubble
			dojo.removeClass(this.BubbleContentNode,'HideElement');
		},

		_onStepNumberClick: function(evt){
			//summary: change to clicked step
			currentNode = evt.currentTarget;
			for( var i=0,iLength=this._stepNavigation.length ; i<iLength ; i++ ){
				var stepNavigationNode = this._stepNavigation[i];
				if(currentNode == stepNavigationNode.node ||currentNode == stepNavigationNode.bubbleNode){
					var stepData = this._steps[stepNavigationNode.stepNumber];
					if(stepData.state != 'Disabled'){
						this._toggleLoaderOverlay(true);
						this.activateStep(stepNavigationNode.stepNumber);
					}
				}
			}
		},

		_onStepNumberHover: function(evt){
			//summary: show stepBubble on hover of stepNumbers
			var currentNode = evt.currentTarget;
			var absPos = $E(currentNode).getRelativePosition();
			this.StepNavigationBubble.setupContent({
				x           : absPos.x - 15,
				y           : absPos.y + 20,
				orientation : 'top-right'
			});
			this.StepNavigationBubble.show();
		},

		_hideStepNavigationBubble: function(evt){
			//summary: hide step navigation bubble
			var _this = this;
			window.clearTimeout(this._hideBubbleTimeout);
			this._hideBubbleTimeout = window.setTimeout(function() {
				_this.StepNavigationBubble.hide();
			}, this.HIDEBUBBLE_TIMEOUT);
		},

		_dontHideStepNavigationBubble: function(evt){
			//summary: clear hide bubble
			window.clearTimeout(this._hideBubbleTimeout);
		},

		_showErrorMessage: function(messageTitle,messageText){
			//summary: show given error message
			dojo.publish("uimessage/show", [messageTitle, messageText, 'Dialog',{
				titleBar: this._steps[this._activeStep].Name,
				typeClass: 'Warning'
			}]);
		},

		//Eventhandling for changes and updates to Previews
		_onDomNodeEvent:function(evt){
			//summary: collect all events that happen on the domNode of this widget to update preview nodes if input nodes were changed
			if(evt.target.nodeName == "INPUT" || evt.target.nodeName == "SELECT" || evt.target.nodeName == "TEXTAREA") {
				var sourceNode = evt.target;
				var epUpdateName = (sourceNode.getAttribute('ep_updatename')) ?  sourceNode.getAttribute('ep_updatename') : sourceNode.name;
				// update known elements
				var updateNodes = dojo.query("[ep_updatesource="+epUpdateName+"]", this.ContainerNode);
				var updateValue = sourceNode.value;

				if(sourceNode.nodeName == "SELECT") {
					updateValue = sourceNode[sourceNode.selectedIndex].innerHTML;
				}
				else if(sourceNode.type == "radio" || sourceNode.className.match("Radio")) {
					var aRadioLabel = dojo.query('[for='+sourceNode.id+']', sourceNode.parentNode.parentNode);
					if(aRadioLabel[0]) {
						updateValue = aRadioLabel[0].innerHTML;
					}
				}
				for( var i=0,iLength=updateNodes.length ; i<iLength ; i++ ){
					var currentNode = updateNodes[i];
					var updateTask = currentNode.getAttribute("ep_updatetask");
					var emptyDefault = currentNode.getAttribute("ep_emptyDefault");
					if(updateValue == "" && emptyDefault) {
						updateValue = emptyDefault;
					}
					this._updatePreview(currentNode, updateTask, updateValue);
				}
			}
		},

		_updatePreview: function(/* dom node*/updateNode, /* string */ updateTask, /* string */ updateValue ) {
			//summary: insert new value to preview dom node
			if(!updateTask){
				return;
			}
			if(updateTask.match("setHTML")) {
				if(updateValue == "") {
					updateValue= "&nbsp;";    // avoid empty tags which are not displayed (e.g. business hours table)
				}
				if(updateNode.innerHTML == updateValue) {
					return;
				}
				updateNode.innerHTML = updateValue;
			}

			if(updateTask.match("setText")) {
				updateValue = epages.string.escapeXml(updateValue);

				if(updateNode.innerHTML == updateValue) {
					return;
				}
				updateNode.innerHTML = updateValue;
			}

			if(updateTask.match("setValue")) {
				if(updateNode.value == updateValue) {
					return;
				}
				updateNode.value = updateValue;
			}

			if(updateTask.match("emphasize")) {
				updateNode.style.fontWeight = "bold";
			}
		},

		_onSwitchToEditMode: function(templateName){
			//summary: switch given step to editmode find step with given templateName
			if(!templateName){
				return;
			}
			for( var i=0,iLength=this._steps.length ; i<iLength ; i++ ){
				var currentStep = this._steps[i];
				if(currentStep.TemplateName == templateName){
					dojo.addClass(currentStep.templateNode, "EditMode");
					dojo.removeClass(currentStep.templateNode, "SummaryMode");
					break;
				}
			}
		},

		_onSwitchToStep: function(templateName) {
			// summary: message function
			var foundTemplate = false;
			for( var i=0,iLength=this._steps.length ; i<iLength ; i++ ){
				var currentStep = this._steps[i];
				if(currentStep.TemplateName == templateName){
					this._toggleLoaderOverlay(true);
					this.activateStep(i);
					foundTemplate= true;
					break;
				}
			}
			if(!foundTemplate) {
				console.warn('Template '+templateName+' not found in _onSwitchToStep() / '+this.declaredClass);
			}
		},

		_onCancel : function() {
			// summary: event function - redirect to cancel page
			if(this.cancelRedirectURL != "") {
				epages.locationHref(this.cancelRedirectURL );
			}
		}
	}
);

}

if(!dojo._hasResource["epages.event.domdispatcher"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.event.domdispatcher"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.event.domdispatcher");



dojo.declare("epages.event.DomDispatcher",
	function() {
		this._events = {};
	},
	{

		_monitoredEvents: $A(),
		_events: null,

		add: function(/* String */eventType, /*function|DOMNode|Array.DOMNode*/nodeList, /*function*/callback, /*Boolean*/outside, /*Document|Document[]*/docs) {
			// description:
			//		add an event to be monitored and dispatched
			//	eventType:
			//		name of an event, like "click"
			//	nodeList:
			//		a single DOM node or an array of DOM nodes to be monitored
			//	outside:
			//		dispatch event if it occurs outside or inside the monitored nodes
			if (outside == null){
				outside = false;
			}
			if (this._events[eventType] === undefined){
				this._events[eventType] = [];
			}
			this._events[eventType].push({
				'outside': outside,
				'nodes': nodeList,
				'callback': callback
			});
			if (!this._monitoredEvents.exists(eventType)){
				this._registerEventHandler(eventType, docs);
			}
		},

		_registerEventHandler: function(eventType, docs) {
			if (docs == null){
				docs = [document];
			}
			if (!dojo.isArrayLike(docs)){
				docs = [docs];
			}
			for( var i=0,iLength=docs.length ; i<iLength ; i++ ) {
				$E(docs[i]).addEventListener(eventType, dojo.hitch(this, 'handleEvent'), true);
			}
			// avoid double entries and recursion
			if (!this._monitoredEvents.exists(eventType)){
				this._monitoredEvents.push(eventType);
			}
		},

		_unregisterEventHandler: function(eventType, docs) {
			if (docs == null){
				docs = [document];
			}
			if (!dojo.isArrayLike(docs)){
				docs = [docs];
			}
			for( var i=0,iLength=docs.length ; i<iLength ; i++ ) {
				$E(docs[i]).removeEventListener(eventType, dojo.hitch(this, 'handleEvent'), true);
			}
			// update monitor list
			var EventIndex = this._monitoredEvents.find(eventType);
			if (EventIndex != null) {
				this._monitoredEvents.remove(EventIndex);
			}
		},

		handleEvent: function(DomEvent) {
			// summary: if this happens, the window is probably not longer member of the dom
			if (window == null){
				return;
			}
			var events = this._events[DomEvent.type];
			if (events.length === undefined){
				return;
			}
			for( var i=0,iLength=events.length ; i<iLength ; i++ ) {
				var event = events[i];
				var nodes = event.nodes;
				if (typeof nodes == 'function'){
					nodes = nodes();
				}
				// dispatch event
				if (event.nodes != null && epages.html.isInnerEvent(DomEvent, nodes) != event.outside) {
					event.callback(DomEvent);
				}
			}
		}

	}
);

dojo.publish('epages/addGlobalSymbol', ['$D', window]);
if ($D === undefined){
	$D = new epages.event.DomDispatcher();
}

epages.onIframeStart.push(function(parentWin, iframeWin) {
	$D._monitoredEvents.each(function(el) {
		$D._registerEventHandler(el, iframeWin.document);
	});
});

}

if(!dojo._hasResource["epages.html.undo"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.html.undo"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.html.undo");



epages.html.UnDo = function(container) {
	this.errorStack    = [];
	this.historyStack  = [];
	this.forwardStack  = [];
	this.currentValues = $H();
	this.defaultValues = $H();

	if (container === undefined){
		container = document;
	}

	this.registerContainerInputs(container);
};

epages.html.UnDo.prototype = {
	POS_OBJECT:  0,
	POS_NEW   :  1,
	POS_OLD   :  2,
	historyStack:   undefined,
	forwardStack:   undefined,
	currentValues:  undefined,
	defaultValues:  undefined,
	isUndoCall:     false,
	lastSavePoint:  0,
	isTyping:		false,
	undoNavigationElementWidgetStack: [],

	registerContainerInputs: function(container) {
		var iterator = this.registerInput;
		dojo.forEach(container.getElementsByTagName("select"),   iterator, this);
		dojo.forEach(container.getElementsByTagName("input"),    iterator, this);
		dojo.forEach(container.getElementsByTagName("textarea"), iterator, this);
	},

	registerInput: function(el) {
		// ignore all inputs with ep_noundo = 1 and without name
		if (el.name != '' & el.getAttribute("ep_noundo")!='1') {
			this.setDefaultValue(el);
			var me = this;
			$E(el).connectChangeEvent(function () { me.addInput(el); });
		}
	},

	setDefaultValue: function (/*HTMLObject*/object) {
		// summary: set default value
		this.defaultValues.set(object.name, $E(object).get());
	},

	_lastValue: function(identifier) {
		// returns: last Value
		var entry = this.currentValues.get(identifier);

		if (entry !== undefined){
			return entry;
		}

		entry = this.defaultValues.get(identifier);

		return entry;
	},

	addInput: function(object, currentValue) {
			// alert('addInput:' + object.name);

		if (! this.isUndoCall) { // ignore self fired events
			var lastValue = this._lastValue(object.name);

			if (currentValue == null){
				currentValue = $E(object).get();
			}
			this.currentValues.set(object.name, currentValue);
			if (lastValue !== null && currentValue != lastValue) {
				if (this.forwardStack.length > 0 && this.historyStack.length < this.lastSavePoint){
					this.lastSavePoint = -1; // save is always false
				}
				this.historyStack.push([ object, currentValue, lastValue ]);
				this.forwardStack = [];
			}

		}
		this.validateInput(object);
	},

	validateInput: function(object) {
		if (typeof(object.getAttribute) !== 'function'){
			return;
		}

		var isError=object.getAttribute("ep_error");
		var inputPosition=$A(this.errorStack).find(object);
		if (isError == "1" && inputPosition == null){
			this.errorStack.push(object);
		}else if (isError == "0" && inputPosition != null){
			this.errorStack.splice([inputPosition],1);
		}
	},

	show: function(object) {
		object.innerHTML  = '<p>history: '       + this.historyStack.flatten()  + '</p>';
		object.innerHTML += '<p>forward: '       + this.forwardStack.flatten()  + '</p>';
		object.innerHTML += '<p>currentValues: ' + this.currentValues.flatten() + '</p>';
		object.innerHTML += '<p>defaultValues: ' + this.defaultValues.flatten() + '</p>';
	},

	_setValue: function (object, value) {
		this.currentValues.set(object.name, value);
		var htmlElement = $E(object);
		htmlElement.set(value);
		this.isUndoCall = true;
		epages.isUndoCall = true;
		htmlElement.callOnChange();
		this.isUndoCall = false;
		epages.isUndoCall = false;
	},

	undo: function() {
		if (this.historyStack.length == 0){
			return;
		}
		var entry = this.historyStack.pop();
		this.forwardStack.push(entry);
		this._setValue(entry[this.POS_OBJECT], entry[this.POS_OLD]);

		// undo stack for dialogs
		for(var i=0, iLength=this.undoNavigationElementWidgetStack.length; i<iLength; i++){
			this.undoNavigationElementWidgetStack[i].resetEditDialogInputValues();
		}
	},

	redo: function() {
		if (this.forwardStack.length == 0){
			return;
		}
		var entry = this.forwardStack.pop();
		this.historyStack.push(entry);
		this._setValue(entry[this.POS_OBJECT], entry[this.POS_NEW]);

		// undo stack for dialogs
		for(var i=0, iLength=this.undoNavigationElementWidgetStack.length; i<iLength; i++){
			this.undoNavigationElementWidgetStack[i].resetEditDialogInputValues();
		}
	},

	existsChanges: function () {
		return this.historyStack.length != this.lastSavePoint;
	},

	clear: function() {
		this.historyStack = [];
		this.forwardStack = [];
		this.lastSavePoint = 0;

		// set changed values as default values
		for(var key in this.currentValues._data){
			this.defaultValues._data[key] = this.currentValues._data[key];
		}

		this.currentValues = $H();
	},

	getChanged: function () {
		return $H(this.currentValues);
	},

	setLastSavePoint: function(){
		this.lastSavePoint = this.historyStack.length;
	},

	checkTyping: function(isTyping) {
		if (this.isTyping != isTyping) {
			this.isTyping = isTyping;
			this.onChangeTyping();
		}
	},


	onChangeTyping: function() {
		// summary: gets called, when the user starts or stops typing
		// description: callback stub
		// tags: extendable
	}

};

// this class is an adapter to epages.html.UnDo to be used by tinymce instead of its custom undomanager
epages.html.TinymceUndoManagerAdapter = function(undoObject, input, onChangeCallback) {
	this.__undoObject = undoObject;
	this.__input = input;
	this.__onChange = onChangeCallback;
};

epages.html.TinymceUndoManagerAdapter.prototype = {
	typing : 0, // Integer - is user currently typing

	__undoObject: null, // Object - reference to epages.html.UnDo object
	__input: null,

	__onChange: null, // function - callback for onChange events

	add : function(info) {
		if (info && info.initial) {
			this.__undoObject.setDefaultValue(this.__input);
		} else {
			//this.__undoObject.addInput(this.__input);
			this.__onChange();
		}
	},

	undo : function() {
		if (this.typing){
			this.add();
		}
		this.__undoObject.undo();
		this.typing = 0;
	},

	redo : function() {
		this.__undoObject.redo();
	},

	clear : function() { this.__undoObject.clear(); },

	hasUndo : function() {
		return this.typing || this.__undoObject.historyStack.length > 0;
	},

	hasRedo : function() {
		return this.__undoObject.forwardStack.length > 0;
	}

};

}

if(!dojo._hasResource['epages.cartridges.de_epages.presentation.widget.InlineEditor']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.presentation.widget.InlineEditor'] = true;
dojo.provide('epages.cartridges.de_epages.presentation.widget.InlineEditor');
//
//






// wrapper widget for all inline editors
dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.InlineEditor",
	//[dijit._Widget, dijit._Templated],
	epages.widget.LocalizedWidget,
	{
		// from fragment
		value:          '',		// insert in displayNode
		valueFormatted:	'',		// insert in contentNode (textarea)
		inputName:      '',
		undoWidget:     '',
		title:          '',

		// public properties
		// widget or tinymce instance
		object:         null,
		templateString: '<div class="InlineEditor"><div dojoAttachPoint="displayNode" dojoAttachEvent="onclick:onClick,onmouseover:onMouseOver,onmouseout:onMouseOut">${!value}</div><textarea style="display: none" dojoAttachPoint="contentNode" id="InlineEditor_${id}" name="${inputName}">${!valueFormatted}</textarea></div>',
		translationName: dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget','templates/translation'),
		objectId:       null,
		attribute:      null,
		languageId:     null,
		undoObject:     null,
		isTyping:       false,
		isInited:       false,
		allowedNodes:   {},
		widgetsInTemplate: true,
		navbar:         '', // parent navbar eg. Content, Left, Top

		// is this widget always visible? (no show/hide switching)
		permanent:      false,

		// private properties
		_jsonIo:        null,
		_computedStyle: null,
		_relevantStyleAttributes: [
			"fontWeight",
			"fontFamily",
			"fontSize",
			"fontStyle",
			"color",
			"backgroundImage",
			"backgroundRepeat",
			"backgroundColor",
			"backgroundPosition",
			"marginTop",
			"marginBottom",
			"marginLeft",
			"marginRight",
			"paddingTop",
			"paddingBottom",
			"paddingLeft",
			"paddingRight",
			"maxHeight",
			"maxWidth"
			],
		// dimensions of the original source node
		_height:        null,
		_width:         null,
		_titleNode:     null,
		_resizeClone:   null,
		_placeHolderText: '...',

		postMixInProperties: function() {
			this.valueFormatted = this.value;	// default -> no formatting
			this.inherited("postMixInProperties", arguments);
		},

		create: function(params, srcNodeRef) {
			switch (srcNodeRef.nodeName.toLowerCase()) {
				case "input":
				case "textarea":
				case "select":
					this.value = srcNodeRef.value;
					break;
				case "img":
					this.value = srcNodeRef.src;
					break;
				default:
					this.value = srcNodeRef.innerHTML;
					break;
			}

			// copy style
			var tmpStyle = dojo.getComputedStyle(srcNodeRef);
			this._computedStyle = {};
			if(tmpStyle){
				dojo.forEach(this._relevantStyleAttributes, function(prop) {
					var t = typeof tmpStyle[prop];
					if ((t == 'number' || t == 'string') && tmpStyle[prop] != "normal") {
						//alert(prop + ": " + tmpStyle[prop]);
						this._computedStyle[prop] = tmpStyle[prop];
					}
				}, this);
			}

			// insert inputfield
			this.inputName = srcNodeRef.getAttribute('ep_input');
			if (this.inputName == null) {
				throw new Error("missing attribute ep_input for InlineEditor " + this.id);
			}
			this._height = srcNodeRef.scrollHeight;
			this._width = srcNodeRef.scrollWidth;
			var inputNameParts = this.inputName.split(':');
			this.objectId = inputNameParts[0];
			this.attribute = inputNameParts[1];
			this.languageId = inputNameParts[2];

			// call parent create method
			this.inherited('create', arguments);

			// insert title node to DOM
			this._titleNode = this.domNode.ownerDocument.createElement('span');
			if (this.title != '') {
				this._titleNode.innerHTML = this.title;
				dojo.addClass(this._titleNode, "TitleDiv");
				this._titleNode.style.display = 'none';
				srcNodeRef.title = '';
			}
			//this.domNode.insertBefore(this._titleNode, this.domNode.firstChild);
			this.domNode.parentNode.insertBefore(this._titleNode, this.domNode);
		},

		postCreate: function() {
			this._copyStyle(this.displayNode, this._computedStyle);
			this.inherited('postCreate', arguments);

			this.domNode.title = this.translate('InsertContentHere');

			if (this.permanent){
				this.show();
			}
			if (this.undoWidget != ''){
				this.undoObject = $$(this.undoWidget).getUndoObject();
			}
			//add content to a helper div to remove html tags for a correct empty check
			var testDiv = document.createElement('div');
			testDiv.innerHTML = this.contentNode.value;
			if (testDiv.textContent.length == 0 && this.displayNode){
				this.displayNode.innerHTML = this._placeHolderText;
			}
		},

		onClick: function(evt) {
			epages.topDojo.publish('InlineEditor/click', [{ instance: this, event: evt }]);
			this.show();
			dojo.stopEvent(evt);
		},

		onBlur: function(/*DOMEvent*/evt) {
			// description:
			//  method to override, called when editor may blur
			//  evt:
			//    event that triggered the blur
			// returns:
			//    whether to blur the editor or not
			return true; //Boolean
		},

		onMouseOver: function(evt) {
			$E(this.displayNode).addClassName('Highlighted');
		},

		onMouseOut: function(evt) {
			$E(this.displayNode).removeClassName('Highlighted');
		},

		show: function() {
			if (epages.cartridges.de_epages.presentation.widget.InlineEditor.selectedEditor != null &&
					epages.cartridges.de_epages.presentation.widget.InlineEditor.selectedEditor != this) {
				// close another opened editor
				epages.cartridges.de_epages.presentation.widget.InlineEditor.selectedEditor.hide();
			}

			this._titleNode.style.display = '';
			this.connect(this.contentNode, 'onchange', 'onChangeContentNode');
			// manage global InlineEditor instance
			epages.cartridges.de_epages.presentation.widget.InlineEditor.selectedEditor = this;
			epages.topDojo.publish('InlineEditor/show', [this]);
			if(this.domNode.clientWidth == 0) {
				this.domNode.style.minWidth = Math.max(0, this._width - this.domNode.offsetWidth) + "px";		// set content minwidth
			}
		},

		_copyStyle: function(node, style) {
			// summary: Copy the style from the source
			// description: -- taken from dijit.InlineEditBox --
			//              Don't copy ALL properties though, just the necessary/applicable ones

			dojo.forEach(this._relevantStyleAttributes, function(prop) {
				node.style[prop] = (style[prop] || "");
			}, this);

		},

		_resizeToContent: function() {
			// this timeout avoids some flickering
			window.setTimeout(dojo.hitch(this, function() {
				var node = this.contentNode;
				var clone = this._resizeClone;
				if (clone == null) {
					var clone = node.ownerDocument.createElement('div');
					var cs = dojo.getComputedStyle(node);
					var s = clone.style;
					for (var p in cs) {
						try {
							s[p] = cs[p];
						} catch(e) {
						}
					}
					// insert it into dom but dont show it
					clone.style.width = '100%';
					clone.style.height = 'auto';
					clone.style.overflow = 'visible';
					clone.style.position = 'absolute';
					clone.style.top = '-9999px';
					clone.style.whiteSpace = 'normal';
					node.parentNode.insertBefore(clone, node);
					this._resizeClone = clone;
				}
				if (node.value != '') {
					clone.innerHTML = epages.html.encodeEntity(node.value, true);
				} else {
					clone.innerHTML = '&nbsp;';
				}
				if (node.value.match(/[\r\n]$/)){
					clone.innerHTML += '&nbsp;';
				}
				var innerHeight = clone.scrollHeight;
				var offsetHeight = 0;
				node.style.height = (innerHeight + offsetHeight) + 'px';

				// callback for height correction in text fields
				if(this.correctCallback !== undefined){
					this.correctCallback(node);
				}
			}), 1);
		},

		hide: function(evt) {
			this._titleNode.style.display = 'none';
			epages.cartridges.de_epages.presentation.widget.InlineEditor.selectedEditor = null;
			if (this.contentNode.value == ''){
				this.displayNode.innerHTML = this._placeHolderText;
			}
			epages.topDojo.publish('InlineEditor/hide', [this]);
		},

		onChange: function() {
			// summary: write contents back to hidden input
			if(this.object){
				this.contentNode.value = this.object.getContent();
			}
			this.onChangeContentNode();
		},

		onChangeContentNode: function() {
			//summary: gets called, when data is changed (from outside)
			if(this.undoObject){
				this.undoObject.addInput(this.contentNode);
			}
		},

		getRemoteValue: function(/*Array.string*/additionalAttributes) {
		  // summary: get the correct value from the server, the content may be manipulated by the browser

			// create new json instance
			if (this._jsonIo == null){
				this._jsonIo = new epages.io.Json();
			}
			var attributes = [ this.attribute ];

			// add additional needed attributes
			if (additionalAttributes != null) {
				attributes = attributes.merge(additionalAttributes);
			}

			// get correct content from server, content may be modified by browser
			var value = this._jsonIo.loadSync('?', {
				'ViewObjectID': this.objectId,
				'ViewAction': 'JSONGet',
				'Attributes': attributes.join(',')
			});

			return value;
		}

	}
);

epages.cartridges.de_epages.presentation.widget.InlineEditor.selectedEditor = null;
$D.add( 'click',
	// summary: adds click event handler to document of editor and topWindow document
	// description: we need to check on click if we are still inside the editor
	//    or ouside. if the click was outside the hide methode of the current editor is called

	function() {
		//summary: return selected editor if available
		if (epages.cartridges.de_epages.presentation.widget.InlineEditor.selectedEditor != null){
			return epages.cartridges.de_epages.presentation.widget.InlineEditor.selectedEditor.domNode;
		}
		else{
			return null;
		}
	},
	function(evt) {
		var ed = epages.cartridges.de_epages.presentation.widget.InlineEditor.selectedEditor;
		if((ed && ed.contentNode == evt.target) //check if editor was clicked for Gecko and WebKit
		|| (ed && ed.contentNode == evt.srcElement)){ // check if editor was clicked for MSIE
			return;
		}

		if (ed != null && ed.onBlur(evt)){ //if blur event of editor was
			ed.hide();
		}
	},
	// outside
	true,
	[document, epages.topWindow.document]
);

}


dojo.i18n._preloadLocalizations("epages.nls.ep_shop", ["ROOT","ca","da","de","en","es","fi","fr","it","nl","no","pt","ro","ru","sv","xx"]);

/* package: ep_shop_tree.js.uncompressed */
/*
	Copyright (c) 2004-2011, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/

/*
	This is an optimized version of Dojo, built for deployment and not for
	development. To get sources and documentation, please visit:

		http://dojotoolkit.org
*/

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.icon"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.icon"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

  epages.cartridges.de_epages.presentation.*

*/
dojo.provide("epages.cartridges.de_epages.presentation.icon");

epages.cartridges.de_epages.presentation.icon.getIconFileName = function(classAlias, isVisible, isProduct, /* ? string */ size) {
	var iSize = (size) ? size : 's';
	if (isVisible === undefined || isVisible == null){ 
		isVisible = true;
	}
	if (isProduct === undefined){ 
		isProduct = false;
	}
	var isVisible = isVisible ? '.png' : '_inactive.png';
	if(isProduct){  
		return 'object_ico_'+iSize+'_product' + isVisible;
	}
	if(classAlias){ 
		return 'object_ico_'+iSize+'_' + classAlias.toLowerCase() + isVisible;
	}
	return 'general_img_transparentpixel.png';
}

epages.cartridges.de_epages.presentation.icon.getIconSpriteName = function(classAlias, isVisible, isProduct, /* ? string */ size) {
	var iSize = (size) ? size : 's';
	if (isVisible === undefined || isVisible == null){ 
		isVisible = true;
	}
	if (isProduct === undefined){ 
		isProduct = false;
	}
	var isVisible = isVisible ? '' : '_inactive';
	if(isProduct){  
		return 'object_ico_'+iSize+'_product' + isVisible;
	}
	if(classAlias){ 
		return 'object_ico_'+iSize+'_' + classAlias.toLowerCase() + isVisible;
	}
	return '';
}


}

if(!dojo._hasResource["dojo.data.api.Request"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.data.api.Request"] = true;
dojo.provide("dojo.data.api.Request");


dojo.declare("dojo.data.api.Request", null, {
	//	summary:
	//		This class defines out the semantics of what a 'Request' object looks like
	//		when returned from a fetch() method.  In general, a request object is
	//		nothing more than the original keywordArgs from fetch with an abort function
	//		attached to it to allow users to abort a particular request if they so choose.
	//		No other functions are required on a general Request object return.  That does not
	//		inhibit other store implementations from adding extentions to it, of course.
	//
	//		This is an abstract API that data provider implementations conform to.
	//		This file defines methods signatures and intentionally leaves all the
	//		methods unimplemented.
	//
	//		For more details on fetch, see dojo.data.api.Read.fetch().

	abort: function(){
		//	summary:
		//		This function is a hook point for stores to provide as a way for
		//		a fetch to be halted mid-processing.
		//	description:
		//		This function is a hook point for stores to provide as a way for
		//		a fetch to be halted mid-processing.  For more details on the fetch() api,
		//		please see dojo.data.api.Read.fetch().
		throw new Error('Unimplemented API: dojo.data.api.Request.abort');
	}
});

}

if(!dojo._hasResource["dojo.data.api.Read"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.data.api.Read"] = true;
dojo.provide("dojo.data.api.Read");



dojo.declare("dojo.data.api.Read", null, {
	//	summary:
	//		This is an abstract API that data provider implementations conform to.
	//		This file defines methods signatures and intentionally leaves all the
	//		methods unimplemented.  For more information on the dojo.data APIs,
	//		please visit: http://www.dojotoolkit.org/node/98

	getValue: function(	/* item */ item,
						/* attribute-name-string */ attribute,
						/* value? */ defaultValue){
		//	summary:
		//		Returns a single attribute value.
		//		Returns defaultValue if and only if *item* does not have a value for *attribute*.
		//		Returns null if and only if null was explicitly set as the attribute value.
		//		Returns undefined if and only if the item does not have a value for the
		//		given attribute (which is the same as saying the item does not have the attribute).
		// description:
		//		Saying that an "item x does not have a value for an attribute y"
		//		is identical to saying that an "item x does not have attribute y".
		//		It is an oxymoron to say "that attribute is present but has no values"
		//		or "the item has that attribute but does not have any attribute values".
		//		If store.hasAttribute(item, attribute) returns false, then
		//		store.getValue(item, attribute) will return undefined.
		//
		//	item:
		//		The item to access values on.
		//	attribute:
		//		The attribute to access represented as a string.
		//	defaultValue:
		//		Optional.  A default value to use for the getValue return in the attribute does not exist or has no value.
		//
		//	exceptions:
		//		Throws an exception if *item* is not an item, or *attribute* is not a string
		//	example:
		//	|	var darthVader = store.getValue(lukeSkywalker, "father");
		var attributeValue = null;
		throw new Error('Unimplemented API: dojo.data.api.Read.getValue');
		return attributeValue; // a literal, an item, null, or undefined (never an array)
	},

	getValues: function(/* item */ item,
						/* attribute-name-string */ attribute){
		//	summary:
		// 		This getValues() method works just like the getValue() method, but getValues()
		//		always returns an array rather than a single attribute value.  The array
		//		may be empty, may contain a single attribute value, or may contain
		//		many attribute values.
		//		If the item does not have a value for the given attribute, then getValues()
		//		will return an empty array: [].  (So, if store.hasAttribute(item, attribute)
		//		has a return of false, then store.getValues(item, attribute) will return [].)
		//
		//	item:
		//		The item to access values on.
		//	attribute:
		//		The attribute to access represented as a string.
		//
		//	exceptions:
		//		Throws an exception if *item* is not an item, or *attribute* is not a string
		//	example:
		//	|	var friendsOfLuke = store.getValues(lukeSkywalker, "friends");
		var array = [];
		throw new Error('Unimplemented API: dojo.data.api.Read.getValues');
		return array; // an array that may contain literals and items
	},

	getAttributes: function(/* item */ item){
		//	summary:
		//		Returns an array with all the attributes that this item has.  This
		//		method will always return an array; if the item has no attributes
		//		at all, getAttributes() will return an empty array: [].
		//
		//	item:
		//		The item to access attributes on.
		//
		//	exceptions:
		//		Throws an exception if *item* is not an item, or *attribute* is not a string
		//	example:
		//	|	var array = store.getAttributes(kermit);
		var array = [];
		throw new Error('Unimplemented API: dojo.data.api.Read.getAttributes');
		return array; // array
	},

	hasAttribute: function(	/* item */ item,
							/* attribute-name-string */ attribute){
		//	summary:
		//		Returns true if the given *item* has a value for the given *attribute*.
		//
		//	item:
		//		The item to access attributes on.
		//	attribute:
		//		The attribute to access represented as a string.
		//
		//	exceptions:
		//		Throws an exception if *item* is not an item, or *attribute* is not a string
		//	example:
		//	|	var trueOrFalse = store.hasAttribute(kermit, "color");
		throw new Error('Unimplemented API: dojo.data.api.Read.hasAttribute');
		return false; // boolean
	},

	containsValue: function(/* item */ item,
							/* attribute-name-string */ attribute,
							/* anything */ value){
		//	summary:
		//		Returns true if the given *value* is one of the values that getValues()
		//		would return.
		//
		//	item:
		//		The item to access values on.
		//	attribute:
		//		The attribute to access represented as a string.
		//	value:
		//		The value to match as a value for the attribute.
		//
		//	exceptions:
		//		Throws an exception if *item* is not an item, or *attribute* is not a string
		//	example:
		//	|	var trueOrFalse = store.containsValue(kermit, "color", "green");
		throw new Error('Unimplemented API: dojo.data.api.Read.containsValue');
		return false; // boolean
	},

	isItem: function(/* anything */ something){
		//	summary:
		//		Returns true if *something* is an item and came from the store instance.
		//		Returns false if *something* is a literal, an item from another store instance,
		//		or is any object other than an item.
		//
		//	something:
		//		Can be anything.
		//
		//	example:
		//	|	var yes = store.isItem(store.newItem());
		//	|	var no  = store.isItem("green");
		throw new Error('Unimplemented API: dojo.data.api.Read.isItem');
		return false; // boolean
	},

	isItemLoaded: function(/* anything */ something){
		//	summary:
		//		Returns false if isItem(something) is false.  Returns false if
		//		if isItem(something) is true but the the item is not yet loaded
		//		in local memory (for example, if the item has not yet been read
		//		from the server).
		//
		//	something:
		//		Can be anything.
		//
		//	example:
		//	|	var yes = store.isItemLoaded(store.newItem());
		//	|	var no  = store.isItemLoaded("green");
		throw new Error('Unimplemented API: dojo.data.api.Read.isItemLoaded');
		return false; // boolean
	},

	loadItem: function(/* object */ keywordArgs){
		//	summary:
		//		Given an item, this method loads the item so that a subsequent call
		//		to store.isItemLoaded(item) will return true.  If a call to
		//		isItemLoaded() returns true before loadItem() is even called,
		//		then loadItem() need not do any work at all and will not even invoke
		//		the callback handlers.  So, before invoking this method, check that
		//		the item has not already been loaded.
		// 	keywordArgs:
		//		An anonymous object that defines the item to load and callbacks to invoke when the
		//		load has completed.  The format of the object is as follows:
		//		{
		//			item: object,
		//			onItem: Function,
		//			onError: Function,
		//			scope: object
		//		}
		//	The *item* parameter.
		//		The item parameter is an object that represents the item in question that should be
		//		contained by the store.  This attribute is required.
		
		//	The *onItem* parameter.
		//		Function(item)
		//		The onItem parameter is the callback to invoke when the item has been loaded.  It takes only one
		//		parameter, the fully loaded item.
		//
		//	The *onError* parameter.
		//		Function(error)
		//		The onError parameter is the callback to invoke when the item load encountered an error.  It takes only one
		//		parameter, the error object
		//
		//	The *scope* parameter.
		//		If a scope object is provided, all of the callback functions (onItem,
		//		onError, etc) will be invoked in the context of the scope object.
		//		In the body of the callback function, the value of the "this"
		//		keyword will be the scope object.   If no scope object is provided,
		//		the callback functions will be called in the context of dojo.global().
		//		For example, onItem.call(scope, item, request) vs.
		//		onItem.call(dojo.global(), item, request)
		if(!this.isItemLoaded(keywordArgs.item)){
			throw new Error('Unimplemented API: dojo.data.api.Read.loadItem');
		}
	},

	fetch: function(/* Object */ keywordArgs){
		//	summary:
		//		Given a query and set of defined options, such as a start and count of items to return,
		//		this method executes the query and makes the results available as data items.
		//		The format and expectations of stores is that they operate in a generally asynchronous
		//		manner, therefore callbacks are always used to return items located by the fetch parameters.
		//
		//	description:
		//		A Request object will always be returned and is returned immediately.
		//		The basic request is nothing more than the keyword args passed to fetch and
		//		an additional function attached, abort().  The returned request object may then be used
		//		to cancel a fetch.  All data items returns are passed through the callbacks defined in the
		//		fetch parameters and are not present on the 'request' object.
		//
		//		This does not mean that custom stores can not add methods and properties to the request object
		//		returned, only that the API does not require it.  For more info about the Request API,
		//		see dojo.data.api.Request
		//
		//	keywordArgs:
		//		The keywordArgs parameter may either be an instance of
		//		conforming to dojo.data.api.Request or may be a simple anonymous object
		//		that may contain any of the following:
		//		{
		//			query: query-object or query-string,
		//			queryOptions: object,
		//			onBegin: Function,
		//			onItem: Function,
		//			onComplete: Function,
		//			onError: Function,
		//			scope: object,
		//			start: int
		//			count: int
		//			sort: array
		//		}
		//		All implementations should accept keywordArgs objects with any of
		//		the 9 standard properties: query, onBegin, onItem, onComplete, onError
		//		scope, sort, start, and count.  Some implementations may accept additional
		//		properties in the keywordArgs object as valid parameters, such as
		//		{includeOutliers:true}.
		//
		//	The *query* parameter.
		//		The query may be optional in some data store implementations.
		//		The dojo.data.api.Read API does not specify the syntax or semantics
		//		of the query itself -- each different data store implementation
		//		may have its own notion of what a query should look like.
		//		However, as of dojo 0.9, 1.0, and 1.1, all the provided datastores in dojo.data
		//		and dojox.data support an object structure query, where the object is a set of
		//		name/value parameters such as { attrFoo: valueBar, attrFoo1: valueBar1}.  Most of the
		//		dijit widgets, such as ComboBox assume this to be the case when working with a datastore
		//		when they dynamically update the query.  Therefore, for maximum compatibility with dijit
		//		widgets the recommended query parameter is a key/value object.  That does not mean that the
		//		the datastore may not take alternative query forms, such as a simple string, a Date, a number,
		//		or a mix of such.  Ultimately, The dojo.data.api.Read API is agnostic about what the query
		//		format.
		//		Further note:  In general for query objects that accept strings as attribute
		//		value matches, the store should also support basic filtering capability, such as *
		//		(match any character) and ? (match single character).  An example query that is a query object
		//		would be like: { attrFoo: "value*"}.  Which generally means match all items where they have
		//		an attribute named attrFoo, with a value that starts with 'value'.
		//
		//	The *queryOptions* parameter
		//		The queryOptions parameter is an optional parameter used to specify optiosn that may modify
		//		the query in some fashion, such as doing a case insensitive search, or doing a deep search
		//		where all items in a hierarchical representation of data are scanned instead of just the root
		//		items.  It currently defines two options that all datastores should attempt to honor if possible:
		//		{
		//			ignoreCase: boolean, //Whether or not the query should match case sensitively or not.  Default behaviour is false.
		//			deep: boolean 	//Whether or not a fetch should do a deep search of items and all child
		//							//items instead of just root-level items in a datastore.  Default is false.
		//		}
		//
		//	The *onBegin* parameter.
		//		function(size, request);
		//		If an onBegin callback function is provided, the callback function
		//		will be called just once, before the first onItem callback is called.
		//		The onBegin callback function will be passed two arguments, the
		//		the total number of items identified and the Request object.  If the total number is
		//		unknown, then size will be -1.  Note that size is not necessarily the size of the
		//		collection of items returned from the query, as the request may have specified to return only a
		//		subset of the total set of items through the use of the start and count parameters.
		//
		//	The *onItem* parameter.
		//		function(item, request);
		//		If an onItem callback function is provided, the callback function
		//		will be called as each item in the result is received. The callback
		//		function will be passed two arguments: the item itself, and the
		//		Request object.
		//
		//	The *onComplete* parameter.
		//		function(items, request);
		//
		//		If an onComplete callback function is provided, the callback function
		//		will be called just once, after the last onItem callback is called.
		//		Note that if the onItem callback is not present, then onComplete will be passed
		//		an array containing all items which matched the query and the request object.
		//		If the onItem callback is present, then onComplete is called as:
		//		onComplete(null, request).
		//
		//	The *onError* parameter.
		//		function(errorData, request);
		//		If an onError callback function is provided, the callback function
		//		will be called if there is any sort of error while attempting to
		//		execute the query.
		//		The onError callback function will be passed two arguments:
		//		an Error object and the Request object.
		//
		//	The *scope* parameter.
		//		If a scope object is provided, all of the callback functions (onItem,
		//		onComplete, onError, etc) will be invoked in the context of the scope
		//		object.  In the body of the callback function, the value of the "this"
		//		keyword will be the scope object.   If no scope object is provided,
		//		the callback functions will be called in the context of dojo.global().
		//		For example, onItem.call(scope, item, request) vs.
		//		onItem.call(dojo.global(), item, request)
		//
		//	The *start* parameter.
		//		If a start parameter is specified, this is a indication to the datastore to
		//		only start returning items once the start number of items have been located and
		//		skipped.  When this parameter is paired withh 'count', the store should be able
		//		to page across queries with millions of hits by only returning subsets of the
		//		hits for each query
		//
		//	The *count* parameter.
		//		If a count parameter is specified, this is a indication to the datastore to
		//		only return up to that many items.  This allows a fetch call that may have
		//		millions of item matches to be paired down to something reasonable.
		//
		//	The *sort* parameter.
		//		If a sort parameter is specified, this is a indication to the datastore to
		//		sort the items in some manner before returning the items.  The array is an array of
		//		javascript objects that must conform to the following format to be applied to the
		//		fetching of items:
		//		{
		//			attribute: attribute || attribute-name-string,
		//			descending: true|false;   // Optional.  Default is false.
		//		}
		//		Note that when comparing attributes, if an item contains no value for the attribute
		//		(undefined), then it the default ascending sort logic should push it to the bottom
		//		of the list.  In the descending order case, it such items should appear at the top of the list.
		//
		//	returns:
		//		The fetch() method will return a javascript object conforming to the API
		//		defined in dojo.data.api.Request.  In general, it will be the keywordArgs
		//		object returned with the required functions in Request.js attached.
		//		Its general purpose is to provide a convenient way for a caller to abort an
		//		ongoing fetch.
		//
		//		The Request object may also have additional properties when it is returned
		//		such as request.store property, which is a pointer to the datastore object that
		//		fetch() is a method of.
		//
		//	exceptions:
		//		Throws an exception if the query is not valid, or if the query
		//		is required but was not supplied.
		//
		//	example:
		//		Fetch all books identified by the query and call 'showBooks' when complete
		//		|	var request = store.fetch({query:"all books", onComplete: showBooks});
		//	example:
		//		Fetch all items in the story and call 'showEverything' when complete.
		//		|	var request = store.fetch(onComplete: showEverything);
		//	example:
		//		Fetch only 10 books that match the query 'all books', starting at the fifth book found during the search.
		//		This demonstrates how paging can be done for specific queries.
		//		|	var request = store.fetch({query:"all books", start: 4, count: 10, onComplete: showBooks});
		//	example:
		//		Fetch all items that match the query, calling 'callback' each time an item is located.
		//		|	var request = store.fetch({query:"foo/bar", onItem:callback});
		//	example:
		//		Fetch the first 100 books by author King, call showKing when up to 100 items have been located.
		//		|	var request = store.fetch({query:{author:"King"}, start: 0, count:100, onComplete: showKing});
		//	example:
		//		Locate the books written by Author King, sort it on title and publisher, then return the first 100 items from the sorted items.
		//		|	var request = store.fetch({query:{author:"King"}, sort: [{ attribute: "title", descending: true}, {attribute: "publisher"}], ,start: 0, count:100, onComplete: 'showKing'});
		//	example:
		//		Fetch the first 100 books by authors starting with the name King, then call showKing when up to 100 items have been located.
		//		|	var request = store.fetch({query:{author:"King*"}, start: 0, count:100, onComplete: showKing});
		//	example:
		//		Fetch the first 100 books by authors ending with 'ing', but only have one character before it (King, Bing, Ling, Sing, etc.), then call showBooks when up to 100 items have been located.
		//		|	var request = store.fetch({query:{author:"?ing"}, start: 0, count:100, onComplete: showBooks});
		//	example:
		//		Fetch the first 100 books by author King, where the name may appear as King, king, KING, kInG, and so on, then call showKing when up to 100 items have been located.
		//		|	var request = store.fetch({query:{author:"King"}, queryOptions:(ignoreCase: true}, start: 0, count:100, onComplete: showKing});
		//	example:
		//		Paging
		//		|	var store = new dojo.data.LargeRdbmsStore({url:"jdbc:odbc:foobar"});
		//		|	var fetchArgs = {
		//		|		query: {type:"employees", name:"Hillary *"}, // string matching
		//		|		sort: [{attribute:"department", descending:true}],
		//		|		start: 0,
		//		|		count: 20,
		//		|		scope: displayer,
		//		|		onBegin: showThrobber,
		//		|		onItem: displayItem,
		//		|		onComplete: stopThrobber,
		//		|		onError: handleFetchError,
		//		|	};
		//		|	store.fetch(fetchArgs);
		//		|	...
		//		and then when the user presses the "Next Page" button...
		//		|	fetchArgs.start += 20;
		//		|	store.fetch(fetchArgs);  // get the next 20 items
		var request = null;
		throw new Error('Unimplemented API: dojo.data.api.Read.fetch');
		return request; // an object conforming to the dojo.data.api.Request API
	},

	getFeatures: function(){
		//	summary:
		//		The getFeatures() method returns an simple keyword values object
		//		that specifies what interface features the datastore implements.
		//		A simple CsvStore may be read-only, and the only feature it
		//		implements will be the 'dojo.data.api.Read' interface, so the
		//		getFeatures() method will return an object like this one:
		//		{'dojo.data.api.Read': true}.
		//		A more sophisticated datastore might implement a variety of
		//		interface features, like 'dojo.data.api.Read', 'dojo.data.api.Write',
		//		'dojo.data.api.Identity', and 'dojo.data.api.Attribution'.
		return {
			'dojo.data.api.Read': true
		};
	},

	close: function(/*dojo.data.api.Request || keywordArgs || null */ request){
		//	summary:
		//		The close() method is intended for instructing the store to 'close' out
		//		any information associated with a particular request.
		//
		//	description:
		//		The close() method is intended for instructing the store to 'close' out
		//		any information associated with a particular request.  In general, this API
		//		expects to recieve as a parameter a request object returned from a fetch.
		//		It will then close out anything associated with that request, such as
		//		clearing any internal datastore caches and closing any 'open' connections.
		//		For some store implementations, this call may be a no-op.
		//
		//	request:
		//		An instance of a request for the store to use to identify what to close out.
		//		If no request is passed, then the store should clear all internal caches (if any)
		//		and close out all 'open' connections.  It does not render the store unusable from
		//		there on, it merely cleans out any current data and resets the store to initial
		//		state.
		//
		//	example:
		//	|	var request = store.fetch({onComplete: doSomething});
		//	|	...
		//	|	store.close(request);
		throw new Error('Unimplemented API: dojo.data.api.Read.close');
	},

	getLabel: function(/* item */ item){
		//	summary:
		//		Method to inspect the item and return a user-readable 'label' for the item
		//		that provides a general/adequate description of what the item is.
		//
		//	description:
		//		Method to inspect the item and return a user-readable 'label' for the item
		//		that provides a general/adequate description of what the item is.  In general
		//		most labels will be a specific attribute value or collection of the attribute
		//		values that combine to label the item in some manner.  For example for an item
		//		that represents a person it may return the label as:  "firstname lastlame" where
		//		the firstname and lastname are attributes on the item.  If the store is unable
		//		to determine an adequate human readable label, it should return undefined.  Users that wish
		//		to customize how a store instance labels items should replace the getLabel() function on
		//		their instance of the store, or extend the store and replace the function in
		//		the extension class.
		//
		//	item:
		//		The item to return the label for.
		//
		//	returns:
		//		A user-readable string representing the item or undefined if no user-readable label can
		//		be generated.
		throw new Error('Unimplemented API: dojo.data.api.Read.getLabel');
		return undefined;
	},

	getLabelAttributes: function(/* item */ item){
		//	summary:
		//		Method to inspect the item and return an array of what attributes of the item were used
		//		to generate its label, if any.
		//
		//	description:
		//		Method to inspect the item and return an array of what attributes of the item were used
		//		to generate its label, if any.  This function is to assist UI developers in knowing what
		//		attributes can be ignored out of the attributes an item has when displaying it, in cases
		//		where the UI is using the label as an overall identifer should they wish to hide
		//		redundant information.
		//
		//	item:
		//		The item to return the list of label attributes for.
		//
		//	returns:
		//		An array of attribute names that were used to generate the label, or null if public attributes
		//		were not used to generate the label.
		throw new Error('Unimplemented API: dojo.data.api.Read.getLabelAttributes');
		return null;
	}
});

}

if(!dojo._hasResource["dojo.data.api.Identity"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.data.api.Identity"] = true;
dojo.provide("dojo.data.api.Identity");



dojo.declare("dojo.data.api.Identity", dojo.data.api.Read, {
	//	summary:
	//		This is an abstract API that data provider implementations conform to.
	//		This file defines methods signatures and intentionally leaves all the
	//		methods unimplemented.

	getFeatures: function(){
		//	summary:
		//		See dojo.data.api.Read.getFeatures()
		return {
			 'dojo.data.api.Read': true,
			 'dojo.data.api.Identity': true
		};
	},

	getIdentity: function(/* item */ item){
		//	summary:
		//		Returns a unique identifier for an item.  The return value will be
		//		either a string or something that has a toString() method (such as,
		//		for example, a dojox.uuid.Uuid object).
		//	item:
		//		The item from the store from which to obtain its identifier.
		//	exceptions:
		//		Conforming implementations may throw an exception or return null if
		//		item is not an item.
		//	example:
		//	|	var itemId = store.getIdentity(kermit);
		//	|	assert(kermit === store.findByIdentity(store.getIdentity(kermit)));
		throw new Error('Unimplemented API: dojo.data.api.Identity.getIdentity');
		var itemIdentityString = null;
		return itemIdentityString; // string
	},

	getIdentityAttributes: function(/* item */ item){
		//	summary:
		//		Returns an array of attribute names that are used to generate the identity.
		//		For most stores, this is a single attribute, but for some complex stores
		//		such as RDB backed stores that use compound (multi-attribute) identifiers
		//		it can be more than one.  If the identity is not composed of attributes
		//		on the item, it will return null.  This function is intended to identify
		//		the attributes that comprise the identity so that so that during a render
		//		of all attributes, the UI can hide the the identity information if it
		//		chooses.
		//	item:
		//		The item from the store from which to obtain the array of public attributes that
		//		compose the identifier, if any.
		//	example:
		//	|	var itemId = store.getIdentity(kermit);
		//	|	var identifiers = store.getIdentityAttributes(itemId);
		//	|	assert(typeof identifiers === "array" || identifiers === null);
		throw new Error('Unimplemented API: dojo.data.api.Identity.getIdentityAttributes');
		return null; // string
	},


	fetchItemByIdentity: function(/* object */ keywordArgs){
		//	summary:
		//		Given the identity of an item, this method returns the item that has
		//		that identity through the onItem callback.  Conforming implementations
		//		should return null if there is no item with the given identity.
		//		Implementations of fetchItemByIdentity() may sometimes return an item
		//		from a local cache and may sometimes fetch an item from a remote server,
		//
		// 	keywordArgs:
		//		An anonymous object that defines the item to locate and callbacks to invoke when the
		//		item has been located and load has completed.  The format of the object is as follows:
		//		{
		//			identity: string|object,
		//			onItem: Function,
		//			onError: Function,
		//			scope: object
		//		}
		//	The *identity* parameter.
		//		The identity parameter is the identity of the item you wish to locate and load
		//		This attribute is required.  It should be a string or an object that toString()
		//		can be called on.
		//
		//	The *onItem* parameter.
		//		Function(item)
		//		The onItem parameter is the callback to invoke when the item has been loaded.  It takes only one
		//		parameter, the item located, or null if none found.
		//
		//	The *onError* parameter.
		//		Function(error)
		//		The onError parameter is the callback to invoke when the item load encountered an error.  It takes only one
		//		parameter, the error object
		//
		//	The *scope* parameter.
		//		If a scope object is provided, all of the callback functions (onItem,
		//		onError, etc) will be invoked in the context of the scope object.
		//		In the body of the callback function, the value of the "this"
		//		keyword will be the scope object.   If no scope object is provided,
		//		the callback functions will be called in the context of dojo.global.
		//		For example, onItem.call(scope, item, request) vs.
		//		onItem.call(dojo.global, item, request)
		if(!this.isItemLoaded(keywordArgs.item)){
			throw new Error('Unimplemented API: dojo.data.api.Identity.fetchItemByIdentity');
		}
	}
});

}

if(!dojo._hasResource["dojo.cookie"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.cookie"] = true;
dojo.provide("dojo.cookie");



/*=====
dojo.__cookieProps = function(){
	//	expires: Date|String|Number?
	//		If a number, the number of days from today at which the cookie
	//		will expire. If a date, the date past which the cookie will expire.
	//		If expires is in the past, the cookie will be deleted.
	//		If expires is omitted or is 0, the cookie will expire when the browser closes. << FIXME: 0 seems to disappear right away? FF3.
	//	path: String?
	//		The path to use for the cookie.
	//	domain: String?
	//		The domain to use for the cookie.
	//	secure: Boolean?
	//		Whether to only send the cookie on secure connections
	this.expires = expires;
	this.path = path;
	this.domain = domain;
	this.secure = secure;
}
=====*/


dojo.cookie = function(/*String*/name, /*String?*/value, /*dojo.__cookieProps?*/props){
	//	summary:
	//		Get or set a cookie.
	//	description:
	// 		If one argument is passed, returns the value of the cookie
	// 		For two or more arguments, acts as a setter.
	//	name:
	//		Name of the cookie
	//	value:
	//		Value for the cookie
	//	props:
	//		Properties for the cookie
	//	example:
	//		set a cookie with the JSON-serialized contents of an object which
	//		will expire 5 days from now:
	//	|	dojo.cookie("configObj", dojo.toJson(config), { expires: 5 });
	//
	//	example:
	//		de-serialize a cookie back into a JavaScript object:
	//	|	var config = dojo.fromJson(dojo.cookie("configObj"));
	//
	//	example:
	//		delete a cookie:
	//	|	dojo.cookie("configObj", null, {expires: -1});
	var c = document.cookie;
	if(arguments.length == 1){
		var matches = c.match(new RegExp("(?:^|; )" + dojo.regexp.escapeString(name) + "=([^;]*)"));
		return matches ? decodeURIComponent(matches[1]) : undefined; // String or undefined
	}else{
		props = props || {};
// FIXME: expires=0 seems to disappear right away, not on close? (FF3)  Change docs?
		var exp = props.expires;
		if(typeof exp == "number"){
			var d = new Date();
			d.setTime(d.getTime() + exp*24*60*60*1000);
			exp = props.expires = d;
		}
		if(exp && exp.toUTCString){ props.expires = exp.toUTCString(); }

		value = encodeURIComponent(value);
		var updatedCookie = name + "=" + value, propName;
		for(propName in props){
			updatedCookie += "; " + propName;
			var propValue = props[propName];
			if(propValue !== true){ updatedCookie += "=" + propValue; }
		}
		document.cookie = updatedCookie;
	}
};

dojo.cookie.isSupported = function(){
	//	summary:
	//		Use to determine if the current browser supports cookies or not.
	//
	//		Returns true if user allows cookies.
	//		Returns false if user doesn't allow cookies.

	if(!("cookieEnabled" in navigator)){
		this("__djCookieTest__", "CookiesAllowed");
		navigator.cookieEnabled = this("__djCookieTest__") == "CookiesAllowed";
		if(navigator.cookieEnabled){
			this("__djCookieTest__", "", {expires: -1});
		}
	}
	return navigator.cookieEnabled;
};

}

if(!dojo._hasResource["dojo.DeferredList"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.DeferredList"] = true;
dojo.provide("dojo.DeferredList");


dojo.DeferredList = function(/*Array*/ list, /*Boolean?*/ fireOnOneCallback, /*Boolean?*/ fireOnOneErrback, /*Boolean?*/ consumeErrors, /*Function?*/ canceller){
	// summary:
	//		Provides event handling for a group of Deferred objects.
	// description:
	//		DeferredList takes an array of existing deferreds and returns a new deferred of its own
	//		this new deferred will typically have its callback fired when all of the deferreds in
	//		the given list have fired their own deferreds.  The parameters `fireOnOneCallback` and
	//		fireOnOneErrback, will fire before all the deferreds as appropriate
	//
	//	list:
	//		The list of deferreds to be synchronizied with this DeferredList
	//	fireOnOneCallback:
	//		Will cause the DeferredLists callback to be fired as soon as any
	//		of the deferreds in its list have been fired instead of waiting until
	//		the entire list has finished
	//	fireonOneErrback:
	//		Will cause the errback to fire upon any of the deferreds errback
	//	canceller:
	//		A deferred canceller function, see dojo.Deferred
	var resultList = [];
	dojo.Deferred.call(this);
	var self = this;
	if(list.length === 0 && !fireOnOneCallback){
		this.resolve([0, []]);
	}
	var finished = 0;
	dojo.forEach(list, function(item, i){
		item.then(function(result){
			if(fireOnOneCallback){
				self.resolve([i, result]);
			}else{
				addResult(true, result);
			}
		},function(error){
			if(fireOnOneErrback){
				self.reject(error);
			}else{
				addResult(false, error);
			}
			if(consumeErrors){
				return null;
			}
			throw error;
		});
		function addResult(succeeded, result){
			resultList[i] = [succeeded, result];
			finished++;
			if(finished === list.length){
				self.resolve(resultList);
			}
			
		}
	});
};
dojo.DeferredList.prototype = new dojo.Deferred();

dojo.DeferredList.prototype.gatherResults= function(deferredList){
	// summary:
	//	Gathers the results of the deferreds for packaging
	//	as the parameters to the Deferred Lists' callback

	var d = new dojo.DeferredList(deferredList, false, true, false);
	d.addCallback(function(results){
		var ret = [];
		dojo.forEach(results, function(result){
			ret.push(result[1]);
		});
		return ret;
	});
	return d;
};

}

if(!dojo._hasResource["dijit.tree.TreeStoreModel"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.tree.TreeStoreModel"] = true;
dojo.provide("dijit.tree.TreeStoreModel");


dojo.declare(
		"dijit.tree.TreeStoreModel",
		null,
	{
		// summary:
		//		Implements dijit.Tree.model connecting to a store with a single
		//		root item.  Any methods passed into the constructor will override
		//		the ones defined here.

		// store: dojo.data.Store
		//		Underlying store
		store: null,

		// childrenAttrs: String[]
		//		One or more attribute names (attributes in the dojo.data item) that specify that item's children
		childrenAttrs: ["children"],

		// newItemIdAttr: String
		//		Name of attribute in the Object passed to newItem() that specifies the id.
		//
		//		If newItemIdAttr is set then it's used when newItem() is called to see if an
		//		item with the same id already exists, and if so just links to the old item
		//		(so that the old item ends up with two parents).
		//
		//		Setting this to null or "" will make every drop create a new item.
		newItemIdAttr: "id",

		// labelAttr: String
		//		If specified, get label for tree node from this attribute, rather
		//		than by calling store.getLabel()
		labelAttr: "",

	 	// root: [readonly] dojo.data.Item
		//		Pointer to the root item (read only, not a parameter)
		root: null,

		// query: anything
		//		Specifies datastore query to return the root item for the tree.
		//		Must only return a single item.   Alternately can just pass in pointer
		//		to root item.
		// example:
		//	|	{id:'ROOT'}
		query: null,

		// deferItemLoadingUntilExpand: Boolean
		//		Setting this to true will cause the TreeStoreModel to defer calling loadItem on nodes
		// 		until they are expanded. This allows for lazying loading where only one
		//		loadItem (and generally one network call, consequently) per expansion
		// 		(rather than one for each child).
		// 		This relies on partial loading of the children items; each children item of a
		// 		fully loaded item should contain the label and info about having children.
		deferItemLoadingUntilExpand: false,

		constructor: function(/* Object */ args){
			// summary:
			//		Passed the arguments listed above (store, etc)
			// tags:
			//		private

			dojo.mixin(this, args);

			this.connects = [];

			var store = this.store;
			if(!store.getFeatures()['dojo.data.api.Identity']){
				throw new Error("dijit.Tree: store must support dojo.data.Identity");
			}

			// if the store supports Notification, subscribe to the notification events
			if(store.getFeatures()['dojo.data.api.Notification']){
				this.connects = this.connects.concat([
					dojo.connect(store, "onNew", this, "onNewItem"),
					dojo.connect(store, "onDelete", this, "onDeleteItem"),
					dojo.connect(store, "onSet", this, "onSetItem")
				]);
			}
		},

		destroy: function(){
			dojo.forEach(this.connects, dojo.disconnect);
			// TODO: should cancel any in-progress processing of getRoot(), getChildren()
		},

		// =======================================================================
		// Methods for traversing hierarchy

		getRoot: function(onItem, onError){
			// summary:
			//		Calls onItem with the root item for the tree, possibly a fabricated item.
			//		Calls onError on error.
			if(this.root){
				onItem(this.root);
			}else{
				this.store.fetch({
					query: this.query,
					onComplete: dojo.hitch(this, function(items){
						if(items.length != 1){
							throw new Error(this.declaredClass + ": query " + dojo.toJson(this.query) + " returned " + items.length +
							 	" items, but must return exactly one item");
						}
						this.root = items[0];
						onItem(this.root);
					}),
					onError: onError
				});
			}
		},

		mayHaveChildren: function(/*dojo.data.Item*/ item){
			// summary:
			//		Tells if an item has or may have children.  Implementing logic here
			//		avoids showing +/- expando icon for nodes that we know don't have children.
			//		(For efficiency reasons we may not want to check if an element actually
			//		has children until user clicks the expando node)
			return dojo.some(this.childrenAttrs, function(attr){
				return this.store.hasAttribute(item, attr);
			}, this);
		},

		getChildren: function(/*dojo.data.Item*/ parentItem, /*function(items)*/ onComplete, /*function*/ onError){
			// summary:
			// 		Calls onComplete() with array of child items of given parent item, all loaded.

			var store = this.store;
			if(!store.isItemLoaded(parentItem)){
				// The parent is not loaded yet, we must be in deferItemLoadingUntilExpand
				// mode, so we will load it and just return the children (without loading each
				// child item)
				var getChildren = dojo.hitch(this, arguments.callee);
				store.loadItem({
					item: parentItem,
					onItem: function(parentItem){
						getChildren(parentItem, onComplete, onError);
					},
					onError: onError
				});
				return;
			}
			// get children of specified item
			var childItems = [];
			for(var i=0; i<this.childrenAttrs.length; i++){
				var vals = store.getValues(parentItem, this.childrenAttrs[i]);
				childItems = childItems.concat(vals);
			}

			// count how many items need to be loaded
			var _waitCount = 0;
			if(!this.deferItemLoadingUntilExpand){
				dojo.forEach(childItems, function(item){ if(!store.isItemLoaded(item)){ _waitCount++; } });
			}

			if(_waitCount == 0){
				// all items are already loaded (or we aren't loading them).  proceed...
				onComplete(childItems);
			}else{
				// still waiting for some or all of the items to load
				dojo.forEach(childItems, function(item, idx){
					if(!store.isItemLoaded(item)){
						store.loadItem({
							item: item,
							onItem: function(item){
								childItems[idx] = item;
								if(--_waitCount == 0){
									// all nodes have been loaded, send them to the tree
									onComplete(childItems);
								}
							},
							onError: onError
						});
					}
				});
			}
		},

		// =======================================================================
		// Inspecting items

		isItem: function(/* anything */ something){
			return this.store.isItem(something);	// Boolean
		},

		fetchItemByIdentity: function(/* object */ keywordArgs){
			this.store.fetchItemByIdentity(keywordArgs);
		},

		getIdentity: function(/* item */ item){
			return this.store.getIdentity(item);	// Object
		},

		getLabel: function(/*dojo.data.Item*/ item){
			// summary:
			//		Get the label for an item
			if(this.labelAttr){
				return this.store.getValue(item,this.labelAttr);	// String
			}else{
				return this.store.getLabel(item);	// String
			}
		},

		// =======================================================================
		// Write interface

		newItem: function(/* dojo.dnd.Item */ args, /*Item*/ parent, /*int?*/ insertIndex){
			// summary:
			//		Creates a new item.   See `dojo.data.api.Write` for details on args.
			//		Used in drag & drop when item from external source dropped onto tree.
			// description:
			//		Developers will need to override this method if new items get added
			//		to parents with multiple children attributes, in order to define which
			//		children attribute points to the new item.

			var pInfo = {parent: parent, attribute: this.childrenAttrs[0]}, LnewItem;

			if(this.newItemIdAttr && args[this.newItemIdAttr]){
				// Maybe there's already a corresponding item in the store; if so, reuse it.
				this.fetchItemByIdentity({identity: args[this.newItemIdAttr], scope: this, onItem: function(item){
					if(item){
						// There's already a matching item in store, use it
						this.pasteItem(item, null, parent, true, insertIndex);
					}else{
						// Create new item in the tree, based on the drag source.
						LnewItem=this.store.newItem(args, pInfo);
						if (LnewItem && (insertIndex!=undefined)){
							// Move new item to desired position
							this.pasteItem(LnewItem, parent, parent, false, insertIndex);
						}
					}
				}});
			}else{
				// [as far as we know] there is no id so we must assume this is a new item
				LnewItem=this.store.newItem(args, pInfo);
				if (LnewItem && (insertIndex!=undefined)){
					// Move new item to desired position
					this.pasteItem(LnewItem, parent, parent, false, insertIndex);
				}
			}
		},

		pasteItem: function(/*Item*/ childItem, /*Item*/ oldParentItem, /*Item*/ newParentItem, /*Boolean*/ bCopy, /*int?*/ insertIndex){
			// summary:
			//		Move or copy an item from one parent item to another.
			//		Used in drag & drop
			var store = this.store,
				parentAttr = this.childrenAttrs[0];	// name of "children" attr in parent item

			// remove child from source item, and record the attribute that child occurred in
			if(oldParentItem){
				dojo.forEach(this.childrenAttrs, function(attr){
					if(store.containsValue(oldParentItem, attr, childItem)){
						if(!bCopy){
							var values = dojo.filter(store.getValues(oldParentItem, attr), function(x){
								return x != childItem;
							});
							store.setValues(oldParentItem, attr, values);
						}
						parentAttr = attr;
					}
				});
			}

			// modify target item's children attribute to include this item
			if(newParentItem){
				if(typeof insertIndex == "number"){
					// call slice() to avoid modifying the original array, confusing the data store
					var childItems = store.getValues(newParentItem, parentAttr).slice();
					childItems.splice(insertIndex, 0, childItem);
					store.setValues(newParentItem, parentAttr, childItems);
				}else{
					store.setValues(newParentItem, parentAttr,
						store.getValues(newParentItem, parentAttr).concat(childItem));
				}
			}
		},

		// =======================================================================
		// Callbacks

		onChange: function(/*dojo.data.Item*/ item){
			// summary:
			//		Callback whenever an item has changed, so that Tree
			//		can update the label, icon, etc.   Note that changes
			//		to an item's children or parent(s) will trigger an
			//		onChildrenChange() so you can ignore those changes here.
			// tags:
			//		callback
		},

		onChildrenChange: function(/*dojo.data.Item*/ parent, /*dojo.data.Item[]*/ newChildrenList){
			// summary:
			//		Callback to do notifications about new, updated, or deleted items.
			// tags:
			//		callback
		},

		onDelete: function(/*dojo.data.Item*/ parent, /*dojo.data.Item[]*/ newChildrenList){
			// summary:
			//		Callback when an item has been deleted.
			// description:
			//		Note that there will also be an onChildrenChange() callback for the parent
			//		of this item.
			// tags:
			//		callback
		},

		// =======================================================================
		// Events from data store

		onNewItem: function(/* dojo.data.Item */ item, /* Object */ parentInfo){
			// summary:
			//		Handler for when new items appear in the store, either from a drop operation
			//		or some other way.   Updates the tree view (if necessary).
			// description:
			//		If the new item is a child of an existing item,
			//		calls onChildrenChange() with the new list of children
			//		for that existing item.
			//
			// tags:
			//		extension

			// We only care about the new item if it has a parent that corresponds to a TreeNode
			// we are currently displaying
			if(!parentInfo){
				return;
			}

			// Call onChildrenChange() on parent (ie, existing) item with new list of children
			// In the common case, the new list of children is simply parentInfo.newValue or
			// [ parentInfo.newValue ], although if items in the store has multiple
			// child attributes (see `childrenAttr`), then it's a superset of parentInfo.newValue,
			// so call getChildren() to be sure to get right answer.
			this.getChildren(parentInfo.item, dojo.hitch(this, function(children){
				this.onChildrenChange(parentInfo.item, children);
			}));
		},

		onDeleteItem: function(/*Object*/ item){
			// summary:
			//		Handler for delete notifications from underlying store
			this.onDelete(item);
		},

		onSetItem: function(/* item */ item,
						/* attribute-name-string */ attribute,
						/* object | array */ oldValue,
						/* object | array */ newValue){
			// summary:
			//		Updates the tree view according to changes in the data store.
			// description:
			//		Handles updates to an item's children by calling onChildrenChange(), and
			//		other updates to an item by calling onChange().
			//
			//		See `onNewItem` for more details on handling updates to an item's children.
			// tags:
			//		extension

			if(dojo.indexOf(this.childrenAttrs, attribute) != -1){
				// item's children list changed
				this.getChildren(item, dojo.hitch(this, function(children){
					// See comments in onNewItem() about calling getChildren()
					this.onChildrenChange(item, children);
				}));
			}else{
				// item's label/icon/etc. changed.
				this.onChange(item);
			}
		}
	});

}

if(!dojo._hasResource["dijit.tree.ForestStoreModel"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.tree.ForestStoreModel"] = true;
dojo.provide("dijit.tree.ForestStoreModel");



dojo.declare("dijit.tree.ForestStoreModel", dijit.tree.TreeStoreModel, {
	// summary:
	//		Interface between a dijit.Tree and a dojo.data store that doesn't have a root item,
	//		a.k.a. a store that has multiple "top level" items.
	//
	// description
	//		Use this class to wrap a dojo.data store, making all the items matching the specified query
	//		appear as children of a fabricated "root item".  If no query is specified then all the
	//		items returned by fetch() on the underlying store become children of the root item.
	//		This class allows dijit.Tree to assume a single root item, even if the store doesn't have one.
	//
	//		When using this class the developer must override a number of methods according to their app and
	//		data, including:
	//			- onNewRootItem
	//			- onAddToRoot
	//			- onLeaveRoot
	//			- onNewItem
	//			- onSetItem

	// Parameters to constructor

	// rootId: String
	//		ID of fabricated root item
	rootId: "$root$",

	// rootLabel: String
	//		Label of fabricated root item
	rootLabel: "ROOT",

	// query: String
	//		Specifies the set of children of the root item.
	// example:
	//	|	{type:'continent'}
	query: null,

	// End of parameters to constructor

	constructor: function(params){
		// summary:
		//		Sets up variables, etc.
		// tags:
		//		private

		// Make dummy root item
		this.root = {
			store: this,
			root: true,
			id: params.rootId,
			label: params.rootLabel,
			children: params.rootChildren	// optional param
		};
	},

	// =======================================================================
	// Methods for traversing hierarchy

	mayHaveChildren: function(/*dojo.data.Item*/ item){
		// summary:
		//		Tells if an item has or may have children.  Implementing logic here
		//		avoids showing +/- expando icon for nodes that we know don't have children.
		//		(For efficiency reasons we may not want to check if an element actually
		//		has children until user clicks the expando node)
		// tags:
		//		extension
		return item === this.root || this.inherited(arguments);
	},

	getChildren: function(/*dojo.data.Item*/ parentItem, /*function(items)*/ callback, /*function*/ onError){
		// summary:
		// 		Calls onComplete() with array of child items of given parent item, all loaded.
		if(parentItem === this.root){
			if(this.root.children){
				// already loaded, just return
				callback(this.root.children);
			}else{
				this.store.fetch({
					query: this.query,
					onComplete: dojo.hitch(this, function(items){
						this.root.children = items;
						callback(items);
					}),
					onError: onError
				});
			}
		}else{
			this.inherited(arguments);
		}
	},

	// =======================================================================
	// Inspecting items

	isItem: function(/* anything */ something){
		return (something === this.root) ? true : this.inherited(arguments);
	},

	fetchItemByIdentity: function(/* object */ keywordArgs){
		if(keywordArgs.identity == this.root.id){
			var scope = keywordArgs.scope?keywordArgs.scope:dojo.global;
			if(keywordArgs.onItem){
				keywordArgs.onItem.call(scope, this.root);
			}
		}else{
			this.inherited(arguments);
		}
	},

	getIdentity: function(/* item */ item){
		return (item === this.root) ? this.root.id : this.inherited(arguments);
	},

	getLabel: function(/* item */ item){
		return	(item === this.root) ? this.root.label : this.inherited(arguments);
	},

	// =======================================================================
	// Write interface

	newItem: function(/* dojo.dnd.Item */ args, /*Item*/ parent, /*int?*/ insertIndex){
		// summary:
		//		Creates a new item.   See dojo.data.api.Write for details on args.
		//		Used in drag & drop when item from external source dropped onto tree.
		if(parent === this.root){
			this.onNewRootItem(args);
			return this.store.newItem(args);
		}else{
			return this.inherited(arguments);
		}
	},

	onNewRootItem: function(args){
		// summary:
		//		User can override this method to modify a new element that's being
		//		added to the root of the tree, for example to add a flag like root=true
	},

	pasteItem: function(/*Item*/ childItem, /*Item*/ oldParentItem, /*Item*/ newParentItem, /*Boolean*/ bCopy, /*int?*/ insertIndex){
		// summary:
		//		Move or copy an item from one parent item to another.
		//		Used in drag & drop
		if(oldParentItem === this.root){
			if(!bCopy){
				// It's onLeaveRoot()'s responsibility to modify the item so it no longer matches
				// this.query... thus triggering an onChildrenChange() event to notify the Tree
				// that this element is no longer a child of the root node
				this.onLeaveRoot(childItem);
			}
		}
		dijit.tree.TreeStoreModel.prototype.pasteItem.call(this, childItem,
			oldParentItem === this.root ? null : oldParentItem,
			newParentItem === this.root ? null : newParentItem,
			bCopy,
			insertIndex
		);
		if(newParentItem === this.root){
			// It's onAddToRoot()'s responsibility to modify the item so it matches
			// this.query... thus triggering an onChildrenChange() event to notify the Tree
			// that this element is now a child of the root node
			this.onAddToRoot(childItem);
		}
	},

	// =======================================================================
	// Handling for top level children

	onAddToRoot: function(/* item */ item){
		// summary:
		//		Called when item added to root of tree; user must override this method
		//		to modify the item so that it matches the query for top level items
		// example:
		//	|	store.setValue(item, "root", true);
		// tags:
		//		extension
		console.log(this, ": item ", item, " added to root");
	},

	onLeaveRoot: function(/* item */ item){
		// summary:
		//		Called when item removed from root of tree; user must override this method
		//		to modify the item so it doesn't match the query for top level items
		// example:
		// 	|	store.unsetAttribute(item, "root");
		// tags:
		//		extension
		console.log(this, ": item ", item, " removed from root");
	},

	// =======================================================================
	// Events from data store

	_requeryTop: function(){
		// reruns the query for the children of the root node,
		// sending out an onSet notification if those children have changed
		var oldChildren = this.root.children || [];
		this.store.fetch({
			query: this.query,
			onComplete: dojo.hitch(this, function(newChildren){
				this.root.children = newChildren;

				// If the list of children or the order of children has changed...
				if(oldChildren.length != newChildren.length ||
					dojo.some(oldChildren, function(item, idx){ return newChildren[idx] != item;})){
					this.onChildrenChange(this.root, newChildren);
				}
			})
		});
	},

	onNewItem: function(/* dojo.data.Item */ item, /* Object */ parentInfo){
		// summary:
		//		Handler for when new items appear in the store.  Developers should override this
		//		method to be more efficient based on their app/data.
		// description:
		//		Note that the default implementation requeries the top level items every time
		//		a new item is created, since any new item could be a top level item (even in
		//		addition to being a child of another item, since items can have multiple parents).
		//
		//		If developers can detect which items are possible top level items (based on the item and the
		//		parentInfo parameters), they should override this method to only call _requeryTop() for top
		//		level items.  Often all top level items have parentInfo==null, but
		//		that will depend on which store you use and what your data is like.
		// tags:
		//		extension
		this._requeryTop();

		this.inherited(arguments);
	},

	onDeleteItem: function(/*Object*/ item){
		// summary:
		//		Handler for delete notifications from underlying store

		// check if this was a child of root, and if so send notification that root's children
		// have changed
		if(dojo.indexOf(this.root.children, item) != -1){
			this._requeryTop();
		}

		this.inherited(arguments);
	},

	onSetItem: function(/* item */ item,
					/* attribute-name-string */ attribute,
					/* object | array */ oldValue,
					/* object | array */ newValue){
		// summary:
		//		Updates the tree view according to changes to an item in the data store.
		//		Developers should override this method to be more efficient based on their app/data.
		// description:
		//		Handles updates to an item's children by calling onChildrenChange(), and
		//		other updates to an item by calling onChange().
		//
		//		Also, any change to any item re-executes the query for the tree's top-level items,
		//		since this modified item may have started/stopped matching the query for top level items.
		//
		//		If possible, developers should override this function to only call _requeryTop() when
		//		the change to the item has caused it to stop/start being a top level item in the tree.
		// tags:
		//		extension

		this._requeryTop();
		this.inherited(arguments);
	}

});

}

if(!dojo._hasResource["dojo.dnd.Container"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.Container"] = true;
dojo.provide("dojo.dnd.Container");




/*
	Container states:
		""		- normal state
		"Over"	- mouse over a container
	Container item states:
		""		- normal state
		"Over"	- mouse over a container item
*/

/*=====
dojo.declare("dojo.dnd.__ContainerArgs", [], {
	creator: function(){
		// summary:
		//		a creator function, which takes a data item, and returns an object like that:
		//		{node: newNode, data: usedData, type: arrayOfStrings}
	},

	// skipForm: Boolean
	//		don't start the drag operation, if clicked on form elements
	skipForm: false,

	// dropParent: Node||String
	//		node or node's id to use as the parent node for dropped items
	//		(must be underneath the 'node' parameter in the DOM)
	dropParent: null,

	// _skipStartup: Boolean
	//		skip startup(), which collects children, for deferred initialization
	//		(this is used in the markup mode)
	_skipStartup: false
});

dojo.dnd.Item = function(){
	// summary:
	//		Represents (one of) the source node(s) being dragged.
	//		Contains (at least) the "type" and "data" attributes.
	// type: String[]
	//		Type(s) of this item, by default this is ["text"]
	// data: Object
	//		Logical representation of the object being dragged.
	//		If the drag object's type is "text" then data is a String,
	//		if it's another type then data could be a different Object,
	//		perhaps a name/value hash.
	
	this.type = type;
	this.data = data;
}
=====*/

dojo.declare("dojo.dnd.Container", null, {
	// summary:
	//		a Container object, which knows when mouse hovers over it,
	//		and over which element it hovers
	
	// object attributes (for markup)
	skipForm: false,
	
	/*=====
	// current: DomNode
	//		The DOM node the mouse is currently hovered over
	current: null,
	
	// map: Hash<String, dojo.dnd.Item>
	//		Map from an item's id (which is also the DOMNode's id) to
	//		the dojo.dnd.Item itself.
	map: {},
	=====*/
	
	constructor: function(node, params){
		// summary:
		//		a constructor of the Container
		// node: Node
		//		node or node's id to build the container on
		// params: dojo.dnd.__ContainerArgs
		//		a dictionary of parameters
		this.node = dojo.byId(node);
		if(!params){ params = {}; }
		this.creator = params.creator || null;
		this.skipForm = params.skipForm;
		this.parent = params.dropParent && dojo.byId(params.dropParent);
		
		// class-specific variables
		this.map = {};
		this.current = null;

		// states
		this.containerState = "";
		dojo.addClass(this.node, "dojoDndContainer");
		
		// mark up children
		if(!(params && params._skipStartup)){
			this.startup();
		}

		// set up events
		this.events = [
			dojo.connect(this.node, "onmouseover", this, "onMouseOver"),
			dojo.connect(this.node, "onmouseout",  this, "onMouseOut"),
			// cancel text selection and text dragging
			dojo.connect(this.node, "ondragstart",   this, "onSelectStart"),
			dojo.connect(this.node, "onselectstart", this, "onSelectStart")
		];
	},
	
	// object attributes (for markup)
	creator: function(){
		// summary:
		//		creator function, dummy at the moment
	},
	
	// abstract access to the map
	getItem: function(/*String*/ key){
		// summary:
		//		returns a data item by its key (id)
		return this.map[key];	// dojo.dnd.Item
	},
	setItem: function(/*String*/ key, /*dojo.dnd.Item*/ data){
		// summary:
		//		associates a data item with its key (id)
		this.map[key] = data;
	},
	delItem: function(/*String*/ key){
		// summary:
		//		removes a data item from the map by its key (id)
		delete this.map[key];
	},
	forInItems: function(/*Function*/ f, /*Object?*/ o){
		// summary:
		//		iterates over a data map skipping members that
		//		are present in the empty object (IE and/or 3rd-party libraries).
		o = o || dojo.global;
		var m = this.map, e = dojo.dnd._empty;
		for(var i in m){
			if(i in e){ continue; }
			f.call(o, m[i], i, this);
		}
		return o;	// Object
	},
	clearItems: function(){
		// summary:
		//		removes all data items from the map
		this.map = {};
	},
	
	// methods
	getAllNodes: function(){
		// summary:
		//		returns a list (an array) of all valid child nodes
		return dojo.query("> .dojoDndItem", this.parent);	// NodeList
	},
	sync: function(){
		// summary:
		//		sync up the node list with the data map
		var map = {};
		this.getAllNodes().forEach(function(node){
			if(node.id){
				var item = this.getItem(node.id);
				if(item){
					map[node.id] = item;
					return;
				}
			}else{
				node.id = dojo.dnd.getUniqueId();
			}
			var type = node.getAttribute("dndType"),
				data = node.getAttribute("dndData");
			map[node.id] = {
				data: data || node.innerHTML,
				type: type ? type.split(/\s*,\s*/) : ["text"]
			};
		}, this);
		this.map = map;
		return this;	// self
	},
	insertNodes: function(data, before, anchor){
		// summary:
		//		inserts an array of new nodes before/after an anchor node
		// data: Array
		//		a list of data items, which should be processed by the creator function
		// before: Boolean
		//		insert before the anchor, if true, and after the anchor otherwise
		// anchor: Node
		//		the anchor node to be used as a point of insertion
		if(!this.parent.firstChild){
			anchor = null;
		}else if(before){
			if(!anchor){
				anchor = this.parent.firstChild;
			}
		}else{
			if(anchor){
				anchor = anchor.nextSibling;
			}
		}
		if(anchor){
			for(var i = 0; i < data.length; ++i){
				var t = this._normalizedCreator(data[i]);
				this.setItem(t.node.id, {data: t.data, type: t.type});
				this.parent.insertBefore(t.node, anchor);
			}
		}else{
			for(var i = 0; i < data.length; ++i){
				var t = this._normalizedCreator(data[i]);
				this.setItem(t.node.id, {data: t.data, type: t.type});
				this.parent.appendChild(t.node);
			}
		}
		return this;	// self
	},
	destroy: function(){
		// summary:
		//		prepares this object to be garbage-collected
		dojo.forEach(this.events, dojo.disconnect);
		this.clearItems();
		this.node = this.parent = this.current = null;
	},

	// markup methods
	markupFactory: function(params, node){
		params._skipStartup = true;
		return new dojo.dnd.Container(node, params);
	},
	startup: function(){
		// summary:
		//		collects valid child items and populate the map
		
		// set up the real parent node
		if(!this.parent){
			// use the standard algorithm, if not assigned
			this.parent = this.node;
			if(this.parent.tagName.toLowerCase() == "table"){
				var c = this.parent.getElementsByTagName("tbody");
				if(c && c.length){ this.parent = c[0]; }
			}
		}
		this.defaultCreator = dojo.dnd._defaultCreator(this.parent);

		// process specially marked children
		this.sync();
	},

	// mouse events
	onMouseOver: function(e){
		// summary:
		//		event processor for onmouseover
		// e: Event
		//		mouse event
		var n = e.relatedTarget;
		while(n){
			if(n == this.node){ break; }
			try{
				n = n.parentNode;
			}catch(x){
				n = null;
			}
		}
		if(!n){
			this._changeState("Container", "Over");
			this.onOverEvent();
		}
		n = this._getChildByEvent(e);
		if(this.current == n){ return; }
		if(this.current){ this._removeItemClass(this.current, "Over"); }
		if(n){ this._addItemClass(n, "Over"); }
		this.current = n;
	},
	onMouseOut: function(e){
		// summary:
		//		event processor for onmouseout
		// e: Event
		//		mouse event
		for(var n = e.relatedTarget; n;){
			if(n == this.node){ return; }
			try{
				n = n.parentNode;
			}catch(x){
				n = null;
			}
		}
		if(this.current){
			this._removeItemClass(this.current, "Over");
			this.current = null;
		}
		this._changeState("Container", "");
		this.onOutEvent();
	},
	onSelectStart: function(e){
		// summary:
		//		event processor for onselectevent and ondragevent
		// e: Event
		//		mouse event
		if(!this.skipForm || !dojo.dnd.isFormElement(e)){
			dojo.stopEvent(e);
		}
	},
	
	// utilities
	onOverEvent: function(){
		// summary:
		//		this function is called once, when mouse is over our container
	},
	onOutEvent: function(){
		// summary:
		//		this function is called once, when mouse is out of our container
	},
	_changeState: function(type, newState){
		// summary:
		//		changes a named state to new state value
		// type: String
		//		a name of the state to change
		// newState: String
		//		new state
		var prefix = "dojoDnd" + type;
		var state  = type.toLowerCase() + "State";
		//dojo.replaceClass(this.node, prefix + newState, prefix + this[state]);
		dojo.replaceClass(this.node, prefix + newState, prefix + this[state]);
		this[state] = newState;
	},
	_addItemClass: function(node, type){
		// summary:
		//		adds a class with prefix "dojoDndItem"
		// node: Node
		//		a node
		// type: String
		//		a variable suffix for a class name
		dojo.addClass(node, "dojoDndItem" + type);
	},
	_removeItemClass: function(node, type){
		// summary:
		//		removes a class with prefix "dojoDndItem"
		// node: Node
		//		a node
		// type: String
		//		a variable suffix for a class name
		dojo.removeClass(node, "dojoDndItem" + type);
	},
	_getChildByEvent: function(e){
		// summary:
		//		gets a child, which is under the mouse at the moment, or null
		// e: Event
		//		a mouse event
		var node = e.target;
		if(node){
			for(var parent = node.parentNode; parent; node = parent, parent = node.parentNode){
				if(parent == this.parent && dojo.hasClass(node, "dojoDndItem")){ return node; }
			}
		}
		return null;
	},
	_normalizedCreator: function(/*dojo.dnd.Item*/ item, /*String*/ hint){
		// summary:
		//		adds all necessary data to the output of the user-supplied creator function
		var t = (this.creator || this.defaultCreator).call(this, item, hint);
		if(!dojo.isArray(t.type)){ t.type = ["text"]; }
		if(!t.node.id){ t.node.id = dojo.dnd.getUniqueId(); }
		dojo.addClass(t.node, "dojoDndItem");
		return t;
	}
});

dojo.dnd._createNode = function(tag){
	// summary:
	//		returns a function, which creates an element of given tag
	//		(SPAN by default) and sets its innerHTML to given text
	// tag: String
	//		a tag name or empty for SPAN
	if(!tag){ return dojo.dnd._createSpan; }
	return function(text){	// Function
		return dojo.create(tag, {innerHTML: text});	// Node
	};
};

dojo.dnd._createTrTd = function(text){
	// summary:
	//		creates a TR/TD structure with given text as an innerHTML of TD
	// text: String
	//		a text for TD
	var tr = dojo.create("tr");
	dojo.create("td", {innerHTML: text}, tr);
	return tr;	// Node
};

dojo.dnd._createSpan = function(text){
	// summary:
	//		creates a SPAN element with given text as its innerHTML
	// text: String
	//		a text for SPAN
	return dojo.create("span", {innerHTML: text});	// Node
};

// dojo.dnd._defaultCreatorNodes: Object
//		a dictionary that maps container tag names to child tag names
dojo.dnd._defaultCreatorNodes = {ul: "li", ol: "li", div: "div", p: "div"};

dojo.dnd._defaultCreator = function(node){
	// summary:
	//		takes a parent node, and returns an appropriate creator function
	// node: Node
	//		a container node
	var tag = node.tagName.toLowerCase();
	var c = tag == "tbody" || tag == "thead" ? dojo.dnd._createTrTd :
			dojo.dnd._createNode(dojo.dnd._defaultCreatorNodes[tag]);
	return function(item, hint){	// Function
		var isObj = item && dojo.isObject(item), data, type, n;
		if(isObj && item.tagName && item.nodeType && item.getAttribute){
			// process a DOM node
			data = item.getAttribute("dndData") || item.innerHTML;
			type = item.getAttribute("dndType");
			type = type ? type.split(/\s*,\s*/) : ["text"];
			n = item;	// this node is going to be moved rather than copied
		}else{
			// process a DnD item object or a string
			data = (isObj && item.data) ? item.data : item;
			type = (isObj && item.type) ? item.type : ["text"];
			n = (hint == "avatar" ? dojo.dnd._createSpan : c)(String(data));
		}
		if(!n.id){
			n.id = dojo.dnd.getUniqueId();
		}
		return {node: n, data: data, type: type};
	};
};

}

if(!dojo._hasResource["dijit.tree._dndContainer"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.tree._dndContainer"] = true;
dojo.provide("dijit.tree._dndContainer");




dojo.getObject("tree", true, dojo);

dijit.tree._compareNodes = function(n1, n2){
	if(n1 === n2){
		return 0;
	}
	
	if('sourceIndex' in document.documentElement){ //IE
		//TODO: does not yet work if n1 and/or n2 is a text node
		return n1.sourceIndex - n2.sourceIndex;
	}else if('compareDocumentPosition' in document.documentElement){ //FF, Opera
		return n1.compareDocumentPosition(n2) & 2 ? 1: -1;
	}else if(document.createRange){ //Webkit
		var r1 = doc.createRange();
		r1.setStartBefore(n1);

		var r2 = doc.createRange();
		r2.setStartBefore(n2);

		return r1.compareBoundaryPoints(r1.END_TO_END, r2);
	}else{
		throw Error("dijit.tree._compareNodes don't know how to compare two different nodes in this browser");
	}
};

dojo.declare("dijit.tree._dndContainer",
	null,
	{

		// summary:
		//		This is a base class for `dijit.tree._dndSelector`, and isn't meant to be used directly.
		//		It's modeled after `dojo.dnd.Container`.
		// tags:
		//		protected

		/*=====
		// current: DomNode
		//		The currently hovered TreeNode.rowNode (which is the DOM node
		//		associated w/a given node in the tree, excluding it's descendants)
		current: null,
		=====*/

		constructor: function(tree, params){
			// summary:
			//		A constructor of the Container
			// tree: Node
			//		Node or node's id to build the container on
			// params: dijit.tree.__SourceArgs
			//		A dict of parameters, which gets mixed into the object
			// tags:
			//		private
			this.tree = tree;
			this.node = tree.domNode;	// TODO: rename; it's not a TreeNode but the whole Tree
			dojo.mixin(this, params);

			// class-specific variables
			this.map = {};
			this.current = null;	// current TreeNode's DOM node

			// states
			this.containerState = "";
			dojo.addClass(this.node, "dojoDndContainer");

			// set up events
			this.events = [
				// container level events
				dojo.connect(this.node, "onmouseenter", this, "onOverEvent"),
				dojo.connect(this.node, "onmouseleave",	this, "onOutEvent"),

				// switching between TreeNodes
				dojo.connect(this.tree, "_onNodeMouseEnter", this, "onMouseOver"),
				dojo.connect(this.tree, "_onNodeMouseLeave", this, "onMouseOut"),

				// cancel text selection and text dragging
				dojo.connect(this.node, "ondragstart", dojo, "stopEvent"),
				dojo.connect(this.node, "onselectstart", dojo, "stopEvent")
			];
		},

		getItem: function(/*String*/ key){
			// summary:
			//		Returns the dojo.dnd.Item (representing a dragged node) by it's key (id).
			//		Called by dojo.dnd.Source.checkAcceptance().
			// tags:
			//		protected

			var widget = this.selection[key],
				ret = {
					data: widget,
					type: ["treeNode"]
				};

			return ret;	// dojo.dnd.Item
		},

		destroy: function(){
			// summary:
			//		Prepares this object to be garbage-collected

			dojo.forEach(this.events, dojo.disconnect);
			// this.clearItems();
			this.node = this.parent = null;
		},

		// mouse events
		onMouseOver: function(/*TreeNode*/ widget, /*Event*/ evt){
			// summary:
			//		Called when mouse is moved over a TreeNode
			// tags:
			//		protected
			this.current = widget;
		},

		onMouseOut: function(/*TreeNode*/ widget, /*Event*/ evt){
			// summary:
			//		Called when mouse is moved away from a TreeNode
			// tags:
			//		protected
			this.current = null;
		},

		_changeState: function(type, newState){
			// summary:
			//		Changes a named state to new state value
			// type: String
			//		A name of the state to change
			// newState: String
			//		new state
			var prefix = "dojoDnd" + type;
			var state = type.toLowerCase() + "State";
			//dojo.replaceClass(this.node, prefix + newState, prefix + this[state]);
			dojo.replaceClass(this.node, prefix + newState, prefix + this[state]);
			this[state] = newState;
		},

		_addItemClass: function(node, type){
			// summary:
			//		Adds a class with prefix "dojoDndItem"
			// node: Node
			//		A node
			// type: String
			//		A variable suffix for a class name
			dojo.addClass(node, "dojoDndItem" + type);
		},

		_removeItemClass: function(node, type){
			// summary:
			//		Removes a class with prefix "dojoDndItem"
			// node: Node
			//		A node
			// type: String
			//		A variable suffix for a class name
			dojo.removeClass(node, "dojoDndItem" + type);
		},

		onOverEvent: function(){
			// summary:
			//		This function is called once, when mouse is over our container
			// tags:
			//		protected
			this._changeState("Container", "Over");
		},

		onOutEvent: function(){
			// summary:
			//		This function is called once, when mouse is out of our container
			// tags:
			//		protected
			this._changeState("Container", "");
		}
});

}

if(!dojo._hasResource["dijit.tree._dndSelector"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.tree._dndSelector"] = true;
dojo.provide("dijit.tree._dndSelector");




dojo.declare("dijit.tree._dndSelector",
	dijit.tree._dndContainer,
	{
		// summary:
		//		This is a base class for `dijit.tree.dndSource` , and isn't meant to be used directly.
		//		It's based on `dojo.dnd.Selector`.
		// tags:
		//		protected

		/*=====
		// selection: Hash<String, DomNode>
		//		(id, DomNode) map for every TreeNode that's currently selected.
		//		The DOMNode is the TreeNode.rowNode.
		selection: {},
		=====*/

		constructor: function(tree, params){
			// summary:
			//		Initialization
			// tags:
			//		private

			this.selection={};
			this.anchor = null;

			dijit.setWaiState(this.tree.domNode, "multiselect", !this.singular);

			this.events.push(
				dojo.connect(this.tree.domNode, "onmousedown", this,"onMouseDown"),
				dojo.connect(this.tree.domNode, "onmouseup", this,"onMouseUp"),
				dojo.connect(this.tree.domNode, "onmousemove", this,"onMouseMove")
			);
		},

		//	singular: Boolean
		//		Allows selection of only one element, if true.
		//		Tree hasn't been tested in singular=true mode, unclear if it works.
		singular: false,

		// methods
		getSelectedTreeNodes: function(){
			// summary:
			//		Returns a list of selected node(s).
			//		Used by dndSource on the start of a drag.
			// tags:
			//		protected
			var nodes=[], sel = this.selection;
			for(var i in sel){
				nodes.push(sel[i]);
			}
			return nodes;
		},

		selectNone: function(){
			// summary:
			//		Unselects all items
			// tags:
			//		private

			this.setSelection([]);
			return this;	// self
		},

		destroy: function(){
			// summary:
			//		Prepares the object to be garbage-collected
			this.inherited(arguments);
			this.selection = this.anchor = null;
		},
		addTreeNode: function(/*dijit._TreeNode*/node, /*Boolean?*/isAnchor){
			// summary
			//		add node to current selection
			// node: Node
			//		node to add
			// isAnchor: Boolean
			//		Whether the node should become anchor.

			this.setSelection(this.getSelectedTreeNodes().concat( [node] ));
			if(isAnchor){ this.anchor = node; }
			return node;
		},
		removeTreeNode: function(/*dijit._TreeNode*/node){
			// summary
			//		remove node from current selection
			// node: Node
			//		node to remove
			this.setSelection(this._setDifference(this.getSelectedTreeNodes(), [node]))
			return node;
		},
		isTreeNodeSelected: function(/*dijit._TreeNode*/node){
			// summary
			//		return true if node is currently selected
			// node: Node
			//		the node to check whether it's in the current selection

			return node.id && !!this.selection[node.id];
		},
		setSelection: function(/*dijit._treeNode[]*/ newSelection){
			// summary
			//      set the list of selected nodes to be exactly newSelection. All changes to the
			//      selection should be passed through this function, which ensures that derived
			//      attributes are kept up to date. Anchor will be deleted if it has been removed
			//      from the selection, but no new anchor will be added by this function.
			// newSelection: Node[]
			//      list of tree nodes to make selected
			var oldSelection = this.getSelectedTreeNodes();
			dojo.forEach(this._setDifference(oldSelection, newSelection), dojo.hitch(this, function(node){
				node.setSelected(false);
				if(this.anchor == node){
					delete this.anchor;
				}
				delete this.selection[node.id];
			}));
			dojo.forEach(this._setDifference(newSelection, oldSelection), dojo.hitch(this, function(node){
				node.setSelected(true);
				this.selection[node.id] = node;
			}));
			this._updateSelectionProperties();
		},
		_setDifference: function(xs,ys){
			// summary
			//      Returns a copy of xs which lacks any objects
			//      occurring in ys. Checks for membership by
			//      modifying and then reading the object, so it will
			//      not properly handle sets of numbers or strings.
			
			dojo.forEach(ys, function(y){ y.__exclude__ = true; });
			var ret = dojo.filter(xs, function(x){ return !x.__exclude__; });

			// clean up after ourselves.
			dojo.forEach(ys, function(y){ delete y['__exclude__'] });
			return ret;
		},
		_updateSelectionProperties: function() {
			// summary
			//      Update the following tree properties from the current selection:
			//      path[s], selectedItem[s], selectedNode[s]
			
			var selected = this.getSelectedTreeNodes();
			var paths = [], nodes = [];
			dojo.forEach(selected, function(node) {
				nodes.push(node);
				paths.push(node.getTreePath());
			});
			var items = dojo.map(nodes,function(node) { return node.item; });
			this.tree._set("paths", paths);
			this.tree._set("path", paths[0] || []);
			this.tree._set("selectedNodes", nodes);
			this.tree._set("selectedNode", nodes[0] || null);
			this.tree._set("selectedItems", items);
			this.tree._set("selectedItem", items[0] || null);
		},
		// mouse events
		onMouseDown: function(e){
			// summary:
			//		Event processor for onmousedown
			// e: Event
			//		mouse event
			// tags:
			//		protected

			// ignore click on expando node
			if(!this.current || this.tree.isExpandoNode( e.target, this.current)){ return; }

			if(e.button == dojo.mouseButtons.RIGHT){ return; }	// ignore right-click

			dojo.stopEvent(e);

			var treeNode = this.current,
			  copy = dojo.isCopyKey(e), id = treeNode.id;

			// if shift key is not pressed, and the node is already in the selection,
			// delay deselection until onmouseup so in the case of DND, deselection
			// will be canceled by onmousemove.
			if(!this.singular && !e.shiftKey && this.selection[id]){
				this._doDeselect = true;
				return;
			}else{
				this._doDeselect = false;
			}
			this.userSelect(treeNode, copy, e.shiftKey);
		},

		onMouseUp: function(e){
			// summary:
			//		Event processor for onmouseup
			// e: Event
			//		mouse event
			// tags:
			//		protected

			// _doDeselect is the flag to indicate that the user wants to either ctrl+click on
			// a already selected item (to deselect the item), or click on a not-yet selected item
			// (which should remove all current selection, and add the clicked item). This can not
			// be done in onMouseDown, because the user may start a drag after mousedown. By moving
			// the deselection logic here, the user can drags an already selected item.
			if(!this._doDeselect){ return; }
			this._doDeselect = false;
			this.userSelect(this.current, dojo.isCopyKey( e ), e.shiftKey);
		},
		onMouseMove: function(e){
			// summary
			//		event processor for onmousemove
			// e: Event
			//		mouse event
			this._doDeselect = false;
		},

		userSelect: function(node, multi, range){
			// summary:
			//		Add or remove the given node from selection, responding
			//      to a user action such as a click or keypress.
			// multi: Boolean
			//		Indicates whether this is meant to be a multi-select action (e.g. ctrl-click)
			// range: Boolean
			//		Indicates whether this is meant to be a ranged action (e.g. shift-click)
			// tags:
			//		protected

			if(this.singular){
				if(this.anchor == node && multi){
					this.selectNone();
				}else{
					this.setSelection([node]);
					this.anchor = node;
				}
			}else{
				if(range && this.anchor){
					var cr = dijit.tree._compareNodes(this.anchor.rowNode, node.rowNode),
					begin, end, anchor = this.anchor;
					
					if(cr < 0){ //current is after anchor
						begin = anchor;
						end = node;
					}else{ //current is before anchor
						begin = node;
						end = anchor;
					}
					nodes = [];
					//add everything betweeen begin and end inclusively
					while(begin != end) {
						nodes.push(begin)
						begin = this.tree._getNextNode(begin);
					}
					nodes.push(end)

					this.setSelection(nodes);
				}else{
				    if( this.selection[ node.id ] && multi ) {
						this.removeTreeNode( node );
				    } else if(multi) {
						this.addTreeNode(node, true);
					} else {
						this.setSelection([node]);
						this.anchor = node;
				    }
				}
			}
		},

		forInSelectedItems: function(/*Function*/ f, /*Object?*/ o){
			// summary:
			//		Iterates over selected items;
			//		see `dojo.dnd.Container.forInItems()` for details
			o = o || dojo.global;
			for(var id in this.selection){
				// console.log("selected item id: " + id);
				f.call(o, this.getItem(id), id, this);
			}
		}
});

}

if(!dojo._hasResource["dijit.Tree"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.Tree"] = true;
dojo.provide("dijit.Tree");













dojo.declare(
	"dijit._TreeNode",
	[dijit._Widget, dijit._Templated, dijit._Container, dijit._Contained, dijit._CssStateMixin],
{
	// summary:
	//		Single node within a tree.   This class is used internally
	//		by Tree and should not be accessed directly.
	// tags:
	//		private

	// item: [const] dojo.data.Item
	//		the dojo.data entry this tree represents
	item: null,

	// isTreeNode: [protected] Boolean
	//		Indicates that this is a TreeNode.   Used by `dijit.Tree` only,
	//		should not be accessed directly.
	isTreeNode: true,

	// label: String
	//		Text of this tree node
	label: "",

	// isExpandable: [private] Boolean
	//		This node has children, so show the expando node (+ sign)
	isExpandable: null,

	// isExpanded: [readonly] Boolean
	//		This node is currently expanded (ie, opened)
	isExpanded: false,

	// state: [private] String
	//		Dynamic loading-related stuff.
	//		When an empty folder node appears, it is "UNCHECKED" first,
	//		then after dojo.data query it becomes "LOADING" and, finally "LOADED"
	state: "UNCHECKED",

	templateString: dojo.cache("dijit", "templates/TreeNode.html", "<div class=\"dijitTreeNode\" role=\"presentation\"\n\t><div dojoAttachPoint=\"rowNode\" class=\"dijitTreeRow\" role=\"presentation\" dojoAttachEvent=\"onmouseenter:_onMouseEnter, onmouseleave:_onMouseLeave, onclick:_onClick, ondblclick:_onDblClick\"\n\t\t><img src=\"${_blankGif}\" alt=\"\" dojoAttachPoint=\"expandoNode\" class=\"dijitTreeExpando\" role=\"presentation\"\n\t\t/><span dojoAttachPoint=\"expandoNodeText\" class=\"dijitExpandoText\" role=\"presentation\"\n\t\t></span\n\t\t><span dojoAttachPoint=\"contentNode\"\n\t\t\tclass=\"dijitTreeContent\" role=\"presentation\">\n\t\t\t<img src=\"${_blankGif}\" alt=\"\" dojoAttachPoint=\"iconNode\" class=\"dijitIcon dijitTreeIcon\" role=\"presentation\"\n\t\t\t/><span dojoAttachPoint=\"labelNode\" class=\"dijitTreeLabel\" role=\"treeitem\" tabindex=\"-1\" aria-selected=\"false\" dojoAttachEvent=\"onfocus:_onLabelFocus\"></span>\n\t\t</span\n\t></div>\n\t<div dojoAttachPoint=\"containerNode\" class=\"dijitTreeContainer\" role=\"presentation\" style=\"display: none;\"></div>\n</div>\n"),

	baseClass: "dijitTreeNode",

	// For hover effect for tree node, and focus effect for label
	cssStateNodes: {
		rowNode: "dijitTreeRow",
		labelNode: "dijitTreeLabel"
	},

	attributeMap: dojo.delegate(dijit._Widget.prototype.attributeMap, {
		label: {node: "labelNode", type: "innerText"},
		tooltip: {node: "rowNode", type: "attribute", attribute: "title"}
	}),

	buildRendering: function(){
		this.inherited(arguments);

		// set expand icon for leaf
		this._setExpando();

		// set icon and label class based on item
		this._updateItemClasses(this.item);

		if(this.isExpandable){
			dijit.setWaiState(this.labelNode, "expanded", this.isExpanded);
		}

		//aria-selected should be false on all selectable elements.
		this.setSelected(false);
	},

	_setIndentAttr: function(indent){
		// summary:
		//		Tell this node how many levels it should be indented
		// description:
		//		0 for top level nodes, 1 for their children, 2 for their
		//		grandchildren, etc.

		// Math.max() is to prevent negative padding on hidden root node (when indent == -1)
		var pixels = (Math.max(indent, 0) * this.tree._nodePixelIndent) + "px";

		dojo.style(this.domNode, "backgroundPosition",	pixels + " 0px");
		dojo.style(this.rowNode, this.isLeftToRight() ? "paddingLeft" : "paddingRight", pixels);

		dojo.forEach(this.getChildren(), function(child){
			child.set("indent", indent+1);
		});
		
		this._set("indent", indent);
	},

	markProcessing: function(){
		// summary:
		//		Visually denote that tree is loading data, etc.
		// tags:
		//		private
		this.state = "LOADING";
		this._setExpando(true);
	},

	unmarkProcessing: function(){
		// summary:
		//		Clear markup from markProcessing() call
		// tags:
		//		private
		this._setExpando(false);
	},

	_updateItemClasses: function(item){
		// summary:
		//		Set appropriate CSS classes for icon and label dom node
		//		(used to allow for item updates to change respective CSS)
		// tags:
		//		private
		var tree = this.tree, model = tree.model;
		if(tree._v10Compat && item === model.root){
			// For back-compat with 1.0, need to use null to specify root item (TODO: remove in 2.0)
			item = null;
		}
		this._applyClassAndStyle(item, "icon", "Icon");
		this._applyClassAndStyle(item, "label", "Label");
		this._applyClassAndStyle(item, "row", "Row");
	},

	_applyClassAndStyle: function(item, lower, upper){
		// summary:
		//		Set the appropriate CSS classes and styles for labels, icons and rows.
		//
		// item:
		//		The data item.
		//
		// lower:
		//		The lower case attribute to use, e.g. 'icon', 'label' or 'row'.
		//
		// upper:
		//		The upper case attribute to use, e.g. 'Icon', 'Label' or 'Row'.
		//
		// tags:
		//		private

		var clsName = "_" + lower + "Class";
		var nodeName = lower + "Node";
		var oldCls = this[clsName];

		this[clsName] = this.tree["get" + upper + "Class"](item, this.isExpanded);
		dojo.replaceClass(this[nodeName], this[clsName] || "", oldCls || "");
 
		dojo.style(this[nodeName], this.tree["get" + upper + "Style"](item, this.isExpanded) || {});
 	},

	_updateLayout: function(){
		// summary:
		//		Set appropriate CSS classes for this.domNode
		// tags:
		//		private
		var parent = this.getParent();
		if(!parent || parent.rowNode.style.display == "none"){
			/* if we are hiding the root node then make every first level child look like a root node */
			dojo.addClass(this.domNode, "dijitTreeIsRoot");
		}else{
			dojo.toggleClass(this.domNode, "dijitTreeIsLast", !this.getNextSibling());
		}
	},

	_setExpando: function(/*Boolean*/ processing){
		// summary:
		//		Set the right image for the expando node
		// tags:
		//		private

		var styles = ["dijitTreeExpandoLoading", "dijitTreeExpandoOpened",
						"dijitTreeExpandoClosed", "dijitTreeExpandoLeaf"],
			_a11yStates = ["*","-","+","*"],
			idx = processing ? 0 : (this.isExpandable ?	(this.isExpanded ? 1 : 2) : 3);

		// apply the appropriate class to the expando node
		dojo.replaceClass(this.expandoNode, styles[idx], styles);

		// provide a non-image based indicator for images-off mode
		this.expandoNodeText.innerHTML = _a11yStates[idx];

	},

	expand: function(){
		// summary:
		//		Show my children
		// returns:
		//		Deferred that fires when expansion is complete

		// If there's already an expand in progress or we are already expanded, just return
		if(this._expandDeferred){
			return this._expandDeferred;		// dojo.Deferred
		}

		// cancel in progress collapse operation
		this._wipeOut && this._wipeOut.stop();

		// All the state information for when a node is expanded, maybe this should be
		// set when the animation completes instead
		this.isExpanded = true;
		dijit.setWaiState(this.labelNode, "expanded", "true");
		if(this.tree.showRoot || this !== this.tree.rootNode){
			dijit.setWaiRole(this.containerNode, "group");
		}
		dojo.addClass(this.contentNode,'dijitTreeContentExpanded');
		this._setExpando();
		this._updateItemClasses(this.item);
		if(this == this.tree.rootNode){
			dijit.setWaiState(this.tree.domNode, "expanded", "true");
		}

		var def,
			wipeIn = dojo.fx.wipeIn({
				node: this.containerNode, duration: dijit.defaultDuration,
				onEnd: function(){
					def.callback(true);
				}
			});

		// Deferred that fires when expand is complete
		def = (this._expandDeferred = new dojo.Deferred(function(){
			// Canceller
			wipeIn.stop();
		}));

		wipeIn.play();

		return def;		// dojo.Deferred
	},

	collapse: function(){
		// summary:
		//		Collapse this node (if it's expanded)

		if(!this.isExpanded){ return; }

		// cancel in progress expand operation
		if(this._expandDeferred){
			this._expandDeferred.cancel();
			delete this._expandDeferred;
		}

		this.isExpanded = false;
		dijit.setWaiState(this.labelNode, "expanded", "false");
		if(this == this.tree.rootNode){
			dijit.setWaiState(this.tree.domNode, "expanded", "false");
		}
		dojo.removeClass(this.contentNode,'dijitTreeContentExpanded');
		this._setExpando();
		this._updateItemClasses(this.item);

		if(!this._wipeOut){
			this._wipeOut = dojo.fx.wipeOut({
				node: this.containerNode, duration: dijit.defaultDuration
			});
		}
		this._wipeOut.play();
	},

	// indent: Integer
	//		Levels from this node to the root node
	indent: 0,

	setChildItems: function(/* Object[] */ items){
		// summary:
		//		Sets the child items of this node, removing/adding nodes
		//		from current children to match specified items[] array.
		//		Also, if this.persist == true, expands any children that were previously
		// 		opened.
		// returns:
		//		Deferred object that fires after all previously opened children
		//		have been expanded again (or fires instantly if there are no such children).

		var tree = this.tree,
			model = tree.model,
			defs = [];	// list of deferreds that need to fire before I am complete


		// Orphan all my existing children.
		// If items contains some of the same items as before then we will reattach them.
		// Don't call this.removeChild() because that will collapse the tree etc.
		dojo.forEach(this.getChildren(), function(child){
			dijit._Container.prototype.removeChild.call(this, child);
		}, this);

		this.state = "LOADED";

		if(items && items.length > 0){
			this.isExpandable = true;

			// Create _TreeNode widget for each specified tree node, unless one already
			// exists and isn't being used (presumably it's from a DnD move and was recently
			// released
			dojo.forEach(items, function(item){
				var id = model.getIdentity(item),
					existingNodes = tree._itemNodesMap[id],
					node;
				if(existingNodes){
					for(var i=0;i<existingNodes.length;i++){
						if(existingNodes[i] && !existingNodes[i].getParent()){
							node = existingNodes[i];
							node.set('indent', this.indent+1);
							break;
						}
					}
				}
				if(!node){
					node = this.tree._createTreeNode({
							item: item,
							tree: tree,
							isExpandable: model.mayHaveChildren(item),
							label: tree.getLabel(item),
							tooltip: tree.getTooltip(item),
							dir: tree.dir,
							lang: tree.lang,
							indent: this.indent + 1
						});
					if(existingNodes){
						existingNodes.push(node);
					}else{
						tree._itemNodesMap[id] = [node];
					}
				}
				this.addChild(node);

				// If node was previously opened then open it again now (this may trigger
				// more data store accesses, recursively)
				if(this.tree.autoExpand || this.tree._state(item)){
					defs.push(tree._expandNode(node));
				}
			}, this);

			// note that updateLayout() needs to be called on each child after
			// _all_ the children exist
			dojo.forEach(this.getChildren(), function(child, idx){
				child._updateLayout();
			});
		}else{
			this.isExpandable=false;
		}

		if(this._setExpando){
			// change expando to/from dot or + icon, as appropriate
			this._setExpando(false);
		}

		// Set leaf icon or folder icon, as appropriate
		this._updateItemClasses(this.item);

		// On initial tree show, make the selected TreeNode as either the root node of the tree,
		// or the first child, if the root node is hidden
		if(this == tree.rootNode){
			var fc = this.tree.showRoot ? this : this.getChildren()[0];
			if(fc){
				fc.setFocusable(true);
				tree.lastFocused = fc;
			}else{
				// fallback: no nodes in tree so focus on Tree <div> itself
				tree.domNode.setAttribute("tabIndex", "0");
			}
		}

		return new dojo.DeferredList(defs);	// dojo.Deferred
	},

	getTreePath: function(){
		var node = this;
		var path = [];
		while(node && node !== this.tree.rootNode){
				path.unshift(node.item);
				node = node.getParent();
		}
		path.unshift(this.tree.rootNode.item);

		return path;
	},

	getIdentity: function() {
		return this.tree.model.getIdentity(this.item);
	},

	removeChild: function(/* treeNode */ node){
		this.inherited(arguments);

		var children = this.getChildren();
		if(children.length == 0){
			this.isExpandable = false;
			this.collapse();
		}

		dojo.forEach(children, function(child){
				child._updateLayout();
		});
	},

	makeExpandable: function(){
		// summary:
		//		if this node wasn't already showing the expando node,
		//		turn it into one and call _setExpando()

		// TODO: hmm this isn't called from anywhere, maybe should remove it for 2.0

		this.isExpandable = true;
		this._setExpando(false);
	},

	_onLabelFocus: function(evt){
		// summary:
		//		Called when this row is focused (possibly programatically)
		//		Note that we aren't using _onFocus() builtin to dijit
		//		because it's called when focus is moved to a descendant TreeNode.
		// tags:
		//		private
		this.tree._onNodeFocus(this);
	},

	setSelected: function(/*Boolean*/ selected){
		// summary:
		//		A Tree has a (single) currently selected node.
		//		Mark that this node is/isn't that currently selected node.
		// description:
		//		In particular, setting a node as selected involves setting tabIndex
		//		so that when user tabs to the tree, focus will go to that node (only).
		dijit.setWaiState(this.labelNode, "selected", selected);
		dojo.toggleClass(this.rowNode, "dijitTreeRowSelected", selected);
	},

	setFocusable: function(/*Boolean*/ selected){
		// summary:
		//		A Tree has a (single) node that's focusable.
		//		Mark that this node is/isn't that currently focsuable node.
		// description:
		//		In particular, setting a node as selected involves setting tabIndex
		//		so that when user tabs to the tree, focus will go to that node (only).

		this.labelNode.setAttribute("tabIndex", selected ? "0" : "-1");
	},

	_onClick: function(evt){
		// summary:
		//		Handler for onclick event on a node
		// tags:
		//		private
		this.tree._onClick(this, evt);
	},
	_onDblClick: function(evt){
		// summary:
		//		Handler for ondblclick event on a node
		// tags:
		//		private
		this.tree._onDblClick(this, evt);
	},

	_onMouseEnter: function(evt){
		// summary:
		//		Handler for onmouseenter event on a node
		// tags:
		//		private
		this.tree._onNodeMouseEnter(this, evt);
	},

	_onMouseLeave: function(evt){
		// summary:
		//		Handler for onmouseenter event on a node
		// tags:
		//		private
		this.tree._onNodeMouseLeave(this, evt);
	}
});

dojo.declare(
	"dijit.Tree",
	[dijit._Widget, dijit._Templated],
{
	// summary:
	//		This widget displays hierarchical data from a store.

	// store: [deprecated] String||dojo.data.Store
	//		Deprecated.  Use "model" parameter instead.
	//		The store to get data to display in the tree.
	store: null,

	// model: dijit.Tree.model
	//		Interface to read tree data, get notifications of changes to tree data,
	//		and for handling drop operations (i.e drag and drop onto the tree)
	model: null,

	// query: [deprecated] anything
	//		Deprecated.  User should specify query to the model directly instead.
	//		Specifies datastore query to return the root item or top items for the tree.
	query: null,

	// label: [deprecated] String
	//		Deprecated.  Use dijit.tree.ForestStoreModel directly instead.
	//		Used in conjunction with query parameter.
	//		If a query is specified (rather than a root node id), and a label is also specified,
	//		then a fake root node is created and displayed, with this label.
	label: "",

	// showRoot: [const] Boolean
	//		Should the root node be displayed, or hidden?
	showRoot: true,

	// childrenAttr: [deprecated] String[]
	//		Deprecated.   This information should be specified in the model.
	//		One ore more attributes that holds children of a tree node
	childrenAttr: ["children"],

	// paths: String[][] or Item[][]
	//		Full paths from rootNode to selected nodes expressed as array of items or array of ids.
	//		Since setting the paths may be asynchronous (because ofwaiting on dojo.data), set("paths", ...)
	//		returns a Deferred to indicate when the set is complete.
	paths: [],
	
	// path: String[] or Item[]
	//      Backward compatible singular variant of paths.
	path: [],

	// selectedItems: [readonly] Item[]
	//		The currently selected items in this tree.
	//		This property can only be set (via set('selectedItems', ...)) when that item is already
	//		visible in the tree.   (I.e. the tree has already been expanded to show that node.)
	//		Should generally use `paths` attribute to set the selected items instead.
	selectedItems: null,

	// selectedItem: [readonly] Item
	//      Backward compatible singular variant of selectedItems.
	selectedItem: null,

	// openOnClick: Boolean
	//		If true, clicking a folder node's label will open it, rather than calling onClick()
	openOnClick: false,

	// openOnDblClick: Boolean
	//		If true, double-clicking a folder node's label will open it, rather than calling onDblClick()
	openOnDblClick: false,

	templateString: dojo.cache("dijit", "templates/Tree.html", "<div class=\"dijitTree dijitTreeContainer\" role=\"tree\"\n\tdojoAttachEvent=\"onkeypress:_onKeyPress\">\n\t<div class=\"dijitInline dijitTreeIndent\" style=\"position: absolute; top: -9999px\" dojoAttachPoint=\"indentDetector\"></div>\n</div>\n"),

	// persist: Boolean
	//		Enables/disables use of cookies for state saving.
	persist: true,

	// autoExpand: Boolean
	//		Fully expand the tree on load.   Overrides `persist`.
	autoExpand: false,

	// dndController: [protected] String
	//		Class name to use as as the dnd controller.  Specifying this class enables DnD.
	//		Generally you should specify this as "dijit.tree.dndSource".
	//      Default of "dijit.tree._dndSelector" handles selection only (no actual DnD).
	dndController: "dijit.tree._dndSelector",

	// parameters to pull off of the tree and pass on to the dndController as its params
	dndParams: ["onDndDrop","itemCreator","onDndCancel","checkAcceptance", "checkItemAcceptance", "dragThreshold", "betweenThreshold"],

	//declare the above items so they can be pulled from the tree's markup

	// onDndDrop: [protected] Function
	//		Parameter to dndController, see `dijit.tree.dndSource.onDndDrop`.
	//		Generally this doesn't need to be set.
	onDndDrop: null,

	/*=====
	itemCreator: function(nodes, target, source){
		// summary:
		//		Returns objects passed to `Tree.model.newItem()` based on DnD nodes
		//		dropped onto the tree.   Developer must override this method to enable
		// 		dropping from external sources onto this Tree, unless the Tree.model's items
		//		happen to look like {id: 123, name: "Apple" } with no other attributes.
		// description:
		//		For each node in nodes[], which came from source, create a hash of name/value
		//		pairs to be passed to Tree.model.newItem().  Returns array of those hashes.
		// nodes: DomNode[]
		//		The DOMNodes dragged from the source container
		// target: DomNode
		//		The target TreeNode.rowNode
		// source: dojo.dnd.Source
		//		The source container the nodes were dragged from, perhaps another Tree or a plain dojo.dnd.Source
		// returns: Object[]
		//		Array of name/value hashes for each new item to be added to the Tree, like:
		// |	[
		// |		{ id: 123, label: "apple", foo: "bar" },
		// |		{ id: 456, label: "pear", zaz: "bam" }
		// |	]
		// tags:
		//		extension
		return [{}];
	},
	=====*/
	itemCreator: null,

	// onDndCancel: [protected] Function
	//		Parameter to dndController, see `dijit.tree.dndSource.onDndCancel`.
	//		Generally this doesn't need to be set.
	onDndCancel: null,

/*=====
	checkAcceptance: function(source, nodes){
		// summary:
		//		Checks if the Tree itself can accept nodes from this source
		// source: dijit.tree._dndSource
		//		The source which provides items
		// nodes: DOMNode[]
		//		Array of DOM nodes corresponding to nodes being dropped, dijitTreeRow nodes if
		//		source is a dijit.Tree.
		// tags:
		//		extension
		return true;	// Boolean
	},
=====*/
	checkAcceptance: null,

/*=====
	checkItemAcceptance: function(target, source, position){
		// summary:
		//		Stub function to be overridden if one wants to check for the ability to drop at the node/item level
		// description:
		//		In the base case, this is called to check if target can become a child of source.
		//		When betweenThreshold is set, position="before" or "after" means that we
		//		are asking if the source node can be dropped before/after the target node.
		// target: DOMNode
		//		The dijitTreeRoot DOM node inside of the TreeNode that we are dropping on to
		//		Use dijit.getEnclosingWidget(target) to get the TreeNode.
		// source: dijit.tree.dndSource
		//		The (set of) nodes we are dropping
		// position: String
		//		"over", "before", or "after"
		// tags:
		//		extension
		return true;	// Boolean
	},
=====*/
	checkItemAcceptance: null,

	// dragThreshold: Integer
	//		Number of pixels mouse moves before it's considered the start of a drag operation
	dragThreshold: 5,

	// betweenThreshold: Integer
	//		Set to a positive value to allow drag and drop "between" nodes.
	//
	//		If during DnD mouse is over a (target) node but less than betweenThreshold
	//		pixels from the bottom edge, dropping the the dragged node will make it
	//		the next sibling of the target node, rather than the child.
	//
	//		Similarly, if mouse is over a target node but less that betweenThreshold
	//		pixels from the top edge, dropping the dragged node will make it
	//		the target node's previous sibling rather than the target node's child.
	betweenThreshold: 0,

	// _nodePixelIndent: Integer
	//		Number of pixels to indent tree nodes (relative to parent node).
	//		Default is 19 but can be overridden by setting CSS class dijitTreeIndent
	//		and calling resize() or startup() on tree after it's in the DOM.
	_nodePixelIndent: 19,

	_publish: function(/*String*/ topicName, /*Object*/ message){
		// summary:
		//		Publish a message for this widget/topic
		dojo.publish(this.id, [dojo.mixin({tree: this, event: topicName}, message || {})]);
	},

	postMixInProperties: function(){
		this.tree = this;

		if(this.autoExpand){
			// There's little point in saving opened/closed state of nodes for a Tree
			// that initially opens all it's nodes.
			this.persist = false;
		}

		this._itemNodesMap={};

		if(!this.cookieName){
			this.cookieName = this.id + "SaveStateCookie";
		}

		this._loadDeferred = new dojo.Deferred();

		this.inherited(arguments);
	},

	postCreate: function(){
		this._initState();

		// Create glue between store and Tree, if not specified directly by user
		if(!this.model){
			this._store2model();
		}

		// monitor changes to items
		this.connect(this.model, "onChange", "_onItemChange");
		this.connect(this.model, "onChildrenChange", "_onItemChildrenChange");
		this.connect(this.model, "onDelete", "_onItemDelete");

		this._load();

		this.inherited(arguments);

		if(this.dndController){
			if(dojo.isString(this.dndController)){
				this.dndController = dojo.getObject(this.dndController);
			}
			var params={};
			for(var i=0; i<this.dndParams.length;i++){
				if(this[this.dndParams[i]]){
					params[this.dndParams[i]] = this[this.dndParams[i]];
				}
			}
			this.dndController = new this.dndController(this, params);
		}
	},

	_store2model: function(){
		// summary:
		//		User specified a store&query rather than model, so create model from store/query
		this._v10Compat = true;
		dojo.deprecated("Tree: from version 2.0, should specify a model object rather than a store/query");

		var modelParams = {
			id: this.id + "_ForestStoreModel",
			store: this.store,
			query: this.query,
			childrenAttrs: this.childrenAttr
		};

		// Only override the model's mayHaveChildren() method if the user has specified an override
		if(this.params.mayHaveChildren){
			modelParams.mayHaveChildren = dojo.hitch(this, "mayHaveChildren");
		}

		if(this.params.getItemChildren){
			modelParams.getChildren = dojo.hitch(this, function(item, onComplete, onError){
				this.getItemChildren((this._v10Compat && item === this.model.root) ? null : item, onComplete, onError);
			});
		}
		this.model = new dijit.tree.ForestStoreModel(modelParams);

		// For backwards compatibility, the visibility of the root node is controlled by
		// whether or not the user has specified a label
		this.showRoot = Boolean(this.label);
	},

	onLoad: function(){
		// summary:
		//		Called when tree finishes loading and expanding.
		// description:
		//		If persist == true the loading may encompass many levels of fetches
		//		from the data store, each asynchronous.   Waits for all to finish.
		// tags:
		//		callback
	},

	_load: function(){
		// summary:
		//		Initial load of the tree.
		//		Load root node (possibly hidden) and it's children.
		this.model.getRoot(
			dojo.hitch(this, function(item){
				var rn = (this.rootNode = this.tree._createTreeNode({
					item: item,
					tree: this,
					isExpandable: true,
					label: this.label || this.getLabel(item),
					indent: this.showRoot ? 0 : -1
				}));
				if(!this.showRoot){
					rn.rowNode.style.display="none";
					// if root is not visible, move tree role to the invisible
					// root node's containerNode, see #12135
					dijit.setWaiRole(this.domNode, 'presentation');
					
					dijit.setWaiRole(rn.labelNode, 'presentation');
					dijit.setWaiRole(rn.containerNode, 'tree');
				}
				this.domNode.appendChild(rn.domNode);
				var identity = this.model.getIdentity(item);
				if(this._itemNodesMap[identity]){
					this._itemNodesMap[identity].push(rn);
				}else{
					this._itemNodesMap[identity] = [rn];
				}

				rn._updateLayout();		// sets "dijitTreeIsRoot" CSS classname

				// load top level children and then fire onLoad() event
				this._expandNode(rn).addCallback(dojo.hitch(this, function(){
					this._loadDeferred.callback(true);
					this.onLoad();
				}));
			}),
			function(err){
				console.error(this, ": error loading root: ", err);
			}
		);
	},

	getNodesByItem: function(/*dojo.data.Item or id*/ item){
		// summary:
		//		Returns all tree nodes that refer to an item
		// returns:
		//		Array of tree nodes that refer to passed item

		if(!item){ return []; }
		var identity = dojo.isString(item) ? item : this.model.getIdentity(item);
		// return a copy so widget don't get messed up by changes to returned array
		return [].concat(this._itemNodesMap[identity]);
	},

	_setSelectedItemAttr: function(/*dojo.data.Item or id*/ item){
		this.set('selectedItems', [item]);
	},

	_setSelectedItemsAttr: function(/*dojo.data.Items or ids*/ items){
		// summary:
		//		Select tree nodes related to passed items.
		//		WARNING: if model use multi-parented items or desired tree node isn't already loaded
		//		behavior is undefined. Use set('paths', ...) instead.
		var tree = this;
		this._loadDeferred.addCallback( dojo.hitch(this, function(){
			var identities = dojo.map(items, function(item){
				return (!item || dojo.isString(item)) ? item : tree.model.getIdentity(item);
			});
			var nodes = [];
			dojo.forEach(identities, function(id){
				nodes = nodes.concat(tree._itemNodesMap[id] || []);
			});
			this.set('selectedNodes', nodes);
		}));
	},

	_setPathAttr: function(/*Item[] || String[]*/ path){
		// summary:
		//      Singular variant of _setPathsAttr
		if(path.length) {
			return this.set("paths", [path]);
		} else {
			//Empty list is interpreted as "select nothing"
			return this.set("paths", []);
		}
	},
	
	_setPathsAttr: function(/*Item[][] || String[][]*/ paths){
		// summary:
		//		Select the tree nodes identified by passed paths.
		// paths:
		//		Array of arrays of items or item id's
		// returns:
		//		Deferred to indicate when the set is complete
		var tree = this;

		// We may need to wait for some nodes to expand, so setting
		// each path will involve a Deferred. We bring those deferreds
		// together witha DeferredList.
		return new dojo.DeferredList(dojo.map(paths, function(path){
			var d = new dojo.Deferred();
			
			// normalize path to use identity
			path = dojo.map(path, function(item){
				return dojo.isString(item) ? item : tree.model.getIdentity(item);
			});

			if(path.length){
				// Wait for the tree to load, if it hasn't already.
				tree._loadDeferred.addCallback(function(){ selectPath(path, [tree.rootNode], d); });
			}else{
				d.errback("Empty path");
			}
			return d;
		})).addCallback(setNodes);

		function selectPath(path, nodes, def){
			// Traverse path; the next path component should be among "nodes".
			var nextPath = path.shift();
			var nextNode = dojo.filter(nodes, function(node){
				return node.getIdentity() == nextPath;
			})[0];
			if(!!nextNode){
				if(path.length){
					tree._expandNode(nextNode).addCallback(function(){ selectPath(path, nextNode.getChildren(), def); });
				}else{
					//Successfully reached the end of this path
					def.callback(nextNode);
				}
			} else {
				def.errback("Could not expand path at " + nextPath);
			}
		}
		
		function setNodes(newNodes){
			//After all expansion is finished, set the selection to
			//the set of nodes successfully found.
			tree.set("selectedNodes", dojo.map(
				dojo.filter(newNodes,function(x){return x[0];}),
				function(x){return x[1];}));
		}
	},

	_setSelectedNodeAttr: function(node){
		this.set('selectedNodes', [node]);
	},
	_setSelectedNodesAttr: function(nodes){
		this._loadDeferred.addCallback( dojo.hitch(this, function(){
			this.dndController.setSelection(nodes);
		}));
	},


	////////////// Data store related functions //////////////////////
	// These just get passed to the model; they are here for back-compat

	mayHaveChildren: function(/*dojo.data.Item*/ item){
		// summary:
		//		Deprecated.   This should be specified on the model itself.
		//
		//		Overridable function to tell if an item has or may have children.
		//		Controls whether or not +/- expando icon is shown.
		//		(For efficiency reasons we may not want to check if an element actually
		//		has children until user clicks the expando node)
		// tags:
		//		deprecated
	},

	getItemChildren: function(/*dojo.data.Item*/ parentItem, /*function(items)*/ onComplete){
		// summary:
		//		Deprecated.   This should be specified on the model itself.
		//
		// 		Overridable function that return array of child items of given parent item,
		//		or if parentItem==null then return top items in tree
		// tags:
		//		deprecated
	},

	///////////////////////////////////////////////////////
	// Functions for converting an item to a TreeNode
	getLabel: function(/*dojo.data.Item*/ item){
		// summary:
		//		Overridable function to get the label for a tree node (given the item)
		// tags:
		//		extension
		return this.model.getLabel(item);	// String
	},

	getIconClass: function(/*dojo.data.Item*/ item, /*Boolean*/ opened){
		// summary:
		//		Overridable function to return CSS class name to display icon
		// tags:
		//		extension
		return (!item || this.model.mayHaveChildren(item)) ? (opened ? "dijitFolderOpened" : "dijitFolderClosed") : "dijitLeaf"
	},

	getLabelClass: function(/*dojo.data.Item*/ item, /*Boolean*/ opened){
		// summary:
		//		Overridable function to return CSS class name to display label
		// tags:
		//		extension
	},

	getRowClass: function(/*dojo.data.Item*/ item, /*Boolean*/ opened){
		// summary:
		//		Overridable function to return CSS class name to display row
		// tags:
		//		extension
	},

	getIconStyle: function(/*dojo.data.Item*/ item, /*Boolean*/ opened){
		// summary:
		//		Overridable function to return CSS styles to display icon
		// returns:
		//		Object suitable for input to dojo.style() like {backgroundImage: "url(...)"}
		// tags:
		//		extension
	},

	getLabelStyle: function(/*dojo.data.Item*/ item, /*Boolean*/ opened){
		// summary:
		//		Overridable function to return CSS styles to display label
		// returns:
		//		Object suitable for input to dojo.style() like {color: "red", background: "green"}
		// tags:
		//		extension
	},

	getRowStyle: function(/*dojo.data.Item*/ item, /*Boolean*/ opened){
		// summary:
		//		Overridable function to return CSS styles to display row
		// returns:
		//		Object suitable for input to dojo.style() like {background-color: "#bbb"}
		// tags:
		//		extension
	},

	getTooltip: function(/*dojo.data.Item*/ item){
		// summary:
		//		Overridable function to get the tooltip for a tree node (given the item)
		// tags:
		//		extension
		return "";	// String
	},

	/////////// Keyboard and Mouse handlers ////////////////////

	_onKeyPress: function(/*Event*/ e){
		// summary:
		//		Translates keypress events into commands for the controller
		if(e.altKey){ return; }
		var dk = dojo.keys;
		var treeNode = dijit.getEnclosingWidget(e.target);
		if(!treeNode){ return; }

		var key = e.charOrCode;
		if(typeof key == "string" && key != " "){	// handle printables (letter navigation)
			// Check for key navigation.
			if(!e.altKey && !e.ctrlKey && !e.shiftKey && !e.metaKey){
				this._onLetterKeyNav( { node: treeNode, key: key.toLowerCase() } );
				dojo.stopEvent(e);
			}
		}else{	// handle non-printables (arrow keys)
			// clear record of recent printables (being saved for multi-char letter navigation),
			// because "a", down-arrow, "b" shouldn't search for "ab"
			if(this._curSearch){
				clearTimeout(this._curSearch.timer);
				delete this._curSearch;
			}

			var map = this._keyHandlerMap;
			if(!map){
				// setup table mapping keys to events
				map = {};
				map[dk.ENTER]="_onEnterKey";
				//On WebKit based browsers, the combination ctrl-enter
				//does not get passed through. To allow accessible
				//multi-select on those browsers, the space key is
				//also used for selection.
				map[dk.SPACE]= map[" "] = "_onEnterKey";
				map[this.isLeftToRight() ? dk.LEFT_ARROW : dk.RIGHT_ARROW]="_onLeftArrow";
				map[this.isLeftToRight() ? dk.RIGHT_ARROW : dk.LEFT_ARROW]="_onRightArrow";
				map[dk.UP_ARROW]="_onUpArrow";
				map[dk.DOWN_ARROW]="_onDownArrow";
				map[dk.HOME]="_onHomeKey";
				map[dk.END]="_onEndKey";
				this._keyHandlerMap = map;
			}
			if(this._keyHandlerMap[key]){
				this[this._keyHandlerMap[key]]( { node: treeNode, item: treeNode.item, evt: e } );
				dojo.stopEvent(e);
			}
		}
	},

	_onEnterKey: function(/*Object*/ message){
		this._publish("execute", { item: message.item, node: message.node } );
		this.dndController.userSelect(message.node, dojo.isCopyKey( message.evt ), message.evt.shiftKey);
		this.onClick(message.item, message.node, message.evt);
	},

	_onDownArrow: function(/*Object*/ message){
		// summary:
		//		down arrow pressed; get next visible node, set focus there
		var node = this._getNextNode(message.node);
		if(node && node.isTreeNode){
			this.focusNode(node);
		}
	},

	_onUpArrow: function(/*Object*/ message){
		// summary:
		//		Up arrow pressed; move to previous visible node

		var node = message.node;

		// if younger siblings
		var previousSibling = node.getPreviousSibling();
		if(previousSibling){
			node = previousSibling;
			// if the previous node is expanded, dive in deep
			while(node.isExpandable && node.isExpanded && node.hasChildren()){
				// move to the last child
				var children = node.getChildren();
				node = children[children.length-1];
			}
		}else{
			// if this is the first child, return the parent
			// unless the parent is the root of a tree with a hidden root
			var parent = node.getParent();
			if(!(!this.showRoot && parent === this.rootNode)){
				node = parent;
			}
		}

		if(node && node.isTreeNode){
			this.focusNode(node);
		}
	},

	_onRightArrow: function(/*Object*/ message){
		// summary:
		//		Right arrow pressed; go to child node
		var node = message.node;

		// if not expanded, expand, else move to 1st child
		if(node.isExpandable && !node.isExpanded){
			this._expandNode(node);
		}else if(node.hasChildren()){
			node = node.getChildren()[0];
			if(node && node.isTreeNode){
				this.focusNode(node);
			}
		}
	},

	_onLeftArrow: function(/*Object*/ message){
		// summary:
		//		Left arrow pressed.
		//		If not collapsed, collapse, else move to parent.

		var node = message.node;

		if(node.isExpandable && node.isExpanded){
			this._collapseNode(node);
		}else{
			var parent = node.getParent();
			if(parent && parent.isTreeNode && !(!this.showRoot && parent === this.rootNode)){
				this.focusNode(parent);
			}
		}
	},

	_onHomeKey: function(){
		// summary:
		//		Home key pressed; get first visible node, and set focus there
		var node = this._getRootOrFirstNode();
		if(node){
			this.focusNode(node);
		}
	},

	_onEndKey: function(/*Object*/ message){
		// summary:
		//		End key pressed; go to last visible node.

		var node = this.rootNode;
		while(node.isExpanded){
			var c = node.getChildren();
			node = c[c.length - 1];
		}

		if(node && node.isTreeNode){
			this.focusNode(node);
		}
	},

	// multiCharSearchDuration: Number
	//		If multiple characters are typed where each keystroke happens within
	//		multiCharSearchDuration of the previous keystroke,
	//		search for nodes matching all the keystrokes.
	//
	//		For example, typing "ab" will search for entries starting with
	//		"ab" unless the delay between "a" and "b" is greater than multiCharSearchDuration.
	multiCharSearchDuration: 250,

	_onLetterKeyNav: function(message){
		// summary:
		//		Called when user presses a prinatable key; search for node starting with recently typed letters.
		// message: Object
		//		Like { node: TreeNode, key: 'a' } where key is the key the user pressed.

		// Branch depending on whether this key starts a new search, or modifies an existing search
		var cs = this._curSearch;
		if(cs){
			// We are continuing a search.  Ex: user has pressed 'a', and now has pressed
			// 'b', so we want to search for nodes starting w/"ab".
			cs.pattern = cs.pattern + message.key;
			clearTimeout(cs.timer);
		}else{
			// We are starting a new search
			cs = this._curSearch = {
					pattern: message.key,
					startNode: message.node
			};
		}

		// set/reset timer to forget recent keystrokes
		var self = this;
		cs.timer = setTimeout(function(){
			delete self._curSearch;
		}, this.multiCharSearchDuration);

		// Navigate to TreeNode matching keystrokes [entered so far].
		var node = cs.startNode;
		do{
			node = this._getNextNode(node);
			//check for last node, jump to first node if necessary
			if(!node){
				node = this._getRootOrFirstNode();
			}
		}while(node !== cs.startNode && (node.label.toLowerCase().substr(0, cs.pattern.length) != cs.pattern));
		if(node && node.isTreeNode){
			// no need to set focus if back where we started
			if(node !== cs.startNode){
				this.focusNode(node);
			}
		}
	},

	isExpandoNode: function(node, widget){
		// summary:
		//		check whether a dom node is the expandoNode for a particular TreeNode widget
		return dojo.isDescendant(node, widget.expandoNode);
	},
	_onClick: function(/*TreeNode*/ nodeWidget, /*Event*/ e){
		// summary:
		//		Translates click events into commands for the controller to process

		var domElement = e.target,
			isExpandoClick = this.isExpandoNode(domElement, nodeWidget);

		if( (this.openOnClick && nodeWidget.isExpandable) || isExpandoClick ){
			// expando node was clicked, or label of a folder node was clicked; open it
			if(nodeWidget.isExpandable){
				this._onExpandoClick({node:nodeWidget});
			}
		}else{
			this._publish("execute", { item: nodeWidget.item, node: nodeWidget, evt: e } );
			this.onClick(nodeWidget.item, nodeWidget, e);
			this.focusNode(nodeWidget);
		}
		dojo.stopEvent(e);
	},
	_onDblClick: function(/*TreeNode*/ nodeWidget, /*Event*/ e){
		// summary:
		//		Translates double-click events into commands for the controller to process

		var domElement = e.target,
			isExpandoClick = (domElement == nodeWidget.expandoNode || domElement == nodeWidget.expandoNodeText);

		if( (this.openOnDblClick && nodeWidget.isExpandable) ||isExpandoClick ){
			// expando node was clicked, or label of a folder node was clicked; open it
			if(nodeWidget.isExpandable){
				this._onExpandoClick({node:nodeWidget});
			}
		}else{
			this._publish("execute", { item: nodeWidget.item, node: nodeWidget, evt: e } );
			this.onDblClick(nodeWidget.item, nodeWidget, e);
			this.focusNode(nodeWidget);
		}
		dojo.stopEvent(e);
	},

	_onExpandoClick: function(/*Object*/ message){
		// summary:
		//		User clicked the +/- icon; expand or collapse my children.
		var node = message.node;

		// If we are collapsing, we might be hiding the currently focused node.
		// Also, clicking the expando node might have erased focus from the current node.
		// For simplicity's sake just focus on the node with the expando.
		this.focusNode(node);

		if(node.isExpanded){
			this._collapseNode(node);
		}else{
			this._expandNode(node);
		}
	},

	onClick: function(/* dojo.data */ item, /*TreeNode*/ node, /*Event*/ evt){
		// summary:
		//		Callback when a tree node is clicked
		// tags:
		//		callback
	},
	onDblClick: function(/* dojo.data */ item, /*TreeNode*/ node, /*Event*/ evt){
		// summary:
		//		Callback when a tree node is double-clicked
		// tags:
		//		callback
	},
	onOpen: function(/* dojo.data */ item, /*TreeNode*/ node){
		// summary:
		//		Callback when a node is opened
		// tags:
		//		callback
	},
	onClose: function(/* dojo.data */ item, /*TreeNode*/ node){
		// summary:
		//		Callback when a node is closed
		// tags:
		//		callback
	},

	_getNextNode: function(node){
		// summary:
		//		Get next visible node

		if(node.isExpandable && node.isExpanded && node.hasChildren()){
			// if this is an expanded node, get the first child
			return node.getChildren()[0];		// _TreeNode
		}else{
			// find a parent node with a sibling
			while(node && node.isTreeNode){
				var returnNode = node.getNextSibling();
				if(returnNode){
					return returnNode;		// _TreeNode
				}
				node = node.getParent();
			}
			return null;
		}
	},

	_getRootOrFirstNode: function(){
		// summary:
		//		Get first visible node
		return this.showRoot ? this.rootNode : this.rootNode.getChildren()[0];
	},

	_collapseNode: function(/*_TreeNode*/ node){
		// summary:
		//		Called when the user has requested to collapse the node

		if(node._expandNodeDeferred){
			delete node._expandNodeDeferred;
		}

		if(node.isExpandable){
			if(node.state == "LOADING"){
				// ignore clicks while we are in the process of loading data
				return;
			}

			node.collapse();
			this.onClose(node.item, node);

			if(node.item){
				this._state(node.item,false);
				this._saveState();
			}
		}
	},

	_expandNode: function(/*_TreeNode*/ node, /*Boolean?*/ recursive){
		// summary:
		//		Called when the user has requested to expand the node
		// recursive:
		//		Internal flag used when _expandNode() calls itself, don't set.
		// returns:
		//		Deferred that fires when the node is loaded and opened and (if persist=true) all it's descendants
		//		that were previously opened too

		if(node._expandNodeDeferred && !recursive){
			// there's already an expand in progress (or completed), so just return
			return node._expandNodeDeferred;	// dojo.Deferred
		}

		var model = this.model,
			item = node.item,
			_this = this;

		switch(node.state){
			case "UNCHECKED":
				// need to load all the children, and then expand
				node.markProcessing();

				// Setup deferred to signal when the load and expand are finished.
				// Save that deferred in this._expandDeferred as a flag that operation is in progress.
				var def = (node._expandNodeDeferred = new dojo.Deferred());

				// Get the children
				model.getChildren(
					item,
					function(items){
						node.unmarkProcessing();

						// Display the children and also start expanding any children that were previously expanded
						// (if this.persist == true).   The returned Deferred will fire when those expansions finish.
						var scid = node.setChildItems(items);

						// Call _expandNode() again but this time it will just to do the animation (default branch).
						// The returned Deferred will fire when the animation completes.
						// TODO: seems like I can avoid recursion and just use a deferred to sequence the events?
						var ed = _this._expandNode(node, true);

						// After the above two tasks (setChildItems() and recursive _expandNode()) finish,
						// signal that I am done.
						scid.addCallback(function(){
							ed.addCallback(function(){
								def.callback();
							})
						});
					},
					function(err){
						console.error(_this, ": error loading root children: ", err);
					}
				);
				break;

			default:	// "LOADED"
				// data is already loaded; just expand node
				def = (node._expandNodeDeferred = node.expand());

				this.onOpen(node.item, node);

				if(item){
					this._state(item, true);
					this._saveState();
				}
		}

		return def;	// dojo.Deferred
	},

	////////////////// Miscellaneous functions ////////////////

	focusNode: function(/* _tree.Node */ node){
		// summary:
		//		Focus on the specified node (which must be visible)
		// tags:
		//		protected

		// set focus so that the label will be voiced using screen readers
		dijit.focus(node.labelNode);
	},

	_onNodeFocus: function(/*dijit._Widget*/ node){
		// summary:
		//		Called when a TreeNode gets focus, either by user clicking
		//		it, or programatically by arrow key handling code.
		// description:
		//		It marks that the current node is the selected one, and the previously
		//		selected node no longer is.

		if(node && node != this.lastFocused){
			if(this.lastFocused && !this.lastFocused._destroyed){
				// mark that the previously focsable node is no longer focusable
				this.lastFocused.setFocusable(false);
			}

			// mark that the new node is the currently selected one
			node.setFocusable(true);
			this.lastFocused = node;
		}
	},

	_onNodeMouseEnter: function(/*dijit._Widget*/ node){
		// summary:
		//		Called when mouse is over a node (onmouseenter event),
		//		this is monitored by the DND code
	},

	_onNodeMouseLeave: function(/*dijit._Widget*/ node){
		// summary:
		//		Called when mouse leaves a node (onmouseleave event),
		//		this is monitored by the DND code
	},

	//////////////// Events from the model //////////////////////////

	_onItemChange: function(/*Item*/ item){
		// summary:
		//		Processes notification of a change to an item's scalar values like label
		var model = this.model,
			identity = model.getIdentity(item),
			nodes = this._itemNodesMap[identity];

		if(nodes){
			var label = this.getLabel(item),
				tooltip = this.getTooltip(item);
			dojo.forEach(nodes, function(node){
				node.set({
					item: item,		// theoretically could be new JS Object representing same item
					label: label,
					tooltip: tooltip
				});
				node._updateItemClasses(item);
			});
		}
	},

	_onItemChildrenChange: function(/*dojo.data.Item*/ parent, /*dojo.data.Item[]*/ newChildrenList){
		// summary:
		//		Processes notification of a change to an item's children
		var model = this.model,
			identity = model.getIdentity(parent),
			parentNodes = this._itemNodesMap[identity];

		if(parentNodes){
			dojo.forEach(parentNodes,function(parentNode){
				parentNode.setChildItems(newChildrenList);
			});
		}
	},

	_onItemDelete: function(/*Item*/ item){
		// summary:
		//		Processes notification of a deletion of an item
		var model = this.model,
			identity = model.getIdentity(item),
			nodes = this._itemNodesMap[identity];

		if(nodes){
			dojo.forEach(nodes,function(node){
				// Remove node from set of selected nodes (if it's selected)
				this.dndController.removeTreeNode(node);

				var parent = node.getParent();
				if(parent){
					// if node has not already been orphaned from a _onSetItem(parent, "children", ..) call...
					parent.removeChild(node);
				}
				node.destroyRecursive();
			}, this);
			delete this._itemNodesMap[identity];
		}
	},

	/////////////// Miscellaneous funcs

	_initState: function(){
		// summary:
		//		Load in which nodes should be opened automatically
		if(this.persist){
			var cookie = dojo.cookie(this.cookieName);
			this._openedItemIds = {};
			if(cookie){
				dojo.forEach(cookie.split(','), function(item){
					this._openedItemIds[item] = true;
				}, this);
			}
		}
	},
	_state: function(item,expanded){
		// summary:
		//		Query or set expanded state for an item,
		if(!this.persist){
			return false;
		}
		var id=this.model.getIdentity(item);
		if(arguments.length === 1){
			return this._openedItemIds[id];
		}
		if(expanded){
			this._openedItemIds[id] = true;
		}else{
			delete this._openedItemIds[id];
		}
	},
	_saveState: function(){
		// summary:
		//		Create and save a cookie with the currently expanded nodes identifiers
		if(!this.persist){
			return;
		}
		var ary = [];
		for(var id in this._openedItemIds){
			ary.push(id);
		}
		dojo.cookie(this.cookieName, ary.join(","), {expires:365});
	},

	destroy: function(){
		if(this._curSearch){
			clearTimeout(this._curSearch.timer);
			delete this._curSearch;
		}
		if(this.rootNode){
			this.rootNode.destroyRecursive();
		}
		if(this.dndController && !dojo.isString(this.dndController)){
			this.dndController.destroy();
		}
		this.rootNode = null;
		this.inherited(arguments);
	},

	destroyRecursive: function(){
		// A tree is treated as a leaf, not as a node with children (like a grid),
		// but defining destroyRecursive for back-compat.
		this.destroy();
	},

	resize: function(changeSize){
		if(changeSize){
			dojo.marginBox(this.domNode, changeSize);
		}

		// The only JS sizing involved w/tree is the indentation, which is specified
		// in CSS and read in through this dummy indentDetector node (tree must be
		// visible and attached to the DOM to read this)
		this._nodePixelIndent = dojo._getMarginSize(this.tree.indentDetector).w;

		if(this.tree.rootNode){
			// If tree has already loaded, then reset indent for all the nodes
			this.tree.rootNode.set('indent', this.showRoot ? 0 : -1);
		}
	},

	_createTreeNode: function(/*Object*/ args){
		// summary:
		//		creates a TreeNode
		// description:
		//		Developers can override this method to define their own TreeNode class;
		//		However it will probably be removed in a future release in favor of a way
		//		of just specifying a widget for the label, rather than one that contains
		//		the children too.
		return new dijit._TreeNode(args);
	}
});

// For back-compat.  TODO: remove in 2.0

}

if(!dojo._hasResource["dojo.data.ItemFileReadStore"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.data.ItemFileReadStore"] = true;
dojo.provide("dojo.data.ItemFileReadStore");





dojo.declare("dojo.data.ItemFileReadStore", null,{
	//	summary:
	//		The ItemFileReadStore implements the dojo.data.api.Read API and reads
	//		data from JSON files that have contents in this format --
	//		{ items: [
	//			{ name:'Kermit', color:'green', age:12, friends:['Gonzo', {_reference:{name:'Fozzie Bear'}}]},
	//			{ name:'Fozzie Bear', wears:['hat', 'tie']},
	//			{ name:'Miss Piggy', pets:'Foo-Foo'}
	//		]}
	//		Note that it can also contain an 'identifer' property that specified which attribute on the items
	//		in the array of items that acts as the unique identifier for that item.
	//
	constructor: function(/* Object */ keywordParameters){
		//	summary: constructor
		//	keywordParameters: {url: String}
		//	keywordParameters: {data: jsonObject}
		//	keywordParameters: {typeMap: object)
		//		The structure of the typeMap object is as follows:
		//		{
		//			type0: function || object,
		//			type1: function || object,
		//			...
		//			typeN: function || object
		//		}
		//		Where if it is a function, it is assumed to be an object constructor that takes the
		//		value of _value as the initialization parameters.  If it is an object, then it is assumed
		//		to be an object of general form:
		//		{
		//			type: function, //constructor.
		//			deserialize:	function(value) //The function that parses the value and constructs the object defined by type appropriately.
		//		}
	
		this._arrayOfAllItems = [];
		this._arrayOfTopLevelItems = [];
		this._loadFinished = false;
		this._jsonFileUrl = keywordParameters.url;
		this._ccUrl = keywordParameters.url;
		this.url = keywordParameters.url;
		this._jsonData = keywordParameters.data;
		this.data = null;
		this._datatypeMap = keywordParameters.typeMap || {};
		if(!this._datatypeMap['Date']){
			//If no default mapping for dates, then set this as default.
			//We use the dojo.date.stamp here because the ISO format is the 'dojo way'
			//of generically representing dates.
			this._datatypeMap['Date'] = {
											type: Date,
											deserialize: function(value){
												return dojo.date.stamp.fromISOString(value);
											}
										};
		}
		this._features = {'dojo.data.api.Read':true, 'dojo.data.api.Identity':true};
		this._itemsByIdentity = null;
		this._storeRefPropName = "_S"; // Default name for the store reference to attach to every item.
		this._itemNumPropName = "_0"; // Default Item Id for isItem to attach to every item.
		this._rootItemPropName = "_RI"; // Default Item Id for isItem to attach to every item.
		this._reverseRefMap = "_RRM"; // Default attribute for constructing a reverse reference map for use with reference integrity
		this._loadInProgress = false; //Got to track the initial load to prevent duelling loads of the dataset.
		this._queuedFetches = [];
		if(keywordParameters.urlPreventCache !== undefined){
			this.urlPreventCache = keywordParameters.urlPreventCache?true:false;
		}
		if(keywordParameters.hierarchical !== undefined){
			this.hierarchical = keywordParameters.hierarchical?true:false;
		}
		if(keywordParameters.clearOnClose){
			this.clearOnClose = true;
		}
		if("failOk" in keywordParameters){
			this.failOk = keywordParameters.failOk?true:false;
		}
	},
	
	url: "",	// use "" rather than undefined for the benefit of the parser (#3539)

	//Internal var, crossCheckUrl.  Used so that setting either url or _jsonFileUrl, can still trigger a reload
	//when clearOnClose and close is used.
	_ccUrl: "",

	data: null,	// define this so that the parser can populate it

	typeMap: null, //Define so parser can populate.
	
	//Parameter to allow users to specify if a close call should force a reload or not.
	//By default, it retains the old behavior of not clearing if close is called.  But
	//if set true, the store will be reset to default state.  Note that by doing this,
	//all item handles will become invalid and a new fetch must be issued.
	clearOnClose: false,

	//Parameter to allow specifying if preventCache should be passed to the xhrGet call or not when loading data from a url.
	//Note this does not mean the store calls the server on each fetch, only that the data load has preventCache set as an option.
	//Added for tracker: #6072
	urlPreventCache: false,
	
	//Parameter for specifying that it is OK for the xhrGet call to fail silently.
	failOk: false,

	//Parameter to indicate to process data from the url as hierarchical
	//(data items can contain other data items in js form).  Default is true
	//for backwards compatibility.  False means only root items are processed
	//as items, all child objects outside of type-mapped objects and those in
	//specific reference format, are left straight JS data objects.
	hierarchical: true,

	_assertIsItem: function(/* item */ item){
		//	summary:
		//		This function tests whether the item passed in is indeed an item in the store.
		//	item:
		//		The item to test for being contained by the store.
		if(!this.isItem(item)){
			throw new Error("dojo.data.ItemFileReadStore: Invalid item argument.");
		}
	},

	_assertIsAttribute: function(/* attribute-name-string */ attribute){
		//	summary:
		//		This function tests whether the item passed in is indeed a valid 'attribute' like type for the store.
		//	attribute:
		//		The attribute to test for being contained by the store.
		if(typeof attribute !== "string"){
			throw new Error("dojo.data.ItemFileReadStore: Invalid attribute argument.");
		}
	},

	getValue: function(	/* item */ item,
						/* attribute-name-string */ attribute,
						/* value? */ defaultValue){
		//	summary:
		//		See dojo.data.api.Read.getValue()
		var values = this.getValues(item, attribute);
		return (values.length > 0)?values[0]:defaultValue; // mixed
	},

	getValues: function(/* item */ item,
						/* attribute-name-string */ attribute){
		//	summary:
		//		See dojo.data.api.Read.getValues()

		this._assertIsItem(item);
		this._assertIsAttribute(attribute);
		// Clone it before returning.  refs: #10474
		return (item[attribute] || []).slice(0); // Array
	},

	getAttributes: function(/* item */ item){
		//	summary:
		//		See dojo.data.api.Read.getAttributes()
		this._assertIsItem(item);
		var attributes = [];
		for(var key in item){
			// Save off only the real item attributes, not the special id marks for O(1) isItem.
			if((key !== this._storeRefPropName) && (key !== this._itemNumPropName) && (key !== this._rootItemPropName) && (key !== this._reverseRefMap)){
				attributes.push(key);
			}
		}
		return attributes; // Array
	},

	hasAttribute: function(	/* item */ item,
							/* attribute-name-string */ attribute){
		//	summary:
		//		See dojo.data.api.Read.hasAttribute()
		this._assertIsItem(item);
		this._assertIsAttribute(attribute);
		return (attribute in item);
	},

	containsValue: function(/* item */ item,
							/* attribute-name-string */ attribute,
							/* anything */ value){
		//	summary:
		//		See dojo.data.api.Read.containsValue()
		var regexp = undefined;
		if(typeof value === "string"){
			regexp = dojo.data.util.filter.patternToRegExp(value, false);
		}
		return this._containsValue(item, attribute, value, regexp); //boolean.
	},

	_containsValue: function(	/* item */ item,
								/* attribute-name-string */ attribute,
								/* anything */ value,
								/* RegExp?*/ regexp){
		//	summary:
		//		Internal function for looking at the values contained by the item.
		//	description:
		//		Internal function for looking at the values contained by the item.  This
		//		function allows for denoting if the comparison should be case sensitive for
		//		strings or not (for handling filtering cases where string case should not matter)
		//
		//	item:
		//		The data item to examine for attribute values.
		//	attribute:
		//		The attribute to inspect.
		//	value:
		//		The value to match.
		//	regexp:
		//		Optional regular expression generated off value if value was of string type to handle wildcarding.
		//		If present and attribute values are string, then it can be used for comparison instead of 'value'
		return dojo.some(this.getValues(item, attribute), function(possibleValue){
			if(possibleValue !== null && !dojo.isObject(possibleValue) && regexp){
				if(possibleValue.toString().match(regexp)){
					return true; // Boolean
				}
			}else if(value === possibleValue){
				return true; // Boolean
			}
		});
	},

	isItem: function(/* anything */ something){
		//	summary:
		//		See dojo.data.api.Read.isItem()
		if(something && something[this._storeRefPropName] === this){
			if(this._arrayOfAllItems[something[this._itemNumPropName]] === something){
				return true;
			}
		}
		return false; // Boolean
	},

	isItemLoaded: function(/* anything */ something){
		//	summary:
		//		See dojo.data.api.Read.isItemLoaded()
		return this.isItem(something); //boolean
	},

	loadItem: function(/* object */ keywordArgs){
		//	summary:
		//		See dojo.data.api.Read.loadItem()
		this._assertIsItem(keywordArgs.item);
	},

	getFeatures: function(){
		//	summary:
		//		See dojo.data.api.Read.getFeatures()
		return this._features; //Object
	},

	getLabel: function(/* item */ item){
		//	summary:
		//		See dojo.data.api.Read.getLabel()
		if(this._labelAttr && this.isItem(item)){
			return this.getValue(item,this._labelAttr); //String
		}
		return undefined; //undefined
	},

	getLabelAttributes: function(/* item */ item){
		//	summary:
		//		See dojo.data.api.Read.getLabelAttributes()
		if(this._labelAttr){
			return [this._labelAttr]; //array
		}
		return null; //null
	},

	_fetchItems: function(	/* Object */ keywordArgs,
							/* Function */ findCallback,
							/* Function */ errorCallback){
		//	summary:
		//		See dojo.data.util.simpleFetch.fetch()
		var self = this,
		    filter = function(requestArgs, arrayOfItems){
			var items = [],
			    i, key;
			if(requestArgs.query){
				var value,
				    ignoreCase = requestArgs.queryOptions ? requestArgs.queryOptions.ignoreCase : false;

				//See if there are any string values that can be regexp parsed first to avoid multiple regexp gens on the
				//same value for each item examined.  Much more efficient.
				var regexpList = {};
				for(key in requestArgs.query){
					value = requestArgs.query[key];
					if(typeof value === "string"){
						regexpList[key] = dojo.data.util.filter.patternToRegExp(value, ignoreCase);
					}else if(value instanceof RegExp){
						regexpList[key] = value;
					}
				}
				for(i = 0; i < arrayOfItems.length; ++i){
					var match = true;
					var candidateItem = arrayOfItems[i];
					if(candidateItem === null){
						match = false;
					}else{
						for(key in requestArgs.query){
							value = requestArgs.query[key];
							if(!self._containsValue(candidateItem, key, value, regexpList[key])){
								match = false;
							}
						}
					}
					if(match){
						items.push(candidateItem);
					}
				}
				findCallback(items, requestArgs);
			}else{
				// We want a copy to pass back in case the parent wishes to sort the array.
				// We shouldn't allow resort of the internal list, so that multiple callers
				// can get lists and sort without affecting each other.  We also need to
				// filter out any null values that have been left as a result of deleteItem()
				// calls in ItemFileWriteStore.
				for(i = 0; i < arrayOfItems.length; ++i){
					var item = arrayOfItems[i];
					if(item !== null){
						items.push(item);
					}
				}
				findCallback(items, requestArgs);
			}
		};

		if(this._loadFinished){
			filter(keywordArgs, this._getItemsArray(keywordArgs.queryOptions));
		}else{
			//Do a check on the JsonFileUrl and crosscheck it.
			//If it doesn't match the cross-check, it needs to be updated
			//This allows for either url or _jsonFileUrl to he changed to
			//reset the store load location.  Done this way for backwards
			//compatibility.  People use _jsonFileUrl (even though officially
			//private.
			if(this._jsonFileUrl !== this._ccUrl){
				dojo.deprecated("dojo.data.ItemFileReadStore: ",
					"To change the url, set the url property of the store," +
					" not _jsonFileUrl.  _jsonFileUrl support will be removed in 2.0");
				this._ccUrl = this._jsonFileUrl;
				this.url = this._jsonFileUrl;
			}else if(this.url !== this._ccUrl){
				this._jsonFileUrl = this.url;
				this._ccUrl = this.url;
			}

			//See if there was any forced reset of data.
			if(this.data != null){
				this._jsonData = this.data;
				this.data = null;
			}

			if(this._jsonFileUrl){
				//If fetches come in before the loading has finished, but while
				//a load is in progress, we have to defer the fetching to be
				//invoked in the callback.
				if(this._loadInProgress){
					this._queuedFetches.push({args: keywordArgs, filter: filter});
				}else{
					this._loadInProgress = true;
					var getArgs = {
							url: self._jsonFileUrl,
							handleAs: "json-comment-optional",
							preventCache: this.urlPreventCache,
							failOk: this.failOk
						};
					var getHandler = dojo.xhrGet(getArgs);
					getHandler.addCallback(function(data){
						try{
							self._getItemsFromLoadedData(data);
							self._loadFinished = true;
							self._loadInProgress = false;
							
							filter(keywordArgs, self._getItemsArray(keywordArgs.queryOptions));
							self._handleQueuedFetches();
						}catch(e){
							self._loadFinished = true;
							self._loadInProgress = false;
							errorCallback(e, keywordArgs);
						}
					});
					getHandler.addErrback(function(error){
						self._loadInProgress = false;
						errorCallback(error, keywordArgs);
					});

					//Wire up the cancel to abort of the request
					//This call cancel on the deferred if it hasn't been called
					//yet and then will chain to the simple abort of the
					//simpleFetch keywordArgs
					var oldAbort = null;
					if(keywordArgs.abort){
						oldAbort = keywordArgs.abort;
					}
					keywordArgs.abort = function(){
						var df = getHandler;
						if(df && df.fired === -1){
							df.cancel();
							df = null;
						}
						if(oldAbort){
							oldAbort.call(keywordArgs);
						}
					};
				}
			}else if(this._jsonData){
				try{
					this._loadFinished = true;
					this._getItemsFromLoadedData(this._jsonData);
					this._jsonData = null;
					filter(keywordArgs, this._getItemsArray(keywordArgs.queryOptions));
				}catch(e){
					errorCallback(e, keywordArgs);
				}
			}else{
				errorCallback(new Error("dojo.data.ItemFileReadStore: No JSON source data was provided as either URL or a nested Javascript object."), keywordArgs);
			}
		}
	},

	_handleQueuedFetches: function(){
		//	summary:
		//		Internal function to execute delayed request in the store.
		//Execute any deferred fetches now.
		if(this._queuedFetches.length > 0){
			for(var i = 0; i < this._queuedFetches.length; i++){
				var fData = this._queuedFetches[i],
				    delayedQuery = fData.args,
				    delayedFilter = fData.filter;
				if(delayedFilter){
					delayedFilter(delayedQuery, this._getItemsArray(delayedQuery.queryOptions));
				}else{
					this.fetchItemByIdentity(delayedQuery);
				}
			}
			this._queuedFetches = [];
		}
	},

	_getItemsArray: function(/*object?*/queryOptions){
		//	summary:
		//		Internal function to determine which list of items to search over.
		//	queryOptions: The query options parameter, if any.
		if(queryOptions && queryOptions.deep){
			return this._arrayOfAllItems;
		}
		return this._arrayOfTopLevelItems;
	},

	close: function(/*dojo.data.api.Request || keywordArgs || null */ request){
		 //	summary:
		 //		See dojo.data.api.Read.close()
		 if(this.clearOnClose &&
			this._loadFinished &&
			!this._loadInProgress){
			 //Reset all internalsback to default state.  This will force a reload
			 //on next fetch.  This also checks that the data or url param was set
			 //so that the store knows it can get data.  Without one of those being set,
			 //the next fetch will trigger an error.

			 if(((this._jsonFileUrl == "" || this._jsonFileUrl == null) &&
				 (this.url == "" || this.url == null)
				) && this.data == null){
				 console.debug("dojo.data.ItemFileReadStore: WARNING!  Data reload " +
					" information has not been provided." +
					"  Please set 'url' or 'data' to the appropriate value before" +
					" the next fetch");
			 }
			 this._arrayOfAllItems = [];
			 this._arrayOfTopLevelItems = [];
			 this._loadFinished = false;
			 this._itemsByIdentity = null;
			 this._loadInProgress = false;
			 this._queuedFetches = [];
		 }
	},

	_getItemsFromLoadedData: function(/* Object */ dataObject){
		//	summary:
		//		Function to parse the loaded data into item format and build the internal items array.
		//	description:
		//		Function to parse the loaded data into item format and build the internal items array.
		//
		//	dataObject:
		//		The JS data object containing the raw data to convery into item format.
		//
		// 	returns: array
		//		Array of items in store item format.
		
		// First, we define a couple little utility functions...
		var addingArrays = false,
		    self = this;
		
		function valueIsAnItem(/* anything */ aValue){
			// summary:
			//		Given any sort of value that could be in the raw json data,
			//		return true if we should interpret the value as being an
			//		item itself, rather than a literal value or a reference.
			// example:
			// 	|	false == valueIsAnItem("Kermit");
			// 	|	false == valueIsAnItem(42);
			// 	|	false == valueIsAnItem(new Date());
			// 	|	false == valueIsAnItem({_type:'Date', _value:'1802-05-14'});
			// 	|	false == valueIsAnItem({_reference:'Kermit'});
			// 	|	true == valueIsAnItem({name:'Kermit', color:'green'});
			// 	|	true == valueIsAnItem({iggy:'pop'});
			// 	|	true == valueIsAnItem({foo:42});
			var isItem = (
				(aValue !== null) &&
				(typeof aValue === "object") &&
				(!dojo.isArray(aValue) || addingArrays) &&
				(!dojo.isFunction(aValue)) &&
				(aValue.constructor == Object || dojo.isArray(aValue)) &&
				(typeof aValue._reference === "undefined") &&
				(typeof aValue._type === "undefined") &&
				(typeof aValue._value === "undefined") &&
				self.hierarchical
			);
			return isItem;
		}
		
		function addItemAndSubItemsToArrayOfAllItems(/* Item */ anItem){
			self._arrayOfAllItems.push(anItem);
			for(var attribute in anItem){
				var valueForAttribute = anItem[attribute];
				if(valueForAttribute){
					if(dojo.isArray(valueForAttribute)){
						var valueArray = valueForAttribute;
						for(var k = 0; k < valueArray.length; ++k){
							var singleValue = valueArray[k];
							if(valueIsAnItem(singleValue)){
								addItemAndSubItemsToArrayOfAllItems(singleValue);
							}
						}
					}else{
						if(valueIsAnItem(valueForAttribute)){
							addItemAndSubItemsToArrayOfAllItems(valueForAttribute);
						}
					}
				}
			}
		}

		this._labelAttr = dataObject.label;

		// We need to do some transformations to convert the data structure
		// that we read from the file into a format that will be convenient
		// to work with in memory.

		// Step 1: Walk through the object hierarchy and build a list of all items
		var i,
		    item;
		this._arrayOfAllItems = [];
		this._arrayOfTopLevelItems = dataObject.items;

		for(i = 0; i < this._arrayOfTopLevelItems.length; ++i){
			item = this._arrayOfTopLevelItems[i];
			if(dojo.isArray(item)){
				addingArrays = true;
			}
			addItemAndSubItemsToArrayOfAllItems(item);
			item[this._rootItemPropName]=true;
		}

		// Step 2: Walk through all the attribute values of all the items,
		// and replace single values with arrays.  For example, we change this:
		//		{ name:'Miss Piggy', pets:'Foo-Foo'}
		// into this:
		//		{ name:['Miss Piggy'], pets:['Foo-Foo']}
		//
		// We also store the attribute names so we can validate our store
		// reference and item id special properties for the O(1) isItem
		var allAttributeNames = {},
		    key;

		for(i = 0; i < this._arrayOfAllItems.length; ++i){
			item = this._arrayOfAllItems[i];
			for(key in item){
				if(key !== this._rootItemPropName){
					var value = item[key];
					if(value !== null){
						if(!dojo.isArray(value)){
							item[key] = [value];
						}
					}else{
						item[key] = [null];
					}
				}
				allAttributeNames[key]=key;
			}
		}

		// Step 3: Build unique property names to use for the _storeRefPropName and _itemNumPropName
		// This should go really fast, it will generally never even run the loop.
		while(allAttributeNames[this._storeRefPropName]){
			this._storeRefPropName += "_";
		}
		while(allAttributeNames[this._itemNumPropName]){
			this._itemNumPropName += "_";
		}
		while(allAttributeNames[this._reverseRefMap]){
			this._reverseRefMap += "_";
		}

		// Step 4: Some data files specify an optional 'identifier', which is
		// the name of an attribute that holds the identity of each item.
		// If this data file specified an identifier attribute, then build a
		// hash table of items keyed by the identity of the items.
		var arrayOfValues;

		var identifier = dataObject.identifier;
		if(identifier){
			this._itemsByIdentity = {};
			this._features['dojo.data.api.Identity'] = identifier;
			for(i = 0; i < this._arrayOfAllItems.length; ++i){
				item = this._arrayOfAllItems[i];
				arrayOfValues = item[identifier];
				var identity = arrayOfValues[0];
				if(!Object.hasOwnProperty.call(this._itemsByIdentity, identity)){
					this._itemsByIdentity[identity] = item;
				}else{
					if(this._jsonFileUrl){
						throw new Error("dojo.data.ItemFileReadStore:  The json data as specified by: [" + this._jsonFileUrl + "] is malformed.  Items within the list have identifier: [" + identifier + "].  Value collided: [" + identity + "]");
					}else if(this._jsonData){
						throw new Error("dojo.data.ItemFileReadStore:  The json data provided by the creation arguments is malformed.  Items within the list have identifier: [" + identifier + "].  Value collided: [" + identity + "]");
					}
				}
			}
		}else{
			this._features['dojo.data.api.Identity'] = Number;
		}

		// Step 5: Walk through all the items, and set each item's properties
		// for _storeRefPropName and _itemNumPropName, so that store.isItem() will return true.
		for(i = 0; i < this._arrayOfAllItems.length; ++i){
			item = this._arrayOfAllItems[i];
			item[this._storeRefPropName] = this;
			item[this._itemNumPropName] = i;
		}

		// Step 6: We walk through all the attribute values of all the items,
		// looking for type/value literals and item-references.
		//
		// We replace item-references with pointers to items.  For example, we change:
		//		{ name:['Kermit'], friends:[{_reference:{name:'Miss Piggy'}}] }
		// into this:
		//		{ name:['Kermit'], friends:[miss_piggy] }
		// (where miss_piggy is the object representing the 'Miss Piggy' item).
		//
		// We replace type/value pairs with typed-literals.  For example, we change:
		//		{ name:['Nelson Mandela'], born:[{_type:'Date', _value:'1918-07-18'}] }
		// into this:
		//		{ name:['Kermit'], born:(new Date(1918, 6, 18)) }
		//
		// We also generate the associate map for all items for the O(1) isItem function.
		for(i = 0; i < this._arrayOfAllItems.length; ++i){
			item = this._arrayOfAllItems[i]; // example: { name:['Kermit'], friends:[{_reference:{name:'Miss Piggy'}}] }
			for(key in item){
				arrayOfValues = item[key]; // example: [{_reference:{name:'Miss Piggy'}}]
				for(var j = 0; j < arrayOfValues.length; ++j){
					value = arrayOfValues[j]; // example: {_reference:{name:'Miss Piggy'}}
					if(value !== null && typeof value == "object"){
						if(("_type" in value) && ("_value" in value)){
							var type = value._type; // examples: 'Date', 'Color', or 'ComplexNumber'
							var mappingObj = this._datatypeMap[type]; // examples: Date, dojo.Color, foo.math.ComplexNumber, {type: dojo.Color, deserialize(value){ return new dojo.Color(value)}}
							if(!mappingObj){
								throw new Error("dojo.data.ItemFileReadStore: in the typeMap constructor arg, no object class was specified for the datatype '" + type + "'");
							}else if(dojo.isFunction(mappingObj)){
								arrayOfValues[j] = new mappingObj(value._value);
							}else if(dojo.isFunction(mappingObj.deserialize)){
								arrayOfValues[j] = mappingObj.deserialize(value._value);
							}else{
								throw new Error("dojo.data.ItemFileReadStore: Value provided in typeMap was neither a constructor, nor a an object with a deserialize function");
							}
						}
						if(value._reference){
							var referenceDescription = value._reference; // example: {name:'Miss Piggy'}
							if(!dojo.isObject(referenceDescription)){
								// example: 'Miss Piggy'
								// from an item like: { name:['Kermit'], friends:[{_reference:'Miss Piggy'}]}
								arrayOfValues[j] = this._getItemByIdentity(referenceDescription);
							}else{
								// example: {name:'Miss Piggy'}
								// from an item like: { name:['Kermit'], friends:[{_reference:{name:'Miss Piggy'}}] }
								for(var k = 0; k < this._arrayOfAllItems.length; ++k){
									var candidateItem = this._arrayOfAllItems[k],
									    found = true;
									for(var refKey in referenceDescription){
										if(candidateItem[refKey] != referenceDescription[refKey]){
											found = false;
										}
									}
									if(found){
										arrayOfValues[j] = candidateItem;
									}
								}
							}
							if(this.referenceIntegrity){
								var refItem = arrayOfValues[j];
								if(this.isItem(refItem)){
									this._addReferenceToMap(refItem, item, key);
								}
							}
						}else if(this.isItem(value)){
							//It's a child item (not one referenced through _reference).
							//We need to treat this as a referenced item, so it can be cleaned up
							//in a write store easily.
							if(this.referenceIntegrity){
								this._addReferenceToMap(value, item, key);
							}
						}
					}
				}
			}
		}
	},

	_addReferenceToMap: function(/*item*/ refItem, /*item*/ parentItem, /*string*/ attribute){
		 //	summary:
		 //		Method to add an reference map entry for an item and attribute.
		 //	description:
		 //		Method to add an reference map entry for an item and attribute. 		 //
		 //	refItem:
		 //		The item that is referenced.
		 //	parentItem:
		 //		The item that holds the new reference to refItem.
		 //	attribute:
		 //		The attribute on parentItem that contains the new reference.
		 
		 //Stub function, does nothing.  Real processing is in ItemFileWriteStore.
	},

	getIdentity: function(/* item */ item){
		//	summary:
		//		See dojo.data.api.Identity.getIdentity()
		var identifier = this._features['dojo.data.api.Identity'];
		if(identifier === Number){
			return item[this._itemNumPropName]; // Number
		}else{
			var arrayOfValues = item[identifier];
			if(arrayOfValues){
				return arrayOfValues[0]; // Object || String
			}
		}
		return null; // null
	},

	fetchItemByIdentity: function(/* Object */ keywordArgs){
		//	summary:
		//		See dojo.data.api.Identity.fetchItemByIdentity()

		// Hasn't loaded yet, we have to trigger the load.
		var item,
		    scope;
		if(!this._loadFinished){
			var self = this;
			//Do a check on the JsonFileUrl and crosscheck it.
			//If it doesn't match the cross-check, it needs to be updated
			//This allows for either url or _jsonFileUrl to he changed to
			//reset the store load location.  Done this way for backwards
			//compatibility.  People use _jsonFileUrl (even though officially
			//private.
			if(this._jsonFileUrl !== this._ccUrl){
				dojo.deprecated("dojo.data.ItemFileReadStore: ",
					"To change the url, set the url property of the store," +
					" not _jsonFileUrl.  _jsonFileUrl support will be removed in 2.0");
				this._ccUrl = this._jsonFileUrl;
				this.url = this._jsonFileUrl;
			}else if(this.url !== this._ccUrl){
				this._jsonFileUrl = this.url;
				this._ccUrl = this.url;
			}
			
			//See if there was any forced reset of data.
			if(this.data != null && this._jsonData == null){
				this._jsonData = this.data;
				this.data = null;
			}

			if(this._jsonFileUrl){

				if(this._loadInProgress){
					this._queuedFetches.push({args: keywordArgs});
				}else{
					this._loadInProgress = true;
					var getArgs = {
							url: self._jsonFileUrl,
							handleAs: "json-comment-optional",
							preventCache: this.urlPreventCache,
							failOk: this.failOk
					};
					var getHandler = dojo.xhrGet(getArgs);
					getHandler.addCallback(function(data){
						var scope = keywordArgs.scope?keywordArgs.scope:dojo.global;
						try{
							self._getItemsFromLoadedData(data);
							self._loadFinished = true;
							self._loadInProgress = false;
							item = self._getItemByIdentity(keywordArgs.identity);
							if(keywordArgs.onItem){
								keywordArgs.onItem.call(scope, item);
							}
							self._handleQueuedFetches();
						}catch(error){
							self._loadInProgress = false;
							if(keywordArgs.onError){
								keywordArgs.onError.call(scope, error);
							}
						}
					});
					getHandler.addErrback(function(error){
						self._loadInProgress = false;
						if(keywordArgs.onError){
							var scope = keywordArgs.scope?keywordArgs.scope:dojo.global;
							keywordArgs.onError.call(scope, error);
						}
					});
				}

			}else if(this._jsonData){
				// Passed in data, no need to xhr.
				self._getItemsFromLoadedData(self._jsonData);
				self._jsonData = null;
				self._loadFinished = true;
				item = self._getItemByIdentity(keywordArgs.identity);
				if(keywordArgs.onItem){
					scope = keywordArgs.scope?keywordArgs.scope:dojo.global;
					keywordArgs.onItem.call(scope, item);
				}
			}
		}else{
			// Already loaded.  We can just look it up and call back.
			item = this._getItemByIdentity(keywordArgs.identity);
			if(keywordArgs.onItem){
				scope = keywordArgs.scope?keywordArgs.scope:dojo.global;
				keywordArgs.onItem.call(scope, item);
			}
		}
	},

	_getItemByIdentity: function(/* Object */ identity){
		//	summary:
		//		Internal function to look an item up by its identity map.
		var item = null;
		if(this._itemsByIdentity &&
		   Object.hasOwnProperty.call(this._itemsByIdentity, identity)){
			item = this._itemsByIdentity[identity];
		}else if (Object.hasOwnProperty.call(this._arrayOfAllItems, identity)){
			item = this._arrayOfAllItems[identity];
		}
		if(item === undefined){
			item = null;
		}
		return item; // Object
	},

	getIdentityAttributes: function(/* item */ item){
		//	summary:
		//		See dojo.data.api.Identity.getIdentityAttributes()
		 
		var identifier = this._features['dojo.data.api.Identity'];
		if(identifier === Number){
			// If (identifier === Number) it means getIdentity() just returns
			// an integer item-number for each item.  The dojo.data.api.Identity
			// spec says we need to return null if the identity is not composed
			// of attributes
			return null; // null
		}else{
			return [identifier]; // Array
		}
	},
	
	_forceLoad: function(){
		//	summary:
		//		Internal function to force a load of the store if it hasn't occurred yet.  This is required
		//		for specific functions to work properly.
		var self = this;
		//Do a check on the JsonFileUrl and crosscheck it.
		//If it doesn't match the cross-check, it needs to be updated
		//This allows for either url or _jsonFileUrl to he changed to
		//reset the store load location.  Done this way for backwards
		//compatibility.  People use _jsonFileUrl (even though officially
		//private.
		if(this._jsonFileUrl !== this._ccUrl){
			dojo.deprecated("dojo.data.ItemFileReadStore: ",
				"To change the url, set the url property of the store," +
				" not _jsonFileUrl.  _jsonFileUrl support will be removed in 2.0");
			this._ccUrl = this._jsonFileUrl;
			this.url = this._jsonFileUrl;
		}else if(this.url !== this._ccUrl){
			this._jsonFileUrl = this.url;
			this._ccUrl = this.url;
		}

		//See if there was any forced reset of data.
		if(this.data != null){
			this._jsonData = this.data;
			this.data = null;
		}

		if(this._jsonFileUrl){
				var getArgs = {
					url: this._jsonFileUrl,
					handleAs: "json-comment-optional",
					preventCache: this.urlPreventCache,
					failOk: this.failOk,
					sync: true
				};
			var getHandler = dojo.xhrGet(getArgs);
			getHandler.addCallback(function(data){
				try{
					//Check to be sure there wasn't another load going on concurrently
					//So we don't clobber data that comes in on it.  If there is a load going on
					//then do not save this data.  It will potentially clobber current data.
					//We mainly wanted to sync/wait here.
					//TODO:  Revisit the loading scheme of this store to improve multi-initial
					//request handling.
					if(self._loadInProgress !== true && !self._loadFinished){
						self._getItemsFromLoadedData(data);
						self._loadFinished = true;
					}else if(self._loadInProgress){
						//Okay, we hit an error state we can't recover from.  A forced load occurred
						//while an async load was occurring.  Since we cannot block at this point, the best
						//that can be managed is to throw an error.
						throw new Error("dojo.data.ItemFileReadStore:  Unable to perform a synchronous load, an async load is in progress.");
					}
				}catch(e){
					console.log(e);
					throw e;
				}
			});
			getHandler.addErrback(function(error){
				throw error;
			});
		}else if(this._jsonData){
			self._getItemsFromLoadedData(self._jsonData);
			self._jsonData = null;
			self._loadFinished = true;
		}
	}
});
//Mix in the simple fetch implementation to this class.
dojo.extend(dojo.data.ItemFileReadStore,dojo.data.util.simpleFetch);

}

if(!dojo._hasResource['epages.data.ItemFileReadStore']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.data.ItemFileReadStore'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.data.ItemFileReadStore');


dojo.declare(
	'epages.data.ItemFileReadStore',
	dojo.data.ItemFileReadStore,
	{
		dataVar : "",

		constructor: function(keywordParameters) {
			if(keywordParameters.data === undefined && keywordParameters.dataVar){
				keywordParameters.data= eval(keywordParameters.dataVar);
			}
			epages.data.ItemFileReadStore.superclass.constructor.apply(this, arguments);
		},

		getItemByIdentity: function(id) {
			return this._getItemByIdentity(id);
		}
	}
);

}

if(!dojo._hasResource['epages.cartridges.de_epages.presentation.widget.Objectstore']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.presentation.widget.Objectstore'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.presentation.widget.Objectstore

*/
dojo.provide('epages.cartridges.de_epages.presentation.widget.Objectstore');








dojo.declare(
	'epages.cartridges.de_epages.presentation.widget.Objectstore',
	[dojo.data.api.Identity],
	{
		/**
		 * public properties
		 */
		actionChildren     : "JSONChildren",       // server ViewAction to get children information
		url                : '?',                  // request url like '/epages/DemoShop.admin/?'
		queryClasses       : undefined,            // request class filter
		titleAttribute     : 'NameOrAlias',        // attribute used to show name at tree
		undoWidgetId       : 'undoWidget',
		_htmlUndo          : undefined,            // html undo object to register changes
		undoWidget         : undefined,
		id                 : 'objectStore',
		ignoreSubproducts  : undefined,

		/**
		 * private properties
		 */
		_info              : undefined,            // epages.lang.Hash values including information about objectid
		_JsonIo            : new epages.io.Json(), // epages.io.Json() JSON communication channel to server
		_serverAttributes  : '',                   // String, list of attributes for server
		_translation       : new epages.io.Translation(dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget', 'templates/translation'), 'auto'), // translation object

		registerUndo: function () {
			this.undoWidget = $$(this.undoWidgetId);
			if (this.undoWidget === undefined) {
				//console.warn(this.id+' : undo widget not found in '+this.declaredClass);
			} else {
				this._htmlUndo = this.undoWidget.getUndoObject();
			}
		},

		constructor: function(keywordParameters){
			dojo.mixin(this,keywordParameters);

			this._info = $H();

			//find undo-Widget
			if (this._htmlUndo === undefined) {
				this.undoWidget = $$(this.undoWidgetId);
				if (this.undoWidget === undefined) {
					var me = this;
					dojo.addOnLoad(function() { me.registerUndo(); });
				} else
					this._htmlUndo = this.undoWidget.getUndoObject();
			}

			//subscribe to undobuttons save
			dojo.subscribe('undobuttons/saveFinished',this, "_reloadStore");
		},

		_correctMissingPositions : function (children) {
			//find objects with position 0 and correct them
			var missingPositionIds = [];
			var firstPosition = undefined;
			dojo.forEach(children, function (el) {
				if(this._info.get(el).isProduct == false){
					if(this._info.get(el).position == 0)
						missingPositionIds.push(el);
					else if(firstPosition == undefined || this._info.get(el).position < firstPosition)
						firstPosition = this._info.get(el).position;
				}
			}, this);
			if(missingPositionIds.length != 0){
				//if undoWidget is not defined do correction at dojo.addOnLoad because then the undo Widget is defined
				if (this.undoWidget === undefined) {
					var me = this;
					dojo.addOnLoad(function() { me._setMissingPositions(missingPositionIds,firstPosition); });
				} else{
					this._setMissingPositions(missingPositionIds,firstPosition);
				}
			}
		},
		_loadElement: function(el) {
			var info = {
				alias      : el.Alias,
				nameOrAlias: el.NameOrAlias,
				title      : el.title === undefined ? el[this.titleAttribute] : el.title,
				objectId   : el.ObjectID,
				position   : el.Position,
				parentId   : el.ParentID,
				isProduct  : el._isProduct ? true : false,
				isDeleted  : false,
				children   : el.hasChildren == 1 ? []: undefined,
				isCategory : el._isCategory ? true : false,
				IsVisibleContentView  : el.IsVisibleContentView === '' ? 0 : el.IsVisibleContentView,
				ClassAlias : el.ClassAlias,
				webUrl     : el.WebUrl,
				webUrlSSL  : el.WebUrlSSL,
				path	   : el.Path,
				classId    : el.ClassID,
				VisibleInNavigation : el.VisibleInNavigation,
				ReadPermissionFor : el.ReadPermissionFor,
				canonicalUrl : el.CanonicalURL ? el.CanonicalURL : '',
				seoQuality : el.SEOQuality,
				canDoSEOCheck : el.CanDoSEOCheck,
				isAppointment : el._isAppointment ? true : false
			};
			if(el.IsVisible){
				info.IsVisibleContentView = el.IsVisible;
			}

			//removeChildren for ImageGallery/GuestBook/Forum/Blog
			if(el.ClassAlias == 'ImageGallery' || el.ClassAlias == 'GuestBook' || el.ClassAlias == 'CustomForm'
			|| el.ClassAlias == 'Forum'|| el.ClassAlias == 'BlogPost'){
				el.children = undefined;
				info.children = undefined;
			}
			if(el.error){
				info.error = el.error;
			}
			if(el.children !== undefined) {
				dojo.forEach(el.children, function (child) {
					this._loadElement(child);
					info.children.push(child.ObjectID);
				}, this);
			}
			this._info.set(el.ObjectID, info);
		},

			// loads the child objects from the server
		_loadList: function(objectId, reload) {
			// exists object
			var info = this._info.get(objectId);

			if(info === undefined) {
				info = {
					objectId : objectId,
					children : []
				};
				this._info.set(objectId, info);
				reload = true;
			}
			var children = info.children;

			if(!reload && (children === undefined || children.length != 0)) {
				return objectId;
			}

			// not loaded or reload
			var attr = {
				'ViewAction' : this.actionChildren,
				'ObjectID'   : objectId,
				'Attributes' : this._serverAttributes,
				'WithPath'   : reload ? 1 : 0
			};
			if(this.queryClasses  !== undefined){
				attr["QueryClasses"] = this.queryClasses;
			}
			if(this.ignoreSubproducts !== undefined){
				attr["IgnoreSubproducts"] = this.ignoreSubproducts;
			}
			var jsonData = this._JsonIo.loadSync(this.url, attr);
			if (jsonData != null && !jsonData.error) {
				// save data at internal structure
				if(jsonData.data.path !== undefined) {
					for(var i=0, iLength=jsonData.data.path.length; i<iLength; i++){
						var elm = jsonData.data.path[i];
						this._loadElement(elm);
					}
				}
				return objectId;
			}
			return undefined;
		},

		_fetch: function (objectId) {
			var childrenIds = this._info.get(objectId).children;
			var items = [];
			var i;
			dojo.forEach(childrenIds, function(el) {
				i = this._info.get(el);
				if (! i.isDeleted) items.push(i);
			}, this);
			return items;
		},

		_fetchItems: function(keywordArgs, findCallback, errorCallback){
			if(this._loadList(keywordArgs.query.id) && typeof findCallback == 'function') {
				findCallback(this._fetch(keywordArgs.query.id), keywordArgs);
			} else {
				console.warn('error while _fetch %d', keywordArgs.query.id, 'in '+this.declaredClass);
				//errorCallback(keywordArgs);
			}
		},

		fetchItemByIdentity: function(objectId, reload){
			reload = (reload === undefined)? false : reload;
			if (this._loadList(objectId, reload))
				return this._info.get(objectId);
			return undefined;
		},

		hasAttribute: function(node, attributeName){
			return node[attributeName] !== undefined;
		},

		getLabel: function(item){
			return item.title;
		},

		getIdentity: function(item){
			return item.objectId;
		},

		getValue: function(item, attribute){
			console.debug('not implemented - getValue %s', attribute);
		},

		getValues: function(item, attribute){
			// set in Objecttree.js indentCurrent or outdenCurrent, deleted in ToolMovePage _onOutdent or _onIndent
			var reload = (this.indentNode)? false : true;
			if (attribute == 'children' && this._loadList(item.objectId, reload)) {
				return this._fetch(item.objectId);
			}
			else{
				console.debug('getValues() unknown attribute', attribute);
			}
		},

		isItemLoaded: function(something){
			//console.debug('isItemLoaded');
			return true;
		},

		deleteItem: function(item) {
			var objectId = item.objectId;
			this._info.get(objectId).isDeleted = true;
			if (this._htmlUndo !== undefined) {
				var inputs = this._createChangeNodes(objectId);
				var parentInput = inputs[1];
				parentInput.value = 'Delete';
				epages.event.fire(parentInput, 'change');
				this._htmlUndo.addInput(parentInput);
			}
			return true;
		},

		_createChangeNodes: function (objectId) {
			var positionInput = $('positionInput_' + objectId);
			if (positionInput == null) {
				positionInput = document.createElement("input");
				positionInput.type  = 'hidden';
				positionInput.id    = 'positionInput_' + objectId;
				positionInput.name  = objectId + ':Position';
				positionInput.value = this._info.get(objectId).position;
				this.undoWidget.domNode.appendChild(positionInput);
				this._htmlUndo.setDefaultValue(positionInput);
				dojo.connect(positionInput, "onchange", this, 'onChangePosition');
			}
			var parentInput = $('parentInput_' + objectId);
			if (parentInput == null) {
				parentInput = document.createElement("input");
				parentInput.type  = 'hidden';
				parentInput.id    = 'parentInput_' + objectId;
				parentInput.name  = objectId + ':Parent';
				parentInput.value = this._info.get(objectId).parentId;
				this.undoWidget.domNode.appendChild(parentInput);
				this._htmlUndo.setDefaultValue(parentInput);
				dojo.connect(parentInput, "onchange", this, 'onChangeParent');
			}
			return [positionInput, parentInput]; //Array
		},

		canMoveItem: function(step, item) {
			if (item.parentId === undefined || item.isProduct || this._info.get(item.parentId) == undefined ||
			   (item.ClassAlias && item.ClassAlias == 'BlogPost')) {
				return false;
			}
			var childrenIds = this._info.get(item.parentId).children;
			var content = $A(childrenIds).grep(function (el) { return !this._info.get(el).isProduct}, this);
			var found = $A(content).find(item.objectId);
			// not found
			if (found == null) {
				return false;
			}
			var newPos = found + step;
			if (newPos < 0 || content.length <= newPos) {
				return false;
			}
			return true;
		},

		moveItem: function (step,item) {
			// find old position
			var parentId = item.parentId;
			var childrenIds = this._info.get(parentId).children;
			var content = $A(childrenIds).grep(function (el) { return !this._info.get(el).isProduct}, this);
			var found = $A(content).find(item.objectId);
			// not found
			if (found == null) return;
			var newPos = found + step;
			// outside (can not move up first or down last)
			if (newPos < 0 || content.length <= newPos) {
				return;
			}
			// set for undo
			if (this._htmlUndo !== undefined) {
				var indexHigh = found < newPos ? newPos : found;
				var indexLow  = found < newPos ? found : newPos;
				var lowObjectId = content[indexLow];
				var highObjectId = content[indexHigh];
				var lowInfo = this._info.get(lowObjectId);
				var highInfo = this._info.get(highObjectId);
				if (indexHigh == content.length - 1) {
					this.setNodePosition(lowInfo, parseInt(highInfo.position) + 10);
				} else {
					// get positions around, to find the larger gap
					var posSmall = indexLow == 0 ? 0 : parseInt(this._info.get(content[indexLow - 1]).position);
					var posLow   = parseInt(lowInfo.position);
					var posHigh  = parseInt(highInfo.position);
					var posLarge = parseInt(this._info.get(content[indexHigh + 1]).position);
					if (posLow - posSmall == 1 && posLarge - posHigh == 1) {
						this.setNodePosition(lowInfo, posHigh);
						this.setNodePosition(highInfo, posLow);
					} else if (posLow - posSmall <= posLarge - posHigh) {
						var d = parseInt((posLarge - posHigh) / 2);
						if (!d) d = 1;
						this.setNodePosition(lowInfo, posHigh + d);
					} else {
						d = parseInt((posLow - posSmall) / 2);
						if (!d) d = 1;
						this.setNodePosition(highInfo, posLow - d);
					}
				}
			}
			childrenIds[found] = childrenIds[newPos];
			childrenIds[newPos] = item.objectId;
			return true;
		},

		setNodePosition: function (info, position) {
			var inputs = this._createChangeNodes(info.objectId);
			info.position = position;
			inputs[0].value = info.position;
			this._htmlUndo.addInput(inputs[0]);
		},

		_setMissingPositions:function(objectIds,firstPosition){
			for(var i=0, iLength=objectIds.length; i<iLength; i++){
				var info = this._info.get(objectIds[i]);
				var newPosition = firstPosition-1-i;
				this.setNodePosition(info,(newPosition));
			}
		},

		onChangePosition: function (evt) {
			dojo.stopEvent(evt);
			var positionNode = evt.currentTarget;
			// correct internal structure
			var position = parseInt(positionNode.value);
			var objectId = parseInt(positionNode.id.replace(/^positionInput_/,''));
			var info = this._info.get(objectId);
			var old = info.position;
			info.position = position;
			var childrenIds = this._info.get(info.parentId).children;
			var waArray = $A(childrenIds);
			var oldPosition = waArray.find(objectId);
			waArray.remove(oldPosition);

			// find right place
			var found = 0;
			waArray.each(function (el) {
				var el_info = this._info.get(el);
				if (!el_info.isProduct && el_info.position <= position) found++;
			}, this);
			// insert on place
			waArray.insertAt(found, objectId);
			dojo.publish(this.id+'/changePosition',[{item:info, oldPosition:old}]);
		},

		onChangeParent: function (evt) {
			dojo.stopEvent(evt);
			var parentNode = evt.currentTarget;

			// correct internal structure
			var parentObjectId = parentNode.value == 'Delete' ? 'Delete' : parseInt(parentNode.value);
			var objectId = parseInt(parentNode.id.replace(/^parentInput_/,''));
			var info = this._info.get(objectId);
			if(parentObjectId == 'Delete'){
				dojo.publish(this.id + '/changeParent', [{ item: info, 'delete': true }]);
			}
			else{
				this._info.get(objectId).isDeleted = false;
				var oldParentObjectId = info.parentId;
				var newParentObjectId = parentObjectId;
				if($A(this._info.get(oldParentObjectId).children).exists(newParentObjectId.toString())){
					this.indentItem(info);
				}
				if($A(this._info.get(newParentObjectId).children).exists(oldParentObjectId.toString())){
					this.outdentItem(info);
				}
				dojo.publish(this.id+'/changeParent',[{item:info, oldParent:oldParentObjectId}]);
			}
		},

		canIndentItem: function(item) {
			if (item.parentId === undefined || item.isProduct || this._info.get(item.parentId) == undefined) {
				return false;
			}
			var children = this._info.get(item.parentId).children;
			var found = $A(children).find(item.objectId);
			var newParent = this._info.get(children[found-1]);
			if (newParent && newParent.isCategory) {
				return true;
			}
			return false;
		},

		indentItem: function (item) {
			var objectId = item.objectId;
			var info = this._info.get(item.objectId);
			var parent = this._info.get(item.parentId);
			var childrenIds = parent.children;
			var found = $A(childrenIds).find(item.objectId);
			// cant not indent first element
			if (found != null && 0 < found) {
				$A(childrenIds).remove(found);
				var newParentObjectId = childrenIds[found - 1];
				if (this._loadList(newParentObjectId)) {
					if(this._info.get(newParentObjectId).isCategory == false) return;
					if(this._info.get(newParentObjectId).children === undefined) this._info.get(newParentObjectId).children = [];
					var children = this._info.get(newParentObjectId).children;
					var content = $A(children).grep(function (el) {
						return !this._info.get(el).isProduct}, this);
					var newIndex = content.length; // products are appended
					var lastPosition = content.length == 0 ? 0 : this._info.get(content[content.length - 1]).position;

					//change Alias if child with same alias already exists
					for(var i=0, iLength=children.length; i<iLength; i++){
						var child = this._info.get(children[i]);
						if(child.alias == info.alias){
							info.alias += new Date().getTime();
							var aliasInput = document.createElement("input");
							aliasInput.type  = 'hidden';
							//aliasInput.id    = 'positionInput_' + objectId;
							aliasInput.name  = objectId + ':Alias';
							aliasInput.value = this._info.get(objectId).alias;
							if(this.undoWidget){
								this.undoWidget.domNode.appendChild(aliasInput);
								this._htmlUndo.addInput(aliasInput);
							}
							break;
						}
					}

					$A(children).insertAt(newIndex,objectId);
					// set for undo
					if (this._htmlUndo !== undefined) {
						var inputs = this._createChangeNodes(item.objectId);
						if (info.position <= lastPosition) {
							info.position = parseInt(lastPosition) + 10;
							inputs[0].value = info.position;
							this._htmlUndo.addInput(inputs[0]); // positionInput
						}
						info.parentId = newParentObjectId;
						item.parentId = newParentObjectId;
						inputs[1].value = newParentObjectId;
						this._htmlUndo.addInput(inputs[1]); // parentInput
					}
					return newParentObjectId;
				}
			}
		},

		canOutdentItem: function(item) {
			if (item.parentId === undefined || item.isProduct || this._info.get(item.parentId) == undefined) {
				return false;
			}
			var newParentObjectId = this._info.get(item.parentId).parentId;
			if (newParentObjectId === undefined || this._info.get(newParentObjectId) == undefined) {
				return false;
			}
			return true;
		},

		outdentItem: function (item) {
			var objectId = item.objectId;
			var info = this._info.get(item.objectId);
			var newParentObjectId = this._info.get(item.parentId).parentId;
			//remove at old Parents childlist
			var oldParent = item.parentId;
			var oldChildPosition = $A(this._info.get(oldParent).children).find(objectId);
			$A(this._info.get(oldParent).children).remove(oldChildPosition);
			if(this._info.get(oldParent).children.length == 0){
				this._info.get(oldParent).children = undefined;
			};

			//insert as child of new Parent behind old Parent
			var content = $A(this._info.get(newParentObjectId).children).grep(function (el) { return !this._info.get(el).isProduct}, this);
			var found = $A(content).find(item.parentId);
			if (found != null) {
				//change Alias if child with same alias already exists
				for(var i=0, iLength=content.length; i<iLength; i++){
					var child = this._info.get(content[i]);
					if(child.alias == info.alias){
						info.alias += new Date().getTime();
						var aliasInput = document.createElement("input");
						aliasInput.type  = 'hidden';
						//aliasInput.id    = 'positionInput_' + objectId;
						aliasInput.name  = objectId + ':Alias';
						aliasInput.value = this._info.get(objectId).alias;
						if(this.undoWidget){
							this.undoWidget.domNode.appendChild(aliasInput);
							this._htmlUndo.addInput(aliasInput);
						}
						break;
					}
				}

				$A(this._info.get(newParentObjectId).children).insertAt(found+1,objectId);
				if (this._htmlUndo !== undefined) {
					var inputs = this._createChangeNodes(item.objectId);
					var before = this._info.get(content[found]);
					var info = this._info.get(item.objectId);
					var deltaPosition = 0;
					if (found == content.length - 1) {
						// last position
						if (info.position <= before.position) {
							deltaPosition = 10;
						}
					} else {
						// inner position
						var behind = this._info.get(content[found + 1]);
						if (before.position < info.position && info.position < behind.position) {
							// do nothing position is good
						} else if (before.position + 1 < behind.position) {
							// there is space
							deltaPosition = (parseInt(before.position) + parseInt( behind.position))/2 - parseInt(info.position);
						} else {
							// no space
							//console.debug('sorry no space');
							deltaPosition = parseInt(behind.position) - parseInt(info.position);
						}
					}
					if (deltaPosition != 0) {
						info.position = parseInt(info.position) + parseInt(deltaPosition);
						inputs[0].value = info.position;
						this._htmlUndo.addInput(inputs[0]); // positionInput
					}
					info.parentId = newParentObjectId;
					item.parentId = newParentObjectId;
					inputs[1].value = newParentObjectId;
					this._htmlUndo.addInput(inputs[1]); // parentInput
				}
				return newParentObjectId;
			}
		},

		createObject: function (objectId, classId, name, isVisible) {
			var children = this._info.get(objectId).children;
			var content = $A(children).grep(function (el) { return !this._info.get(el).isProduct}, this);
			var position = 10;
			if (content.length) {
				var posLastItem = parseInt(this._info.get(content[content.length-1]).position);
				position += (posLastItem !== isNaN) ? posLastItem : 0;
			}
			var data = {
				'ViewAction':   'JSONGet',
				'Attributes':   'ObjectID,ClassAlias=Class.Alias,IsVisibleContentView,Position,Name=NameOrAlias,Alias',
				'ObjectID':     objectId,
				'ChangeAction': 'NewObject',
				'ClassID':      classId,
				'Name':         name,
				'Position':     position
			};

			if(isVisible){
				data['IsVisibleContentView'] = 1;
			}

			var result  = this._JsonIo.loadSync(this.url,data);
			if (result.error != null) {
				var error = result.error.data.Errors[0];
				var expectedErrors = {
					// try to translate a feature specific language tag, otherwise use default FeatureLimitExceeded
					'FeatureLimitExceeded': function(error) {
						if (this._translation.exists('FeatureLimitExceeded' + error.Feature)) return 'FeatureLimitExceeded' + error.Feature;
						return 'FeatureLimitExceeded';
					}
				};
				var message = this._translation.get(expectedErrors[error.Reason] ? expectedErrors[error.Reason].call(this, error) : 'Error (Code: ' + error.Reason + ')', error.Vars);
				dojo.publish("uimessage/show", [
					this._translation.get("CantCreatePage"),
					message,
					"Dialog",
					{
						titleBar: this._translation.get("Notification"),
						typeClass:"Warning",
						sizeClass:"Large"
					}
				]);
				return;
			}
			else {
				var data = result.data;
				var newObjectId = result.data.ObjectID;
				if(this._loadList(objectId,true) != undefined){
					if (this._htmlUndo !== undefined) {
						this._info.get(newObjectId).parentId = 'Delete';
						var inputs = this._createChangeNodes(newObjectId);
						inputs[1].value = objectId;
						this._info.get(newObjectId).parentId = objectId;
						this._htmlUndo.addInput(inputs[1]);
					}
					return this._info.get(newObjectId);
				}
				else{
					return;
				}
			}
		},

		onChangeVisibility:function(evt){
			dojo.stopEvent(evt);
			var node = evt.currentTarget;
			var objectId = parseInt(node.id.replace(/^IsVisibleContentViewInput_/,''));
			var info = this._info.get(objectId);
			info.IsVisibleContentView = node.value;

			dojo.publish(this.id+'/changeVisibility',[{item:info}]);
		},

		changeVisibility: function(item){
			var objectId = item.objectId;
			//new Visibility is opposite of the old
			var newVisibility = item.IsVisibleContentView == 0 ? 1 : 0;
			var visibilityInput = $('IsVisibleContentViewInput_' + objectId);
			if (visibilityInput == null) {
				visibilityInput = document.createElement("input");
				visibilityInput.type  = 'hidden';
				visibilityInput.id    = 'IsVisibleContentViewInput_' + objectId;
				visibilityInput.name  = objectId + ':IsVisibleContentView';
				visibilityInput.value = this._info.get(objectId).IsVisibleContentView;
				this.undoWidget.domNode.appendChild(visibilityInput);
				this._htmlUndo.setDefaultValue(visibilityInput);
				dojo.connect(visibilityInput, "onchange", this, 'onChangeVisibility');
			}
			this._info.get(objectId).IsVisibleContentView = newVisibility;
			visibilityInput.value = newVisibility;
			this._htmlUndo.addInput(visibilityInput);
			return newVisibility;
		},

		changeAttribute: function(attribute){
			if(attribute.languageId){
				var attributeInputId = attribute.name +'Input_' + attribute.objectId+'_'+attribute.languageId;
				var attributeName = attribute.objectId + ':'+ attribute.name +':'+attribute.languageId;
			}
			else {
				var attributeInputId = attribute.name +'Input_' + attribute.objectId;
				var attributeName = attribute.objectId + ':'+ attribute.name;
			}
			if ($(attributeInputId) == null) {
				var attributeInput = document.createElement("input");
				attributeInput.type  = 'hidden';
				attributeInput.id    = attributeInputId;
				attributeInput.name  = attributeName;
				if(attribute.oldValue){
					var oldValue = attribute.oldValue;
				}
				else{
					var oldValue = this._info.get(attribute.objectId);
					oldValue = oldValue[attribute.name];
				}
				attributeInput.value = oldValue;
				this.undoWidget.domNode.appendChild(attributeInput);
				this._htmlUndo.setDefaultValue(attributeInput);
			}
			var attributeInput = $(attributeInputId);
			if(!attribute.oldValue){
				this._info.get(attribute.objectId)[attribute.name] = attribute.value;
			}
			attributeInput.value = attribute.value;
			this._htmlUndo.addInput(attributeInput);
		},

		_reloadStore:function(){
			if(this.undoWidget && this.undoWidget.id == "undoWidget" && this.undoWidget.existsChanges() == false){
				this._info = $H();
				var childNodes = this.undoWidget.domNode.childNodes;
				for(var i=0, iLength=childNodes.length; i<iLength; i++){	// remove hidden inputs
					if(childNodes[i] && childNodes[i].value && childNodes[i].value == 'Delete'){
						this.undoWidget.domNode.removeChild(childNodes[i]);
					}
				}
				dojo.publish(this.id+'/reloadStore');

			}
		}
});

dojo.extend(epages.cartridges.de_epages.presentation.widget.Objectstore,dojo.data.util.simpleFetch);

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Objecttree"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Objecttree"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.presentation.widget.Objectcontroller

*/
dojo.provide("epages.cartridges.de_epages.presentation.widget.Objecttree");



dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.Objecttree",
	[dijit.Tree],
	{
		/**
		 * public properties
		 */
		selectedNodeId     : undefined,
		persist            : false,
		/**
		 * private properties
		 */
		_translation       : new epages.io.Translation(dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget', 'templates/translation'), 'auto'), // epages.io.Translation - translation object

		postCreate  : function() {
			this.inherited("postCreate", arguments);
			dojo.subscribe(this.model.store.id+'/changePosition',this,'_onStoreChangePosition');
			dojo.subscribe(this.model.store.id+'/changeParent',this,'_onStoreChangeParent');
			dojo.subscribe(this.model.store.id+'/changeVisibility',this,'_onStoreChangeVisibility');
			dojo.subscribe(this.model.store.id+'/reloadStore',this,'_reloadTree');
			var me = this;
			//set Children state when node expands
			dojo.subscribe(this.id+'/nodeexpand',function(node){
				me.setChildrenState(node);
				});
			// add item for root object
			 this.item = this.model.store.fetchItemByIdentity(this.model.query.id);
			 dojo.mixin(this.rootNode.item,this.item);
			// set Selected node on load
			if(this.selectedNodeId){
				this.focusNodeById(this.selectedNodeId);
			}

			//set Icons for Children of Tree and connect setChildren method to prototype of TreeNodes
			this.setChildrenState(this.rootNode);
			// set Icon of root node

			this.setState(this.rootNode,this.item.IsVisibleContentView);
		},

		focusNodeById: function(/* objectid */id) {
			// summary: expands & selects node in tree
				var currentItem = this.model.store.fetchItemByIdentity(id);
				var path = [id];
				while (currentItem.objectId != this.model.query.id) {
					currentItem = this.model.store.fetchItemByIdentity(currentItem.parentId);
					if(currentItem == undefined){
						return;
					}
					path.unshift(currentItem.objectId);
				}
				this.item.parentId = undefined;
				for( var i=0,iLength=path.length ; i<iLength ; i++ ) {
					var objectId = path[i];
					var node = this._getNodeByObjectId(objectId);
					if(node.rootNode){
						this._expandNode(node.rootNode);
					}
					else{
						this._expandNode(node);
					}
					if (i == path.length - 1) {
						if(node.rootNode){
							node = node.rootNode;
							this.item = this.model.store.fetchItemByIdentity(this.item.objectId);
							node.item = this.item;
						}
						window.setTimeout(dojo.hitch(this,this._onNodeFocus,node),20);
						epages.event.fire(node.labelNode, 'focus');
						// timeout is needed, without timeout after reload the tree does not select the current element correct
						//caused problems in the ToolNewPage EPG-27243
						window.setTimeout(function(){
							epages.event.fire(node.labelNode, 'click');
						},1);

						dojo.publish(this.id+'/select',[node]);
						if(epages && epages.vars){
							epages.vars.currentSelectedObjectID = node.item.objectId;
						}
					}
				}
			},

		focusNode: function(node) {
			this._onNodeFocus(node);
		},
		_onNodeFocus: function(/*dijit._Widget*/ node){
			// summary:
			//		Called when a TreeNode gets focus, either by user clicking
			//		it, or programatically by arrow key handling code.
			// description:
			//		It marks that the current node is the selected one, and the previously
			//		selected node no longer is.

			if(node){
				if(node != this.lastFocused && this.lastFocused && !this.lastFocused._destroyed){
					// mark that the previously selected node is no longer the selected one
					this.blurNode();
					this.lastFocused.setSelected(false);
				}

				// mark that the new node is the currently selected one
				dojo.addClass(node.labelNode,"Selected");
				node.setSelected(true);
				this.lastFocused = node;
			}
		},

		blurNode: function() {
			var node = this.lastFocused;
			if(!node){
				return;
			}
			var labelNode = node.labelNode;
			dojo.removeClass(labelNode, "Selected");
			labelNode.setAttribute("tabIndex", "-1");
		},

		onClick: function(item, node){
			if(item && item.children !== undefined){
				this._expandNode(node);

				this.setChildrenState(node);
			}
			dojo.publish(this.id+'/select',[node]);
			if(epages && epages.vars){
				epages.vars.currentSelectedObjectID = node.item.objectId;
			}
			//if item with to many children error was clicked restore expand node
			var item = this.model.store.fetchItemByIdentity(node.item.objectId);
			if(item.error && item.error == 'ERROR_TOO_MANY_CHILDREN'){
				node.state = "UNCHECKED";
				node.isExpandable = true;
				node._setExpando(false);
			}

			// use jquery to release event in top frame (force blur for active CKEditors)
			top.jq('body').trigger("click");
		},

		selectNodeByObjectId : function(/* string */ objectId) {
		// summary:  select a tree node by object id
			var node = this._getNodeByObjectId(objectId);
			this.onClick(node.item, node.rootNode ? node.rootNode : node);
		},

		currentItem: function(){
			return this.lastFocused.item;
		},

		currentObjectID: function(){
			return this.lastFocused.item.objectId;
		},

		deleteCurrent: function() {
			var node = this.lastFocused;
			//treenode cant't be delete
			if (node === undefined || node.rootNode || node.item.ClassAlias == "StartPage"  || node.item.isProduct == true){
				return;
			}
			if(this.model.store.deleteItem(node.item)){
				node.domNode.style.display = "none";
			}
			var parentNode = node.getParent();
			if(parentNode){
				this._onNodeFocus(parentNode);
				dojo.publish(this.id+'/select',[parentNode]);
				if(epages && epages.vars){
					epages.vars.currentSelectedObjectID = parentNode.item.objectId;
				}
				var children = parentNode.getChildren();
				var visible = false;
				for( var i=0,iLength=children.length ; i<iLength ; i++ ){
					if(children[i].domNode.style.display != "none"){
						visible = true;
					}
				}
				if(visible != true){
					parentNode.isExpandable = false;
					parentNode.isExpanded = false;
					parentNode._setExpando(false);
				}
			}
		},

		moveUpCurrent:   function () {
			var node = this.lastFocused;
			//can not move (tree node) or products
			if (node === undefined || node.rootNode || node.item.isProduct){
				return;
			}
			if(this.model.store.moveItem(-1,node.item)){
				var parentWidget = node.getParent();
				var TreeNodes = parentWidget.getChildren();
				var index = $A(TreeNodes).find(node);
				$A(TreeNodes).insertAt(index-1,node);
				$A(TreeNodes).remove(index+1);
				$A(TreeNodes).each(function(el) {
					parentWidget.addChild(el);
				});
				this._onNodeFocus(node);
			}
		},

		moveDownCurrent: function () {
			var node = this.lastFocused;
			//can not move (tree node) or products
			if (node === undefined || node.rootNode || node.item.isProduct){
				return;
			}
			if(this.model.store.moveItem( 1,node.item)){
				var parentWidget = node.getParent();
				var TreeNodes = parentWidget.getChildren();
				var index = $A(TreeNodes).find(node);
				$A(TreeNodes).insertAt(index+2,node);
				$A(TreeNodes).remove(index);
				$A(TreeNodes).each(function(el) {
					parentWidget.addChild(el);
				});
				this._onNodeFocus(node);
			}
		},

		_onStoreChangePosition: function(opt){
			var node = this._getNodeByObjectId(opt.item.objectId);
			var newPosition = opt.item.position;
			var oldPosition = opt.oldPosition;
			var parentWidget = node.getParent();
			var treeNodes = parentWidget.getChildren();
			var treeNodesArray = $A(treeNodes);
			//find old Position in ChildrenArray
			var index = treeNodesArray.find(node);
			if(oldPosition == newPosition){
				this._reloadTree();
				return;
			}
			if(oldPosition > newPosition){
				//move up
				if(index == 0){
					console.warn('first in Array can not move up');
				}
				else{
					//insert one element before and remove old element
					treeNodesArray.insertAt(index-1,node);
					treeNodesArray.remove(index+1);
				}
			}
			if(oldPosition < newPosition){
				//move down
				//insert one element after and remove old element
				treeNodesArray.insertAt(index+2,node);
				treeNodesArray.remove(index);
			}
			treeNodesArray.each(function(el) {
					parentWidget.addChild(el);
				});
		},

		_reloadNode: function(node){
			if(node.isExpanded == true){
				this._collapseNode(node);
			}
			node.state = "UNCHECKED";
			if(node.item.children && node.item.children.length > 0){
				node.isExpandable = true;
				node._setExpando(false);
				this._expandNode(node);
			}
			else{
				node.isExpandable = false;
				node._setExpando(false);
			}
			this.setState(node,node.item.IsVisibleContentView);
		},

		_reloadTree: function(noFocus){
			var lastId = (this.lastFocused) ? this.lastFocused.item.objectId : undefined;
			this._itemNodesMap = {};
			this.rootNode.item = this.model.store.fetchItemByIdentity(this.rootNode.item.objectId, true);
			this._reloadNode(this.rootNode);
			if(lastId && !noFocus){
				this.focusNodeById(lastId);
			}
		},

		_getNodeByObjectId: function(objectId, parentNode) {
			if (parentNode == undefined){
				parentNode = this.rootNode;
			}
			if(objectId == this.item.objectId){
				return this;
			}
			var nodesWithChildren = [];
			var children = parentNode.getChildren();
			for( var i=0,iLength=children.length ; i<iLength ; i++ ) {
				var node = children[i];
				if (node.item.objectId == objectId){
					return node;
				}
				if (node.getChildren() && node.getChildren().length > 0){
					nodesWithChildren.push(node);
				}
			}
			for( var i=0,iLength=nodesWithChildren.length ; i<iLength ; i++ ) {
				var node = this._getNodeByObjectId(objectId, nodesWithChildren[i]);
				if (node != null){
					return node;
				}
			}
			return null;
		},

		_onStoreChangeParent: function(opt){
			var node = this._getNodeByObjectId(opt.item.objectId);
			if(!node){
				//console.debug('cant find node');
				 return;
				}
			if(opt['delete']){
				node.domNode.style.display = 'none';
				var parentNode = node.getParent();
				if(parentNode){
					this._onNodeFocus(parentNode);
					dojo.publish(this.id+'/select',[parentNode]);
				}
				return;
			}
			//if Old Parent and New Parent equal than the it was an undo delete
			if(opt.oldParent == opt.item.parentId){
				node.domNode.style.display = '';
				return;
			}
			var oldParentNode = this._getNodeByObjectId(opt.oldParent);
			var newParentNode = this._getNodeByObjectId(opt.item.parentId);
			if(oldParentNode.rootNode){
				this._indentNode(node,newParentNode,oldParentNode.rootNode);
			}
			else if(newParentNode.rootNode){
				this._outdentNode(node,newParentNode.rootNode,oldParentNode);
			}
			else{
				if($A(newParentNode.item.children).exists(oldParentNode.item.objectId)){
					this._outdentNode(node,newParentNode,oldParentNode);
				}
				if($A(oldParentNode.item.children).exists(newParentNode.item.objectId)){
					this._indentNode(node,newParentNode,oldParentNode);
				}
			}
		},

		_indentNode: function(node,newParentNode,oldParentNode){
			newParentNode.item = this.model.store.fetchItemByIdentity(newParentNode.item.objectId);
			oldParentNode.item = this.model.store.fetchItemByIdentity(oldParentNode.item.objectId);
			this._reloadNode(newParentNode);
			this._reloadNode(oldParentNode);
			var objectId = node.item.objectId;
			var newNode = this._getNodeByObjectId(objectId);
			this._onNodeFocus(newNode);
		},

		indentCurrent: function () {
			var node = this.lastFocused;
			//can not indent (tree node) or products
			if (node === undefined || node.rootNode || node.item.isProduct){
				return;
			}
			var oldParentNode = this._getNodeByObjectId(node.item.parentId);
			if(oldParentNode.rootNode){
				oldParentNode = oldParentNode.rootNode;
			}
			var newParentObjectId = this.model.store.indentItem(node.item);
			if(newParentObjectId){
				var newParentNode = this._getNodeByObjectId(newParentObjectId);
				// Flag to decide if a node is indented or outdented
				this.model.store.indentNode = true;
				this._indentNode(node,newParentNode,oldParentNode);
			}
			else{
				console.warn('can not ident');
			}
		},

		_outdentNode: function(node,newParentNode,oldParentNode){
			this._reloadNode(newParentNode);
			this._reloadNode(oldParentNode);
			var objectId = node.item.objectId;
			var newNode = this._getNodeByObjectId(objectId);
			this._onNodeFocus(newNode);
		},

		outdentCurrent: function () {
			var node = this.lastFocused;
			// can not outdent tree node (start page)
			if (node === undefined || node.rootNode || node.item.isProduct){
				return;
			}
			// can not outdent first level
			var oldParentNode = this._getNodeByObjectId(node.item.parentId);
			if (oldParentNode == undefined || oldParentNode.rootNode){
				return;
			}
			// find position of parent to insert node behind
			var newParentObjectId = this.model.store.outdentItem(node.item);
			if(newParentObjectId){
				var newParentNode = this._getNodeByObjectId(newParentObjectId);
				// Flag to decide if a node is indented or outdented
				this.model.store.indentNode = true;
				if(!newParentNode || newParentNode.rootNode){
					newParentNode = this.rootNode;
				}
				this._outdentNode(node,newParentNode,oldParentNode);
			}
	},

		createObject: function (/* form element */ classNode, /* form element */ nameNode, /* string? */ enterNameMessage, /* string? */ insertParentObjectId,isVisible) {
		// summary:
		//		create a new object
		// classNode:
		//		form element with class node id
		// nameNode:
		// 		form element with object name
		// enterNameMessage:
		//		possibility to pass e debug message if nameNode value is empty
		// insertParentObjectId:
		// 	  specify a different parent object

			var node = this.lastFocused;
			if (node === undefined){
				return;
			}
			var objectId = undefined;
			if(node.item){
				objectId = node.item.objectId;
			}	else{
				if(node.rootNode){
					objectId = this.model.store.objectId;
				}
			}
			if(insertParentObjectId && this.model.store.fetchItemByIdentity(insertParentObjectId)) {	// override current parent object
				objectId = insertParentObjectId;
			}
			if(!objectId){
				return;
			}
			var name = $E(nameNode).get();
			var classId = $E(classNode).get();
			if (name == '') {
				if (enterNameMessage == ''){
					enterNameMessage = 'Enter a name !';
				}
				console.warn(enterNameMessage);
				return;
			}
			newItem = this.model.store.createObject(objectId, classId, name,isVisible);
			if(newItem){
				node.item = this.model.store.fetchItemByIdentity(node.item.objectId);
				if(!node.isExpandable){
					node.makeExpandable();
				}
				this._reloadTree(true);
				//check if all children of parent are visible (not marked as deleted)
				var children = node.getChildren();
				for( var i=0,iLength=children.length ; i<iLength ; i++ ){
					//correct is deleted after reload
					if($('parentInput_'+children[i].item.objectId) && $('parentInput_'+children[i].item.objectId).value == 'Delete'){
						children[i].item.isDeleted = true;
					}
					if(children[i].item.isDeleted == true){
						children[i].domNode.style.display = 'none';
					}
				}
				var newNode = this._getNodeByObjectId(newItem.objectId);
				this.focusNodeById(newItem.objectId);
			}
			else {
				console.warn('unable to created object in '+ this.declaredClass);
			}
		},

		getIconClass: function(/*dojo.data.Item*/ item){
				return item.persistentIconClass || '';
		},
		getLabelClass: function(/*dojo.data.Item*/ item){
			// summary: user overridable function to return CSS class name to display label
			// description: if no return value is set dojo adds a class "undefined" to every label in the tree
			// tags: extendable
			return '';
		},

		setChildrenState: function(node){
			var children = node.getChildren();
			for( var i=0,iLength=children.length ; i<iLength ; i++ ){
				this.setState(children[i],children[i].item.IsVisibleContentView);
			}
		},

		setState: function(node,IsVisibleContentView){
			IsVisibleContentView = parseInt(IsVisibleContentView);
			var item = node.item;
			if(node.rootNode){
				item =this.item;
				node = node.rootNode;
			}
			//remove class Icon of IconNode if Node has no ClassAlias and is not a product
			if(!item.ClassAlias && !item.isProduct){
				dojo.removeClass(node.iconNode,"Icon");
			}
			else{
				var iconSpriteName = epages.cartridges.de_epages.presentation.icon.getIconSpriteName(item.ClassAlias, IsVisibleContentView, item.isProduct);
				dojo.addClass(node.iconNode, "Sprite");
				dojo.removeClass(node.iconNode, iconSpriteName + "_inactive");
				dojo.addClass(node.iconNode, iconSpriteName);
			}
			if(IsVisibleContentView) {
				dojo.removeClass(node.contentNode,"NotVisible");
			}else {
				dojo.addClass(node.contentNode,"NotVisible");
			}
			item.persistentIconClass = node.iconNode.className;
		},

		changeVisibilityCurrent: function(){
			var node = this.lastFocused;
			if (node === undefined){
				return;
			}
			node.item.IsVisibleContentView = this.model.store.changeVisibility(node.item);
			this.setState(node,node.item.IsVisibleContentView);
			dojo.publish(this.id+'/changeCurrentVisibility',[node]);
		},

		_onStoreChangeVisibility: function(opt){
				var node = this._getNodeByObjectId(opt.item.objectId);
				var IsVisibleContentView = parseInt(opt.item.IsVisibleContentView);
				this.setState(node,IsVisibleContentView);
				if(node == this.lastFocused){
					dojo.publish(this.id+'/changeCurrentVisibility',[node]);
				}
		},
		currentItem: function(){
			return this.lastFocused.item;
		},

		onOpen: function(item,node){
			// add childNodes to childArray of item
			var childNodes = node.getChildren();
			var itemChildArray = node.item.children;
			for( var i=0,iLength=childNodes.length ; i<iLength ; i++ ){
				if(childNodes[i].item && childNodes[i].item.objectId){
					var childId = childNodes[i].item.objectId;
					if(!$A(itemChildArray).exists(childId)){
						node.item.children.push(childId);
					}
				}
			}
		},

		_onExpandoClick: function(/*Object*/ message){
			// summary: user clicked the +/- icon; expand or collapse my children.
			var node = message.node;

			// If we are collapsing, we might be hiding the currently focused node.
			// Also, clicking the expando node might have erased focus from the current node.
			// For simplicity's sake just focus on the node with the expando.

			if(node.isExpanded){
				this._collapseNode(node);
			}else{
				this._expandNode(node);
				this.setChildrenState(node);
			}
			//if a node with too many children was expanded the server gives an error code
			//check this code and show warning if necessary
			var item = this.model.store.fetchItemByIdentity(node.item.objectId);
			if(item.error && item.error == 'ERROR_TOO_MANY_CHILDREN'){
				this._showManyChildrenWarning(this.item.objectId);
			}
		},

		_showManyChildrenWarning: function(id){
			//summary: shows warning if selected item has too many children to show
			var currentObjectLink = '<br /><br /><a link class="DialogAction" style="font-weight:bold" onclick="window.location.href=\'?ObjectID='+id+'&ViewAction=MBO-ViewGeneral\'" >'+this._translation.get('OpenDatasheetView')+'</a>';
				dojo.publish("uimessage/show", [ this._translation.get('TooManyChildrenWarning'), this._translation.get('TooManyChildrenHint') + currentObjectLink, 'Dialog', {
					titleBar: this._translation.get('Notification'),
					typeClass: 'Notification'
				}]);
		}
	}
);

}


/* package: ep_shop_preview.js.uncompressed */
/*
	Copyright (c) 2004-2011, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/

/*
	This is an optimized version of Dojo, built for deployment and not for
	development. To get sources and documentation, please visit:

		http://dojotoolkit.org
*/

if(!dojo._hasResource['epages.lang.color']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.lang.color'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.lang.color');

epages.lang.color = {

	_hex:	function(c){
		c = parseInt(c).toString(16);
		return c.length < 2 ? "0" + c : c;
	},

	rgb2Hex: function(rgb){
		if (rgb.transparent == 1){
			return "transparent";
		}
		return '#' + this._hex(rgb.r) + this._hex(rgb.g) + this._hex(rgb.b);
	},

	hex2Rgb: function(hex) {
		if (hex == "transparent" || hex == "none"){
			return { r:255, g:255, b:255, transparent:1 };
		}
		hex = hex.toUpperCase();
		if(hex.charAt(0) == "#"){
			hex = hex.substring(1,hex.length);
		}
		if (hex.length == 6) {
			var rgb = {
				r: parseInt(hex.substring(0,2),16),
				g: parseInt(hex.substring(2,4),16),
				b: parseInt(hex.substring(4,6),16),
				transparent: 0
			};
		} else if (hex.length == 3) {
			var rgb = {
				r: parseInt(hex.substring(0,1) + hex.substring(0,1),16),
				g: parseInt(hex.substring(1,2) + hex.substring(1,2),16),
				b: parseInt(hex.substring(2,3) + hex.substring(2,3),16),
				transparent: 0
			};
		} else {
			//return white if no hex value was given
			var rgb = {
				r: 255,
				g: 255,
				b: 255,
				transparent: 0
			};
		}
		if(isNaN(rgb.r)){ rgb.r = 0; }
		if(isNaN(rgb.g)){ rgb.g = 0; }
		if(isNaN(rgb.b)){ rgb.b = 0; }

		return (rgb);
	},

	rgb2Hsb: function(rgb) {
		var min = new Number(Math.min(rgb.r, rgb.g));
		var max = new Number(Math.max(rgb.r, rgb.g));
		var sat = new Number(0);
		var lumin = new Number(0);
		min = Math.min(min, rgb.b);
		max = Math.max(max, rgb.b);
		var delta = (max - min);
		if (max != 0) {
			sat = delta / max;
			lumin = max / 255;
		}
		var hue = 0;
		if ( delta != 0 ) {
			if (rgb.r==max){
				hue = (rgb.g - rgb.b) / delta;
			}else if (rgb.g==max){
				hue = 2 + ((rgb.b - rgb.r) / delta);
			}else{
				hue = 4 + ((rgb.r - rgb.g) / delta);
			}
		}
		hue = (hue * 60);
		if (hue < 0){
			hue = hue + 360;
		}
		var tSat = (sat * 100);
		var tLum = (lumin * 100);

		return {s: Math.round(tSat), b: Math.round(tLum), h: Math.round(hue)};
	},

	hsb2Rgb: function(hsb) {
		var r = 0; var g = 0; var b = 0;
		var sat = hsb.s/100;
		var lum = hsb.b/100;
		//console.debug('sat ',sat,' lum ',lum,' hsb.h ',hsb.h);
		if (sat == 0) {
			r = lum;  g = r;  b = r;
		}
		else {
			var h = hsb.h/60;
			//if(h == 6) h = 0;
			var i = parseInt(h);
			var p = lum * (1.0 - sat);
			var q = lum * (1.0 - sat * (h - i));
			var t = lum * (1.0 - sat * (1- (h - i)));
			switch (i) {
				case 0: r = lum; g = t;   b = p;   break;
				case 1: r = q;   g = lum; b = p;   break;
				case 2: r = p;   g = lum; b = t;   break;
				case 3: r = p;   g = q;   b = lum; break;
				case 4: r = t;   g = p;   b = lum; break;
				case 5: r = lum; g = p;   b  = q;  break;
				case 6: r = lum; g = t;   b  = p;  break;
			}
		}
		return { r : (r*255), g : (g*255) , b : (b*255) };
	},

	cssString2Rgb: function(cssString) {
		return this.hex2Rgb(epages.validate.css.color2Hex(cssString));
	}

};

}

if(!dojo._hasResource['epages.validate.css']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.validate.css'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.validate.css');




epages.validate.css.validColors = {
    'aliceblue': 'f0f8ff',
    'antiquewhite': 'faebd7',
    'aqua': '00ffff',
    'aquamarine': '7fffd4',
    'azure': 'f0ffff',
    'beige': 'f5f5dc',
    'bisque': 'ffe4c4',
    'black': '000000',
    'blanchedalmond': 'ffebcd',
    'blue': '0000ff',
    'blueviolet': '8a2be2',
    'brown': 'a52a2a',
    'burlywood': 'deb887',
    'cadetblue': '5f9ea0',
    'chartreuse': '7fff00',
    'chocolate': 'd2691e',
    'coral': 'ff7f50',
    'cornflowerblue': '6495ed',
    'cornsilk': 'fff8dc',
    'crimson': 'dc143c',
    'cyan': '00ffff',
    'darkblue': '00008b',
    'darkcyan': '008b8b',
    'darkgoldenrod': 'b8860b',
    'darkgray': 'a9a9a9',
    'darkgrey': 'a9a9a9',
    'darkgreen': '006400',
    'darkkhaki': 'bdb76b',
    'darkmagenta': '8b008b',
    'darkolivegreen': '556b2f',
    'darkorange': 'ff8c00',
    'darkorchid': '9932cc',
    'darkred': '8b0000',
    'darksalmon': 'e9967a',
    'darkseagreen': '8fbc8f',
    'darkslateblue': '483d8b',
    'darkslategray': '2f4f4f',
    'darkslategrey': '2f4f4f',
    'darkturquoise': '00ced1',
    'darkviolet': '9400d3',
    'deeppink': 'ff1493',
    'deepskyblue': '00bfff',
    'dimgray': '696969',
    'dimgrey': '696969',
    'dodgerblue': '1e90ff',
    'firebrick': 'b22222',
    'floralwhite': 'fffaf0',
    'forestgreen': '228b22',
    'fuchsia': 'ff00ff',
    'gainsboro': 'dcdcdc',
    'ghostwhite': 'f8f8ff',
    'gold': 'ffd700',
    'goldenrod': 'daa520',
    'gray': '808080',
    'grey': '808080',
    'green': '008000',
    'greenyellow': 'adff2f',
    'honeydew': 'f0fff0',
    'hotpink': 'ff69b4',
    'indianred': ':cd5c5c',
    'indigo': ':4b0082',
    'ivory': 'fffff0',
    'khaki': 'f0e68c',
    'lavender': 'e6e6fa',
    'lavenderblush': 'fff0f5',
    'lawngreen': '7cfc00',
    'lemonchiffon': 'fffacd',
    'lightblue': 'add8e6',
    'lightcoral': 'f08080',
    'lightcyan': 'e0ffff',
    'lightgoldenrodyellow': 'fafad2',
    'lightgray': 'd3d3d3',
    'lightgrey': 'd3d3d3',
    'lightgreen': '90ee90',
    'lightpink': 'ffb6c1',
    'lightsalmon': 'ffa07a',
    'lightseagreen': '20b2aa',
    'lightskyblue': '87cefa',
    'lightslategray': '778899',
    'lightslategrey': '778899',
    'lightsteelblue': 'b0c4de',
    'lightyellow': 'ffffe0',
    'lime': '00ff00',
    'limegreen': '32cd32',
    'linen': 'faf0e6',
    'magenta': 'ff00ff',
    'maroon': '800000',
    'mediumaquamarine': '66cdaa',
    'mediumblue': '0000cd',
    'mediumorchid': 'ba55d3',
    'mediumpurple': '9370d8',
    'mediumseagreen': '3cb371',
    'mediumslateblue': '7b68ee',
    'mediumspringgreen': '00fa9a',
    'mediumturquoise': '48d1cc',
    'mediumvioletred': 'c71585',
    'midnightblue': '191970',
    'mintcream': 'f5fffa',
    'mistyrose': 'ffe4e1',
    'moccasin': 'ffe4b5',
    'navajowhite': 'ffdead',
    'navy': '000080',
    'oldlace': 'fdf5e6',
    'olive': '808000',
    'olivedrab': '6b8e23',
    'orange': 'ffa500',
    'orangered': 'ff4500',
    'orchid': 'da70d6',
    'palegoldenrod': 'eee8aa',
    'palegreen': '98fb98',
    'paleturquoise': 'afeeee',
    'palevioletred': 'd87093',
    'papayawhip': 'ffefd5',
    'peachpuff': 'ffdab9',
    'peru': 'cd853f',
    'pink': 'ffc0cb',
    'plum': 'dda0dd',
    'powderblue': 'b0e0e6',
    'purple': '800080',
    'red': 'ff0000',
    'rosybrown': 'bc8f8f',
    'royalblue': '4169e1',
    'saddlebrown': '8b4513',
    'salmon': 'fa8072',
    'sandybrown': 'f4a460',
    'seagreen': '2e8b57',
    'seashell': 'fff5ee',
    'sienna': 'a0522d',
    'silver': 'c0c0c0',
    'skyblue': '87ceeb',
    'slateblue': '6a5acd',
    'slategray': '708090',
    'slategrey': '708090',
    'snow': 'fffafa',
    'springgreen': '00ff7f',
    'steelblue': '4682b4',
    'tan': 'd2b48c',
    'teal': '008080',
    'thistle': 'd8bfd8',
    'tomato': 'ff6347',
    'turquoise': '40e0d0',
    'violet': 'ee82ee',
    'wheat': 'f5deb3',
    'white': 'ffffff',
    'whitesmoke': 'f5f5f5',
    'yellow': 'ffff00',
    'yellowgreen': '9acd32'
};

epages.validate.css.color2Hex = function (value) {
    value = value.toLowerCase();
    var rx;
    if (value.match(/transparent/i)) {
        // transparent
        return "transparent";
    } else if (value.match(/^\s*$|none/i)) {
        //none
        return "none";
    } else if (value.match(/^#[0-9A-F]{6}$/i)) {
        // 6 digit hex rgb value (#1234FF or 1234FF)
        return value.toLowerCase();
    } else if (epages.validate.css.validColors[value] !== undefined) {
        // known color name
        return '#' + epages.validate.css.validColors[value];
    } else if (rx = value.match(/^#([0-9A-F])([0-9A-F])([0-9A-F])$/i)) {
        // 3 digit hex rgb value (#123 or #FFF)
        return ("#" + rx[1] + rx[1] + rx[2] + rx[2] + rx[3] + rx[3]).toLowerCase();
    } else if (rx = value.match(/^rgb\(\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*,\s*([0-9]{1,3})\s*\)$/i)) {
        // rgb values - pattern: "rgb(123,234,1)"
        return epages.lang.color.rgb2Hex({
            r: rx[1],
            g: rx[2],
            b: rx[3]
        }).toLowerCase();
    } else {
        return false;
    }
};

epages.validate.css.isColor = function (value) {
    return epages.validate.css.color2Hex(value) !== false;
};

epages.validate.css.isSize = function (value, settings, negativAllowed) {
    nbr_value = epages.string.cssSizeToNumber(value);
    if (nbr_value !== NaN && settings !== undefined) {
        if (settings.min && settings.max && (nbr_value < settings.min || nbr_value > settings.max)) {
            return 'NOT_IN_RANGE';
        }

        if (settings.min != null && nbr_value < settings.min) {
            return 'LOWER_THAN_MIN';
        }
        if (settings.max != null && nbr_value > settings.max) {
            return 'GREATER_THAN_MAX';
        }
    }

    var getExp = function (exp) {
        return new RegExp('^(' + (settings.autoAllowed ? 'auto|' : '') + (settings.negativeAllowed ? '-?' : '') + exp + ')$', 'i');
    };

    if (value.match(getExp('[0-9]+(px|pt)'))) {
        return true;
    }
    if (value.match(getExp('[0-9]*\.?[0-9]+(pc|%|mm|cm|em|in|ex)'))) {
        return true;
    }
    if (value.match(getExp('[0]+'))) {
        return true;
    }

    // comment.translate:NO_UNIT_VALUE,NO_UNIT,NO_NUMBER,FLOAT_NOT_ALLOWED,UNKNOWN_UNIT,UNKNOWN_ERROR
    if (value == "") {
        return 'NO_UNIT_VALUE';
    }
    if (value.match(getExp('[0-9]+'))) {
        return 'NO_UNIT';
    }
    if (!value.match(getExp('[0-9]*\.?[0-9]'))) {
        return 'NO_NUMBER';
    }
    if (value.match(getExp('[0-9]*\.[0-9]+(?:px|pt)'))) {
        return 'FLOAT_NOT_ALLOWED';
    }
    if (value.match(getExp('[0-9]*\.[0-9]'))) {
        return 'NO_UNIT';
    }
    if (value.match(getExp('[0-9]*\.?[0-9]+[a-z]+'))) {
        return 'UNKNOWN_UNIT';
    }
    return 'UNKNOWN_ERROR';
};

epages.validate.css.isWidth = epages.validate.css.isSize;
epages.validate.css.isHeight = epages.validate.css.isSize;
epages.validate.css.isPadding = epages.validate.css.isSize;
epages.validate.css.isMargin = epages.validate.css.isSize;

}

if(!dojo._hasResource['epages.validate.number']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.validate.number'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.validate.number');

epages.validate.number.isInteger = function(value, settings) {
  if (settings == null){
    settings = {};
  }
  // convert to string
  value += '';

	// comment.translate:NO_VALUE,NO_INTEGER,NOT_IN_RANGE,LOWER_THAN_MIN,GREATER_THAN_MAX
  if (value == ''){
  	return 'NO_VALUE';
  }
  if (!(/^(?:0|-?[1-9][0-9]*)$/).test(value)){
  	return 'NO_INTEGER';
 	}
  value = Number(value);
  if ((settings.min != null && value < settings.min) ||
      (settings.max != null && value > settings.max)){
      	return 'NOT_IN_RANGE';
  }
  if (settings.min != null && value < settings.min){
  	return 'LOWER_THAN_MIN';
  }
  if (settings.max != null && value > settings.max){
  	return 'GREATER_THAN_MAX';
  }
  return true;
};

}

if(!dojo._hasResource['epages.validate.string']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.validate.string'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.validate.string');

epages.validate.string.isXMLAttribute = function(attributeName) {
	if (attributeName == ''){
		return false;
	}

	// reference http://www.w3.org/TR/REC-xml/#NT-Name
	var XML_SYNTAX_BaseChar      = "[\u0041-\u005A\u0061-\u007A\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF\u0100-\u0131\u0134-\u013E\u0141-\u0148\u014A-\u017E\u0180-\u01C3\u01CD-\u01F0\u01F4-\u01F5\u01FA-\u0217\u0250-\u02A8\u02BB-\u02C1\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03CE\u03D0-\u03D6\u03DA\u03DC\u03DE\u03E0\u03E2-\u03F3\u0401-\u040C\u040E-\u044F\u0451-\u045C\u045E-\u0481\u0490-\u04C4\u04C7-\u04C8\u04CB-\u04CC\u04D0-\u04EB\u04EE-\u04F5\u04F8-\u04F9\u0531-\u0556\u0559\u0561-\u0586\u05D0-\u05EA\u05F0-\u05F2\u0621-\u063A\u0641-\u064A\u0671-\u06B7\u06BA-\u06BE\u06C0-\u06CE\u06D0-\u06D3\u06D5\u06E5-\u06E6\u0905-\u0939\u093D\u0958-\u0961\u0985-\u098C\u098F-\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09DC-\u09DD\u09DF-\u09E1\u09F0-\u09F1\u0A05-\u0A0A\u0A0F-\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32-\u0A33\u0A35-\u0A36\u0A38-\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8B\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2-\u0AB3\u0AB5-\u0AB9\u0ABD\u0AE0\u0B05-\u0B0C\u0B0F-\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32-\u0B33\u0B36-\u0B39\u0B3D\u0B5C-\u0B5D\u0B5F-\u0B61\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99-\u0B9A\u0B9C\u0B9E-\u0B9F\u0BA3-\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB5\u0BB7-\u0BB9\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C33\u0C35-\u0C39\u0C60-\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CDE\u0CE0-\u0CE1\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D28\u0D2A-\u0D39\u0D60-\u0D61\u0E01-\u0E2E\u0E30\u0E32-\u0E33\u0E40-\u0E45\u0E81-\u0E82\u0E84\u0E87-\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA-\u0EAB\u0EAD-\u0EAE\u0EB0\u0EB2-\u0EB3\u0EBD\u0EC0-\u0EC4\u0F40-\u0F47\u0F49-\u0F69\u10A0-\u10C5\u10D0-\u10F6\u1100\u1102-\u1103\u1105-\u1107\u1109\u110B-\u110C\u110E-\u1112\u113C\u113E\u1140\u114C\u114E\u1150\u1154-\u1155\u1159\u115F-\u1161\u1163\u1165\u1167\u1169\u116D-\u116E\u1172-\u1173\u1175\u119E\u11A8\u11AB\u11AE-\u11AF\u11B7-\u11B8\u11BA\u11BC-\u11C2\u11EB\u11F0\u11F9\u1E00-\u1E9B\u1EA0-\u1EF9\u1F00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2126\u212A-\u212B\u212E\u2180-\u2182\u3041-\u3094\u30A1-\u30FA\u3105-\u312C\uAC00-\uD7A3]";
	var XML_SYNTAX_Ideographic   = "[\u4E00-\u9FA5\u3007\u3021-\u3029]";
	var XML_SYNTAX_CombiningChar = "[\u0300-\u0345\u0360-\u0361\u0483-\u0486\u0591-\u05A1\u05A3-\u05B9\u05BB-\u05BD\u05BF\u05C1-\u05C2\u05C4\u064B-\u0652\u0670\u06D6-\u06DC\u06DD-\u06DF\u06E0-\u06E4\u06E7-\u06E8\u06EA-\u06ED\u0901-\u0903\u093C\u093E-\u094C\u094D\u0951-\u0954\u0962-\u0963\u0981-\u0983\u09BC\u09BE\u09BF\u09C0-\u09C4\u09C7-\u09C8\u09CB-\u09CD\u09D7\u09E2-\u09E3\u0A02\u0A3C\u0A3E\u0A3F\u0A40-\u0A42\u0A47-\u0A48\u0A4B-\u0A4D\u0A70-\u0A71\u0A81-\u0A83\u0ABC\u0ABE-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0B01-\u0B03\u0B3C\u0B3E-\u0B43\u0B47-\u0B48\u0B4B-\u0B4D\u0B56-\u0B57\u0B82-\u0B83\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD7\u0C01-\u0C03\u0C3E-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55-\u0C56\u0C82-\u0C83\u0CBE-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5-\u0CD6\u0D02-\u0D03\u0D3E-\u0D43\u0D46-\u0D48\u0D4A-\u0D4D\u0D57\u0E31\u0E34-\u0E3A\u0E47-\u0E4E\u0EB1\u0EB4-\u0EB9\u0EBB-\u0EBC\u0EC8-\u0ECD\u0F18-\u0F19\u0F35\u0F37\u0F39\u0F3E\u0F3F\u0F71-\u0F84\u0F86-\u0F8B\u0F90-\u0F95\u0F97\u0F99-\u0FAD\u0FB1-\u0FB7\u0FB9\u20D0-\u20DC\u20E1\u302A-\u302F\u3099\u309A]";
	var XML_SYNTAX_Digit         = "[\u0030-\u0039\u0660-\u0669\u06F0-\u06F9\u0966-\u096F\u09E6-\u09EF\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0BE7-\u0BEF\u0C66-\u0C6F\u0CE6-\u0CEF\u0D66-\u0D6F\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F29]";
	var XML_SYNTAX_Extender      = "[\u00B7\u02D0\u02D1\u0387\u0640\u0E46\u0EC6\u3005\u3031-\u3035\u309D-\u309E\u30FC-\u30FE]";
	var XML_SYNTAX_Letter        = XML_SYNTAX_BaseChar + "|" + XML_SYNTAX_Ideographic;
	var XML_SYNTAX_NameChar      = XML_SYNTAX_Letter + "|" + XML_SYNTAX_Digit + "|[-._:]|" + XML_SYNTAX_CombiningChar + "|" + XML_SYNTAX_Extender;
	var XML_SYNTAX_Name          = "^(" + XML_SYNTAX_Letter + "|[_:])" + "(" + XML_SYNTAX_NameChar + ")*$";

	return attributeName.match( new RegExp( XML_SYNTAX_Name ) ) ? true : false;
};
epages.validate.string.filterInvalidChars = function(/*string*/ insertString){
	// summary: removes invalid chars from given string
   // description: function removes invalid chars or combination of chars from given string
   // remove all backslashes can cause errors on the server
   // example:
   //    var result = epages.validate.string.filterInvalidChars('Affe/\Ente');
   // returns:  Affe/Ente
	var regExpString = /%5C/gi;
	insertString = encodeURIComponent(insertString);
	var returnString = insertString.replace(regExpString,'');
	returnString = decodeURIComponent(returnString);
	return returnString;
};

}

if(!dojo._hasResource["epages.widget.Validateinput"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Validateinput"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.widget.Validateinput");









(function(dj){

	var handleID = 0;
	
	var _validateInput = {
		/**
		* public properties
		*/
		validationType  : "",
		errorBox        : null,
		inputError      : false,
		undoWidgetId    : 'undoWidget',
		dictionary      : epages.io.dictionary,
		allowEmpty      : '0',
		/**
		 * settings: String 
		 * comma seperated parameters will be passed to the validate function
		 * as hash object (processed from string e.g. settings="min:10,max:100" becomes
		 * { min: 10, max: 100 } [Object])
		 */
		settings        : '',

		postCreate: function() {
			this.validationType = this.domNode.getAttribute('validationType') || this.validationType;
			this.undoWidgetId   = this.domNode.getAttribute('undoWidgetId') || this.undoWidgetId;
			this.settings       = this.domNode.getAttribute('settings') || this.settings;
			this.allowEmpty     = this.domNode.getAttribute('allowEmpty') || this.allowEmpty;
		
			//this.inherited("postCreate", arguments);
			this.allowEmpty = epages.string.toBoolean(this.allowEmpty);

			dojo.addOnLoad(this, "_appendEvent");

			//create Error-Attribute
			var atr = document.createAttribute("ep_error");
			atr.nodeValue = "0";
			this.domNode.setAttributeNode(atr);
			if (dojo.isString(this.settings) && this.settings.length > 0) {
			  this.settings = dojo.fromJson('{' + this.settings + '}');
			}
		},
		
		connect: function( node, event, fn ){
			handleID++;
			this.addHandle( 'validateInput.handle_'+handleID , node, event, fn );
			this.connectHandle( 'validateInput.handle_'+handleID );
		},

		_appendEvent: function() {
			if(this.validationType != "") {
				this.connect(this.domNode, 'onkeyup', '_keyupValidation');
				this.connect(this.domNode, 'onclick', '_keyupValidation');
				this.connect(this.domNode, 'onchange', '_onChange');
				this.connect(this.domNode, 'onkeyup', '_onChange');
				this.connect(this.domNode, 'onclick', '_onChange');
			}
		},

		_validate: function() {
			var value = this.domNode.value;
			if (value !== undefined) {
  			if (this.allowEmpty && value == ''){
  				return true;
  			}
				switch (this.validationType.toLowerCase()) {
					case 'integer':
						var result = epages.validate.number.isInteger(value, this.settings);
						break;
					case 'size':
						var result = epages.validate.css.isSize(value, this.settings);
						break;
					case 'color':
						// comment.translate:NO_COLOR_VALUE
						var result = epages.validate.css.isColor(value, this.settings) ? true : "NO_COLOR_VALUE";
						break;
					case 'date':
						var result = epages.validate.date.isDate(value, this.settings);
						break;
					case 'time':
						var result = epages.validate.date.isTime(value, this.settings);
						break;
					case 'datetime':
						var result = epages.validate.date.isDateTime(value, this.settings);
						break;
					default:
						console.warn("Unknown validationType " + this.validationType + " for widget " + this.id);
						break;
				}
				return result;
			}
		},

		_keyupValidation: function() {
			var result = this._validate();
			if(result == true){
				//remove Error
				this._removeError();
			} else {
				//add Css-Error-Class
				this._setError();
			}

			if (this.undoWidgetId !== undefined) {
				if ($$(this.undoWidgetId) !== undefined) {
					$$(this.undoWidgetId).undoObject.validateInput(this.domNode);
				} else {
					console.warn('undoWidget "' + this.undoWidgetId + '" does not exist. ('+this.declaredClass+')');
					this.undoWidgetId = undefined;
				}
			}
		},

		_setError: function() {
			dojo.addClass(this.domNode, "DialogError");
			//set Error-Attribute
			this.domNode.setAttribute("ep_error", "1");
			dojo.publish(this.id+'/Error',[{ id: this.id, errorState: true }]);
		},

		_removeError: function() {
			dojo.removeClass(this.domNode, "DialogError");
			//remove Error-Box
			if(this.domNode.getAttribute("ep_error") == "1") {
				dojo.publish("uimessage/hide", []);
			}
			//reset Error-Attribute
			this.domNode.setAttribute("ep_error", "0");
			dojo.publish(this.id+'/Error',[{ id: this.id, errorState: false }]);
		},

		_onChange: function() {
			//set 'px' as default-unit
			var result = this._validate();
			if (result != true) {
				//display Error-Box-Widget
				var position = $E(this.domNode).getAbsolutePosition();

				dojo.publish("uimessage/show", ["", this.dictionary.get(result, this.settings), "Bubble", {
					typeClass: "Warning",
					sizeClass: "Small",
					x: position.x,
					y: (position.y + this.domNode.clientHeight + 4)
				}]);
			}
			else {
				//hide Error-Box
				// dojo.publish("uimessage/hide", []);
			}
			this._keyupValidation();
		}
	};

	epages.widget.Validateinput = function( options, domNode ){
		this.destroy();
		
		var widget = new epages.widget.FormText( options, domNode );
		
			widget = dj.mixin( widget, _validateInput );
			
			widget.postCreate();

		return widget;
	};
	epages.widget.Validateinput.prototype = new dijit._Widget();

})(dojo);


}

if(!dojo._hasResource["dojo.dnd.Selector"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.Selector"] = true;
dojo.provide("dojo.dnd.Selector");




/*
	Container item states:
		""			- an item is not selected
		"Selected"	- an item is selected
		"Anchor"	- an item is selected, and is an anchor for a "shift" selection
*/

/*=====
dojo.declare("dojo.dnd.__SelectorArgs", [dojo.dnd.__ContainerArgs], {
	//	singular: Boolean
	//		allows selection of only one element, if true
	singular: false,

	//	autoSync: Boolean
	//		autosynchronizes the source with its list of DnD nodes,
	autoSync: false
});
=====*/

dojo.declare("dojo.dnd.Selector", dojo.dnd.Container, {
	// summary:
	//		a Selector object, which knows how to select its children
	
	/*=====
	// selection: Set<String>
	//		The set of id's that are currently selected, such that this.selection[id] == 1
	//		if the node w/that id is selected.  Can iterate over selected node's id's like:
	//	|		for(var id in this.selection)
	selection: {},
	=====*/

	constructor: function(node, params){
		// summary:
		//		constructor of the Selector
		// node: Node||String
		//		node or node's id to build the selector on
		// params: dojo.dnd.__SelectorArgs?
		//		a dictionary of parameters
		if(!params){ params = {}; }
		this.singular = params.singular;
		this.autoSync = params.autoSync;
		// class-specific variables
		this.selection = {};
		this.anchor = null;
		this.simpleSelection = false;
		// set up events
		this.events.push(
			dojo.connect(this.node, "onmousedown", this, "onMouseDown"),
			dojo.connect(this.node, "onmouseup",   this, "onMouseUp"));
	},
	
	// object attributes (for markup)
	singular: false,	// is singular property
	
	// methods
	getSelectedNodes: function(){
		// summary:
		//		returns a list (an array) of selected nodes
		var t = new dojo.NodeList();
		var e = dojo.dnd._empty;
		for(var i in this.selection){
			if(i in e){ continue; }
			t.push(dojo.byId(i));
		}
		return t;	// NodeList
	},
	selectNone: function(){
		// summary:
		//		unselects all items
		return this._removeSelection()._removeAnchor();	// self
	},
	selectAll: function(){
		// summary:
		//		selects all items
		this.forInItems(function(data, id){
			this._addItemClass(dojo.byId(id), "Selected");
			this.selection[id] = 1;
		}, this);
		return this._removeAnchor();	// self
	},
	deleteSelectedNodes: function(){
		// summary:
		//		deletes all selected items
		var e = dojo.dnd._empty;
		for(var i in this.selection){
			if(i in e){ continue; }
			var n = dojo.byId(i);
			this.delItem(i);
			dojo.destroy(n);
		}
		this.anchor = null;
		this.selection = {};
		return this;	// self
	},
	forInSelectedItems: function(/*Function*/ f, /*Object?*/ o){
		// summary:
		//		iterates over selected items;
		//		see `dojo.dnd.Container.forInItems()` for details
		o = o || dojo.global;
		var s = this.selection, e = dojo.dnd._empty;
		for(var i in s){
			if(i in e){ continue; }
			f.call(o, this.getItem(i), i, this);
		}
	},
	sync: function(){
		// summary:
		//		sync up the node list with the data map
		
		dojo.dnd.Selector.superclass.sync.call(this);
		
		// fix the anchor
		if(this.anchor){
			if(!this.getItem(this.anchor.id)){
				this.anchor = null;
			}
		}
		
		// fix the selection
		var t = [], e = dojo.dnd._empty;
		for(var i in this.selection){
			if(i in e){ continue; }
			if(!this.getItem(i)){
				t.push(i);
			}
		}
		dojo.forEach(t, function(i){
			delete this.selection[i];
		}, this);
		
		return this;	// self
	},
	insertNodes: function(addSelected, data, before, anchor){
		// summary:
		//		inserts new data items (see `dojo.dnd.Container.insertNodes()` method for details)
		// addSelected: Boolean
		//		all new nodes will be added to selected items, if true, no selection change otherwise
		// data: Array
		//		a list of data items, which should be processed by the creator function
		// before: Boolean
		//		insert before the anchor, if true, and after the anchor otherwise
		// anchor: Node
		//		the anchor node to be used as a point of insertion
		var oldCreator = this._normalizedCreator;
		this._normalizedCreator = function(item, hint){
			var t = oldCreator.call(this, item, hint);
			if(addSelected){
				if(!this.anchor){
					this.anchor = t.node;
					this._removeItemClass(t.node, "Selected");
					this._addItemClass(this.anchor, "Anchor");
				}else if(this.anchor != t.node){
					this._removeItemClass(t.node, "Anchor");
					this._addItemClass(t.node, "Selected");
				}
				this.selection[t.node.id] = 1;
			}else{
				this._removeItemClass(t.node, "Selected");
				this._removeItemClass(t.node, "Anchor");
			}
			return t;
		};
		dojo.dnd.Selector.superclass.insertNodes.call(this, data, before, anchor);
		this._normalizedCreator = oldCreator;
		return this;	// self
	},
	destroy: function(){
		// summary:
		//		prepares the object to be garbage-collected
		dojo.dnd.Selector.superclass.destroy.call(this);
		this.selection = this.anchor = null;
	},

	// markup methods
	markupFactory: function(params, node){
		params._skipStartup = true;
		return new dojo.dnd.Selector(node, params);
	},

	// mouse events
	onMouseDown: function(e){
		// summary:
		//		event processor for onmousedown
		// e: Event
		//		mouse event
		if(this.autoSync){ this.sync(); }
		if(!this.current){ return; }
		if(!this.singular && !dojo.isCopyKey(e) && !e.shiftKey && (this.current.id in this.selection)){
			this.simpleSelection = true;
			if(e.button === dojo.mouseButtons.LEFT){
				// accept the left button and stop the event
				// for IE we don't stop event when multiple buttons are pressed
				dojo.stopEvent(e);
			}
			return;
		}
		if(!this.singular && e.shiftKey){
			if(!dojo.isCopyKey(e)){
				this._removeSelection();
			}
			var c = this.getAllNodes();
			if(c.length){
				if(!this.anchor){
					this.anchor = c[0];
					this._addItemClass(this.anchor, "Anchor");
				}
				this.selection[this.anchor.id] = 1;
				if(this.anchor != this.current){
					var i = 0;
					for(; i < c.length; ++i){
						var node = c[i];
						if(node == this.anchor || node == this.current){ break; }
					}
					for(++i; i < c.length; ++i){
						var node = c[i];
						if(node == this.anchor || node == this.current){ break; }
						this._addItemClass(node, "Selected");
						this.selection[node.id] = 1;
					}
					this._addItemClass(this.current, "Selected");
					this.selection[this.current.id] = 1;
				}
			}
		}else{
			if(this.singular){
				if(this.anchor == this.current){
					if(dojo.isCopyKey(e)){
						this.selectNone();
					}
				}else{
					this.selectNone();
					this.anchor = this.current;
					this._addItemClass(this.anchor, "Anchor");
					this.selection[this.current.id] = 1;
				}
			}else{
				if(dojo.isCopyKey(e)){
					if(this.anchor == this.current){
						delete this.selection[this.anchor.id];
						this._removeAnchor();
					}else{
						if(this.current.id in this.selection){
							this._removeItemClass(this.current, "Selected");
							delete this.selection[this.current.id];
						}else{
							if(this.anchor){
								this._removeItemClass(this.anchor, "Anchor");
								this._addItemClass(this.anchor, "Selected");
							}
							this.anchor = this.current;
							this._addItemClass(this.current, "Anchor");
							this.selection[this.current.id] = 1;
						}
					}
				}else{
					if(!(this.current.id in this.selection)){
						this.selectNone();
						this.anchor = this.current;
						this._addItemClass(this.current, "Anchor");
						this.selection[this.current.id] = 1;
					}
				}
			}
		}
		dojo.stopEvent(e);
	},
	onMouseUp: function(e){
		// summary:
		//		event processor for onmouseup
		// e: Event
		//		mouse event
		if(!this.simpleSelection){ return; }
		this.simpleSelection = false;
		this.selectNone();
		if(this.current){
			this.anchor = this.current;
			this._addItemClass(this.anchor, "Anchor");
			this.selection[this.current.id] = 1;
		}
	},
	onMouseMove: function(e){
		// summary
		//		event processor for onmousemove
		// e: Event
		//		mouse event
		this.simpleSelection = false;
	},
	
	// utilities
	onOverEvent: function(){
		// summary:
		//		this function is called once, when mouse is over our container
		this.onmousemoveEvent = dojo.connect(this.node, "onmousemove", this, "onMouseMove");
	},
	onOutEvent: function(){
		// summary:
		//		this function is called once, when mouse is out of our container
		dojo.disconnect(this.onmousemoveEvent);
		delete this.onmousemoveEvent;
	},
	_removeSelection: function(){
		// summary:
		//		unselects all items
		var e = dojo.dnd._empty;
		for(var i in this.selection){
			if(i in e){ continue; }
			var node = dojo.byId(i);
			if(node){ this._removeItemClass(node, "Selected"); }
		}
		this.selection = {};
		return this;	// self
	},
	_removeAnchor: function(){
		if(this.anchor){
			this._removeItemClass(this.anchor, "Anchor");
			this.anchor = null;
		}
		return this;	// self
	}
});

}

if(!dojo._hasResource["dojo.dnd.Avatar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.Avatar"] = true;
dojo.provide("dojo.dnd.Avatar");



dojo.declare("dojo.dnd.Avatar", null, {
	// summary:
	//		Object that represents transferred DnD items visually
	// manager: Object
	//		a DnD manager object

	constructor: function(manager){
		this.manager = manager;
		this.construct();
	},

	// methods
	construct: function(){
		// summary:
		//		constructor function;
		//		it is separate so it can be (dynamically) overwritten in case of need
		this.isA11y = dojo.hasClass(dojo.body(),"dijit_a11y");
		var a = dojo.create("table", {
				"class": "dojoDndAvatar",
				style: {
					position: "absolute",
					zIndex:   "1999",
					margin:   "0px"
				}
			}),
			source = this.manager.source, node,
			b = dojo.create("tbody", null, a),
			tr = dojo.create("tr", null, b),
			td = dojo.create("td", null, tr),
			icon = this.isA11y ? dojo.create("span", {
						id : "a11yIcon",
						innerHTML : this.manager.copy ? '+' : "<"
					}, td) : null,
			span = dojo.create("span", {
				innerHTML: source.generateText ? this._generateText() : ""
			}, td),
			k = Math.min(5, this.manager.nodes.length), i = 0;
		// we have to set the opacity on IE only after the node is live
		dojo.attr(tr, {
			"class": "dojoDndAvatarHeader",
			style: {opacity: 0.9}
		});
		for(; i < k; ++i){
			if(source.creator){
				// create an avatar representation of the node
				node = source._normalizedCreator(source.getItem(this.manager.nodes[i].id).data, "avatar").node;
			}else{
				// or just clone the node and hope it works
				node = this.manager.nodes[i].cloneNode(true);
				if(node.tagName.toLowerCase() == "tr"){
					// insert extra table nodes
					var table = dojo.create("table"),
						tbody = dojo.create("tbody", null, table);
					tbody.appendChild(node);
					node = table;
				}
			}
			node.id = "";
			tr = dojo.create("tr", null, b);
			td = dojo.create("td", null, tr);
			td.appendChild(node);
			dojo.attr(tr, {
				"class": "dojoDndAvatarItem",
				style: {opacity: (9 - i) / 10}
			});
		}
		this.node = a;
	},
	destroy: function(){
		// summary:
		//		destructor for the avatar; called to remove all references so it can be garbage-collected
		dojo.destroy(this.node);
		this.node = false;
	},
	update: function(){
		// summary:
		//		updates the avatar to reflect the current DnD state
		dojo[(this.manager.canDropFlag ? "add" : "remove") + "Class"](this.node, "dojoDndAvatarCanDrop");
		if (this.isA11y){
			var icon = dojo.byId("a11yIcon");
			var text = '+';   // assume canDrop && copy
			if (this.manager.canDropFlag && !this.manager.copy) {
				text = '< '; // canDrop && move
			}else if (!this.manager.canDropFlag && !this.manager.copy) {
				text = "o"; //!canDrop && move
			}else if(!this.manager.canDropFlag){
				text = 'x';  // !canDrop && copy
			}
			icon.innerHTML=text;
		}
		// replace text
		dojo.query(("tr.dojoDndAvatarHeader td span" +(this.isA11y ? " span" : "")), this.node).forEach(
			function(node){
				node.innerHTML = this._generateText();
			}, this);
	},
	_generateText: function(){
		// summary: generates a proper text to reflect copying or moving of items
		return this.manager.nodes.length.toString();
	}
});

}

if(!dojo._hasResource["dojo.dnd.Manager"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.Manager"] = true;
dojo.provide("dojo.dnd.Manager");





dojo.declare("dojo.dnd.Manager", null, {
	// summary:
	//		the manager of DnD operations (usually a singleton)
	constructor: function(){
		this.avatar  = null;
		this.source = null;
		this.nodes = [];
		this.copy  = true;
		this.target = null;
		this.canDropFlag = false;
		this.events = [];
	},

	// avatar's offset from the mouse
	OFFSET_X: 16,
	OFFSET_Y: 16,
	
	// methods
	overSource: function(source){
		// summary:
		//		called when a source detected a mouse-over condition
		// source: Object
		//		the reporter
		if(this.avatar){
			this.target = (source && source.targetState != "Disabled") ? source : null;
			this.canDropFlag = Boolean(this.target);
			this.avatar.update();
		}
		dojo.publish("/dnd/source/over", [source]);
	},
	outSource: function(source){
		// summary:
		//		called when a source detected a mouse-out condition
		// source: Object
		//		the reporter
		if(this.avatar){
			if(this.target == source){
				this.target = null;
				this.canDropFlag = false;
				this.avatar.update();
				dojo.publish("/dnd/source/over", [null]);
			}
		}else{
			dojo.publish("/dnd/source/over", [null]);
		}
	},
	startDrag: function(source, nodes, copy){
		// summary:
		//		called to initiate the DnD operation
		// source: Object
		//		the source which provides items
		// nodes: Array
		//		the list of transferred items
		// copy: Boolean
		//		copy items, if true, move items otherwise
		this.source = source;
		this.nodes  = nodes;
		this.copy   = Boolean(copy); // normalizing to true boolean
		this.avatar = this.makeAvatar();
		dojo.body().appendChild(this.avatar.node);
		dojo.publish("/dnd/start", [source, nodes, this.copy]);
		this.events = [
			dojo.connect(dojo.doc, "onmousemove", this, "onMouseMove"),
			dojo.connect(dojo.doc, "onmouseup",   this, "onMouseUp"),
			dojo.connect(dojo.doc, "onkeydown",   this, "onKeyDown"),
			dojo.connect(dojo.doc, "onkeyup",     this, "onKeyUp"),
			// cancel text selection and text dragging
			dojo.connect(dojo.doc, "ondragstart",   dojo.stopEvent),
			dojo.connect(dojo.body(), "onselectstart", dojo.stopEvent)
		];
		var c = "dojoDnd" + (copy ? "Copy" : "Move");
		dojo.addClass(dojo.body(), c);
	},
	canDrop: function(flag){
		// summary:
		//		called to notify if the current target can accept items
		var canDropFlag = Boolean(this.target && flag);
		if(this.canDropFlag != canDropFlag){
			this.canDropFlag = canDropFlag;
			this.avatar.update();
		}
	},
	stopDrag: function(){
		// summary:
		//		stop the DnD in progress
		dojo.removeClass(dojo.body(), ["dojoDndCopy", "dojoDndMove"]);
		dojo.forEach(this.events, dojo.disconnect);
		this.events = [];
		this.avatar.destroy();
		this.avatar = null;
		this.source = this.target = null;
		this.nodes = [];
	},
	makeAvatar: function(){
		// summary:
		//		makes the avatar; it is separate to be overwritten dynamically, if needed
		return new dojo.dnd.Avatar(this);
	},
	updateAvatar: function(){
		// summary:
		//		updates the avatar; it is separate to be overwritten dynamically, if needed
		this.avatar.update();
	},
	
	// mouse event processors
	onMouseMove: function(e){
		// summary:
		//		event processor for onmousemove
		// e: Event
		//		mouse event
		var a = this.avatar;
		if(a){
			dojo.dnd.autoScrollNodes(e);
			//dojo.dnd.autoScroll(e);
			var s = a.node.style;
			s.left = (e.pageX + this.OFFSET_X) + "px";
			s.top  = (e.pageY + this.OFFSET_Y) + "px";
			var copy = Boolean(this.source.copyState(dojo.isCopyKey(e)));
			if(this.copy != copy){
				this._setCopyStatus(copy);
			}
		}
	},
	onMouseUp: function(e){
		// summary:
		//		event processor for onmouseup
		// e: Event
		//		mouse event
		if(this.avatar){
			if(this.target && this.canDropFlag){
				var copy = Boolean(this.source.copyState(dojo.isCopyKey(e))),
				params = [this.source, this.nodes, copy, this.target, e];
				dojo.publish("/dnd/drop/before", params);
				dojo.publish("/dnd/drop", params);
			}else{
				dojo.publish("/dnd/cancel");
			}
			this.stopDrag();
		}
	},
	
	// keyboard event processors
	onKeyDown: function(e){
		// summary:
		//		event processor for onkeydown:
		//		watching for CTRL for copy/move status, watching for ESCAPE to cancel the drag
		// e: Event
		//		keyboard event
		if(this.avatar){
			switch(e.keyCode){
				case dojo.keys.CTRL:
					var copy = Boolean(this.source.copyState(true));
					if(this.copy != copy){
						this._setCopyStatus(copy);
					}
					break;
				case dojo.keys.ESCAPE:
					dojo.publish("/dnd/cancel");
					this.stopDrag();
					break;
			}
		}
	},
	onKeyUp: function(e){
		// summary:
		//		event processor for onkeyup, watching for CTRL for copy/move status
		// e: Event
		//		keyboard event
		if(this.avatar && e.keyCode == dojo.keys.CTRL){
			var copy = Boolean(this.source.copyState(false));
			if(this.copy != copy){
				this._setCopyStatus(copy);
			}
		}
	},
	
	// utilities
	_setCopyStatus: function(copy){
		// summary:
		//		changes the copy status
		// copy: Boolean
		//		the copy status
		this.copy = copy;
		this.source._markDndStatus(this.copy);
		this.updateAvatar();
		dojo.replaceClass(dojo.body(),
			"dojoDnd" + (this.copy ? "Copy" : "Move"),
			"dojoDnd" + (this.copy ? "Move" : "Copy"));
	}
});

// dojo.dnd._manager:
//		The manager singleton variable. Can be overwritten if needed.
dojo.dnd._manager = null;

dojo.dnd.manager = function(){
	// summary:
	//		Returns the current DnD manager.  Creates one if it is not created yet.
	if(!dojo.dnd._manager){
		dojo.dnd._manager = new dojo.dnd.Manager();
	}
	return dojo.dnd._manager;	// Object
};

}

if(!dojo._hasResource["dojo.dnd.Source"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.Source"] = true;
dojo.provide("dojo.dnd.Source");




/*
	Container property:
		"Horizontal"- if this is the horizontal container
	Source states:
		""			- normal state
		"Moved"		- this source is being moved
		"Copied"	- this source is being copied
	Target states:
		""			- normal state
		"Disabled"	- the target cannot accept an avatar
	Target anchor state:
		""			- item is not selected
		"Before"	- insert point is before the anchor
		"After"		- insert point is after the anchor
*/

/*=====
dojo.dnd.__SourceArgs = function(){
	//	summary:
	//		a dict of parameters for DnD Source configuration. Note that any
	//		property on Source elements may be configured, but this is the
	//		short-list
	//	isSource: Boolean?
	//		can be used as a DnD source. Defaults to true.
	//	accept: Array?
	//		list of accepted types (text strings) for a target; defaults to
	//		["text"]
	//	autoSync: Boolean
	//		if true refreshes the node list on every operation; false by default
	//	copyOnly: Boolean?
	//		copy items, if true, use a state of Ctrl key otherwise,
	//		see selfCopy and selfAccept for more details
	//	delay: Number
	//		the move delay in pixels before detecting a drag; 0 by default
	//	horizontal: Boolean?
	//		a horizontal container, if true, vertical otherwise or when omitted
	//	selfCopy: Boolean?
	//		copy items by default when dropping on itself,
	//		false by default, works only if copyOnly is true
	//	selfAccept: Boolean?
	//		accept its own items when copyOnly is true,
	//		true by default, works only if copyOnly is true
	//	withHandles: Boolean?
	//		allows dragging only by handles, false by default
	//  generateText: Boolean?
	//		generate text node for drag and drop, true by default
	this.isSource = isSource;
	this.accept = accept;
	this.autoSync = autoSync;
	this.copyOnly = copyOnly;
	this.delay = delay;
	this.horizontal = horizontal;
	this.selfCopy = selfCopy;
	this.selfAccept = selfAccept;
	this.withHandles = withHandles;
	this.generateText = true;
}
=====*/

dojo.declare("dojo.dnd.Source", dojo.dnd.Selector, {
	// summary:
	//		a Source object, which can be used as a DnD source, or a DnD target
	
	// object attributes (for markup)
	isSource: true,
	horizontal: false,
	copyOnly: false,
	selfCopy: false,
	selfAccept: true,
	skipForm: false,
	withHandles: false,
	autoSync: false,
	delay: 0, // pixels
	accept: ["text"],
	generateText: true,
	
	constructor: function(/*DOMNode|String*/node, /*dojo.dnd.__SourceArgs?*/params){
		// summary:
		//		a constructor of the Source
		// node:
		//		node or node's id to build the source on
		// params:
		//		any property of this class may be configured via the params
		//		object which is mixed-in to the `dojo.dnd.Source` instance
		dojo.mixin(this, dojo.mixin({}, params));
		var type = this.accept;
		if(type.length){
			this.accept = {};
			for(var i = 0; i < type.length; ++i){
				this.accept[type[i]] = 1;
			}
		}
		// class-specific variables
		this.isDragging = false;
		this.mouseDown = false;
		this.targetAnchor = null;
		this.targetBox = null;
		this.before = true;
		this._lastX = 0;
		this._lastY = 0;
		// states
		this.sourceState  = "";
		if(this.isSource){
			dojo.addClass(this.node, "dojoDndSource");
		}
		this.targetState  = "";
		if(this.accept){
			dojo.addClass(this.node, "dojoDndTarget");
		}
		if(this.horizontal){
			dojo.addClass(this.node, "dojoDndHorizontal");
		}
		// set up events
		this.topics = [
			dojo.subscribe("/dnd/source/over", this, "onDndSourceOver"),
			dojo.subscribe("/dnd/start",  this, "onDndStart"),
			dojo.subscribe("/dnd/drop",   this, "onDndDrop"),
			dojo.subscribe("/dnd/cancel", this, "onDndCancel")
		];
	},
	
	// methods
	checkAcceptance: function(source, nodes){
		// summary:
		//		checks if the target can accept nodes from this source
		// source: Object
		//		the source which provides items
		// nodes: Array
		//		the list of transferred items
		if(this == source){
			return !this.copyOnly || this.selfAccept;
		}
		for(var i = 0; i < nodes.length; ++i){
			var type = source.getItem(nodes[i].id).type;
			// type instanceof Array
			var flag = false;
			for(var j = 0; j < type.length; ++j){
				if(type[j] in this.accept){
					flag = true;
					break;
				}
			}
			if(!flag){
				return false;	// Boolean
			}
		}
		return true;	// Boolean
	},
	copyState: function(keyPressed, self){
		// summary:
		//		Returns true if we need to copy items, false to move.
		//		It is separated to be overwritten dynamically, if needed.
		// keyPressed: Boolean
		//		the "copy" key was pressed
		// self: Boolean?
		//		optional flag that means that we are about to drop on itself
		
		if(keyPressed){ return true; }
		if(arguments.length < 2){
			self = this == dojo.dnd.manager().target;
		}
		if(self){
			if(this.copyOnly){
				return this.selfCopy;
			}
		}else{
			return this.copyOnly;
		}
		return false;	// Boolean
	},
	destroy: function(){
		// summary:
		//		prepares the object to be garbage-collected
		dojo.dnd.Source.superclass.destroy.call(this);
		dojo.forEach(this.topics, dojo.unsubscribe);
		this.targetAnchor = null;
	},

	// markup methods
	markupFactory: function(params, node){
		params._skipStartup = true;
		return new dojo.dnd.Source(node, params);
	},

	// mouse event processors
	onMouseMove: function(e){
		// summary:
		//		event processor for onmousemove
		// e: Event
		//		mouse event
		if(this.isDragging && this.targetState == "Disabled"){ return; }
		dojo.dnd.Source.superclass.onMouseMove.call(this, e);
		var m = dojo.dnd.manager();
		if(!this.isDragging){
			if(this.mouseDown && this.isSource &&
					(Math.abs(e.pageX - this._lastX) > this.delay || Math.abs(e.pageY - this._lastY) > this.delay)){
				var nodes = this.getSelectedNodes();
				if(nodes.length){
					m.startDrag(this, nodes, this.copyState(dojo.isCopyKey(e), true));
				}
			}
		}
		if(this.isDragging){
			// calculate before/after
			var before = false;
			if(this.current){
				if(!this.targetBox || this.targetAnchor != this.current){
					this.targetBox = dojo.position(this.current, true);
				}
				if(this.horizontal){
					before = (e.pageX - this.targetBox.x) < (this.targetBox.w / 2);
				}else{
					before = (e.pageY - this.targetBox.y) < (this.targetBox.h / 2);
				}
			}
			if(this.current != this.targetAnchor || before != this.before){
				this._markTargetAnchor(before);
				m.canDrop(!this.current || m.source != this || !(this.current.id in this.selection));
			}
		}
	},
	onMouseDown: function(e){
		// summary:
		//		event processor for onmousedown
		// e: Event
		//		mouse event
		if(!this.mouseDown && this._legalMouseDown(e) && (!this.skipForm || !dojo.dnd.isFormElement(e))){
			this.mouseDown = true;
			this._lastX = e.pageX;
			this._lastY = e.pageY;
			dojo.dnd.Source.superclass.onMouseDown.call(this, e);
		}
	},
	onMouseUp: function(e){
		// summary:
		//		event processor for onmouseup
		// e: Event
		//		mouse event
		if(this.mouseDown){
			this.mouseDown = false;
			dojo.dnd.Source.superclass.onMouseUp.call(this, e);
		}
	},
	
	// topic event processors
	onDndSourceOver: function(source){
		// summary:
		//		topic event processor for /dnd/source/over, called when detected a current source
		// source: Object
		//		the source which has the mouse over it
		if(this != source){
			this.mouseDown = false;
			if(this.targetAnchor){
				this._unmarkTargetAnchor();
			}
		}else if(this.isDragging){
			var m = dojo.dnd.manager();
			m.canDrop(this.targetState != "Disabled" && (!this.current || m.source != this || !(this.current.id in this.selection)));
		}
	},
	onDndStart: function(source, nodes, copy){
		// summary:
		//		topic event processor for /dnd/start, called to initiate the DnD operation
		// source: Object
		//		the source which provides items
		// nodes: Array
		//		the list of transferred items
		// copy: Boolean
		//		copy items, if true, move items otherwise
		if(this.autoSync){ this.sync(); }
		if(this.isSource){
			this._changeState("Source", this == source ? (copy ? "Copied" : "Moved") : "");
		}
		var accepted = this.accept && this.checkAcceptance(source, nodes);
		this._changeState("Target", accepted ? "" : "Disabled");
		if(this == source){
			dojo.dnd.manager().overSource(this);
		}
		this.isDragging = true;
	},
	onDndDrop: function(source, nodes, copy, target){
		// summary:
		//		topic event processor for /dnd/drop, called to finish the DnD operation
		// source: Object
		//		the source which provides items
		// nodes: Array
		//		the list of transferred items
		// copy: Boolean
		//		copy items, if true, move items otherwise
		// target: Object
		//		the target which accepts items
		if(this == target){
			// this one is for us => move nodes!
			this.onDrop(source, nodes, copy);
		}
		this.onDndCancel();
	},
	onDndCancel: function(){
		// summary:
		//		topic event processor for /dnd/cancel, called to cancel the DnD operation
		if(this.targetAnchor){
			this._unmarkTargetAnchor();
			this.targetAnchor = null;
		}
		this.before = true;
		this.isDragging = false;
		this.mouseDown = false;
		this._changeState("Source", "");
		this._changeState("Target", "");
	},
	
	// local events
	onDrop: function(source, nodes, copy){
		// summary:
		//		called only on the current target, when drop is performed
		// source: Object
		//		the source which provides items
		// nodes: Array
		//		the list of transferred items
		// copy: Boolean
		//		copy items, if true, move items otherwise
		
		if(this != source){
			this.onDropExternal(source, nodes, copy);
		}else{
			this.onDropInternal(nodes, copy);
		}
	},
	onDropExternal: function(source, nodes, copy){
		// summary:
		//		called only on the current target, when drop is performed
		//		from an external source
		// source: Object
		//		the source which provides items
		// nodes: Array
		//		the list of transferred items
		// copy: Boolean
		//		copy items, if true, move items otherwise
		
		var oldCreator = this._normalizedCreator;
		// transferring nodes from the source to the target
		if(this.creator){
			// use defined creator
			this._normalizedCreator = function(node, hint){
				return oldCreator.call(this, source.getItem(node.id).data, hint);
			};
		}else{
			// we have no creator defined => move/clone nodes
			if(copy){
				// clone nodes
				this._normalizedCreator = function(node, hint){
					var t = source.getItem(node.id);
					var n = node.cloneNode(true);
					n.id = dojo.dnd.getUniqueId();
					return {node: n, data: t.data, type: t.type};
				};
			}else{
				// move nodes
				this._normalizedCreator = function(node, hint){
					var t = source.getItem(node.id);
					source.delItem(node.id);
					return {node: node, data: t.data, type: t.type};
				};
			}
		}
		this.selectNone();
		if(!copy && !this.creator){
			source.selectNone();
		}
		this.insertNodes(true, nodes, this.before, this.current);
		if(!copy && this.creator){
			source.deleteSelectedNodes();
		}
		this._normalizedCreator = oldCreator;
	},
	onDropInternal: function(nodes, copy){
		// summary:
		//		called only on the current target, when drop is performed
		//		from the same target/source
		// nodes: Array
		//		the list of transferred items
		// copy: Boolean
		//		copy items, if true, move items otherwise
		
		var oldCreator = this._normalizedCreator;
		// transferring nodes within the single source
		if(this.current && this.current.id in this.selection){
			// do nothing
			return;
		}
		if(copy){
			if(this.creator){
				// create new copies of data items
				this._normalizedCreator = function(node, hint){
					return oldCreator.call(this, this.getItem(node.id).data, hint);
				};
			}else{
				// clone nodes
				this._normalizedCreator = function(node, hint){
					var t = this.getItem(node.id);
					var n = node.cloneNode(true);
					n.id = dojo.dnd.getUniqueId();
					return {node: n, data: t.data, type: t.type};
				};
			}
		}else{
			// move nodes
			if(!this.current){
				// do nothing
				return;
			}
			this._normalizedCreator = function(node, hint){
				var t = this.getItem(node.id);
				return {node: node, data: t.data, type: t.type};
			};
		}
		this._removeSelection();
		this.insertNodes(true, nodes, this.before, this.current);
		this._normalizedCreator = oldCreator;
	},
	onDraggingOver: function(){
		// summary:
		//		called during the active DnD operation, when items
		//		are dragged over this target, and it is not disabled
	},
	onDraggingOut: function(){
		// summary:
		//		called during the active DnD operation, when items
		//		are dragged away from this target, and it is not disabled
	},
	
	// utilities
	onOverEvent: function(){
		// summary:
		//		this function is called once, when mouse is over our container
		dojo.dnd.Source.superclass.onOverEvent.call(this);
		dojo.dnd.manager().overSource(this);
		if(this.isDragging && this.targetState != "Disabled"){
			this.onDraggingOver();
		}
	},
	onOutEvent: function(){
		// summary:
		//		this function is called once, when mouse is out of our container
		dojo.dnd.Source.superclass.onOutEvent.call(this);
		dojo.dnd.manager().outSource(this);
		if(this.isDragging && this.targetState != "Disabled"){
			this.onDraggingOut();
		}
	},
	_markTargetAnchor: function(before){
		// summary:
		//		assigns a class to the current target anchor based on "before" status
		// before: Boolean
		//		insert before, if true, after otherwise
		if(this.current == this.targetAnchor && this.before == before){ return; }
		if(this.targetAnchor){
			this._removeItemClass(this.targetAnchor, this.before ? "Before" : "After");
		}
		this.targetAnchor = this.current;
		this.targetBox = null;
		this.before = before;
		if(this.targetAnchor){
			this._addItemClass(this.targetAnchor, this.before ? "Before" : "After");
		}
	},
	_unmarkTargetAnchor: function(){
		// summary:
		//		removes a class of the current target anchor based on "before" status
		if(!this.targetAnchor){ return; }
		this._removeItemClass(this.targetAnchor, this.before ? "Before" : "After");
		this.targetAnchor = null;
		this.targetBox = null;
		this.before = true;
	},
	_markDndStatus: function(copy){
		// summary:
		//		changes source's state based on "copy" status
		this._changeState("Source", copy ? "Copied" : "Moved");
	},
	_legalMouseDown: function(e){
		// summary:
		//		checks if user clicked on "approved" items
		// e: Event
		//		mouse event
		
		// accept only the left mouse button
		if(!dojo.mouseButtons.isLeft(e)){ return false; }
		
		if(!this.withHandles){ return true; }
		
		// check for handles
		for(var node = e.target; node && node !== this.node; node = node.parentNode){
			if(dojo.hasClass(node, "dojoDndHandle")){ return true; }
			if(dojo.hasClass(node, "dojoDndItem") || dojo.hasClass(node, "dojoDndIgnore")){ break; }
		}
		return false;	// Boolean
	}
});

dojo.declare("dojo.dnd.Target", dojo.dnd.Source, {
	// summary: a Target object, which can be used as a DnD target
	
	constructor: function(node, params){
		// summary:
		//		a constructor of the Target --- see the `dojo.dnd.Source.constructor` for details
		this.isSource = false;
		dojo.removeClass(this.node, "dojoDndSource");
	},

	// markup methods
	markupFactory: function(params, node){
		params._skipStartup = true;
		return new dojo.dnd.Target(node, params);
	}
});

dojo.declare("dojo.dnd.AutoSource", dojo.dnd.Source, {
	// summary:
	//		a source that syncs its DnD nodes by default
	
	constructor: function(node, params){
		// summary:
		//		constructor of the AutoSource --- see the Source constructor for details
		this.autoSync = true;
	},

	// markup methods
	markupFactory: function(params, node){
		params._skipStartup = true;
		return new dojo.dnd.AutoSource(node, params);
	}
});

}

if(!dojo._hasResource['epages.cartridges.de_epages.presentation.objectupdater']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.presentation.objectupdater'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.browser

*/
dojo.provide('epages.cartridges.de_epages.presentation.objectupdater');





epages.cartridges.de_epages.presentation.ObjectUpdater = new epages.Class();
epages.cartridges.de_epages.presentation.ObjectUpdater.prototype = {
	siteId:       epages.vars.SiteID,
	initialize: function (options) {
		if (options !== undefined){
			dojo.mixin(this,options);
		}

		var tmpFunc = function() {
			var body = dojo.body();
			var stateHint = document.createElement("div");
			stateHint.appendChild(document.createTextNode('Loading...'));
			//dojo.addClass(stateHint, 'epagesObjectupdaterStateHint');
			stateHint.setAttribute('id', 'epagesObjectupdaterStateHint');
			stateHint.style.position = "absolute";
			stateHint.style.backgroundColor="red";
			stateHint.style.color = "white";
			stateHint.style.left = "150px";
			stateHint.style.top = "0px";
			stateHint.style.width = "150px";
			stateHint.style.height = "18px";
			stateHint.style.zIndex = "255";
			stateHint.style.display = "none";
			body.appendChild(stateHint);
		};

		if (dojo.body()) {
			if (!document.getElementById('epagesObjectupdaterStateHint')) {
				tmpFunc();
			}
		} else {
			dojo.addOnLoad(tmpFunc);
		}
	},

	getFormDataViaArray: function(/*ArrayLike*/data) {
	// depricated - will be removed in the next version
		var formData = [];
		$A(data).each( function(el) {
			formData.push($H(el).toQueryString());
		});
		return formData.join('&');
	},

	getFormDataViaHash: function(/*String*/guid, /*epages.lang.Hash||Object*/data) {
	  //alert("getFormDataViaHash is still in use!")
	  //used inside external content google map
		var formData = {
		  'GUID': [],
		  'Name': [],
		  'Value': []
		};
		$A($H(data).keys()).each( function(key) {
		  formData.GUID.push(guid);
		  formData.Name.push(key);
		  formData.Value.push(data[key]);
		});
		return formData;
	},

	getFormDataViaObjectForm: function(/*ObjectLike*/data) {
		var formData = {
		  'GUID': [],
		  'Name': [],
		  'Value': [],
		  'LocalizedGUID': [],
		  'LocalizedName': [],
		  'LocalizedValue': [],
		  'LanguageID': [],
		  'DeleteGUID': []
		};
		$H(data).each( function(el) {
			var hElement = el.key;
			var names = el.key.split(':');
			if (el.value == 'Delete')  {
			  formData.DeleteGUID.push(names[0]);
			} else if (names.length == 2) {
	  		  formData.GUID.push(names[0]);
	  		  formData.Name.push(names[1]);
	  		  // EPG-23763: Set value to '' if undefined
	  		  formData.Value.push(el.value ? el.value : '');
			} else if (names.length == 3) {
	  		  formData.LocalizedGUID.push(names[0]);
	  		  formData.LocalizedName.push(names[1]);
	  		  formData.LocalizedValue.push(el.value);
	  		  formData.LanguageID.push(names[2]);
			}
		});
		return formData;
	},

	sendAsync: function(/*String*/url, /*Object?*/formData, /*function?*/callback,isWizard/*boolean*/) {
		if (formData == ''){
			return;
		}
		var params = {
			ViewAction:   'JSONViewResponse',
			ObjectID:     this.siteId,
			ChangeAction: 'SaveGUIDList'
		};
		if(isWizard){
			params.IsWizard = true;
		}
		if (formData != null){
			dojo.mixin(params, formData);
		}
		var jsonIo = new epages.io.Json();
		jsonIo.loadAsync(url, callback, params, epages.io.json.defaultErrorCallback);
	}

};

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Toolcolor"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Toolcolor"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.presentation.widget.Toolfont

*/
/*global dojo,epages,tinyMCE,jQuery,ep*/
dojo.provide("epages.cartridges.de_epages.presentation.widget.Toolcolor");



(function(){

var colorPicker;

dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.Toolcolor",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		label               : '',           // String - label of color field
		color               : '',           // String - color value
		colorType           : '',           // String - type of color input e.g. Background, ListeHeadBackground, ... (used for input name example: input name="${objectId}:${colorType}" value="myval" />)
		isBackgroundColor   : 'false',      // Boolean - flag that indicates that color is a Backgroundcolor
		templateType        : "tablerow",   // String - selected template type
		defaultTemplateType : "tablerow",   // [readonly] String - default value template type
		isTinyMCE           : 'false',      // Boolean - flag that indicates weather the current tinyMCE selection should be save or not
		'class'             : '',           // String - css class attribute
		userColors: epages.vars.userColors, // String - user defined colors e.g. "#ff0000|#000000"
		currentWizardScheme : 'Compound',   // String - selected color scheme
		objectId            : '',           // String - current epages object id
		styleId             : '',           // String - current epages object id
		allowEmpty          : '0',          // Boolean - allow empty value (will be passed to colorpicker widget)

		/**
		 * private properties
		 */
		_templateMapping:{
			'tablerow' : {templateString:"<tr class=\"ToolColor\"><td colspan=\"2\"><table><tr>\n  <td class=\"InputLabelling NoWrap\">${label}</td>\n  <td>\n    <input dojoAttachPoint=\"colorInputNode\"\n           class=\"Color\"\n           id=\"${colorType}\"\n           name=\"${objectId}:${colorType}\"\n           value=\"${color}\"\n           type=\"hidden\" />\n    <!-- insert color picker here -->\n    <div dojoAttachPoint=\"colorBoxNode\"\n         class=\"ColorBox EnableHover\"\n         style=\"background-color: ${color}\"\n         ></div>\n    <span dojoAttachPoint=\"notSetNode\" class=\"LeftSmallPadding AdditionalInfo\" style=\"display:none\">({NotSet})</span>\n  </td>\n</tr></table></td></tr>\n"},
			'tablerownew' : {templateString:"<tr class=\"ToolColor\">\n  <td class=\"InputLabelling NoWrap\">${label}</td>\n  <td class=\"FontSize\"></td>\n  <td>\n    <input dojoAttachPoint=\"colorInputNode\"\n           class=\"Color\"\n           id=\"${colorType}\"\n           name=\"${objectId}:${colorType}\"\n           value=\"${color}\"\n           type=\"hidden\" />\n    <!-- insert color picker here -->\n    <div dojoAttachPoint=\"colorBoxNode\"\n         class=\"ColorBox EnableHover\"\n         style=\"background-color: ${color}\"\n         ></div>\n    <span dojoAttachPoint=\"notSetNode\" class=\"LeftSmallPadding AdditionalInfo\" style=\"display:none\">({NotSet})</span>\n  </td>\n</tr>\n"},
			'colorbox' : {templateString:"<div class=\"ToolColor\">\n  <input dojoAttachPoint=\"colorInputNode\"\n         class=\"Color\"\n         id=\"${colorType}\"\n         name=\"${objectId}:${colorType}\"\n         value=\"${color}\"\n         type=\"hidden\" />\n  <!-- insert color picker here -->\n  <div dojoAttachPoint=\"colorBoxNode\"\n       class=\"ColorBox EnableHover\"\n       style=\"background-color: ${color}\"\n       ></div>\n  <span dojoAttachPoint=\"notSetNode\" class=\"LeftSmallPadding AdditionalInfo\" style=\"display:none\">({NotSet})</span>\n</div>\n"},
			'colorbutton' : {templateString:"<span class=\"ToolColor\">\n  <input dojoAttachPoint=\"colorInputNode\"\n         class=\"Color\"\n         id=\"${colorType}\"\n         name=\"${objectId}:${colorType}\"\n         value=\"${color}\"\n         type=\"hidden\" />\n  <!-- insert color picker here -->\n  <button dojoAttachPoint=\"colorBoxNode\"\n       class=\"ColorBox EnableHover\"\n       style=\"background-color: ${color}\"\n       ></button>\n  <span dojoAttachPoint=\"notSetNode\" class=\"LeftSmallPadding AdditionalInfo\" style=\"display:none\">({NotSet})</span>\n</span>\n"},
			'palette'  : {templateString:"<div class=\"ToolColor CommandSmallMedium Extend\"\n     dojoAttachPoint=\"clickNode\">\n  <input dojoAttachPoint=\"colorInputNode\"\n         class=\"Color\"\n         id=\"${colorType}\"\n         name=\"${objectId}:${colorType}\"\n         value=\"${color}\"\n         type=\"hidden\" />\n  <!-- insert color picker here -->\n  <div style=\"float: left\">\n    <img src=\"${imagePath}/ico_colorpalette_${_palette}.png\"\n         alt=\"${label}\" title=\"${label}\"\n         style=\"margin: 0 2px;\"\n         />\n    <div dojoAttachPoint=\"colorBoxNode\"\n         class=\"ColorBox Stripe EnableHover\"\n         style=\"background-color: ${color}\"\n         ></div>\n  </div>\n  <img style=\"margin: 2px 7px 0 7px;#margin: -5px 7px 0 7px;\"\n       src=\"${imagePath}/img_extend.png\"\n       />\n</div>\n"},
			'xlicon'   : {templateString:"<div class=\"ToolColor WithXLIcon\">\n  <input dojoAttachPoint=\"colorInputNode\"\n         class=\"Color\"\n         id=\"${colorType}\"\n         name=\"${objectId}:${colorType}\"\n         value=\"${color}\"\n         type=\"hidden\" />\n  <div class=\"CommandPane ExtraLarge\" dojoAttachPoint=\"clickNode\">\n    <i class=\"Sprite ico_xl_pickcolor\" title=\"{PickColor}\"></i><br />\n    ${label}<br />\n    <img src=\"${imagePath}/img_extend.png\"\n         alt=\"{PickColor}\" title=\"{PickColor}\" />\n    <div dojoAttachPoint=\"colorBoxNode\"\n         class=\"ColorBox Stripe EnableHover\"\n         style=\"background-color: ${color}\"\n         ></div>\n  </div>\n</div>\n"}
		},                                // [protected] Object - hash which associates templateType key with template filename
		_palette            : 'fore',     // [protected] String - template variable used in template Toolcolorpalette (icon switch)
		_tinyMceSelection   : undefined,  // [protected] TinyMceSelection - current selection in tiny mce editor

		/**
		 * constants
		 */
		COLORPICKER_OFFSET_X: 18,         // [const] Integer
		COLORPICKER_OFFSET_Y: 0,          // [const] Integer

		/**
		 * widget properties
		 */
		templateString:"<tr class=\"ToolColor\"><td colspan=\"2\"><table><tr>\n  <td class=\"InputLabelling NoWrap\">${label}</td>\n  <td>\n    <input dojoAttachPoint=\"colorInputNode\"\n           class=\"Color\"\n           id=\"${colorType}\"\n           name=\"${objectId}:${colorType}\"\n           value=\"${color}\"\n           type=\"hidden\" />\n    <!-- insert color picker here -->\n    <div dojoAttachPoint=\"colorBoxNode\"\n         class=\"ColorBox EnableHover\"\n         style=\"background-color: ${color}\"\n         ></div>\n    <span dojoAttachPoint=\"notSetNode\" class=\"LeftSmallPadding AdditionalInfo\" style=\"display:none\">({NotSet})</span>\n  </td>\n</tr></table></td></tr>\n",  // String - template path + filename
		imagePath       : epages.themeUrl('images'),                                                                      // String - icon path
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget', 'templates/translation'),     // String - translation path + filename

		postMixInProperties: function() {
		// summary: initialize values
			this._templateDirectory = dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget', 'templates');
			this.inherited("postMixInProperties", arguments);
			this.isBackgroundColor = epages.string.toBoolean(this.isBackgroundColor);
			this.isTinyMCE = epages.string.toBoolean(this.isTinyMCE);
			this.allowEmpty = epages.string.toBoolean(this.allowEmpty);
			this._palette = this.isBackgroundColor ? 'back' : 'fore';
			if(this.color === '' && ! this.allowEmpty) {
				this.color = 'transparent';
			}
			this.styleId = epages.vars.StyleId === undefined ? '' : epages.vars.StyleId;
		},

		postCreate  : function() {
		// summary: initialize widget / append events
			this.inherited("postCreate", arguments);

			dojo.addClass(this.domNode,this['class']);
			if(this.objectId === '') {
				this.colorInputNode.name=this.colorType;
			}
			this._appendEvents();
			this._changeColorBoxColor();
		},

		/**
		 * private methods
		 */

		_appendEvents: function() {
		// summary: append events to buttons (bold, italic, underline)
			this.connect(this.colorInputNode,     'onchange', '_changeColorBoxColor');

			// save selection in editor iframe for msie
			if (this.isTinyMCE && epages.Browser.engine === "MSIE"){
				this.connect(this.clickNode,        'onmousedown', '_tinyMceSaveSelection');
			}

			// open color picker
			if(this.clickNode){
				this.connect(this.clickNode,        'onclick', '_openColorPicker');
			}else{
				this.connect(this.colorBoxNode,     'onclick', '_openColorPicker');
			}
		},

		_changeColorBoxColor: function() {
			// summary: set background color of color preview box
			var color=this.colorInputNode.value;

			if(this.notSetNode) {	// this node does not exisit within every template type
				if(color === "") {
					this.notSetNode.style.display="";
				} else {
					this.notSetNode.style.display="none";
				}
			}

			// set color preview

			if(this.templateType === 'colorbutton'){
				this.colorBoxNode.style.background=color;
			}
			else{
				this.colorBoxNode.style.backgroundColor=color;
			}
			if(color==='transparent') {
				dojo.addClass(this.colorBoxNode,"Transparent");
			} else {
				dojo.removeClass(this.colorBoxNode,"Transparent");
			}

			if (this.isTinyMCE && tinyMCE.selectedInstance !== null) {
				if(this._tinyMceSelection === undefined) {
					tinyMCE.execCommand((this.isBackgroundColor ? 'HiliteColor': 'forecolor'), false, color);
				} else { // IE only - tinymce fixes
					this._tinyMceSelection.execCommand((this.isBackgroundColor ? 'BackColor': 'forecolor'), false, color);
					tinyMCE.activeEditor.focus();
					tinyMCE.activeEditor.selection.setRng(this._tinyMceSelection);
					this._tinyMceSelection=undefined;
				}
			}
		},

		_openColorPicker: function( event ) {
			var self = this,
				colorTarget = ep(event.target),
				colorInput = jQuery(this.colorInputNode);

			if( colorPicker ){
				colorPicker.element = colorPicker.elem = colorTarget;
				colorPicker.option( 'callback', function( color ){
					colorTarget
						.css('background-color', color);
					colorInput
						.val( color )
						.trigger({ type:'change', dojoconnect:true });
				});
				colorPicker.colorSelect( colorInput.val(), true );
				colorPicker.open();
			}
			else{
				jQuery.ready( ['ep.ajax', 'ep.ui.colorpicker'], function($){
					var options = {
							orientation:	'bottom'
						};

					if( epages.vars.StyleUserDefinedColors ){
						var extended = {
								baseColors:	$('#LayoutBackgroundColor').val(),
								userColors: {},
								userColorsSave: function( data ){
									var ajaxData = [
											{name: 'ViewAction',	value: 'JSONViewResponse'},
											{name: 'ChangeAction',	value: 'SaveGUIDList'},
											{name: 'ObjectID',		value: ep.config.siteId}
										];

									$.each( data, function(){
										ajaxData.push(
											{name: 'GUID',			value: self.styleId},
											{name: 'Name',			value: this.name},
											{name: 'Value',			value: this.value}
										);
									});

									ep.ajax({
										type:		'post',
										dataType:	'json',
										data:		ajaxData
									});
								}
							};

						$.each( epages.vars.StyleUserDefinedColors.split('|'), function( i, val ){
							extended.userColors[ 'UserDefinedColor'+i ] = val;
						});

						options.extended = extended;
					}

					colorPicker = ep('<div>')
						.uiColorpicker(options)
						.uiColorpicker('instance');
					self._openColorPicker( event );
				});
			}
		},

		_tinyMceSaveSelection: function() {
		// summary: stores the current tinymce select
			if(tinyMCE.activeEditor && tinyMCE.activeEditor.selection){
				this._tinyMceSelection = tinyMCE.activeEditor.selection.getRng();
		}

		}
	});

}());

}

if(!dojo._hasResource["dijit.form.ToggleButton"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form.ToggleButton"] = true;
dojo.provide("dijit.form.ToggleButton");




}

if(!dojo._hasResource["dijit.layout.StackController"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.layout.StackController"] = true;
dojo.provide("dijit.layout.StackController");







dojo.declare(
		"dijit.layout.StackController",
		[dijit._Widget, dijit._Templated, dijit._Container],
		{
			// summary:
			//		Set of buttons to select a page in a page list.
			// description:
			//		Monitors the specified StackContainer, and whenever a page is
			//		added, deleted, or selected, updates itself accordingly.

			templateString: "<span role='tablist' dojoAttachEvent='onkeypress' class='dijitStackController'></span>",

			// containerId: [const] String
			//		The id of the page container that I point to
			containerId: "",

			// buttonWidget: [const] String
			//		The name of the button widget to create to correspond to each page
			buttonWidget: "dijit.layout._StackButton",

			constructor: function(){
				this.pane2button = {};		// mapping from pane id to buttons
				this.pane2connects = {};	// mapping from pane id to this.connect() handles
				this.pane2watches = {};		// mapping from pane id to watch() handles
			},

			buildRendering: function(){
				this.inherited(arguments);
				dijit.setWaiRole(this.domNode, "tablist");	// TODO: unneeded?   it's in template above.
			},

			postCreate: function(){
				this.inherited(arguments);

				// Listen to notifications from StackContainer
				this.subscribe(this.containerId+"-startup", "onStartup");
				this.subscribe(this.containerId+"-addChild", "onAddChild");
				this.subscribe(this.containerId+"-removeChild", "onRemoveChild");
				this.subscribe(this.containerId+"-selectChild", "onSelectChild");
				this.subscribe(this.containerId+"-containerKeyPress", "onContainerKeyPress");
			},

			onStartup: function(/*Object*/ info){
				// summary:
				//		Called after StackContainer has finished initializing
				// tags:
				//		private
				dojo.forEach(info.children, this.onAddChild, this);
				if(info.selected){
					// Show button corresponding to selected pane (unless selected
					// is null because there are no panes)
					this.onSelectChild(info.selected);
				}
			},

			destroy: function(){
				for(var pane in this.pane2button){
					this.onRemoveChild(dijit.byId(pane));
				}
				this.inherited(arguments);
			},

			onAddChild: function(/*dijit._Widget*/ page, /*Integer?*/ insertIndex){
				// summary:
				//		Called whenever a page is added to the container.
				//		Create button corresponding to the page.
				// tags:
				//		private

				// create an instance of the button widget
				var cls = dojo.getObject(this.buttonWidget);
				var button = new cls({
					id: this.id + "_" + page.id,
					label: page.title,
					dir: page.dir,
					lang: page.lang,
					showLabel: page.showTitle,
					iconClass: page.iconClass,
					closeButton: page.closable,
					title: page.tooltip
				});
				dijit.setWaiState(button.focusNode,"selected", "false");


				// map from page attribute to corresponding tab button attribute
				var pageAttrList = ["title", "showTitle", "iconClass", "closable", "tooltip"],
					buttonAttrList = ["label", "showLabel", "iconClass", "closeButton", "title"];

				// watch() so events like page title changes are reflected in tab button
				this.pane2watches[page.id] = dojo.map(pageAttrList, function(pageAttr, idx){
					return page.watch(pageAttr, function(name, oldVal, newVal){
						button.set(buttonAttrList[idx], newVal);
					});
				});
					
				// connections so that clicking a tab button selects the corresponding page
				this.pane2connects[page.id] = [
					this.connect(button, 'onClick', dojo.hitch(this,"onButtonClick", page)),
					this.connect(button, 'onClickCloseButton', dojo.hitch(this,"onCloseButtonClick", page))
				];

				this.addChild(button, insertIndex);
				this.pane2button[page.id] = button;
				page.controlButton = button;	// this value might be overwritten if two tabs point to same container
				if(!this._currentChild){ // put the first child into the tab order
					button.focusNode.setAttribute("tabIndex", "0");
					dijit.setWaiState(button.focusNode, "selected", "true");
					this._currentChild = page;
				}
				// make sure all tabs have the same length
				if(!this.isLeftToRight() && dojo.isIE && this._rectifyRtlTabList){
					this._rectifyRtlTabList();
				}
			},

			onRemoveChild: function(/*dijit._Widget*/ page){
				// summary:
				//		Called whenever a page is removed from the container.
				//		Remove the button corresponding to the page.
				// tags:
				//		private

				if(this._currentChild === page){ this._currentChild = null; }

				// disconnect/unwatch connections/watches related to page being removed
				dojo.forEach(this.pane2connects[page.id], dojo.hitch(this, "disconnect"));
				delete this.pane2connects[page.id];
				dojo.forEach(this.pane2watches[page.id], function(w){ w.unwatch(); });
				delete this.pane2watches[page.id];

				var button = this.pane2button[page.id];
				if(button){
					this.removeChild(button);
					delete this.pane2button[page.id];
					button.destroy();
				}
				delete page.controlButton;
			},

			onSelectChild: function(/*dijit._Widget*/ page){
				// summary:
				//		Called when a page has been selected in the StackContainer, either by me or by another StackController
				// tags:
				//		private

				if(!page){ return; }

				if(this._currentChild){
					var oldButton=this.pane2button[this._currentChild.id];
					oldButton.set('checked', false);
					dijit.setWaiState(oldButton.focusNode, "selected", "false");
					oldButton.focusNode.setAttribute("tabIndex", "-1");
				}

				var newButton=this.pane2button[page.id];
				newButton.set('checked', true);
				dijit.setWaiState(newButton.focusNode, "selected", "true");
				this._currentChild = page;
				newButton.focusNode.setAttribute("tabIndex", "0");
				var container = dijit.byId(this.containerId);
				dijit.setWaiState(container.containerNode, "labelledby", newButton.id);
			},

			onButtonClick: function(/*dijit._Widget*/ page){
				// summary:
				//		Called whenever one of my child buttons is pressed in an attempt to select a page
				// tags:
				//		private

				var container = dijit.byId(this.containerId);
				container.selectChild(page);
			},

			onCloseButtonClick: function(/*dijit._Widget*/ page){
				// summary:
				//		Called whenever one of my child buttons [X] is pressed in an attempt to close a page
				// tags:
				//		private

				var container = dijit.byId(this.containerId);
				container.closeChild(page);
				if(this._currentChild){
					var b = this.pane2button[this._currentChild.id];
					if(b){
						dijit.focus(b.focusNode || b.domNode);
					}
				}
			},

			// TODO: this is a bit redundant with forward, back api in StackContainer
			adjacent: function(/*Boolean*/ forward){
				// summary:
				//		Helper for onkeypress to find next/previous button
				// tags:
				//		private

				if(!this.isLeftToRight() && (!this.tabPosition || /top|bottom/.test(this.tabPosition))){ forward = !forward; }
				// find currently focused button in children array
				var children = this.getChildren();
				var current = dojo.indexOf(children, this.pane2button[this._currentChild.id]);
				// pick next button to focus on
				var offset = forward ? 1 : children.length - 1;
				return children[ (current + offset) % children.length ]; // dijit._Widget
			},

			onkeypress: function(/*Event*/ e){
				// summary:
				//		Handle keystrokes on the page list, for advancing to next/previous button
				//		and closing the current page if the page is closable.
				// tags:
				//		private

				if(this.disabled || e.altKey ){ return; }
				var forward = null;
				if(e.ctrlKey || !e._djpage){
					var k = dojo.keys;
					switch(e.charOrCode){
						case k.LEFT_ARROW:
						case k.UP_ARROW:
							if(!e._djpage){ forward = false; }
							break;
						case k.PAGE_UP:
							if(e.ctrlKey){ forward = false; }
							break;
						case k.RIGHT_ARROW:
						case k.DOWN_ARROW:
							if(!e._djpage){ forward = true; }
							break;
						case k.PAGE_DOWN:
							if(e.ctrlKey){ forward = true; }
							break;
						case k.HOME:
						case k.END:
							var children = this.getChildren();
							if(children && children.length){
								children[e.charOrCode == k.HOME ? 0 : children.length-1].onClick();
							}
							dojo.stopEvent(e);
							break;
						case k.DELETE:
							if(this._currentChild.closable){
								this.onCloseButtonClick(this._currentChild);
							}
							dojo.stopEvent(e);
							break;
						default:
							if(e.ctrlKey){
								if(e.charOrCode === k.TAB){
									this.adjacent(!e.shiftKey).onClick();
									dojo.stopEvent(e);
								}else if(e.charOrCode == "w"){
									if(this._currentChild.closable){
										this.onCloseButtonClick(this._currentChild);
									}
									dojo.stopEvent(e); // avoid browser tab closing.
								}
							}
					}
					// handle next/previous page navigation (left/right arrow, etc.)
					if(forward !== null){
						this.adjacent(forward).onClick();
						dojo.stopEvent(e);
					}
				}
			},

			onContainerKeyPress: function(/*Object*/ info){
				// summary:
				//		Called when there was a keypress on the container
				// tags:
				//		private
				info.e._djpage = info.page;
				this.onkeypress(info.e);
			}
	});


dojo.declare("dijit.layout._StackButton",
		dijit.form.ToggleButton,
		{
		// summary:
		//		Internal widget used by StackContainer.
		// description:
		//		The button-like or tab-like object you click to select or delete a page
		// tags:
		//		private

		// Override _FormWidget.tabIndex.
		// StackContainer buttons are not in the tab order by default.
		// Probably we should be calling this.startupKeyNavChildren() instead.
		tabIndex: "-1",

		buildRendering: function(/*Event*/ evt){
			this.inherited(arguments);
			dijit.setWaiRole((this.focusNode || this.domNode), "tab");
		},

		onClick: function(/*Event*/ evt){
			// summary:
			//		This is for TabContainer where the tabs are <span> rather than button,
			//		so need to set focus explicitly (on some browsers)
			//		Note that you shouldn't override this method, but you can connect to it.
			dijit.focus(this.focusNode);

			// ... now let StackController catch the event and tell me what to do
		},

		onClickCloseButton: function(/*Event*/ evt){
			// summary:
			//		StackContainer connects to this function; if your widget contains a close button
			//		then clicking it should call this function.
			//		Note that you shouldn't override this method, but you can connect to it.
			evt.stopPropagation();
		}
	});

}

if(!dojo._hasResource["dijit.layout.StackContainer"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.layout.StackContainer"] = true;
dojo.provide("dijit.layout.StackContainer");







dojo.declare(
	"dijit.layout.StackContainer",
	dijit.layout._LayoutWidget,
	{
	// summary:
	//		A container that has multiple children, but shows only
	//		one child at a time
	//
	// description:
	//		A container for widgets (ContentPanes, for example) That displays
	//		only one Widget at a time.
	//
	//		Publishes topics [widgetId]-addChild, [widgetId]-removeChild, and [widgetId]-selectChild
	//
	//		Can be base class for container, Wizard, Show, etc.

	// doLayout: Boolean
	//		If true, change the size of my currently displayed child to match my size
	doLayout: true,

	// persist: Boolean
	//		Remembers the selected child across sessions
	persist: false,

	baseClass: "dijitStackContainer",

/*=====
	// selectedChildWidget: [readonly] dijit._Widget
	//		References the currently selected child widget, if any.
	//		Adjust selected child with selectChild() method.
	selectedChildWidget: null,
=====*/

	buildRendering: function(){
		this.inherited(arguments);
		dojo.addClass(this.domNode, "dijitLayoutContainer");
		dijit.setWaiRole(this.containerNode, "tabpanel");
	},

	postCreate: function(){
		this.inherited(arguments);
		this.connect(this.domNode, "onkeypress", this._onKeyPress);
	},

	startup: function(){
		if(this._started){ return; }

		var children = this.getChildren();

		// Setup each page panel to be initially hidden
		dojo.forEach(children, this._setupChild, this);

		// Figure out which child to initially display, defaulting to first one
		if(this.persist){
			this.selectedChildWidget = dijit.byId(dojo.cookie(this.id + "_selectedChild"));
		}else{
			dojo.some(children, function(child){
				if(child.selected){
					this.selectedChildWidget = child;
				}
				return child.selected;
			}, this);
		}
		var selected = this.selectedChildWidget;
		if(!selected && children[0]){
			selected = this.selectedChildWidget = children[0];
			selected.selected = true;
		}

		// Publish information about myself so any StackControllers can initialize.
		// This needs to happen before this.inherited(arguments) so that for
		// TabContainer, this._contentBox doesn't include the space for the tab labels.
		dojo.publish(this.id+"-startup", [{children: children, selected: selected}]);

		// Startup each child widget, and do initial layout like setting this._contentBox,
		// then calls this.resize() which does the initial sizing on the selected child.
		this.inherited(arguments);
	},

	resize: function(){
		// Resize is called when we are first made visible (it's called from startup()
		// if we are initially visible).   If this is the first time we've been made
		// visible then show our first child.
		var selected = this.selectedChildWidget;
		if(selected && !this._hasBeenShown){
			this._hasBeenShown = true;
			this._showChild(selected);
		}
		this.inherited(arguments);
	},

	_setupChild: function(/*dijit._Widget*/ child){
		// Overrides _LayoutWidget._setupChild()

		this.inherited(arguments);

		dojo.replaceClass(child.domNode, "dijitHidden", "dijitVisible");

		// remove the title attribute so it doesn't show up when i hover
		// over a node
		child.domNode.title = "";
	},

	addChild: function(/*dijit._Widget*/ child, /*Integer?*/ insertIndex){
		// Overrides _Container.addChild() to do layout and publish events

		this.inherited(arguments);

		if(this._started){
			dojo.publish(this.id+"-addChild", [child, insertIndex]);

			// in case the tab titles have overflowed from one line to two lines
			// (or, if this if first child, from zero lines to one line)
			// TODO: w/ScrollingTabController this is no longer necessary, although
			// ScrollTabController.resize() does need to get called to show/hide
			// the navigation buttons as appropriate, but that's handled in ScrollingTabController.onAddChild()
			this.layout();

			// if this is the first child, then select it
			if(!this.selectedChildWidget){
				this.selectChild(child);
			}
		}
	},

	removeChild: function(/*dijit._Widget*/ page){
		// Overrides _Container.removeChild() to do layout and publish events

		this.inherited(arguments);

		if(this._started){
			// this will notify any tablists to remove a button; do this first because it may affect sizing
			dojo.publish(this.id + "-removeChild", [page]);
		}

		// If we are being destroyed than don't run the code below (to select another page), because we are deleting
		// every page one by one
		if(this._beingDestroyed){ return; }

		// Select new page to display, also updating TabController to show the respective tab.
		// Do this before layout call because it can affect the height of the TabController.
		if(this.selectedChildWidget === page){
			this.selectedChildWidget = undefined;
			if(this._started){
				var children = this.getChildren();
				if(children.length){
					this.selectChild(children[0]);
				}
			}
		}

		if(this._started){
			// In case the tab titles now take up one line instead of two lines
			// (note though that ScrollingTabController never overflows to multiple lines),
			// or the height has changed slightly because of addition/removal of tab which close icon
			this.layout();
		}
	},

	selectChild: function(/*dijit._Widget|String*/ page, /*Boolean*/ animate){
		// summary:
		//		Show the given widget (which must be one of my children)
		// page:
		//		Reference to child widget or id of child widget

		page = dijit.byId(page);

		if(this.selectedChildWidget != page){
			// Deselect old page and select new one
			var d = this._transition(page, this.selectedChildWidget, animate);
			this._set("selectedChildWidget", page);
			dojo.publish(this.id+"-selectChild", [page]);

			if(this.persist){
				dojo.cookie(this.id + "_selectedChild", this.selectedChildWidget.id);
			}
		}

		return d;		// If child has an href, promise that fires when the child's href finishes loading
	},

	_transition: function(/*dijit._Widget*/ newWidget, /*dijit._Widget*/ oldWidget, /*Boolean*/ animate){
		// summary:
		//		Hide the old widget and display the new widget.
		//		Subclasses should override this.
		// tags:
		//		protected extension
		if(oldWidget){
			this._hideChild(oldWidget);
		}
		var d = this._showChild(newWidget);

		// Size the new widget, in case this is the first time it's being shown,
		// or I have been resized since the last time it was shown.
		// Note that page must be visible for resizing to work.
		if(newWidget.resize){
			if(this.doLayout){
				newWidget.resize(this._containerContentBox || this._contentBox);
			}else{
				// the child should pick it's own size but we still need to call resize()
				// (with no arguments) to let the widget lay itself out
				newWidget.resize();
			}
		}

		return d;	// If child has an href, promise that fires when the child's href finishes loading
	},

	_adjacent: function(/*Boolean*/ forward){
		// summary:
		//		Gets the next/previous child widget in this container from the current selection.
		var children = this.getChildren();
		var index = dojo.indexOf(children, this.selectedChildWidget);
		index += forward ? 1 : children.length - 1;
		return children[ index % children.length ]; // dijit._Widget
	},

	forward: function(){
		// summary:
		//		Advance to next page.
		return this.selectChild(this._adjacent(true), true);
	},

	back: function(){
		// summary:
		//		Go back to previous page.
		return this.selectChild(this._adjacent(false), true);
	},

	_onKeyPress: function(e){
		dojo.publish(this.id+"-containerKeyPress", [{ e: e, page: this}]);
	},

	layout: function(){
		// Implement _LayoutWidget.layout() virtual method.
		if(this.doLayout && this.selectedChildWidget && this.selectedChildWidget.resize){
			this.selectedChildWidget.resize(this._containerContentBox || this._contentBox);
		}
	},

	_showChild: function(/*dijit._Widget*/ page){
		// summary:
		//		Show the specified child by changing it's CSS, and call _onShow()/onShow() so
		//		it can do any updates it needs regarding loading href's etc.
		// returns:
		//		Promise that fires when page has finished showing, or true if there's no href
		var children = this.getChildren();
		page.isFirstChild = (page == children[0]);
		page.isLastChild = (page == children[children.length-1]);
		page._set("selected", true);

		dojo.replaceClass(page.domNode, "dijitVisible", "dijitHidden");

		return page._onShow() || true;
	},

	_hideChild: function(/*dijit._Widget*/ page){
		// summary:
		//		Hide the specified child by changing it's CSS, and call _onHide() so
		//		it's notified.
		page._set("selected", false);
		dojo.replaceClass(page.domNode, "dijitHidden", "dijitVisible");

		page.onHide();
	},

	closeChild: function(/*dijit._Widget*/ page){
		// summary:
		//		Callback when user clicks the [X] to remove a page.
		//		If onClose() returns true then remove and destroy the child.
		// tags:
		//		private
		var remove = page.onClose(this, page);
		if(remove){
			this.removeChild(page);
			// makes sure we can clean up executeScripts in ContentPane onUnLoad
			page.destroyRecursive();
		}
	},

	destroyDescendants: function(/*Boolean*/ preserveDom){
		dojo.forEach(this.getChildren(), function(child){
			this.removeChild(child);
			child.destroyRecursive(preserveDom);
		}, this);
	}
});

// For back-compat, remove for 2.0


// These arguments can be specified for the children of a StackContainer.
// Since any widget can be specified as a StackContainer child, mix them
// into the base widget class.  (This is a hack, but it's effective.)
dojo.extend(dijit._Widget, {
	// selected: Boolean
	//		Parameter for children of `dijit.layout.StackContainer` or subclasses.
	//		Specifies that this widget should be the initially displayed pane.
	//		Note: to change the selected child use `dijit.layout.StackContainer.selectChild`
	selected: false,

	// closable: Boolean
	//		Parameter for children of `dijit.layout.StackContainer` or subclasses.
	//		True if user can close (destroy) this child, such as (for example) clicking the X on the tab.
	closable: false,

	// iconClass: String
	//		Parameter for children of `dijit.layout.StackContainer` or subclasses.
	//		CSS Class specifying icon to use in label associated with this pane.
	iconClass: "",

	// showTitle: Boolean
	//		Parameter for children of `dijit.layout.StackContainer` or subclasses.
	//		When true, display title of this widget as tab label etc., rather than just using
	//		icon specified in iconClass
	showTitle: true
});

}

if(!dojo._hasResource["dijit.layout.AccordionPane"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.layout.AccordionPane"] = true;
dojo.provide("dijit.layout.AccordionPane");



dojo.declare("dijit.layout.AccordionPane", dijit.layout.ContentPane, {
	// summary:
	//		Deprecated widget.   Use `dijit.layout.ContentPane` instead.
	// tags:
	//		deprecated

	constructor: function(){
		dojo.deprecated("dijit.layout.AccordionPane deprecated, use ContentPane instead", "", "2.0");
	},

	onSelected: function(){
		// summary:
		//		called when this pane is selected
	}
});

}

if(!dojo._hasResource["dijit.layout.AccordionContainer"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.layout.AccordionContainer"] = true;
dojo.provide("dijit.layout.AccordionContainer");








//dojo.require("dijit.layout.AccordionPane ");	// for back compat, remove for 2.0

// Design notes:
//
// An AccordionContainer is a StackContainer, but each child (typically ContentPane)
// is wrapped in a _AccordionInnerContainer.   This is hidden from the caller.
//
// The resulting markup will look like:
//
//	<div class=dijitAccordionContainer>
//		<div class=dijitAccordionInnerContainer>	(one pane)
//				<div class=dijitAccordionTitle>		(title bar) ... </div>
//				<div class=dijtAccordionChildWrapper>   (content pane) </div>
//		</div>
//	</div>
//
// Normally the dijtAccordionChildWrapper is hidden for all but one child (the shown
// child), so the space for the content pane is all the title bars + the one dijtAccordionChildWrapper,
// which on claro has a 1px border plus a 2px bottom margin.
//
// During animation there are two dijtAccordionChildWrapper's shown, so we need
// to compensate for that.

dojo.declare(
	"dijit.layout.AccordionContainer",
	dijit.layout.StackContainer,
	{
		// summary:
		//		Holds a set of panes where every pane's title is visible, but only one pane's content is visible at a time,
		//		and switching between panes is visualized by sliding the other panes up/down.
		// example:
		//	| 	<div dojoType="dijit.layout.AccordionContainer">
		//	|		<div dojoType="dijit.layout.ContentPane" title="pane 1">
		//	|		</div>
		//	|		<div dojoType="dijit.layout.ContentPane" title="pane 2">
		//	|			<p>This is some text</p>
		//	|		</div>
		//	|	</div>

		// duration: Integer
		//		Amount of time (in ms) it takes to slide panes
		duration: dijit.defaultDuration,

		// buttonWidget: [const] String
		//		The name of the widget used to display the title of each pane
		buttonWidget: "dijit.layout._AccordionButton",

/*=====
		// _verticalSpace: Number
		//		Pixels of space available for the open pane
		//		(my content box size minus the cumulative size of all the title bars)
		_verticalSpace: 0,
=====*/
		baseClass: "dijitAccordionContainer",

		buildRendering: function(){
			this.inherited(arguments);
			this.domNode.style.overflow = "hidden";		// TODO: put this in dijit.css
			dijit.setWaiRole(this.domNode, "tablist");	// TODO: put this in template
		},

		startup: function(){
			if(this._started){ return; }
			this.inherited(arguments);
			if(this.selectedChildWidget){
				var style = this.selectedChildWidget.containerNode.style;
				style.display = "";
				style.overflow = "auto";
				this.selectedChildWidget._wrapperWidget.set("selected", true);
			}
		},

		layout: function(){
			// Implement _LayoutWidget.layout() virtual method.
			// Set the height of the open pane based on what room remains.

			var openPane = this.selectedChildWidget;
			
			if(!openPane){ return;}

			// space taken up by title, plus wrapper div (with border/margin) for open pane
			var wrapperDomNode = openPane._wrapperWidget.domNode,
				wrapperDomNodeMargin = dojo._getMarginExtents(wrapperDomNode),
				wrapperDomNodePadBorder = dojo._getPadBorderExtents(wrapperDomNode),
				wrapperContainerNode = openPane._wrapperWidget.containerNode,
				wrapperContainerNodeMargin = dojo._getMarginExtents(wrapperContainerNode),
				wrapperContainerNodePadBorder = dojo._getPadBorderExtents(wrapperContainerNode),
				mySize = this._contentBox;

			// get cumulative height of all the unselected title bars
			var totalCollapsedHeight = 0;
			dojo.forEach(this.getChildren(), function(child){
	            if(child != openPane){
					totalCollapsedHeight += dojo._getMarginSize(child._wrapperWidget.domNode).h;
				}
			});
			this._verticalSpace = mySize.h - totalCollapsedHeight - wrapperDomNodeMargin.h
			 	- wrapperDomNodePadBorder.h - wrapperContainerNodeMargin.h - wrapperContainerNodePadBorder.h
				- openPane._buttonWidget.getTitleHeight();

			// Memo size to make displayed child
			this._containerContentBox = {
				h: this._verticalSpace,
				w: this._contentBox.w - wrapperDomNodeMargin.w - wrapperDomNodePadBorder.w
					- wrapperContainerNodeMargin.w - wrapperContainerNodePadBorder.w
			};

			if(openPane){
				openPane.resize(this._containerContentBox);
			}
		},

		_setupChild: function(child){
			// Overrides _LayoutWidget._setupChild().
			// Put wrapper widget around the child widget, showing title

			child._wrapperWidget = new dijit.layout._AccordionInnerContainer({
				contentWidget: child,
				buttonWidget: this.buttonWidget,
				id: child.id + "_wrapper",
				dir: child.dir,
				lang: child.lang,
				parent: this
			});

			this.inherited(arguments);
		},

		addChild: function(/*dijit._Widget*/ child, /*Integer?*/ insertIndex){
			if(this._started){
				// Adding a child to a started Accordion is complicated because children have
				// wrapper widgets.  Default code path (calling this.inherited()) would add
				// the new child inside another child's wrapper.

				// First add in child as a direct child of this AccordionContainer
				dojo.place(child.domNode, this.containerNode, insertIndex);

				if(!child._started){
					child.startup();
				}
				
				// Then stick the wrapper widget around the child widget
				this._setupChild(child);

				// Code below copied from StackContainer
				dojo.publish(this.id+"-addChild", [child, insertIndex]);
				this.layout();
				if(!this.selectedChildWidget){
					this.selectChild(child);
				}
			}else{
				// We haven't been started yet so just add in the child widget directly,
				// and the wrapper will be created on startup()
				this.inherited(arguments);
			}
		},

		removeChild: function(child){
			// Overrides _LayoutWidget.removeChild().

			// Destroy wrapper widget first, before StackContainer.getChildren() call.
			// Replace wrapper widget with true child widget (ContentPane etc.).
			// This step only happens if the AccordionContainer has been started; otherwise there's no wrapper.
			if(child._wrapperWidget){
				dojo.place(child.domNode, child._wrapperWidget.domNode, "after");
				child._wrapperWidget.destroy();
				delete child._wrapperWidget;
			}

			dojo.removeClass(child.domNode, "dijitHidden");

			this.inherited(arguments);
		},

		getChildren: function(){
			// Overrides _Container.getChildren() to return content panes rather than internal AccordionInnerContainer panes
			return dojo.map(this.inherited(arguments), function(child){
				return child.declaredClass == "dijit.layout._AccordionInnerContainer" ? child.contentWidget : child;
			}, this);
		},

		destroy: function(){
			if(this._animation){
				this._animation.stop();
			}
			dojo.forEach(this.getChildren(), function(child){
				// If AccordionContainer has been started, then each child has a wrapper widget which
				// also needs to be destroyed.
				if(child._wrapperWidget){
					child._wrapperWidget.destroy();
				}else{
					child.destroyRecursive();
				}
			});
			this.inherited(arguments);
		},

		_showChild: function(child){
			// Override StackContainer._showChild() to set visibility of _wrapperWidget.containerNode
			child._wrapperWidget.containerNode.style.display="block";
			return this.inherited(arguments);
		},

		_hideChild: function(child){
			// Override StackContainer._showChild() to set visibility of _wrapperWidget.containerNode
			child._wrapperWidget.containerNode.style.display="none";
			this.inherited(arguments);
		},

		_transition: function(/*dijit._Widget?*/ newWidget, /*dijit._Widget?*/ oldWidget, /*Boolean*/ animate){
			// Overrides StackContainer._transition() to provide sliding of title bars etc.

			if(dojo.isIE < 8){
				// workaround animation bugs by not animating; not worth supporting animation for IE6 & 7
				animate = false;
			}

			if(this._animation){
				// there's an in-progress animation.  speedily end it so we can do the newly requested one
				this._animation.stop(true);
				delete this._animation;
			}

			var self = this;

			if(newWidget){
				newWidget._wrapperWidget.set("selected", true);

				var d = this._showChild(newWidget);	// prepare widget to be slid in

				// Size the new widget, in case this is the first time it's being shown,
				// or I have been resized since the last time it was shown.
				// Note that page must be visible for resizing to work.
				if(this.doLayout && newWidget.resize){
					newWidget.resize(this._containerContentBox);
				}
			}

			if(oldWidget){
				oldWidget._wrapperWidget.set("selected", false);
				if(!animate){
					this._hideChild(oldWidget);
				}
			}

			if(animate){
				var newContents = newWidget._wrapperWidget.containerNode,
					oldContents = oldWidget._wrapperWidget.containerNode;

				// During the animation we will be showing two dijitAccordionChildWrapper nodes at once,
				// which on claro takes up 4px extra space (compared to stable AccordionContainer).
				// Have to compensate for that by immediately shrinking the pane being closed.
				var wrapperContainerNode = newWidget._wrapperWidget.containerNode,
					wrapperContainerNodeMargin = dojo._getMarginExtents(wrapperContainerNode),
					wrapperContainerNodePadBorder = dojo._getPadBorderExtents(wrapperContainerNode),
					animationHeightOverhead = wrapperContainerNodeMargin.h + wrapperContainerNodePadBorder.h;

				oldContents.style.height = (self._verticalSpace - animationHeightOverhead) + "px";

				this._animation = new dojo.Animation({
					node: newContents,
					duration: this.duration,
					curve: [1, this._verticalSpace - animationHeightOverhead - 1],
					onAnimate: function(value){
						value = Math.floor(value);	// avoid fractional values
						newContents.style.height = value + "px";
						oldContents.style.height = (self._verticalSpace - animationHeightOverhead - value) + "px";
					},
					onEnd: function(){
						delete self._animation;
						newContents.style.height = "auto";
						oldWidget._wrapperWidget.containerNode.style.display = "none";
						oldContents.style.height = "auto";
						self._hideChild(oldWidget);
					}
				});
				this._animation.onStop = this._animation.onEnd;
				this._animation.play();
			}

			return d;	// If child has an href, promise that fires when the widget has finished loading
		},

		// note: we are treating the container as controller here
		_onKeyPress: function(/*Event*/ e, /*dijit._Widget*/ fromTitle){
			// summary:
			//		Handle keypress events
			// description:
			//		This is called from a handler on AccordionContainer.domNode
			//		(setup in StackContainer), and is also called directly from
			//		the click handler for accordion labels
			if(this.disabled || e.altKey || !(fromTitle || e.ctrlKey)){
				return;
			}
			var k = dojo.keys,
				c = e.charOrCode;
			if((fromTitle && (c == k.LEFT_ARROW || c == k.UP_ARROW)) ||
					(e.ctrlKey && c == k.PAGE_UP)){
				this._adjacent(false)._buttonWidget._onTitleClick();
				dojo.stopEvent(e);
			}else if((fromTitle && (c == k.RIGHT_ARROW || c == k.DOWN_ARROW)) ||
					(e.ctrlKey && (c == k.PAGE_DOWN || c == k.TAB))){
				this._adjacent(true)._buttonWidget._onTitleClick();
				dojo.stopEvent(e);
			}
		}
	}
);

dojo.declare("dijit.layout._AccordionInnerContainer",
	[dijit._Widget, dijit._CssStateMixin], {
		// summary:
		//		Internal widget placed as direct child of AccordionContainer.containerNode.
		//		When other widgets are added as children to an AccordionContainer they are wrapped in
		//		this widget.
		
/*=====
		// buttonWidget: String
		//		Name of class to use to instantiate title
		//		(Wish we didn't have a separate widget for just the title but maintaining it
		//		for backwards compatibility, is it worth it?)
		 buttonWidget: null,
=====*/

/*=====
		// contentWidget: dijit._Widget
		//		Pointer to the real child widget
	 	contentWidget: null,
=====*/

		baseClass: "dijitAccordionInnerContainer",

		// tell nested layout widget that we will take care of sizing
		isContainer: true,
		isLayoutContainer: true,

		buildRendering: function(){
			// Builds a template like:
			//	<div class=dijitAccordionInnerContainer>
			//		Button
			//		<div class=dijitAccordionChildWrapper>
			//			ContentPane
			//		</div>
			//	</div>

			// Create wrapper div, placed where the child is now
			this.domNode = dojo.place("<div class='" + this.baseClass + "'>", this.contentWidget.domNode, "after");
			
			// wrapper div's first child is the button widget (ie, the title bar)
			var child = this.contentWidget,
				cls = dojo.getObject(this.buttonWidget);
			this.button = child._buttonWidget = (new cls({
				contentWidget: child,
				label: child.title,
				title: child.tooltip,
				dir: child.dir,
				lang: child.lang,
				iconClass: child.iconClass,
				id: child.id + "_button",
				parent: this.parent
			})).placeAt(this.domNode);
			
			// and then the actual content widget (changing it from prior-sibling to last-child),
			// wrapped by a <div class=dijitAccordionChildWrapper>
			this.containerNode = dojo.place("<div class='dijitAccordionChildWrapper' style='display:none'>", this.domNode);
			dojo.place(this.contentWidget.domNode, this.containerNode);
		},

		postCreate: function(){
			this.inherited(arguments);

			// Map changes in content widget's title etc. to changes in the button
			var button = this.button;
			this._contentWidgetWatches = [
				this.contentWidget.watch('title', dojo.hitch(this, function(name, oldValue, newValue){
					button.set("label", newValue);
				})),
				this.contentWidget.watch('tooltip', dojo.hitch(this, function(name, oldValue, newValue){
					button.set("title", newValue);
				})),
				this.contentWidget.watch('iconClass', dojo.hitch(this, function(name, oldValue, newValue){
					button.set("iconClass", newValue);
				}))
			];
		},

		_setSelectedAttr: function(/*Boolean*/ isSelected){
			this._set("selected", isSelected);
			this.button.set("selected", isSelected);
			if(isSelected){
				var cw = this.contentWidget;
				if(cw.onSelected){ cw.onSelected(); }
			}
		},

		startup: function(){
			// Called by _Container.addChild()
			this.contentWidget.startup();
		},

		destroy: function(){
			this.button.destroyRecursive();

			dojo.forEach(this._contentWidgetWatches || [], function(w){ w.unwatch(); });

			delete this.contentWidget._buttonWidget;
			delete this.contentWidget._wrapperWidget;

			this.inherited(arguments);
		},
		
		destroyDescendants: function(){
			// since getChildren isn't working for me, have to code this manually
			this.contentWidget.destroyRecursive();
		}
});

dojo.declare("dijit.layout._AccordionButton",
	[dijit._Widget, dijit._Templated, dijit._CssStateMixin],
	{
	// summary:
	//		The title bar to click to open up an accordion pane.
	//		Internal widget used by AccordionContainer.
	// tags:
	//		private

	templateString: dojo.cache("dijit.layout", "templates/AccordionButton.html", "<div dojoAttachEvent='onclick:_onTitleClick' class='dijitAccordionTitle'>\n\t<div dojoAttachPoint='titleNode,focusNode' dojoAttachEvent='onkeypress:_onTitleKeyPress'\n\t\t\tclass='dijitAccordionTitleFocus' role=\"tab\" aria-expanded=\"false\"\n\t\t><span class='dijitInline dijitAccordionArrow' role=\"presentation\"></span\n\t\t><span class='arrowTextUp' role=\"presentation\">+</span\n\t\t><span class='arrowTextDown' role=\"presentation\">-</span\n\t\t><img src=\"${_blankGif}\" alt=\"\" class=\"dijitIcon\" dojoAttachPoint='iconNode' style=\"vertical-align: middle\" role=\"presentation\"/>\n\t\t<span role=\"presentation\" dojoAttachPoint='titleTextNode' class='dijitAccordionText'></span>\n\t</div>\n</div>\n"),
	attributeMap: dojo.mixin(dojo.clone(dijit.layout.ContentPane.prototype.attributeMap), {
		label: {node: "titleTextNode", type: "innerHTML" },
		title: {node: "titleTextNode", type: "attribute", attribute: "title"},
		iconClass: { node: "iconNode", type: "class" }
	}),

	baseClass: "dijitAccordionTitle",

	getParent: function(){
		// summary:
		//		Returns the AccordionContainer parent.
		// tags:
		//		private
		return this.parent;
	},

	buildRendering: function(){
		this.inherited(arguments);
		var titleTextNodeId = this.id.replace(' ','_');
		dojo.attr(this.titleTextNode, "id", titleTextNodeId+"_title");
		dijit.setWaiState(this.focusNode, "labelledby", dojo.attr(this.titleTextNode, "id"));
		dojo.setSelectable(this.domNode, false);
	},

	getTitleHeight: function(){
		// summary:
		//		Returns the height of the title dom node.
		return dojo._getMarginSize(this.domNode).h;	// Integer
	},

	// TODO: maybe the parent should set these methods directly rather than forcing the code
	// into the button widget?
	_onTitleClick: function(){
		// summary:
		//		Callback when someone clicks my title.
		var parent = this.getParent();
			parent.selectChild(this.contentWidget, true);
			dijit.focus(this.focusNode);
	},

	_onTitleKeyPress: function(/*Event*/ evt){
		return this.getParent()._onKeyPress(evt, this.contentWidget);
	},

	_setSelectedAttr: function(/*Boolean*/ isSelected){
		this._set("selected", isSelected);
		dijit.setWaiState(this.focusNode, "expanded", isSelected);
		dijit.setWaiState(this.focusNode, "selected", isSelected);
		this.focusNode.setAttribute("tabIndex", isSelected ? "0" : "-1");
	}
});

}

if(!dojo._hasResource['epages.cartridges.de_epages.presentation.visualaidcontroller']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.presentation.visualaidcontroller'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.presentation.visualaidcontroller

*/
dojo.provide('epages.cartridges.de_epages.presentation.visualaidcontroller');

epages.cartridges.de_epages.presentation.visualaidcontroller = {
	isVisualAidVisible: true,
	visualAidClassNames: ["HideVisualAid", "ShowVisualAid"],
	win: window,

	toggleVisualAid: function() {
		this.isVisualAidVisible = !this.isVisualAidVisible;
		this.setVisualAid(this.isVisualAidVisible);
	},
	getVisualAidClassName: function () {
		return this.visualAidClassNames[this.isVisualAidVisible ? 1 : 0];
	},
	setVisualAid: function(isVisible) {
		var a = this.visualAidClassNames[isVisible ? 1 : 0];
		var r = this.visualAidClassNames[isVisible ? 0 : 1];
		if(this.win.tinyMCE){
			for (var e in this.win.tinyMCE.instances) {
				iDoc=$E(this.win.tinyMCE.instances[e].iframeElement).getIframeDocument();
				dojo.addClass(iDoc.body,a);
				dojo.removeClass(iDoc.body,r);
			}
		}
		dojo.addClass(this.win.document.body,a);
		dojo.removeClass(this.win.document.body,r);
		this.isVisualAidVisible=isVisible;
		dojo.publish('presentation/setVisualAid', [{
			isVisible: this.isVisualAidVisible
		}]);
	}
};

dojo.subscribe("EmbeddedStorefront/onLoad", function(iframe) {
	epages.cartridges.de_epages.presentation.visualaidcontroller.win = iframe.contentWindow;
	epages.cartridges.de_epages.presentation.visualaidcontroller.setVisualAid(epages.cartridges.de_epages.presentation.visualaidcontroller.isVisualAidVisible);
});

dojo.subscribe("EmbeddedStorefront/onChange", function(iframe) {
	epages.cartridges.de_epages.presentation.visualaidcontroller.win = iframe.contentWindow;
	epages.cartridges.de_epages.presentation.visualaidcontroller.setVisualAid(epages.cartridges.de_epages.presentation.visualaidcontroller.isVisualAidVisible);
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Undobuttons"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Undobuttons"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.presentation.widget.Undobuttons");




dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.Undobuttons",
	[	epages.widget.LocalizedWidget ],
	{
		undoObject      : undefined,
		updateObject    : undefined,
		templateString:"<form>\n<div class=\"UndoButtons\">\n  <button type=\"button\" class=\"FloatLeft Button SaveButton Disabled\"  dojoAttachPoint=\"savebutton\">{Save}</button>\n  <div class=\"CommandMedium UndoIcon DisabledButton\" dojoAttachPoint=\"undobutton\">\n     <i class=\"Sprite ico_m_undo\" title=\"{Undo}\"></i>\n  </div>\n  <div class=\"CommandMedium RedoIcon DisabledButton\" dojoAttachPoint=\"redobutton\">\n    <i class=\"Sprite ico_m_redo\" title=\"{Redo}\"></i>\n  </div>\n</div>\n</form>\n",
		imagePath       : epages.themeUrl('images'),
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget', 'templates/translation'),
		containerId     : "",
		validate        : null,
		siteId          : epages.vars.SiteID || '',
		url             : '?',
		isWizard        : false,

		postMixInProperties: function() {
			if ($$(this.id)) {
				// a widget with this id already exists
				var newId = '';
				var counter = 0;
				do {
					newId = this.id + '_' + counter;
				} while ($$(newId));
				this.id = newId;
			}
		},

		getUndoObject: function () {
			return this.undoObject;
		},

		postCreate: function() {
			if(this.containerId != "" && $(this.containerId) ){
				this.undoObject = new epages.html.UnDo($(this.containerId));
			}else{
				this.undoObject = new epages.html.UnDo();
			}
			dojo.addOnLoad(this, "init");
			this.inherited("postCreate", arguments);
		},

		init: function() {
			this.connect(this.undoObject, "validateInput", "toggleButtons");

			this.connect(this.undoObject, "undo", "toggleButtons");
			dojo.connect(this.undobutton, "onclick", this.undoObject, "undo");

			this.connect(this.undoObject, "redo", "toggleButtons");
			dojo.connect(this.redobutton, "onclick", this.undoObject, "redo");

			this.connect(this.savebutton, "onclick", "sendChanges");
			this.connect(this.savebutton, "onclick", "toggleButtons");

			this.connect(this.undoObject, "onChangeTyping", "toggleButtons");
		},

		toggleButtons: function(evt) {
			if (this.undoObject.historyStack.length != 0) {
				dojo.removeClass(this.undobutton, "DisabledButton");
			} else {
				dojo.addClass(this.undobutton, "DisabledButton");
			}
			if (this.undoObject.forwardStack.length != 0) {
				dojo.removeClass(this.redobutton, "DisabledButton");
			} else {
				dojo.addClass(this.redobutton, "DisabledButton");
			}
			if (this.undoObject.errorStack.length == 0 && (
						this.undoObject.isTyping ||
						this.undoObject.existsChanges()
					)
			) {
				dojo.removeClass(this.savebutton, "Disabled");
			} else {
				dojo.addClass(this.savebutton, "Disabled");
			}
		},

		sendChanges: function(messageOpt) {
			var message = this.translate("BusyWhileSavingData");
			var permanentMessage = false;
			if(messageOpt) {
				if(messageOpt.text){ message = messageOpt.text; }
				if(messageOpt.permanent){ permanentMessage = true; }
			}
			if (this.undoObject.errorStack.length == 0 && this.existsChanges()) {
				dojo.publish("uimessage/startBusy", ["Undobuttons", message ]);
				if (this.updateObject === undefined) {
					
					this.updateObject = new epages.cartridges.de_epages.presentation.ObjectUpdater({siteId:this.siteId});
				}
				this.updateObject.sendAsync(this.url, this.updateObject.getFormDataViaObjectForm(this.undoObject.getChanged()), function() {
					// dojo.publish("uimessage/stopBusy", ["Undobuttons"]);
					if(permanentMessage != true){
						window.setTimeout(function() {dojo.publish('uimessage/stopBusy', ["Undobuttons"]);} , 500);
					}
					dojo.publish('undobuttons/saveFinished', []);
				},this.isWizard);
				this.undoObject.checkTyping(false);
				this.undoObject.clear();
				this.toggleButtons();
			}// else  alert("errors: " + this.undoObject.errorStack.length);
		},

		existsChanges: function(){
			return this.undoObject.existsChanges();
		}
	}
);

epages.onUnloadFunctions.push(function() {
	var w = $$("undoWidget");
	if(w){
		return w.existsChanges();
	}
	return false;
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Toolvisualaid"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Toolvisualaid"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.presentation.widget.Toolfont

*/
dojo.provide("epages.cartridges.de_epages.presentation.widget.Toolvisualaid");




dojo.declare("epages.cartridges.de_epages.presentation.widget.Toolvisualaid",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * private properties
		 */
		_classes      : ['ico_s_visualaid','ico_s_visualaid_hidden'],
		/**
		 * widget properties
		 */
		templateString:"<div class=\"CommandSmallWithLink VisualAid TopMargin NoPadding\" title=\"{ToggleGuideLines}\" /><i dojoAttachPoint=\"iconNode\" class=\"Sprite ico_s_visualaid\"></i>{GuideLines}</div>\n",
		imagePath    : epages.themeUrl('images'),
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget', 'templates/translation'),

		postCreate  : function() {
			this.inherited("postCreate", arguments);
			this.connect(this.domNode, "onclick", '_setVisualAid');
			dojo.subscribe('presentation/setVisualAid', this, '_updateButton');  // multiple instances of this widget can react on a change
		},

		_setVisualAid: function() {
			epages.cartridges.de_epages.presentation.visualaidcontroller.toggleVisualAid();
		},

		_updateButton: function(opt) {
			epages.html.replaceClass(this.iconNode, this._classes[opt.isVisible ? 0 : 1], this._classes[opt.isVisible ? 1 : 0]);
		}
});

}

if(!dojo._hasResource['epages.html.form']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.html.form'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.html.form');



epages.html.Form = function (object) {
	if (object === undefined) {
		console.warn('epages.html.Form: initialize without object.');
		// raise error for callback
		var name = object.className;
	}
	this.object = object;
};

dojo.extend(epages.html.Form, {
	object: undefined,

	get: function () {
		var content = $H();
		for( var i=0,iLength=this.object.elements.length ; i<iLength ; i++ ){
			var elm = this.object.elements[i];
			if (elm.getAttribute('ep_form') != 'false') {
				var name = elm.name;
				var value = content.get(name);
				if (value === undefined){
					value = [];
				}
				value.push($E(elm).get());
				content.set(name, value);
			}
		}
		return content;
	},

	set: function (content,callOnChange) {
		if(callOnChange === undefined){
			callOnChange = true;
		}
		if (dojo.isString(content)){
			content = $H(dojo.fromJson(content));
		}

		for( var i=0,iLength=this.object.elements.length ; i<iLength ; i++ ){
			var elm = this.object.elements[i];
			var name = elm.name;
			var value = content.get(name);
			if(value != '' && value != undefined && elm.getAttribute('widgetid') && (dojo.hasClass(elm,'Radio') || dojo.hasClass(elm,'Checkbox'))){
				$$(elm.getAttribute('widgetid')).setChecked(true);
			}
			if (value !== undefined) {
				var hlm = $E(elm);
				hlm.set(value.shift());
				if(callOnChange){
					hlm.callOnChange();
				}
				content.set(name, value);
			}
		}
	},

	toString: function() {
		return this.get().toString();
	}

});

}

if(!dojo._hasResource['epages.widget.Slider']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.widget.Slider'] = true;
/*
	Copyright (c) 2006-2008, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.widget.Slider');



dojo.declare("epages.widget.Slider", [dijit._Widget,dijit._Templated], {
	timerLeft         : null,
	timerRight        : null,
	slideSpeed        : 0,
	currentWidth      : 0,   // Integer - total width of the container that holds all images
	menuWidth         : 0,   // Integer - width of the visible part of the slider
	currentMoveState  : '',  // String - current State of Animation, left, right or empty
	maxSpeed          : 15,  // Integer - max Speed of Animation on the End of the Slider increase to speed up Slider
	totalOffsetLeft   : 0,   // Integer - total Offset of the Slider to the left side of the browser

	templateString:"<div class=\"ImageSlide\">\n  <div dojoAttachPoint=\"crossSlide\"><nobr dojoAttachPoint=\"containerNode\"></nobr></div>\n</div>\n",

	postCreate: function() {
		this.inherited("postCreate", arguments);
		// summary: standard init routine
		// description: Link needed events to appropriate functions
		// 		and set all global variables needed in other functions.
		//		Also hide the horizontal fallback scrollbar and revise
		//		the height of the main element.
		//
		//		An Image Slide frame must look like this:
		//		...and YES, every char has a purpose!
		//		E. g. to ensure a fallback alternative for
		//		people without javascript.
		//		for a detailed example look at the SliderTest.html
		// example:
		//	|	<div dojoType="epages.widget.Slider" maxSpeed="50" class="ImageSlide">
		//	|		<nobr style="width:50px"> //total Width of Container width of picture * number of pictures
		//	|		      <a href="#go">
		//	|		        <img src="pic1.gif"/>
		//	|		      </a>
		//	|		      <a href="#go">
		//	|		        <img src="pic2.gif"/>
		//	|		      </a>
		//	|		      <a href="#go">
		//	|		        <img src="pic3.gif"/>
		//	|		      </a>
		//	|					...
		//	|		    </nobr>
		//	|	</div>
		this.connect(window, 'onresize', '_arrangeResizedDocument');
		this.domNode.style.overflow = 'hidden';
		this.domNode.style.height = this.crossSlide.offsetHeight+'px';
		this.menuWidth = this.domNode.offsetWidth;
		var crossSlideWidth = (this.crossSlide.style.width != "") ? parseInt(this.crossSlide.style.width) : 0;
		this.currentWidth = this.crossSlide.offsetWidth? this.crossSlide.offsetWidth : crossSlideWidth;
		this.crossSlide.style.left = 0;
		this.totalOffsetLeft = this.domNode.offsetLeft;
		this._appendEvents();
	},

	_appendEvents: function() {
		this.connect(this.domNode,'onmousemove', '_doMotion');
		this.connect(this.domNode,'onmouseout', '_stopMotion');
	},

	_updateAfterEvent: function() {
		// summary: update the image slide line
		// description: We must force the css engine of some browsers
		//    to refresh the style on the whole image slide.
		//    Otherwise the styles will not be updated and e. g.
		//    the :hover class misfires for all prior invisible images.
		// example:
		//  |  _updateAfterEvent();
		this.domNode.style.clear = 'both';
		this.domNode.style.clear = 'none';
	},

	_moveLeft: function() {
		// summary: move the image line inside the container to the left
		// description: First we check if it is necessary to move the
		//		image line and if "yes" we move it as long the cursor indicates
		//    that it should move. To not confuse other functions we state
		//		that we are currently really moving it to the left. MOVE!
		// example:
		//  | _moveLeft();
		this.currentMoveState = 'left';
		if(parseInt(this.crossSlide.style.left) > (this.menuWidth - this.currentWidth)){
			this.crossSlide.style.left = parseInt(this.crossSlide.style.left) - this.slideSpeed + 'px';
		}
		this.timerLeft = setTimeout(epages.lang.hitch(this, this._moveLeft), 10);
	},

	_moveRight: function(){
		// summary: move the image line inside the container to the rights
		// description: First we check if it is necessary to move the
		//		image line and if "yes" we move it as long the cursor indicates
		//    that it should move. To not confuse other functions we state
		//		that we are currently really moving it to the right. MOVE!
		// example:
		//  | _moveRight();
		this.currentMoveState = 'right';
		if(parseInt(this.crossSlide.style.left) < 0){
			this.crossSlide.style.left = parseInt(this.crossSlide.style.left) + this.slideSpeed + 'px';
		}
		this.timerRight = setTimeout(epages.lang.hitch(this, this._moveRight), 10);
	},

	_doMotion: function(/*Object?*/ mouseEvent){
		// summary: the heart of our sliding effect
		// description: It does all the stuff like calculating the speed of
		//		the image slide, observing the cursor for new motions and
		//		initiating the move[...]() functions.
		// example:
		//  | mynode.onmousemove = function(mouseEvent){
		//  |   _doMotion(mouseEvent);
		//  |   _updateAfterEvent();
		//  | }
		var mouseXPoint = mouseEvent.clientX;
		var currentYPosition = mouseEvent.clientX - this.totalOffsetLeft;
		var edgeBound = (this.menuWidth / 2);
		if (currentYPosition > edgeBound){
			this.slideSpeed = (currentYPosition - edgeBound) / this.menuWidth / 2 * this.maxSpeed;
			clearTimeout(this.timerRight);
			if (this.currentMoveState != 'left'){
				this._moveLeft();
			}
		} else if (currentYPosition < edgeBound){
			this.slideSpeed = (edgeBound - currentYPosition) / this.menuWidth / 2 * this.maxSpeed;;
			clearTimeout(this.timerLeft);
			if (this.currentMoveState != 'right'){
			this._moveRight();
			}
		}else{
			this.slideSpeed = 0;
		}
	},

	_stopMotion: function(/*Object?*/ mouseEvent){
		// summary: stops all slide motions
		// description: If called with a mouse position where the slide
		//    should be stopped - we have to immediately clear all
		//		active timeouts that would call the move[...] functions.
		//		Furthermore we state that there is no motion active anymore.
		// example:
		//  | mynode.onmouseout = function(mouseEvent){
		//  |   _stopMotion(mouseEvent);
		//  |   _updateAfterEvent();
		//  | }
		if ((window.event && !this.domNode.contains(event.toElement)) || (mouseEvent && mouseEvent.currentTarget && mouseEvent.currentTarget!= mouseEvent.relatedTarget && !this._checkNode(mouseEvent.currentTarget, mouseEvent.relatedTarget))){
			clearTimeout(this.timerLeft);
			clearTimeout(this.timerRight);
			this.currentMoveState = "";
		}
	},

	_checkNode: function(/*Object?*/ currentTarget, /*Object?*/ relatedTarget) {
		// summary: check if we are in the right element
		// description: Naturally there is one browser that behaves unintentional.
		//		This time nearly all browsers fail. Without this routine
		//		Firefox would refer the mousemove event to every single image
		//		(the motion would only start if the cursor points an image).
		//		Netscape would inherit the mousemove event to the whole
		//		document body and the Internet Explorer would produce sensless
		//		error messages because it does not know the attribute.
		// example:
		//  |  var canIPleaseKillTheTimout = _checkNode(currentTarget, relatedTarget);
		if (relatedTarget !== null){
			while (relatedTarget.parentNode){
				relatedTarget = relatedTarget.parentNode;
				if (relatedTarget == currentTarget){
					return true; // Boolean
				}
			}
		}
	},

	_arrangeResizedDocument: function() {
		// summary: adjust the whole thing on window resizing
		// description: We have to resize and realign the slide
		//		if the size of the browser window changes.
		// example:
		//  | window.onresize = _arrangeResizedDocument;
		this.menuWidth = this.domNode.offsetWidth;
		this.crossSlide.style.left = this.menuWidth - this.currentWidth + 'px';
	}
});

}


dojo.i18n._preloadLocalizations("epages.nls.ep_shop_preview", ["ROOT","ca","da","de","en","es","fi","fr","it","nl","no","pt","ro","ru","sv","xx"]);

/* package: ep_shop_contenteditor.js.uncompressed */
/*
	Copyright (c) 2004-2011, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/

/*
	This is an optimized version of Dojo, built for deployment and not for
	development. To get sources and documentation, please visit:

		http://dojotoolkit.org
*/

if(!dojo._hasResource['epages.cartridges.de_epages.presentation.widget.EditorPlaceholder']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.presentation.widget.EditorPlaceholder'] = true;
dojo.provide('epages.cartridges.de_epages.presentation.widget.EditorPlaceholder');




dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.EditorPlaceholder",
	[dijit._Widget, dijit._Templated],
	{
		ep_info: '',
		_info: undefined,
		base64: new epages.string.Base64,
		src : epages.vars.StoreRoot + '/BO/icons/general_img_transparentpixel.gif',

		templateString: '<img width="" height="" ep_group="" ep_info="${ep_info}" title="" alt="" style="" class="epItemContent" src="${src}" />',

		decodeInfo: function(string) {
			if(string && string != ''){
				var info = eval("(" + this.base64.decode(string) + ")");
				if (info.formData !== undefined){ 
					info.formData = $H(info.formData);
				}
				return info;
			}
	},

		postMixInProperties:function(){
			this.inherited("postMixInProperties", arguments);
			this._info = this.decodeInfo(this.ep_info);
		},
		postCreate: function(){
			this.inherited("postCreate", arguments);
			if(this._info && this._info != ''){
				if(this._info.width == "100%") {
					this.domNode.setAttribute('width',this.domNode.parentNode.offsetWidth);
				}else {
					this.domNode.setAttribute('width',this._info.width);
				}
				if(this._info.height == "100%") {
					this.domNode.setAttribute('height',this.domNode.parentNode.offsetHeight);
				}else {
					this.domNode.setAttribute('height',this._info.height);
				}
				this.domNode.setAttribute('alt',this._info.title);
				this.domNode.setAttribute('title',this._info.title);
				this.domNode.style.backgroundImage = 'url('+epages.locationWebRoot(this._info.preview)+')';
				this.domNode.setAttribute('ep_group',this._info.group);
				var width = (this._info.width.toString().match(/%/)) ? this._info.width : this._info.width+'px';
				var height = (this._info.height.toString().match(/%/)) ? this._info.height : this._info.height+'px';
				var epStyle="background:url('"+this._info.preview+"'); width:"+width+"; height:"+height+";";
				this.domNode.setAttribute('ep_style',epStyle);
			}
		}
	}
);

}

if(!dojo._hasResource['epages.cartridges.de_epages.presentation.widget.TextInlineEditor']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.presentation.widget.TextInlineEditor'] = true;
dojo.provide('epages.cartridges.de_epages.presentation.widget.TextInlineEditor');



// inline editor for simple (unformatted) text
dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.TextInlineEditor",
	epages.cartridges.de_epages.presentation.widget.InlineEditor,
	{
		postMixInProperties: function() {
			this.inherited("postMixInProperties", arguments);
			this.valueFormatted = this.value.replace(/\<br\s*\/?\>(?:\r?\n)?/gi, "\n");		// formatting for textarea
		},

		create: function() {
			this.inherited('create', arguments);

			if(this.additionalClass !== undefined) {
				this.domNode.className += " " + this.additionalClass;
			}
		},

		show: function() {
			// simple text input
			if (!this.isInited) {
				this._copyStyle(this.contentNode, this._computedStyle);
				this._resizeToContent();
				this.contentNode.style.display = '';
				this.contentNode.style.overflow = 'hidden';
				if (this.undoObject){
					this.undoObject.registerInput(this.contentNode);
				}
				// connect events
				this.connect(this.contentNode, 'click', '_resizeToContent');
				this.connect(this.contentNode, 'onkeyup', '_resizeToContent');
				this.connect(this.contentNode, 'onpaste', '_resizeToContent');
				this.connect(this.contentNode, 'onkeyup', 'onChangeContentNode');
				this.connect(this.contentNode, 'onpaste', 'onChangeContentNode');
				this.isInited = true;
			} else {
				this.contentNode.style.display = '';
			}
			this._resizeToContent();
			this.displayNode.style.display = 'none';
			this.contentNode.focus();
			this.inherited('show', arguments);
		},

		hide: function(evt) {
			if (!this.isInited){
				return;
			}
			if (this.contentNode.value == '') {
				this.displayNode.innerHTML = this._placeHolderText;
			} else {
				this.displayNode.innerHTML = epages.html.encodeEntity(this.contentNode.value, true);
			}
			this.displayNode.style.display = '';
			this.contentNode.style.display = 'none';
			this.inherited('hide', arguments);
		},

		// gets called, when data is changed (from outside)
		onChangeContentNode: function() {
			if(!this.allowLineBreaks){
				this.contentNode.value = this.contentNode.value.replace(/\n/g, "");
			}
			
			this.displayNode.innerHTML = epages.html.encodeEntity(this.contentNode.value);
			this.inherited("onChangeContentNode", arguments);
		}
	}
);

}

if(!dojo._hasResource['epages.cartridges.de_epages.presentation.widget.HtmlInlineEditor']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.presentation.widget.HtmlInlineEditor'] = true;
dojo.provide('epages.cartridges.de_epages.presentation.widget.HtmlInlineEditor');





dojo.publish('epages/addGlobalSymbol', ['tinymce', window]);
dojo.publish('epages/addGlobalSymbol', ['tinyMCE', window]);

// inline editor for html (formatted) text, uses TinyMCE Rich-Text-Editor
dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.HtmlInlineEditor",
	epages.cartridges.de_epages.presentation.widget.InlineEditor,
	{
		getAction 	: 'JSONGet',
		showPageBreak: 'false',

		postCreate: function() {
			this.inherited('postCreate', arguments);
			epages.topDojo.subscribe('tinymce_windowmanager_open/changeContent',this,'onTinyMCEChangeContent');
			epages.topDojo.subscribe("uimessage/startBusy",this,"hideOnSave");
		},

		show: function() {
			// needed for rendering of editors
			tinymce.DOM.doc = window.document;

			// TinyMCE WYSIWYG Editor
			if (this.displayNode.innerHTML == this._placeHolderText){
				this.displayNode.innerHTML = '';
			}
			if (this.object == null) {
				var doc = this.domNode.ownerDocument;
				var settings = tinyMCE.settings;

				settings.content_element = this.displayNode;
				this.value = (this.getRemoteValue() || "");
				settings.content_element.innerHTML = this.value;

				this.replaceGadgets(settings.content_element);

				settings.body_class = "ShowVisualAid  Inline ";
				if(this.navbar != ""){
					settings.body_class +="mceShow"+ this.navbar;
				}

				this.object = new tinymce.Editor("InlineEditor_" + this.id, settings);

				this.object.onInit.add(dojo.hitch(this, function() {
					// add undo functionality
					if (this.undoObject) {

						// force refresh of content, to get the effects of tinymce cleanup functions
						var content = this.object.getContent();
						this.object.setContent(content);
						this.contentNode.value = content;

						if (this.undoObject){
							this.undoObject.setDefaultValue(this.contentNode);
						}
						this.object.undoManager = new epages.html.TinymceUndoManagerAdapter(
							this.undoObject,
							this.contentNode,
							dojo.hitch(this, 'onChange')
						);

						this.object.onEvent.add(dojo.hitch(this, function() {
							this.undoObject.checkTyping(Boolean(this.object.undoManager.typing));
						}));
					}

				}));

				this.object.render();

				// add css class to iframe
				var iframe = $('InlineEditor_' + this.id + '_ifr', doc);
				$E(iframe).addClassName('EditorIframe');
				iframe.allowTransparency="true";

				this.isInited = true;
			} else {
				this.object.show();
			}
			this.displayNode.style.display = 'none';

			// enable pagebreak button?
			if(this.showPageBreak == 'true') {
				var div = dojo.query('.MCEElementsBox-InsertPageBreak',top.$('MCEElementsBox'));
				if(div) {
					dojo.removeClass(div[0], 'HideElement');
				}
			}

			this.inherited('show', arguments);
		},

		hide: function(evt) {
			if (!this.isInited){
				return;
			}
			this.object.hide();
			this.contentNode.style.display = 'none';
			this.contentNode.value = this.object.getContent().replace(/\s*\<br\s*\/?\>\s*$/, "");
			this.displayNode.innerHTML = this.contentNode.value;
			this.displayNode.style.display = '';
			if(this.undoObject.isTyping == true){
				this.undoObject.checkTyping(false);
			}

			// disable pagebreak button?
			if(this.showPageBreak == 'true') {
				var div = dojo.query('.MCEElementsBox-InsertPageBreak',top.$('MCEElementsBox'));
				if(div) {
					dojo.addClass(div[0], 'HideElement');
				}
			}

			this.inherited('hide', arguments);
		},

		// gets called, when data is changed (from outside)
		onChangeContentNode: function() {
			var value = this.contentNode.value;

			// put value to DOM, replaceGadgets only work with DOM, not with strings
			var tmp = dojo.query("div[name='temp']")[0]
			if( !tmp ) {
				tmp = dojo.create("div", {"name":"temp"});
			}
			tmp.innerHTML = value;
			this.replaceGadgets(tmp);
			value = tmp.innerHTML;

			// update editor
			if(this.object){
				this.object.setContent(value);
			}
			// update displayed content
			this.displayNode.innerHTML = value;
		},

		onTinyMCEChangeContent: function(editorId){
			if(editorId == this.contentNode.id){
				this.onChange();
			}
		},

		getRemoteValue: function() {
			var json = new epages.io.Json();
			var result = json.loadSync(
				'?ObjectID=' + this.objectId + '&ViewAction=' + this.getAction,
				{
					'Attributes': this.attribute,
					'LanguageID': this.languageId
				}
			);
			return result.data[this.attribute];
		},

		hideOnSave: function(id){
			if(id == 'Undobuttons'){
				this.hide();
			}
		},

		replaceGadgets: function (domNode) {
			var gadgets = epages.html.getElementsByClassName('epItemContent', domNode);
			for( var i=0,l=gadgets.length ; i<l ; i++ ) {
				var g = gadgets[i];
				var epInfo = g.getAttribute('ep_info');
				if(!epInfo){
					var epRegEx = new RegExp ("ep_info:(.*)","mig");
					var regExResult = epRegEx.exec(g.className);
					if(regExResult){
						epInfo = regExResult[1];
					}
				}
				if(epInfo){
					new epages.cartridges.de_epages.presentation.widget.EditorPlaceholder({ep_info: epInfo},g);
				}
			}
		}

	}
);

}

if(!dojo._hasResource['epages.cartridges.de_epages.presentation.widget.Createobjectbutton']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.presentation.widget.Createobjectbutton'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.presentation.widget.Createobjectlink

*/
dojo.provide('epages.cartridges.de_epages.presentation.widget.Createobjectbutton');




dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.Createobjectbutton",
	[epages.widget.LocalizedWidget],
	{
		templateString:     '',
		templateString:"<div class=\"Ghost New\">\n\t<a href=\"javascript: void(0)\" data-ep-preview=\"show\" class=\"Createobjectbutton Container\">\n\t\t<i class=\"fa fa-plus\"></i>\n\t\t${description}\n\t</a>\n</div>\n",
		translationName: 		dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget', 'templates/translation'),

		className:					'',
		objectId:						'',
		description:				'',
		iconFile:						'',
		url :								'?',
		undoWidget:					'',
		languageId:					undefined,
		formNode:						null,
		dialogTitle:				'',
		focusFirstInput:		false,

		_errorInputs:				null,

		postMixInProperties: function() {
			if(!this.languageId) {
				this.languageId = epages.vars.Locale.languageId;
			}

			if(this.iconFile == ''){
				this.iconFile = epages.themeUrl('/images/ico_s_add.png');
			}

			if (this.description == "") {
				this.description = this.translate('New');
			}

			this.focusFirstInput = Boolean(this.focusFirstInput);
			this.inherited("postMixInProperties", arguments);
		},

		postCreate: function () {
			this.inherited("postCreate", arguments);
			this._errorInputs = [];
			// add events to buttons
			this.connect(this.domNode, "onclick", "createObject");
		},

		createObject: function() {
			var undoWidget = $$(this.undoWidget);
			if(undoWidget && undoWidget.existsChanges()) {
				this._confirmSaveChanges();
				return;
			}
			var _this = this;
			var doCreateObject = dojo.hitch(this, function(params, button) {
				var json = new epages.io.Json();
				if (params == null){
					params = {};
				}
				params = dojo.mixin({
					ChangeAction: 'NewObject',
					ObjectID: 		this.objectId,
					Class: 				this.className,
					ViewAction:   'JSONGet',
					Attributes:   'ObjectID,ClassAlias=Class.Alias,IsVisible,Position,Name=NameOrAlias' //isProduct is not set for Forum/Guestbook...
				}, params);
				if (button) {
					button._modalDialogWidget.hide();
				}
				var data = json.loadAsync(this.url, dojo.hitch(this,function(result){
					if(result.error){
						if (button) {
							button._modalDialogWidget.show();
						}
						for( var i=0,iLength=this._errorInputs.length ; i<iLength ; i++ ) {
							$E(this._errorInputs[i]).removeClassName('DialogError');
						}
						this._errorInputs = [];
						var data = result.error.data;
						for( var i=0,iLength=data.Errors.length ; i<iLength ; i++ ) {
							var error = data.Errors[i];
							// find element for error by name
							var input = parent.dojo.query('*[name=' + error.Parameter + ']', button._modalDialogWidget.domNode);
							if (input.length > 0) {
								input = input[0];
								epages.topDojo.publish("uimessage/show", ["", this.translate(error.Reason), "Bubble", {
									typeClass: "Warning",
									sizeClass: "Small",
									element: input,
									attachNode: input.parentNode,
									baseNode: button._modalDialogWidget.domNode
								}]);
								$E(input).addClassName('DialogError');
								this._errorInputs.push(input);
							}
						}
					}
					else{
						if (button) {
							button._modalDialogWidget.destroyRecursive();
						}
						window.setTimeout(function() {
							parent.dojo.publish('Createobjectbutton/objectCreated', [{ result: result }]);
						}, 100);
					}
				}), params);
			});
			var json = new epages.io.Json();
			json.loadAsync(this.url, function(result) {
				if (result.data.snippet !== null) {
					// display create object form
					epages.topDojo.require('epages.widget.Modaldialog');
					var newDiv = epages.topWindow.document.createElement('div');
					epages.topWindow.document.getElementsByTagName('body')[0].appendChild(newDiv);
					this._createObjectWidget = new epages.topWindow.epages.widget.Modaldialog({
						// we have to focus the input ourselves, so disable default autofocus
						autofocus : !_this.focusFirstInput,
						options:{
							title : _this.dialogTitle,
							content: result.data.snippet
						},
						buttons: [{
							cssClass: 'Active ep-button ep-button-cta',
							label: _this.translate('Insert'),
							onclick: function() {
								// get values from form
								var formNode = this._modalDialogWidget.containerNode.getElementsByTagName('form');
								if(formNode){
									var params = {};
									if (formNode.length > 0) {
										formNode = formNode[0];
										for( var i=0,iLength=formNode.elements.length ; i<iLength ; i++ ) {
											var element = formNode.elements[i];
											if ((element.nodeName.match(/INPUT/i) && element.type.match(/HIDDEN|RADIO|TEXT|CHECKBOX/i)) ||
												element.nodeName.match(/TEXTAREA|SELECT/i)) {
												params[element.name] = element.value;
											}
										}
									}
									doCreateObject(params, this);
								}
							}
						}, {
							cssClass: 'ep-button ep-button-cancel',
							label: _this.translate('Cancel'),
							onclick: function() {
								this._modalDialogWidget.destroyRecursive();
								parent.dojo.publish('Createobjectbutton/closed');
							}
						}]
					}, newDiv);
					this._createObjectWidget.show();
				} else {
					// empty snippet - no dialog
					// this happens when no template is defined for this class
					doCreateObject();
				}
			},
			{
				'ViewAction': 'JSONSnippet',
				'TemplateAction': 'CreateObjectSnippet',
				'TemplateLanguageID': this.languageId,
				'ObjectID': this.objectId,
				'Class': this.className,
				'DontFail': '1'
			});
		},

		_confirmSaveChanges: function(){
			var me = this;
			parent.dojo.publish("uimessage/show", [
				this.translation.get("SaveQuestion"),
				this.translation.get("CreateObjectDescription"),
				'Dialog',
				{
					titleBar: this.translation.get("ChangeOnContent"),
					sizeClass:"Large",
					typeClass:"Warning",
					buttons: [{
						cssClass: 'Active ep-button ep-button-cta',
						label: this.translation.get("Save"),
						onclick: function() {
							this._modalDialogWidget.destroyRecursive();
							//if Save was clicked, undowidget saves changes
							$$(me.undoWidget).sendChanges();
							$$(me.undoWidget).undoObject.clear();
							//perform action
							me.createObject();
						}
					},
					{
						cssClass: 'ep-button ep-button-cancel',
						label: this.translation.get("Cancel"),
						onclick: function() {
							this._modalDialogWidget.destroyRecursive();
						}
					}]
				}
			]);
		}

	}
);

}


/* package: ep_content.js.uncompressed */
/*
	Copyright (c) 2004-2011, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/

/*
	This is an optimized version of Dojo, built for deployment and not for
	development. To get sources and documentation, please visit:

		http://dojotoolkit.org
*/

if(!dojo._hasResource["epages.cartridges.de_epages.content.widget.ToolChangeVisibility"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.content.widget.ToolChangeVisibility"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.content.widget.ToolChangeVisibility");



dojo.declare(
	"epages.cartridges.de_epages.content.widget.ToolChangeVisibility",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		objectTreeId  : 'contentExplorerObjectTree',
		classStoreId  : 'contentClassStore',
		imageUrl      : epages.vars.StoreRoot + '/BO/icons',
		userGroups    : '',
		url           : '?',

		/**
		 * private properties
		 */
		_classStore      :   undefined,
		_objectTree      :   undefined,
		_currentItem     :   undefined,
		_currentNodeItem :   undefined,
		_dialogWidget    :   undefined,
		_advanced        :   false,
		_userGroups      :   [],
		_currentLanguageID : null,

		/**
		 * widget properties
		 */
		templateString:"<div class=\"CommandPane Medium FloatLeft\" dojoAttachPoint=\"clickNode\" dojoAttachEvent=\"onclick:_onClick\">\n  <i dojoAttachPoint=\"imageNode\" class=\"Sprite ico_m_visible\" title=\"{ChangeVisibility}\"></i>\n  <div>{Visibility}</div>\n  <div dojoAttachPoint=\"dialogNode\" style=\"display: none\">\n    <table class=\"FullWidth\">\n      <tr>\n        <td class=\"InputLabelling\"><label for=\"IsVisibleContentView\" dojoAttachPoint=\"VisiblityLabelNode\">{VisibleOnWebsite}</label></td>\n        <td>\n          <form>\n            <input class=\"Radio\" type=\"text\" dojoAttachPoint=\"IsVisibleContentViewOnNode\" id=\"${id}_IsVisibleContentViewOn\"\n              name=\"IsVisibleContentView\" value=\"1\"/>\n            <label for=\"${id}_IsVisibleContentViewOn\" dojoAttachPoint=\"VisiblityOnLabelNode\">{Yes}</label>\n            <input class=\"Radio\" type=\"text\" dojoAttachPoint=\"IsVisibleContentViewOffNode\" id=\"${id}_IsVisibleContentViewOff\"\n              name=\"IsVisibleContentView\" value=\"0\"/>\n            <label for=\"${id}_IsVisibleContentViewOff\" dojoAttachPoint=\"VisiblityOffLabelNode\">{No}</label>\n            <img src=\"${imageUrl}/ico_s_bubblehelp.png\" alt=\"\" class=\"BubbleHelp\" />\n            <span class=\"Tooltip ep-js\" data-js=\".uiTooltip({})\">{BubbleHelpVisibleOnWebsite}</span>\n          </form>\n        </td>\n      </tr>\n      <tr dojoAttachPoint=\"visibleInNavigationNode\">\n        <td class=\"InputLabelling\">{ShownInNavigation}</td>\n        <td>\n          <form>\n            <input class=\"Radio\" type=\"text\" dojoAttachPoint=\"visibleInNavigationOnNode\" id=\"${id}_visibleInNavigationOn\"\n                   name=\"VisibleInNavigation\" value=\"1\"/>\n            <label for=\"${id}_visibleInNavigationOn\">{Yes}</label>\n            <input class=\"Radio\" type=\"text\" dojoAttachPoint=\"visibleInNavigationOffNode\" id=\"${id}_visibleInNavigationOff\"\n              name=\"VisibleInNavigation\" value=\"0\"/>\n            <label for=\"${id}_visibleInNavigationOff\">{No}</label>\n            <img src=\"${imageUrl}/ico_s_bubblehelp.png\" alt=\"\" class=\"BubbleHelp\" />\n            <span class=\"Tooltip ep-js\"  data-js=\".uiTooltip({})\">{BubbleHelpVisibleInNavigation}</span>\n          </form>\n        </td>\n      </tr>\n      <tr dojoAttachPoint=\"readPermissionNode\">\n        <td class=\"InputLabelling\"><label for=\"ReadPermissionFor\">{ReadPermissionFor}</label></td>\n        <td>\n          <select name=\"ReadPermissionFor\" dojoAttachPoint=\"readPermissionSelectNode\">\n          </select>\n        </td>\n      </tr>\n      <tr dojoAttachPoint=\"textNode\" style=\"display:none;\">\n        <td class=\"InputLabelling TopPadding\" colspan=\"2\">\n          <table class=\"FullWidth AlignBottom\"><tr><td class=\"AlignBottom\">\n            <label for=\"${id}_textAreaNode\" dojoAttachPoint=\"textAreaLabelNode\"></label>\n          </td><td>\n            <input value=\"{StartWYSIWYGEditor}\"\n                   iconSrc=\"dialog_ico_s_richtext\"\n                   onclick=\"epages.cartridges.de_epages.presentation.richtext.openDialog({\n                          name               :'${id}_textAreaNode',\n                          insertCompleteUrl  : false,\n                          savePage           : false\n                   });\"\n                   type=\"button\" class=\"Button StartWYSIWYG\"\n            />\n          </td></tr></table>\n          <div>\n            <textarea dojoAttachPoint=\"textAreaNode\" id=\"${id}_textAreaNode\" class=\"FullSize\">\n            </textarea>\n          </div>\n          <div class=\"ClearLeft\"></div>\n        </td>\n      </tr>\n    </table>\n  </div>\n</div>\n",
		translationName: dojo.moduleUrl('epages.cartridges.de_epages.content.widget', 'templates/translation'),
		widgetsInTemplate:true,

		postCreate: function() {
			this.inherited("postCreate", arguments);
			this._classStore = dojo.getObject(this.classStoreId);
			this._objectTree = $$(this.objectTreeId);
			dojo.subscribe(this.objectTreeId+'/select', this, '_onSelectObject');
			dojo.subscribe(this.objectTreeId+'/changeCurrentVisibility',this,'_onSelectObject');

			this.IsVisibleContentViewOnNode = new epages.widget.FormElement({}, this.IsVisibleContentViewOnNode).elementNode;
			this.IsVisibleContentViewOffNode = new epages.widget.FormElement({}, this.IsVisibleContentViewOffNode).elementNode;
			this.visibleInNavigationOnNode = new epages.widget.FormElement({}, this.visibleInNavigationOnNode).elementNode;
			this.visibleInNavigationOffNode = new epages.widget.FormElement({}, this.visibleInNavigationOffNode).elementNode;
			this.readPermissionSelectNode = new epages.widget.FormElement({}, this.readPermissionSelectNode).elementNode;

			dojo.connect(this.IsVisibleContentViewOnNode, 'onclick', this, '_onClickIsVisibleContentView');
			dojo.connect(this.IsVisibleContentViewOffNode, 'onclick', this, '_onClickIsVisibleContentView');

			var groups = this.userGroups.split(",");
			for( var i=0,iLength=groups.length ; i<iLength ; i++ ){
				var group = groups[i].split("|");
				if(group && group[0] && group[1]){
					var groupId = parseInt(group[0]);
					var groupName = group[1];
					var optionNode = document.createElement('option');
					optionNode.value = groupId;
					optionNode.innerHTML = groupName;
					this.readPermissionSelectNode.appendChild(optionNode);
				}
			}

		},

		_onSelectObject:function(node){
			this._currentClassId = node.item.classId;
			this._currentItem = this._classStore.fetchItemByIdentity(this._currentClassId);
			this._currentNodeItem = node.item;

			this._changeVisibilityIcon(node.item.IsVisibleContentView);
			if(this._currentItem.EffectedVisibilityAttributes){
				var attr = this._currentItem.EffectedVisibilityAttributes;
				if(attr.IsVisibleContentView){
					this._advanced = false;
					this.VisiblityLabelNode.innerHTML = this.translate('Visible');
					this.VisiblityOnLabelNode.innerHTML = this.translate('Yes');
					this.VisiblityOffLabelNode.innerHTML = this.translate('No');
					if(parseInt(this._currentNodeItem.IsVisibleContentView) == 1) {
						$$(this.IsVisibleContentViewOnNode.id).setChecked(true);
						$$(this.IsVisibleContentViewOnNode.id).domNode.checked=true;
					}else {
						$$(this.IsVisibleContentViewOffNode.id).setChecked(true);
					}
				}
				//EPG-19425 on these pages it should not be able to change read permission
				var excludePages = /TermsAndConditions|CustomerInformation|PrivacyPolicy|Imprint|ShippingAndPaymentInformation/;
				if(attr.ReadPermissionFor && !(this._currentItem.alias.match(excludePages))){
					this._advanced = true;
					this.readPermissionNode.style.display = '';
					var selectedIndex = null;
					for( var i=0,iLength=this.readPermissionSelectNode.options.length ; i<iLength ; i++ ){
						var el = this.readPermissionSelectNode.options[i];
						if(el.value == node.item.ReadPermissionFor){
							selectedIndex = el.index;
						}
					}
					if(selectedIndex != null){
						this.readPermissionSelectNode.selectedIndex = selectedIndex;
					}
				}
				else {
					this.readPermissionNode.style.display = 'none';
				}
				if(attr.VisibleInNavigation){
					this._advanced = true;
					this.visibleInNavigationNode.style.display = '';
				}
				else{
					this.visibleInNavigationNode.style.display = 'none';
				}
				if(attr.Text){
					this._advanced = true;
					if(attr.Text.Alias && attr.Text.Alias == 'ShopClosedMessage'){
						this.VisiblityLabelNode.innerHTML = this.translate('ShopStatusIs');
						this.VisiblityOnLabelNode.innerHTML = this.translate('IsOpen');
						this.VisiblityOffLabelNode.innerHTML = this.translate('IsClosed');
					}
				}
			}
			else{
				this._advanced = false;
			}
		},

		_onClick: function (evt) {
			if(this._objectTree == undefined){
				this._objectTree = $$(this.objectTreeId);
			}
			if(this._advanced){
				if (this._dialogWidget === undefined){
					this.createModalDialog();
				}
				this._dialogWidget.setTitle(this.translate('ChangeVisibility')+": "+this._currentNodeItem.title);
				this._dialogWidget.show();
				//set radio buttons
				$$( parseInt(this._currentNodeItem.IsVisibleContentView) ?
					this.IsVisibleContentViewOnNode.id :
					this.IsVisibleContentViewOffNode.id ).attr('checked',true);
				$$( parseInt(this._currentNodeItem.VisibleInNavigation) ?
					this.visibleInNavigationOnNode.id :
					this.visibleInNavigationOffNode.id ).attr('checked',true);

				// check radio buttons for visibility: no is checked
				if(this.IsVisibleContentViewOffNode.checked){
					this._manageVisibility(true, [this.visibleInNavigationOnNode, this.visibleInNavigationOffNode, this.readPermissionSelectNode]);
				// yes is checked
				}else if(this.IsVisibleContentViewOnNode.checked){
					this._manageVisibility(false, [this.visibleInNavigationOnNode, this.visibleInNavigationOffNode, this.readPermissionSelectNode]);
				}

				var visibilityText = this._currentItem.EffectedVisibilityAttributes.Text;
				if(visibilityText){
					this.textNode.style.display = '';
					this.VisibleNavigationTooltip.style.display = 'none';
					this.VisibleTooltip.style.display = 'none';
					var languageNative = null;
					for( var i=0,iLength=epages.vars.CurrentLanguages.length ; i<iLength ; i++ ){
						var elm = epages.vars.CurrentLanguages[i];
						if(elm.LocaleID == contentEventHandler._locale){
							this._currentLanguageID = elm.LanguageID;
							languageNative = elm.Native;
						}
					}
					if(!this._currentItem.EffectedVisibilityAttributes.Text.originalValue || !this._currentItem.EffectedVisibilityAttributes.Text.originalValue[this._currentLanguageID]){
						var json = new epages.io.Json();
						var result = json.loadSync(this.url, {
							'ViewAction': 'JSONGet',
							'Attributes': visibilityText.Alias,
							'ObjectID'  : epages.vars.SiteID,
							'LanguageID': this._currentLanguageID
						});
						if(!result.error){
							if(!this._currentItem.EffectedVisibilityAttributes.Text.originalValue){
								this._currentItem.EffectedVisibilityAttributes.Text.originalValue = {};
							}
							this._currentItem.EffectedVisibilityAttributes.Text.originalValue[this._currentLanguageID] = result.data[visibilityText.Alias];
						}
					}
					var textAreaValue = '';
					if(this._currentItem.EffectedVisibilityAttributes.Text.originalValue[this._currentLanguageID]){
						textAreaValue = this._currentItem.EffectedVisibilityAttributes.Text.originalValue[this._currentLanguageID];
					}
					var objectId = this._currentItem.EffectedVisibilityAttributes.Text.objectId ? this._currentItem.EffectedVisibilityAttributes.Text.objectId : epages.vars.SiteID;
					var inputId = visibilityText.Alias+'Input_'+objectId+'_'+this._currentLanguageID;
					if($(inputId)){
						textAreaValue = $(inputId).value;
					}
					this.textAreaNode.value= textAreaValue;
					this.textAreaLabelNode.innerHTML = this.translate(visibilityText.Alias);
				}
				else {
					this.textNode.style.display = 'none';
					this.VisibleNavigationTooltip.style.display = '';
					this.VisibleTooltip.style.display = '';
				}
			}
			else{
				this._objectTree.changeVisibilityCurrent();
			}
		},

		_onClickIsVisibleContentView: function(evt){
			// check radio buttons for visibility: no is checked
			if(this.IsVisibleContentViewOffNode.checked){
				this._manageVisibility(true, [this.visibleInNavigationOnNode, this.visibleInNavigationOffNode, this.readPermissionSelectNode]);
			// yes is checked
			}else if(this.IsVisibleContentViewOnNode.checked){
				this._manageVisibility(false, [this.visibleInNavigationOnNode, this.visibleInNavigationOffNode, this.readPermissionSelectNode]);
			}
		},

		_manageVisibility: function(visible, nodeList){
			var strOp = visible? "addClass" : "removeClass";

			for(var key in nodeList){
				var objTmp = nodeList[key];
				if(objTmp){
					objTmp.disabled = visible;
					dojo[strOp](objTmp.parentNode, "Disabled");
				}
			}
		},

		createModalDialog: function () {
			
			var me = this;
			this._dialogWidget = new epages.widget.Modaldialog({
				options:{
					title : this.translate('ChangeVisibility'),
					width : 450,
					scroll: "auto",
					content: this.dialogNode
				},
				buttons: [{
					cssClass: 'ep-button ep-button-apply',
					label: this.translate('Apply'),
					onclick: function() {
						me.changeAttributes();
						this._modalDialogWidget.hide();
					}
				},{
					cssClass: 'ep-button ep-button-cancel',
					label: epages.io.dictionary.get('Cancel'),
					onclick: function() {
						this._modalDialogWidget.hide();
					}
				}]
			});
			document.body.appendChild(this._dialogWidget.domNode);
			this.dialogNode.style.display = "";
		},

		_changeVisibilityIcon: function(status){
			this.imageNode.src = this.imageUrl + ((status == 1 ) ? '/ico_m_visible.png' : '/ico_m_notvisible.png');
		},

		changeAttributes: function(){
			var attr = this._currentItem.EffectedVisibilityAttributes;
			var objectId = this._objectTree.currentItem().objectId;
			if(attr.ReadPermissionFor){
				if(this.readPermissionSelectNode.options[this.readPermissionSelectNode.selectedIndex].value != this._currentNodeItem.ReadPermissionFor){
					this._objectTree.model.store.changeAttribute(
						{
							objectId: objectId,
							name:'ReadPermissionFor',
							value:this.readPermissionSelectNode.options[this.readPermissionSelectNode.selectedIndex].value
						}
					);
				}
			}
			if(attr.VisibleInNavigation){
				var VisibleInNavigationNew = this.visibleInNavigationOnNode.checked  == true ? 1 : 0;
				var objectId = this._objectTree.currentItem().objectId;
				if(parseInt(this._currentNodeItem.VisibleInNavigation) != VisibleInNavigationNew){
					this._objectTree.model.store.changeAttribute(
						{
							objectId: objectId,
							name:'VisibleInNavigation',
							value:VisibleInNavigationNew
						}
					);
				}
			}
			if(attr.IsVisibleContentView){
				var IsVisibleContentViewNew = this.IsVisibleContentViewOnNode.checked == true ? 1 : 0;
				if(parseInt(this._currentNodeItem.IsVisibleContentView) != IsVisibleContentViewNew){
					this._objectTree.changeVisibilityCurrent();
				}
			}
			if(attr.Text && this._currentLanguageID){
				var name = attr.Text.Alias;
				var textNew = this.textAreaNode.value;
				if(textNew != attr.Text.originalValue[this._currentLanguageID]){
					this._objectTree.model.store.changeAttribute(
						{
							objectId: epages.vars.SiteID,
							name:name,
							value:textNew,
							languageId: this._currentLanguageID,
							oldValue: attr.Text.originalValue[this._currentLanguageID]
						}
					);
					attr.Text.originalValue[this._currentLanguageID] = textNew;
				}
			}
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.content.widget.ToolMovePage"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.content.widget.ToolMovePage"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.content.widget.ToolMovePage");


dojo.declare(
	"epages.cartridges.de_epages.content.widget.ToolMovePage",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		uri           : '?',
		objectTreeId  : 'contentExplorerObjectTree',
		classStoreId  : 'contentClassStore',
		objectStoreId : 'objectStore',
		imagePath     : epages.themeUrl('images'),
		horizontalMovement: true,//is indent and outdent allowed, feature dependent

		/**
		 * private properties
		 */
		 _classStore  : undefined,
		 _objectStore : undefined,
		 _objectTree  : undefined,

		_upClickConnect: undefined,
		_downClickConnect: undefined,
		_leftClickConnect: undefined,
		_rightClickConnect: undefined,

		/**
		 * widget properties
		 */
		templateString:"<div class=\"ToolMovePage\">\n  {MovePage}<br />\n  <span class=\"Buttons\">\n    <div class=\"CommandMedium DisabledButton\"><i class=\"Sprite ico_m_move_up\" dojoAttachpoint=\"moveUpNode\" title=\"{PageUp}\"></i></div>\n    <div class=\"CommandMedium DisabledButton\"><i class=\"Sprite ico_m_move_down\" dojoAttachpoint=\"moveDownNode\" title=\"{PageDown}\"></i></div>\n    <div class=\"CommandLineBreak\"></div>\n    <div class=\"CommandMedium DisabledButton\"><i class=\"Sprite ico_m_indent\" dojoAttachpoint=\"indentNode\" title=\"{PageIndent}\"></i></div>\n    <div class=\"CommandMedium DisabledButton\"><i class=\"Sprite ico_m_outdent\" dojoAttachpoint=\"outdentNode\" title=\"{PageOutdent}\"></i></div>\n  </span>\n</div>\n",
		translationName: dojo.moduleUrl('epages.cartridges.de_epages.content.widget', 'templates/translation'),

		postCreate: function() {
			this.inherited("postCreate", arguments);
			dojo.subscribe(this.objectTreeId+'/select', this, '_onSelectObject');
			this._classStore = dojo.getObject(this.classStoreId);
			this._objectStore = dojo.getObject(this.objectStoreId);
			this._objectTree = $$(this.objectTreeId);
			if(this.horizontalMovement == false){
				dojo.addClass(this.indentNode, 'HideElement');
				dojo.addClass(this.outdentNode, 'HideElement');
			}
		},

		objectTree: function () {
			if (!this._objectTree) {
				this._objectTree = $$(this.objectTreeId);
				if (!this._objectTree){
					console.warn('%s is not a tree', this.objectTreeId);
				}
			}
			return this._objectTree;
		},

		_onMoveDown: function () { this.objectTree().moveDownCurrent();this._onSelectObject(this.objectTree().lastFocused);},
		_onMoveUp:   function () { this.objectTree().moveUpCurrent();  this._onSelectObject(this.objectTree().lastFocused);},
		_onOutdent:  function () { this.objectTree().outdentCurrent(); this._onSelectObject(this.objectTree().lastFocused); delete this._objectStore.indentNode;},
		_onIndent:   function () { this.objectTree().indentCurrent();  this._onSelectObject(this.objectTree().lastFocused); delete this._objectStore.indentNode;},

		_onSelectObject:function(node){
			// move down
			if (this._objectStore.canMoveItem(1, node.item)&&this.canMoveItem(1,node.item)) {
				if (this._downClickConnect === undefined) {
					dojo.removeClass(this.moveDownNode.parentNode,'DisabledButton');
					this._downClickConnect = this.connect(this.moveDownNode.parentNode,'click', '_onMoveDown')[0];
				}
			} else {
				if (this._downClickConnect !== undefined) {
					dojo.addClass(this.moveDownNode.parentNode,'DisabledButton');
					dojo.disconnect(this._downClickConnect);
					this._downClickConnect = undefined;
				}
			}
			// move up
			if (this._objectStore.canMoveItem(-1, node.item) && this.canMoveItem(-1,node.item)) {
				if (this._upClickConnect === undefined) {
					dojo.removeClass(this.moveUpNode.parentNode,'DisabledButton');
					this._upClickConnect = this.connect(this.moveUpNode.parentNode,'click', '_onMoveUp')[0];
				}
			} else {
				if (this._upClickConnect !== undefined) {
					dojo.addClass(this.moveUpNode.parentNode,'DisabledButton');
					dojo.disconnect(this._upClickConnect);
					this._upClickConnect = undefined;
				}
			}
			// outdent
			if (this._objectStore.canOutdentItem(node.item) && this.canOutdentItem(node.item)) {
				if (this._outdentClickConnect === undefined) {
					dojo.removeClass(this.outdentNode.parentNode,'DisabledButton');
					this._outdentClickConnect = this.connect(this.outdentNode.parentNode,'click', '_onOutdent')[0];
				}
			} else {
				if (this._outdentClickConnect !== undefined) {
					dojo.addClass(this.outdentNode.parentNode,'DisabledButton');
					dojo.disconnect(this._outdentClickConnect);
					this._outdentClickConnect = undefined;
				}
			}
			// indent
			if (this._objectStore.canIndentItem(node.item) && this.canIdentItem(node.item)) {
				if (this._indentClickConnect === undefined) {
					dojo.removeClass(this.indentNode.parentNode,'DisabledButton');
					this._indentClickConnect = this.connect(this.indentNode.parentNode,'click', '_onIndent')[0];
				}
			} else {
				if (this._indentClickConnect !== undefined) {
					dojo.addClass(this.indentNode.parentNode,'DisabledButton');
					dojo.disconnect(this._indentClickConnect);
					this._indentClickConnect = undefined;
				}
			}
		},

		canIdentItem: function(item) {
			var upper = this._findCloseByVisibleItem(item,-1);
			if(upper == undefined){
				return null;
			}
			var upperClass = this._classStore.fetchItemByIdentity(upper.classId);

			return null != $A(upperClass.contentChildClasses).find(item.classId);
		},

		canOutdentItem: function(item) {
			var parent = this._objectStore.fetchItemByIdentity(item.parentId);
			var parentClass = this._classStore.fetchItemByIdentity(parent.classId);

			return null != $A(parentClass.contentChildClasses).find(item.classId);
		},

		_findCloseByVisibleItem: function(item,step){
			//summary: find item that is close to the given one
			//step is the movment defines if the item cames before or after the current item
			var parent = this._objectStore.fetchItemByIdentity(item.parentId);
			var childrenIds = parent.children;
			var foundItem = $A(childrenIds).find(item.objectId);
			var upper = this._objectStore.fetchItemByIdentity(childrenIds[foundItem+step]);
			if(upper == undefined){
				return undefined;
			}
			if(upper.isDeleted == false){
				return upper;
			}
			else{
				return this._findCloseByVisibleItem(upper);
			}
		},

		canMoveItem:function(step,item){
			var upper = this._findCloseByVisibleItem(item,step);
			if(upper == undefined){
				return false;
			}
			else{
				return true;
			}
		}
	}
);

}

if(!dojo._hasResource['epages.lang.sort']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.lang.sort'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.lang.sort');

epages.lang.sort = {
	integer:  function (a,b) { return a - b; },
	position: function (a,b) { return a.position - b.position; }
}

}

if(!dojo._hasResource["epages.cartridges.de_epages.content.widget.ToolNewPage"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.content.widget.ToolNewPage"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.content.widget.ToolNewPage");







dojo.declare(
	"epages.cartridges.de_epages.content.widget.ToolNewPage",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		uri           : '?',
		objectTreeId  : 'contentExplorerObjectTree',
		classStoreId  : 'contentClassStore',
		imageUrl      : epages.vars.StoreRoot + '/BO/icons',
		widgetsInTemplate  : true,
		disabled      : false,

		/**
		 * private properties
		 */
		_classStore :   undefined,
		_currentClassId: undefined,					// current classid of selected element in tree
		_overloadClassId: undefined,				// overload currentClassId (to create a new page on different page) - temporary only
		_overloadObjectId : undefined, 			// overload current parent object - temporary only
		_newPageWidget:  undefined,
		_imageClickConnect: undefined,
		_selectedItemNoFeature: false,

		/**
		 * widget properties
		 */
		templateString:"<div class=\"ToolNewPage CommandPane Medium FloatLeft\">\n  <i dojoAttachPoint=\"imageNode\" class=\"Sprite ico_m_document_new\" title=\"{CreateNewPage}\"></i>\n  <br />\n  {New}\n  <div dojoAttachPoint=\"dialogNode\" class=\"ToolNewPageDialog\" style=\"display: none\">\n    <table>\n      <tr>\n        <td class=\"RightPadding InputLabellingSlim\">{Type}</td>\n        <td>\n          <select class=\"Text\" dojoAttachPoint=\"selectNode\" size=\"9\">\n          </select>\n        </td>\n        <td rowspan=\"3\" class=\"LeftSmallPadding AlignTop\">\n          <div dojoAttachPoint=\"typeNameNode\" class=\"TypeName\"></div>\n          <div dojoAttachPoint=\"typeDescNode\" class=\"TypeDesc\"></div>\n          <div dojoAttachPoint=\"disabledFeatureNode\" class=\"DialogMessageSmall MessageInfo TopMargin\" style=\"display:none\">{FEATURE_LIMIT_EXCEEDED}</div>\n        </td>\n      </tr>\n      <tr>\n        <td class=\"RightPadding InputLabellingSlim\">{Name}<span class=\"MandatoryStar\">{MandatoryStar}</span></td>\n        <td>\n          <input dojoAttachPoint=\"newNameWidget\" dojotype=\"epages.widget.FormElement\" type=\"text\" class=\"Name Mandatory\" />\n        </td>\n      </tr>\n      <tr>\n        <td class=\"RightPadding InputLabellingSlim\">{Visible}</td>\n        <td>\n          <input dojoAttachPoint=\"isVisibleOnNode\" id=\"${id}_isVisibleOn\" name=\"IsVisible\" value=\"1\" class=\"Radio\" type=\"text\"/>\n          <label for=\"${id}_isVisibleOn\">{Yes}</label>\n          <input dojoAttachPoint=\"isVisibleOffNode\" id=\"${id}_isVisibleOff\" name=\"IsVisible\" value=\"0\" checked=\"checked\"  class=\"Radio\" type=\"text\"/>\n          <label for=\"${id}_isVisibleOff\">{No}</label>\n        </td>\n      </tr>\n    </table>\n    <br />\n    {MandatoryFields}\n  </div>\n</div>\n",
		translationName: dojo.moduleUrl('epages.cartridges.de_epages.content.widget', 'templates/translation'),

		postCreate: function() {
			this.inherited("postCreate", arguments);
			dojo.subscribe(this.objectTreeId+'/select', this, '_onSelectObject');
			this._imageClickConnect = dojo.connect(this.imageNode.parentNode, 'click', this, '_onClick');
			this._classStore = dojo.getObject(this.classStoreId);
			this.isVisibleOffNode = new epages.widget.FormElement({}, this.isVisibleOffNode).elementNode;
			this.isVisibleOnNode = new epages.widget.FormElement({}, this.isVisibleOnNode).elementNode;
			this.selectNode = new epages.widget.FormElement({}, this.selectNode).elementNode;
			this.connect(this.selectNode,'onchange', '_onChangeType');
			this.connect(this.newNameWidget.domNode,'onkeyup', '_onChangeName');
		},

		_onSelectObject:function(node) {
			this._currentClassId = node.item.classId;
			this._overloadClassId = undefined;  // reset _overloadClassId
			this._overloadObjectId = undefined; // reset _overloadObjectId
			var item = this._classStore.fetchItemByIdentity(this._currentClassId);
			if(item.contentChildClasses.length == 0) {
				var parentNode = node.getParent();
				if(parentNode && parentNode.item && parentNode.item.classId){
					this._currentClassId = parentNode.item.classId;
					this._overloadClassId = parentNode.item.classId;
					this._overloadObjectId = parentNode.item.objectId;
				}
			}
				if (this._imageClickConnect === undefined) {
					this._imageClickConnect = dojo.connect(this.imageNode, 'click', this, '_onClick');
				}
				dojo.publish(this.id+"/enabled", []);
				this.disabled=false;
		},

		_onClick: function (/* event */ evt, /* object? */ opt) {
		// summary: init & open dialog
		//  event - event object
		//  opt - options object
		//    preselectedClass -> this ClassID will be preselected
		//    overloadClassId  -> ClassID overload parent object
		//    overloadObjectId -> ObjectID overload parent object
			if(opt) {
				if(opt.overloadClassId) {
					this._overloadClassId=opt.overloadClassId;
				}
				if(opt.overloadObjectId) {
					this._overloadObjectId = opt.overloadObjectId;
				}
			}

			if (this._newPageWidget === undefined) {
				this.createModalDialog();
			}
			this.refreshInputs(this._currentClassId, (opt && opt.preselectedClass) ? opt.preselectedClass : undefined );
			this._newPageWidget.show();

			setTimeout(dojo.hitch(this, function() {
				epages.event.fire( this.newNameWidget.domNode, 'focus' );
				this.newNameWidget.domNode.focus();
				this.newNameWidget.domNode.select();
			}), 200);
		},

		refreshInputs: function (/* string */ classId, preselectedClass) {
		// summary: load options in select field
		//  classId - ClassID of current page
			var item = this._classStore.fetchItemByIdentity(this._overloadClassId ? this._overloadClassId : classId);
			epages.html.removeChildren(this.selectNode);
			var classItems = [];
			var hasSel = false;
			dojo.forEach(item.contentChildClasses, function (el) {
				classItems.push(this._classStore.fetchItemByIdentity(el));
			}, this);
			dojo.forEach(classItems.sort(epages.lang.sort.position), function (optionItem) {
				var feature = optionItem.feature;
				var option = document.createElement('option');
				option.value=optionItem.objectId;
				option.innerHTML=optionItem.title;
				if(feature.currentValue != undefined && feature.maxValue != undefined && (
					parseInt(optionItem.feature.currentValue) >= parseInt(optionItem.feature.maxValue))){
					dojo.addClass(option, "FeatureDisabled");
				}
				if(!hasSel) {
					option.selected=true;
					hasSel = true;
				}
				this.selectNode.appendChild(option);
			}, this);

			this.newNameWidget.domNode.value='';
			dojo.removeClass(this._newPageWidget.buttons[0].domNode,'Active');
			dojo.addClass(this._newPageWidget.buttons[0].domNode,'Disabled');
			$$(this.isVisibleOffNode.id).setChecked(true);

			if(preselectedClass) {
				this.selectNode.value = preselectedClass;
				if(this.selectNode.value == preselectedClass) {
					this.newNameWidget.attr('value',this.selectNode[this.selectNode.selectedIndex].text);
				}
			} else {
				this.selectNode.startupIndex = 0;
			}

			this._onChangeType();

		},

		createModalDialog: function () {
			
			var me = this;
			this._newPageWidget = new epages.widget.Modaldialog({
				options:{
					title : this.translate('CreateNewPage'),
					width : 700,
					scroll: "auto",
					content: this.dialogNode
				},
				buttons: [{
					label: this.translate('Insert'),
					cssClass: 'Disabled ep-button ep-button-cta ep-button-disabled',
					onclick: function() {
						if(!dojo.hasClass(this.domNode,'Disabled')){
							dojo.addClass(this.domNode,'Disabled');
							dojo.removeClass(this.domNode,'Active');
							var isVisibleTemp = me.isVisibleOnNode.checked;
							var objectTree = $$(me.objectTreeId);
							var tmpObjectId = me._overloadObjectId;
							if(me._overloadObjectId) {
								objectTree.selectNodeByObjectId(me._overloadObjectId);
							}
							me._overloadClassId = undefined; 	// reset _overloadClassId
							me._overloadObjectId = undefined; // reset _overloadObjectId
							objectTree.createObject(me.selectNode, me.newNameWidget.domNode, me.translate('EnterAlias'),tmpObjectId,isVisibleTemp);
							this._modalDialogWidget.hide();
						}
					}
				},{
					cssClass: 'ep-button ep-button-cancel',
					label: epages.io.dictionary.get('Cancel'),
					onclick: function() {
						this._modalDialogWidget.hide();
					}
				}]
			});
			document.body.appendChild(this._newPageWidget.domNode);
			this.dialogNode.style.display="";
		},

		_setSaveButton: function(isTooLong) {
			if(this.newNameWidget.domNode.value !== '' && !this._selectedItemNoFeature && !isTooLong){
				dojo.removeClass(this._newPageWidget.buttons[0].domNode,'Disabled');
				dojo.addClass(this._newPageWidget.buttons[0].domNode,'Active');
			} else {
				dojo.removeClass(this._newPageWidget.buttons[0].domNode,'Active');
				dojo.addClass(this._newPageWidget.buttons[0].domNode,'Disabled');
			}

			if(this._selectedItemNoFeature) {
				dojo.addClass(this.selectNode, "DialogErrorNormalFontWeight Force");
			} else {
				dojo.removeClass(this.selectNode, "DialogErrorNormalFontWeight Force");
			}
		},

		_onChangeName: function(evt){
			var isTooLong = this.newNameWidget.domNode.value.length>100;

			dojo[isTooLong? 'addClass' : 'removeClass'](this.newNameWidget.domNode, 'DialogError');
			this._setSaveButton(isTooLong);
		},

		_onChangeType: function(evt) {
			var cTypeId = this.selectNode.value;
			var item = this._classStore.fetchItemByIdentity(cTypeId);
			if(item) {
				var icName=epages.cartridges.de_epages.presentation.icon.getIconFileName(item.alias, true, false, 'l');
				if(item.title){
					this.typeNameNode.innerHTML=item.title;
					this.newNameWidget.domNode.value = item.title;
					this.newNameWidget.domNode.select();
				}else{
					this.typeNameNode.innerHTML="";
				}
				if(item.description){
					this.typeDescNode.innerHTML=item.description;
				}else{
					this.typeDescNode.innerHTML="";
				}
				var feature = item.feature;
				if(feature.currentValue != undefined && feature.maxValue != undefined && (
					parseInt(feature.currentValue) >= parseInt(feature.maxValue))){
					this.disabledFeatureNode.style.display='';
					this._selectedItemNoFeature=true;
				} else {
					this.disabledFeatureNode.style.display='none';
					this._selectedItemNoFeature=false;
				}
				this.typeDescNode.style.backgroundImage="url("+epages.vars.IconsRoot+"/"+icName+")";
				this._setSaveButton();

			}
		}
	}
);

}

if(!dojo._hasResource['epages.cartridges.de_epages.content.ClassStore']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.content.ClassStore'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

*/
dojo.provide('epages.cartridges.de_epages.content.ClassStore');





dojo.declare(
	'epages.cartridges.de_epages.content.ClassStore',
	[dojo.data.api.Identity],
	{
		/**
		 * public properties
		 */
		actionInfo         : "JSONContentClasses", // server ViewAction to get children information
		url                : '?',              // request url like '/epages/DemoShop.admin/?'
		objectId           : '',               // objectId for info request
		titleAttribute     : 'NameOrAlias',    // attribute used to show name at tree
		title              : '',               // title of the rode node
		id                 : 'ClassStore',

		/**
		 * private properties
		 */
		_info              : undefined,            // epages.lang.Hash values including information about classes
		_JsonIo            : new epages.io.Json(), // epages.io.Json() JSON communication channel to server
		_serverAttributes  : '',                   // String, list of attributes for server

		constructor: function(keywordParameters){
			dojo.mixin(this,keywordParameters);
			this._info = $H();
			dojo.subscribe('uimessage/stopBusy',this, "_reloadStore");
		},

		_loadList: function(classId) {
			if(classId && !this._info.existsKey(classId)) {
				var jsonData = this._JsonIo.loadSync(this.url, {
					'ViewAction' : this.actionInfo,
					'ObjectID'   : this.objectId,
					'ClassID': classId
				});
				if (jsonData != null && !jsonData.error) {
					// save data at internal structure
					dojo.forEach(jsonData.data, function (el) {
						var info = {
							alias: el.Alias,
							title: el.NameOrAlias,
							objectId: el.ObjectID,
							contentChildClasses: el.ContentChildClasses,
							EffectedVisibilityAttributes: el.EffectedVisibilityAttributes,
							position: el.Position,
							feature: {
								currentValue: el.FeatureCurrentValue ? el.FeatureCurrentValue: undefined,
								maxValue: el.FeatureMaxValue ? el.FeatureMaxValue: undefined
							},
							description : el.Description
						};
						this._info.set(el.ObjectID, info);
					}, this);
				} else {
					return false;
				}
			}
			return true;
		},

		_fetch: function (objectId) {
			var childrenIds = this._info.get(objectId).contentChildClasses;
			var items = [];
			var i;
			dojo.forEach(childrenIds, function(el) {
				i = this._info.get(el);
				if (! i.isDeleted){ 
					items.push(i);
				}
			}, this);
			return items;
		},

		_fetchItems: function(keywordArgs, findCallback, errorCallback){
			if(this._loadList(keywordArgs.query.id) && typeof findCallback == 'function') {
				findCallback(this._fetch(keywordArgs.query.id), keywordArgs);
			} else {
				console.warn('error while _fetch %d', keywordArgs.query.id);
				//errorCallback(keywordArgs);
			}
		},

		fetchItemByIdentity: function(objectId){
			if (this._loadList(objectId)){
				return this._info.get(objectId);
			}
			return undefined;
		},

		hasAttribute: function(node, attributeName){
			return node[attributeName] !== undefined;
		},

		getLabel: function(item){
			return item.title;
		},

		getIdentity: function(item){
			return item.objectId;
		},

		getValue: function(item, attribute){
			console.warn('getValue %s', attribute);
		},

		getValues: function(item, attribute){
			if (attribute == 'children' && this._loadList(item.objectId)) {
				return this._fetch(item.objectId);
			}
			else{
				console.warn('getValues() unknown attribute', attribute);
			}
		},

		isItemLoaded: function(something){
			//console.debug('isItemLoaded');
			return this._info.existsKey(objectId);
		},

		_reloadStore:function(id){
				this._info = $H();
			}
});

dojo.extend(epages.cartridges.de_epages.content.ClassStore,dojo.data.util.simpleFetch);

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Designtoolitem"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Designtoolitem"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.design.widget.Designtoolitem");


dojo.declare(
	"epages.cartridges.de_epages.design.widget.Designtoolitem",
	[dijit._Widget, dijit._Templated, dijit._Contained],
	{
		/**
		 * public properties
		 */
		label: '',
		infoText: '',
		iconSrc: '',
		objectId: '',
		tooltipWidget: undefined,
		 /**
		 * widget properties
		 */
		imagePath         :  epages.themeUrl('images'),
		templateString:"<div class=\"dijitReset dijitMenuItem\"\n    dojoAttachEvent=\"ondijitclick:onClick,onmouseenter:_onHover,onmouseleave:_onUnhover\"\n    style=\"float:left; padding: 3px; margin: 3px 3px 3px 3px\"\n    >\n  <span tabIndex=\"-1\" waiRole=\"menuitem\" >\n  <span class=\"dijitReset dijitMenuItemIcon\" dojoAttachPoint=\"iconNode\" style=\"position:static\"><img src=\"${iconSrc}\" alt=\"\" /><span dojoAttachPoint=\"tooltipNode\"></span></span>\n  <span style=\"display: none\" class=\"dijitReset dijitMenuItemLabel\" dojoAttachPoint=\"containerNode\" ></span>\n  <span style=\"display: none\" class=\"dijitReset\" dojoAttachPoint=\"arrowCell\">\n    <span class=\"dijitMenuExpand\" dojoAttachPoint=\"expand\" style=\"display:none\">\n      <span class=\"dijitInline dijitArrowNode dijitMenuExpandInner\">+</span>\n    </span>\n  </span>\n</div>\n",

		postCreate: function(){
			dojo.setSelectable(this.domNode, false);
			if(this.label){
				this.containerNode.innerHTML=this.label;
			}
			if(this.label != "") {
				var ttContent= "";
				if(this.infoText && this.infoText != ""){
					ttContent = "<b>"+this.label+"</b><br />"+this.infoText;
				}else{
					ttContent = this.label;
				}
				this.tooltipNode.innerHTML= ttContent;
				var tt = new epages.widget.Tooltip({},this.tooltipNode);
				this.tooltipWidget = tt;
			}
		},
		onClick: function() {
		},

		_onHover: function(){
			dojo.addClass(this.domNode, 'dijitMenuItemHover');
		},

		_onUnhover: function(){
			dojo.removeClass(this.domNode, 'dijitMenuItemHover');
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Designtool"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Designtool"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.design.widget.Designtool");




dojo.declare(
	"epages.cartridges.de_epages.design.widget.Designtool", [epages.widget.LocalizedWidget], {
	/**
	 * public properties
	 */
	title: 'Select',
	data: "",
	imagedir: "",
	active: "",
	controllerId: "",
	folder: "",
	folderID: "",
	objectId: "",
	visible: false,
	position: 99, // to sort folder

	/**
	 * private properties
	 */
	_lookup: undefined,
	_lastSelected: null,
	_width: "",
	_height: "",
	_overflowY: "scroll",
	_tooltipCoor: null, //coordinates to position tooltip

	/**
	 * constants
	 */

	ITEM_WIDTH: 62, //Width of the div with padding and margin where the ico is in
	ITEM_HEIGHT: 62, //Height of the div with padding and margin where the ico is in
	WIDTH_SCROLLBAR: 20, //width of scrollbar
	NUMBER_ITEMS_FIRST_ROW: 5, // number of items in the first row
	NUMBER_ITEMS_SECOND_ROW: 10, //number of items in the first an second row together
	NUMBER_ITEMS_THIRD_ROW: 15, //number of items in the first, second and third row together

	/**
	 * widget properties
	 */
	declaredClass: 'epages.design.Designtool',
	imagePath: epages.themeUrl('images'),
	templateString:"<div style=\"display:none\" >\n<div class=\"Designtool WithXLIcon\"  dojoAttachPoint=\"DesigntoolNode\"><div dojoAttachPoint=\"seperatorNode\" class=\"VerticalSeperator\"></div>\n  <div class=\"CommandPane ExtraLarge\" dojoAttachPoint=\"clickNode\">\n    ${title}<br />\n    <img dojoAttachPoint=\"SelectedOptionNode\"\n         src=\"${imagePath}/blank.gif\"\n         alt=\"\" title=\"\"\n         /><br />\n    <img src=\"${imagePath}/img_extend.png\"\n         alt=\"\" title=\"${title}\" />\n  </div>\n</div>\n<div class=\"HideElement\" dojoAttachPoint=\"toolTipTarget\"></div>\n</div>\n",
	translationName: dojo.moduleUrl('epages.cartridges.de_epages.design.widget', 'templates/translation'),
	widgetsInTemplate: true,

	postMixInProperties: function () {
		if (this.data != "") {
			if (typeof (this.data) == 'string') {
				this.data = dojo.fromJson(this.data);
			}
			this._lookup = {};
			for (var i = 0, l = this.data.length; i < l; i++) {
				var t = {};
				var s = this.data[i];
				t.objectId = s.ID;
				t.title = s.Name != undefined ? s.Name : '';
				t.image = this.imagedir + '/' + (s.PreviewImage || "general_img_transparentpixel.gif");
				t.text = s.InfoText;
				t.alias = s.Alias;
				if (s.PageSize) {
					t.pagesize = s.PageSize;
				}
				this._lookup[t.objectId] = this.data[i] = t;
			}
		}
		this.inherited("postMixInProperties", arguments);
	},

	postCreate: function () {
		this.inherited("postCreate", arguments);
		this._setWidthHeight();

		if (this._lookup[this.folderID] && this._lookup[this.folderID].pagesize) {
			var pagesize = this._lookup[this.folderID].pagesize;
		}

		var templateString = '<div class="Tooltip DesigntoolMenu"><div class="Menu" style="margin:-12px;"><div class="Layer"><div class="PropertyContainer">' +
			'<div class="dijit dijitMenu dijitReset dijitMenuTable" waiRole="menu">' +
			'<div class="dijitReset" dojoAttachPoint="containerNode"><div dojoAttachPoint="layoutsNode"></div><div class="ClearBoth"></div></div>' +
			'</div>';

		if (this.folder === "Content-Products" && pagesize) {
			templateString += '<span class="ep-designtool-content-productsperpage">' + this.translation.get("ProductsPerPage") + ': <span class="ep-designtool-content-pagesize">' + pagesize.selected + '</span> <a name="ProductSettingsLink" class="Action" href="?ViewAction=MBO-ViewProductSettings&amp;ObjectID=' + epages.vars.SiteID + '">' + this.translation.get("ToChange") + '</a>';
		}

		templateString += '</div></div>' +
			'<div class="LayerFooter"><div class="PropertyContainer"></div></div></div></div>';

		this._toolTipWidget = new epages.widget.Tooltip({
			templateString: templateString,
			tooltipArea: this.toolTipTarget,
			interactive: true
		});
		this.DesigntoolNode.appendChild(this._toolTipWidget.domNode);
		// _toolTipWidget style props
		this._toolTipWidget.containerNode.style.height = this._height;
		this._toolTipWidget.containerNode.style.overflowX = "hidden";
		this._toolTipWidget.containerNode.style.overflowY = this._overflowY;
		this._toolTipWidget.containerNode.parentNode.style.width = this._width;
		this._toolTipWidget.containerNode.parentNode.style.paddingTop = "4px";
		setTimeout(dojo.hitch(this, function () {
			this._toolTipWidget.show(-9999, -9999);
			this._toolTipWidget.hide();
		}), 1);
		for (var i = 0, l = this.data.length; i < l; i++) {
			this._addLayout(this.data[i]);
		}
		if (this.active) {
			this.setOption(this.active);
		}
		this.connect(this.clickNode, 'onclick', '_OnClickSelector');
	},

	_addLayout: function (layout) {
		var parentWidget = this;
		var entry = new epages.cartridges.de_epages.design.widget.Designtoolitem({
			id: this.title + ':' + layout.objectId + ':MenuItem',
			label: layout.title,
			infoText: layout.text,
			iconSrc: layout.image,
			objectId: layout.objectId,
			onClick: function () {
				parentWidget.setOption(this.objectId);
				parentWidget._toolTipWidget.hide();
			}
		});
		this._toolTipWidget.layoutsNode.appendChild(entry.domNode);


		if (this.active == layout.objectId) {
			dojo.addClass(entry.domNode, "dojoMenuItem2Selected");
		}
	},

	setOption: function (active, publish, objectId) {
		if (objectId) {
			this.objectId = objectId;
		}
		var menuItem = $$(this.title + ':' + active + ':MenuItem');
		if (menuItem != this._lastSelected) {
			if (this._lastSelected) {
				dojo.removeClass(this._lastSelected.domNode, "Selected");
			}
			dojo.addClass(menuItem.domNode, "Selected");
			if (this.folder === 'Content-Products' && this.active) {
				var productSettingsLink = dojo.query('a[name="ProductSettingsLink"]', this._toolTipWidget.domNode),
					newPageSize = this._lookup[active].pagesize,
					activePageSize = this._lookup[this.active].pagesize,
					pagesizeNode = dojo.query('.ep-designtool-content-pagesize'),
					productsPerPageNode = dojo.query('.ep-designtool-content-productsperpage');

				if (newPageSize && activePageSize && newPageSize.selected !== activePageSize.selected && productSettingsLink) {
					productSettingsLink[0].innerHTML = this.translation.get("ToChange");
					pagesizeNode[0].innerHTML = newPageSize.selected;
				} else if (newPageSize && !activePageSize) {
					dojo.create(
						"span", {
						'class': 'ep-designtool-content-productsperpage',
						'innerHTML': this.translation.get("ProductsPerPage") + ': <span class=ep-designtool-content-pagesize>' + newPageSize.selected + '</span> <a name="ProductSettingsLink" class="Action" href="?ViewAction=MBO-ViewProductSettings&amp;ObjectID=' + epages.vars.SiteID + '">' + this.translation.get("ToChange") + '</a>'
					},
						dojo.query('div.dijitMenuTable', this._toolTipWidget.domNode)[0]);
				} else if (!newPageSize && productSettingsLink) {
					dojo.destroy(productsPerPageNode[0]);
				}
			}

			this._lastSelected = menuItem;
			var data = this._lookup[active];
			if (data === undefined || data == null) {
				return;
			}
			this.SelectedOptionNode.src = data.image;
			this.SelectedOptionNode.alt = data.title;
			this.SelectedOptionNode.title = data.title;
			this.active = active;
			if (publish !== false) {
				dojo.publish('Designtool/select', [{
						id: this.id
					}]);
			}
		}
	},

	getActive: function () {
		if (this.active === "") {
			return undefined;
		} else {
			var data = this._lookup[this.active];
			if (data === undefined || data == null) {
				return;
			}
			return {
				folder: this.folder,
				alias: data.alias,
				objectId: this.objectId,
				templateTypeId: data.objectId,
				lastSelected: this._lastSelected
			};
		}
	},


	_OnClickSelector: function (opt) {
		var curTarget = $E(opt.currentTarget);
		var coords = curTarget.getAbsolutePosition();
		coords['y'] += curTarget.object.clientHeight;

		this._tooltipCoor = {
			x: coords['x'],
			y: coords['y']
		};
		if (this.controllerId == "") {
			this.openMenuWidget();
		} else {
			//if Controller is defined ask if SelectLayout is allowed
			$$(this.controllerId).allowSelectLayout(this.id);
		}
	},

	openMenuWidget: function () {
		this._toolTipWidget.show(parseInt(this._tooltipCoor.x), parseInt(this._tooltipCoor.y));
	},

	_setWidthHeight: function () {
		var layouts = this.data.length;
		var multiWidth = this.NUMBER_ITEMS_FIRST_ROW;
		var multiHeight = 3;
		var scrollbar = 0;
		var overflowY = "hidden";
		if (layouts <= this.NUMBER_ITEMS_FIRST_ROW) {
			multiWidth = layouts;
			multiHeight = 1;
			scrollbar = 0;
		} else if (layouts > this.NUMBER_ITEMS_FIRST_ROW && layouts <= this.NUMBER_ITEMS_SECOND_ROW) {
			multiHeight = 2;
		} else if (layouts > this.NUMBER_ITEMS_THIRD_ROW) {
			overflowY = "scroll";
			scrollbar = this.WIDTH_SCROLLBAR;
		}
		//this._width = ((multiWidth*this.ITEM_WIDTH)+scrollbar)+"px";
		//this._height = (multiHeight*this.ITEM_HEIGHT)+"px";
		this._overflowY = overflowY;
	},

	show: function () {
		this.visible = true;
		this.domNode.style.display = "";
	},

	hide: function () {
		this.visible = false;
		this.domNode.style.display = "none";
	},
	setSeperator: function (active) {
		if (active == true) {
			this.seperatorNode.style.display = "";
		} else {
			this.seperatorNode.style.display = "none";
		}
	}
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Designtoolcontroller"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Designtoolcontroller"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.design.widget.Designtoolcontroller");







dojo.declare(
	"epages.cartridges.de_epages.design.widget.Designtoolcontroller",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		uri                : '?',
		id                 : 'Designtoolcontroller',
		undobuttonsId      : 'undoWidget',
		objectTreeId       : 'contentExplorerObjectTree',
		eventHandler       : '',
		imageUrl           : epages.vars.StoreRoot ? epages.vars.StoreRoot + '/BO/icons' : undefined,

		/**
		 * private properties
		 */
		 objects   : {},
		 pagetypes : {},
		_dialogWidget      : undefined,
		_visiblePageType : undefined, // _showDesignTools

		/**
		 * widget properties
		 */
		templateString:"<div class=\"Designtoolcontroller\" dojoAttachPoint=\"ControllerNode\">\n  <div dojoAttachPoint=\"ContainerNode\"></div>\n</div>\n",
		translationName  : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'),

		postCreate: function() {
			this.inherited("postCreate", arguments);
			dojo.subscribe(this.objectTreeId+'/select', this, '_onSelectObject');
			dojo.subscribe('Designtool/select', this, '_onSelectDesigntool');
			//set Reference to EventHandler if exists
			this.eventHandler = typeof contentEventHandler != 'undefined' ? contentEventHandler : undefined;
		},

		_createInputsForUndo: function (objectId) {
			var templates = this.objects[objectId].templates;
			var inputFields = {};
			var me = this;
			$H(templates).each( function(pair){
				var inputField = document.createElement('input');
				inputField.type = "hidden";
				inputField.name = objectId +':'+ pair.key + ':1:LayoutUndo';
				inputField.value = pair.value; // read current values
				inputField.size = 4;
				me.ControllerNode.appendChild(inputField);
				me.connect(inputField, 'onchange', 'callOnChange');
				var undoObject = $$(me.undobuttonsId).getUndoObject();
				undoObject.setDefaultValue(inputField);
				inputFields[pair.key] = inputField;
			});
			return inputFields;
		},

		_loadObject:function(node){
			if (this.objects[node.item.objectId] === undefined) {
				var json = new epages.io.Json();
				var output = json.loadSync(this.uri, {
					ObjectID:       node.item.objectId,
					ViewAction:     'JSONViewResponse',
					ChangeAction:   'JSONLayout',
					KnownPageTypes: $H(this.pagetypes).keys()
				});
				this.objects[node.item.objectId] = {
					templates : output.data.Templates,
					pagetype  : output.data.PageType,
					treeNode  : node
				};
				if (this.pagetypes[output.data.PageType] === undefined) {
					this.pagetypes[output.data.PageType] = {
						templates  : output.data.TemplateTypes,
						controller : undefined
					};
				}
			}
		},

		_showDesignTools: function (objectId) {
			$('Designbox').style.display = 'none';
			// hide old
			if (this._visiblePageType !== undefined) {
				$A(this.pagetypes[this._visiblePageType].controller).each(function (widget) {
					widget.hide();
				});
			}

			// create new if necessary
			var pagetype = this.objects[objectId].pagetype;
			if (this.pagetypes[pagetype].controller === undefined) {
				this.pagetypes[pagetype].controller = this._createDesigntoolcontroller(pagetype,objectId);
			}

			// show new
			this._visiblePageType = pagetype;
			var templates = this.objects[objectId].templates;
			if(this.pagetypes[pagetype].controller.length != 0){
				$A(this.pagetypes[pagetype].controller).each(function (widget) {
					if(templates[widget.folder] != 0){
						widget.setOption(templates[widget.folder],false,objectId);
						widget.show();
					}
				});
				//correct Layout if some Designtools are hidden
				var first = true;
				$A(this.pagetypes[this._visiblePageType].controller).each(function (widget) {
					if(widget.visible && first){
						widget.isfirst = true;
						widget.setSeperator(false);
						first = false;
					}
					else{
						widget.isfirst = false;
						widget.setSeperator(true);
					}
				});
				//show Designtoolcontroller
				$('Designbox').style.display = '';
			}
			//hide Designtoolcontroller if there are no templates for this pagetype
			else{
				$('Designbox').style.display = 'none';
			}
		},

		_onSelectObject: function(node){
			this._loadObject(node);
			this._showDesignTools(node.item.objectId);
		},

		allowSelectLayout: function(widgetId){
			//check if changes in page where made an ask to save them before opening Designtool
			if($$(this.undobuttonsId) !== undefined && $$(this.undobuttonsId).existsChanges()){
				this._activDesigntoolId = widgetId;
				if(!this._dialogWidget){
					 this._createDialog();
				}
				this._dialogWidget.show();
			}
			else{
				//if no changes where made open Designtool
				$$(widgetId).openMenuWidget();
			}
		},

		_createDialog: function(){

			var messageWidget = new epages.widget.Message({
				headline:this.translation.get("SaveQuestion"),
				message: this.translation.get("ChangeLayoutDescription"),
				sizeClass:"Large",
				typeClass:"Warning"
			});

			var me =this;
			var buttons = [{
				label: this.translation.get("Save"),
				cssClass: 'Active',
				onclick: function() {
					this._modalDialogWidget.hide();
					//if Save was clicked, undowidget saves changes
					$$(me.undobuttonsId).sendChanges();
					//open Designtool
					$$(me._activDesigntoolId).openMenuWidget();
				}
			},
			{
				label: this.translation.get("Cancel"),
				onclick: function() {
					this._modalDialogWidget.hide();
				}
			}];
			this._dialogWidget = new epages.widget.Modaldialog({
				id: "Designtoolcontroller_DialogWidget",
				options:{
					title : this.translation.get("ChangeOnLayout"),
					width : 400,
					height: 120,
					content: messageWidget
				},
				buttons : buttons

			});
			document.body.appendChild(this._dialogWidget.domNode);

		},

		_createDesigntoolcontroller: function(pagetype,objectId){
			if(this.imageUrl){
				var returnArray = [];
				var templates = this.pagetypes[pagetype].templates;
				for(templateTypeFolder in templates){
					var info = templates[templateTypeFolder];
					if (info.Variations.length) {
						var widget = new epages.cartridges.de_epages.design.widget.Designtool({
							folder       : templateTypeFolder,
							folderID     : this.objects[objectId].templates[templateTypeFolder],
							objectId     : objectId,
							title        : info.NameOrAlias,
							data         : info.Variations,
							imagedir     : this.imageUrl,
							controllerId : this.id,
							position     : info.Position
						});
						returnArray.push(widget);
					}
				}
				dojo.forEach(returnArray.sort(function(a,b) { return a.position - b.position; }), function (el) {
					this.ContainerNode.appendChild(el.domNode);
				}, this);
				return returnArray;
			}
			else{
				return [];
			}
		},

		_onSelectDesigntool:function(opt){

			var widgetId = opt.id;
			var active = $$(widgetId).getActive();
			if(active !== undefined){
				this.changeLayout(active);
			}
		},

		changeLayout:function(active){

			// save changes on server
			var json = new epages.io.Json();
			var params = {
				ObjectID    : active.objectId,
				ViewAction  : 'JSONViewResponse',
				ChangeAction: 'SaveDesign'
			};
			params[active.folder] = active.alias;
			var output = json.loadSync(this.uri, params);
			var objectInfo = this.objects[active.objectId];
			// correct internal data for next time
			objectInfo.templates[active.folder] = active.templateTypeId;
			if($$(this.undobuttonsId) !== undefined){
				$$(this.undobuttonsId).sendChanges();
			}
			// reload content if contentEventHandler is defined
			if(this.eventHandler !== undefined){
				 this.eventHandler.reloadContent(active.objectId, true);
			}
			//update page cache flag
			if(typeof pageCache_SetStatus == 'function'){
				pageCache_SetStatus(true);
			}
		},

		callOnChange: function(evt){
			var name = evt.target.name.split(':');
			var templateType = evt.target.value;
			var objectId = name[0];
			var templateTypeFolder = name[1];
			var pagetype = this.objects[objectId].pagetype;
			for( var i=0,iLength=this.pagetypes[pagetype].controller.length ; i<iLength ; i++ ){
				if(this.pagetypes[pagetype].controller[i].folder == templateTypeFolder){
					var designtool = this.pagetypes[pagetype].controller[i];
					designtool.setOption(templateType,true,objectId);
					this._showDesignTools(objectId);
					//$$(this.objectControllerId).selectNode(this.objects[objectId].treeNode);
				}
			}


		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.content.widget.TagEditor"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.content.widget.TagEditor"] = true;
dojo.provide("epages.cartridges.de_epages.content.widget.TagEditor");






parent.epages.cartridges.de_epages.content.widget.valueGrouped = {}; // collection of all selected tags in TagEditors grouped by a groupname

dojo.declare(
	"epages.cartridges.de_epages.content.widget._TagEditorMenu",
	dijit.form._ComboBoxMenu,
	{
		templateString: "<ul class='dijitReset dijitMenu dijitTagEditor' style='background-color:#FFF;' dojoAttachEvent='onmousedown:_onMouseDown,onmouseup:_onMouseUp,onmouseover:_onMouseOver,onmouseout:_onMouseOut' tabIndex='-1' style='overflow: \"auto\"; overflow-x: \"hidden\";'>"
			+"<li class='dijitMenuPreviousButton' dojoAttachPoint='previousButton' waiRole='option'></li>"
			+"<li class='dijitMenuNextButton' dojoAttachPoint='nextButton' waiRole='option'></li>"
		+"</ul>",
		itemClasses : "dijitReset",

		createOptions: function(results, dataObject, labelFunc){
			// summary:
			//		Fills in the items in the drop down list
			// results:
			//		Array of dojo.data items
			// dataObject:
			//		dojo.data store
			// labelFunc:
			//		Function to produce a label in the drop down list from a dojo.data item

			//this._dataObject=dataObject;
			//this._dataObject.onComplete=dojo.hitch(comboBox, comboBox._openResultList);
			// display "Previous . . ." button
			this.previousButton.style.display = (dataObject.start == 0) ? "none" : "";
			dojo.attr(this.previousButton, "id", this.id + "_prev");
			// create options using _createOption function defined by parent
			// ComboBox (or FilteringSelect) class
			// #2309:
			//		iterate over cache nondestructively
			dojo.forEach(results, function(item, i){
				var menuitem = this._createOption(item, labelFunc);
				menuitem.className = this.itemClasses;
				dojo.attr(menuitem, "id", this.id + i);
				this.domNode.insertBefore(menuitem, this.nextButton);
			}, this);
			// display "Next . . ." button
			var displayMore = false;
			//Try to determine if we should show 'more'...
			if(dataObject._maxOptions && dataObject._maxOptions != -1){
				if((dataObject.start + dataObject.count) < dataObject._maxOptions){
					displayMore = true;
				}else if((dataObject.start + dataObject.count) > (dataObject._maxOptions - 1)){
					//Weird return from a datastore, where a start + count > maxOptions
					// implies maxOptions isn't really valid and we have to go into faking it.
					//And more or less assume more if count == results.length
					if(dataObject.count == results.length){
						displayMore = true;
					}
				}
			}else if(dataObject.count == results.length){
				//Don't know the size, so we do the best we can based off count alone.
				//So, if we have an exact match to count, assume more.
				displayMore = true;
			}

			this.nextButton.style.display = displayMore ? "" : "none";
			dojo.attr(this.nextButton,"id", this.id + "_next");
			return this.domNode.childNodes;
		}
	}
);

dojo.declare(
	"epages.cartridges.de_epages.content.widget.TagEditor",
	dijit.form.ComboBox,
	{
		templateString: '',
		templateString:"<span id=\"widget_${id}\" style=\"border: 0px;\"\n\tdojoAttachEvent=\"\" dojoAttachPoint=\"comboNode\" waiRole=\"combobox\" tabIndex=\"-1\"\n\t><span style=\"overflow:hidden;\"\n\t\t><input name=\"${name}\" type=\"text\" autocomplete=\"off\" class='dijitReset'\n\t\t\tdojoAttachEvent=\"onkeypress:_onKeyPress,compositionend\"\n\t\t\tdojoAttachPoint=\"textbox,focusNode\" waiRole=\"textbox\" waiState=\"haspopup-true,autocomplete-list\"\n\t\t\tplaceholder=\"${placeholder}\"\n\t/></span\n>\n<span dojoAttachPoint=\"downArrowNode\" style=\"display:none\"></span>\n</span>\n",
		pageSize : 5, // old numberOfEntries

		/**
		 * public properties
		 */

		// this can be used to group multiple TagEditors on the same page
		// if a tag is added, then all TagEditors in the same group will
		// be updated with the new tag
		group:              "", // string - name of all tag inputs which share the same tags
		presetTags:      	"", // string - use this to preset Tags, seperate with ","
		value:              "", // string[]
		name:               "Tags", // string
		delimiter:			',', // string - tagseperator
		placeholder: '',

		description:        '', // string

		// hasDownArrow: [const] Boolean
		//		Set this textbox to have a down arrow button, to display the drop down list.
		//		Defaults to true.
		hasDownArrow: false,

		// searchDelay: Integer
		//		Delay in milliseconds between when user types something and we start
		//		searching based on that value
		searchDelay: 100,
		style: '',
		labelType: "html",

		storeType : "epages.cartridges.de_epages.content.widget._TagEditorStore",
		/**
		 * private properties
		 */

		_editAtLastEl  :    true, // is the user edition the last tag in the taglist
		_activeTagIndex:    null, // current working tag

		postMixInProperties: function() {

			this.store = {"dummy":"dummy"};
			this.inherited("postMixInProperties",arguments);
			this.baseClass="";
		},
		postCreate: function() {
			// summary: create store, read preset tags, set input value, subscribe events
			// needs to be done BEFORE inherited

			// read preset tags
			if (typeof(this.presetTags) == "string") {
				this.presetTags = this._splitTags(this.presetTags);
			} else {
				this.presetTags = $A();
			}
			// add preset to value group
			var valueGrouped = parent.epages.cartridges.de_epages.content.widget.valueGrouped;
			// added compatiblity to previous tageditor
			if(dojo.isArray(valueGrouped[this.group])){
				this.presetTags.merge(valueGrouped[this.group]);
				valueGrouped[this.group] = undefined;
			}
			// create tag source
			if (valueGrouped[this.group] === undefined) {
				valueGrouped[this.group] = new(eval(this.storeType))(this.id);
			}
			if (this.presetTags.length) {
				valueGrouped[this.group].mergeIn(this.presetTags);
			}
			if (typeof(this.value) == "string") {
				this.value = this._splitTags(this.value);
			}
			this.store = valueGrouped[this.group];

			// remove dojo magic, someone somewhere deep in dojo sets an id on the input
			this.focusNode.removeAttribute("id");
			this.focusNode = new epages.widget.FormElement({}, this.focusNode).elementNode;
			if (this.delimiter) {
				this.focusNode.value = this.value.join(this.delimiter + ' ');
			} else if(this.value.length){
				this.focusNode.value = this.value[0];
			} else {
				this.focusNode.value = "";
			}
			this.inherited("postCreate",arguments);

			if(this.description.length > 1) {
				this.focusNode.setAttribute("description", this.description);
			}
			//
			this._updatevalue();
			this.connect(this.focusNode, "onkeyup", "_evaluateInput");
			epages.topDojo.subscribe('Createobjectbutton/objectCreated',this,"hide");
			epages.topDojo.subscribe('Createobjectbutton/closed',this,"hide");

			dojo.forEach(dojo.query('.dijitPlaceHolder',this.domNode),function(item){
				dojo.destroy(item);
			});
		},
		_getQueryString: function(/*String*/ text){
			// overwrite dijit.form.ComboBoxMixin
			// summary: add trim
			return dojo.string.trim(dojo.string.substitute(this.queryExpr, [text]));
		},
		_showResults: function(/*String*/ key,/*Sting?*/lastTyped){
			// - changed popup class
			// - set _activeTagIndex, _editAtLastEl
			if (this.delimiter) {
				var tagList = this.focusNode.value;
				var caretPosition = this._getCaretPos(this.focusNode);
				var countTags = tagList.substr(0, caretPosition).match(new RegExp(this.delimiter, 'g'));
				this._activeTagIndex = countTags ? countTags.length : 0;
				if (!tagList.substr(caretPosition).match(new RegExp(this.delimiter, 'g'))) {
					this._editAtLastEl = true;
				}
				else {
					this._editAtLastEl = false;
				}
			}
			if(!this._popupWidget){
				// create the suggest popup
				var popupId = this.id + "_popup";
				this._popupWidget = new epages.cartridges.de_epages.content.widget._TagEditorMenu({
					onChange: dojo.hitch(this, function(evt){
						this._selectOption(evt);
						if (this.delimiter && evt.target != this._popupWidget.nextButton &&
							evt.target != this._popupWidget.previousButton && this._editAtLastEl) {
							// if last tag is edited and tag is selected add delimitter
							this.focusNode.value = this.focusNode.value + this.delimiter+" ";
						}
					}),
					id: popupId
				});
				dijit.removeWaiState(this.focusNode,"activedescendant");
				dijit.setWaiState(this.focusNode,"owns",popupId); // associate popup with focusNode
			}
			// create a new query to prevent accidentally querying for a hidden
			// value from FilteringSelect's keyField
			var query = dojo.clone(this.query); // #5970
			this._lastInput = lastTyped ? lastTyped : key; // Store exactly what was entered by the user.
			this._lastQuery = query[this.searchAttr] = this._getQueryString(key);
			// #5970: set _lastQuery, *then* start the timeout
			// otherwise, if the user types and the last query returns before the timeout,
			// _lastQuery won't be set and their input gets rewritten
			this.searchTimer=setTimeout(dojo.hitch(this, function(query, _this){
				this.searchTimer = null;
				var fetch = {
					queryOptions: {
						ignoreCase: this.ignoreCase,
						deep: true
					},
					query: query,
					onBegin: dojo.hitch(this, "_setMaxOptions"),
					onComplete: dojo.hitch(this, "_openResultList"),
					onError: function(errText){
						_this._fetchHandle = null;
						console.error('dijit.form.ComboBox: ' + errText);
						dojo.hitch(_this, "_hideResultList")();
					},
					start: 0,
					count: this.pageSize,
					origKey: key,
					tagEditorId: this.id // exclude tags of own id
				};
				dojo.mixin(fetch, _this.fetchProperties);
				this._fetchHandle = _this.store.fetch(fetch);

				var nextSearch = function(dataObject, direction){
					dataObject.start += dataObject.count*direction;
					// #4091:
					//		tell callback the direction of the paging so the screen
					//		reader knows which menu option to shout
					dataObject.direction = direction;
					this._fetchHandle = this.store.fetch(dataObject);
				};
				this._nextSearch = this._popupWidget.onPage = dojo.hitch(this, nextSearch, this._fetchHandle);
			}, query, this), this.searchDelay);
		},
		_startSearch: function(/*String*/ key,/*Sting?*/lastTyped){
			// overwrite dijit.form.ComboBoxMixin
			this._showResults(key,lastTyped);
		},
		_announceOption: function(/*Node*/ node){
			// summary:
			//		a11y code that puts the highlighted option in the focusNode.
			//		This way screen readers will know what is happening in the
			//		menu.
			// overwrite dijit.form.ComboBoxMixin
			if(!node){
				return;
			}
			// pull the text value from the item attached to the DOM node
			var newValue;
			if( node == this._popupWidget.nextButton ||
				node == this._popupWidget.previousButton){
				this.item = undefined;
				this.value = '';
			}else{
				newValue = this.inputLabelFunc(node.item, this.store);
				// get the text that the user manually entered (cut off autocompleted text)
				this.focusNode.value = this.focusNode.value.substring(0, this._lastInput.length);
				// set up ARIA activedescendant
				dijit.setWaiState(this.focusNode, "activedescendant", dojo.attr(node, "id"));
				// autocomplete the rest of the option to announce change
				this._autoCompleteText(newValue);
			}
		},
		_autoCompleteText: function(/*String*/ text){
			// overwrite dijit.form.ComboBoxMixin
			var fn = this.focusNode;
			// IE7: clear selection so next highlight works all the time
			var oldCpos = this._getCaretPos(fn);
			dijit.selectInputText(fn, fn.value.length);
			// does text autoComplete the value in the focusNode?
			var newCpos = this._getCaretPos(fn);
			// only try to extend if we added the last character at the end of the input
			if((newCpos+1) > fn.value.length){
				// only add to input node as we would overwrite Capitalisation of chars
				// actually, that is ok
				var tagList = fn.value;
				if (this.delimiter) {
					var tlSplit = tagList.split(this.delimiter);
					if(tlSplit.length>this._activeTagIndex){
						// replace old with new tag but keep leading and trailing spaces
						tlSplit[this._activeTagIndex] = tlSplit[this._activeTagIndex].replace(/^(\s*).*(\s*)$/,"$1"+text+"$2");
						// calculate chars to select
						var selectEnd = tlSplit.slice(0,this._activeTagIndex+1).join(this.delimiter).length;
						fn.value = tlSplit.join(this.delimiter);
						dijit.selectInputText(fn, oldCpos,selectEnd);
					}
				} else {
					fn.value = tagList.replace(/^(\s*).*(\s*)$/,"$1"+text+"$2");
					dijit.selectInputText(fn, oldCpos);
				}

			}
		},

		_startSearchFromInput: function(){
			// overwrite dijit.form.ComboBoxMixin
			// fix for multi tag
			// calculate tag which is currently under edit
			var tagList = this.focusNode.value;
			var caretPosition = this._getCaretPos(this.focusNode);
			var tag = this._getTagAt(caretPosition, tagList);
			this._startSearch(tag.replace(/([\\\*\?])/g, "\\$1"),this.focusNode.value.replace(/([\\\*\?])/g, "\\$1"));
		},
		_startSearchAll: function(){
			// overwrite dijit.form.ComboBoxMixin
			// fix for multi tag
			this._startSearch('',this.focusNode.value.replace(/([\\\*\?])/g, "\\$1"));
		},
		_getTagAt: function(/*int*/position, /*string*/tagList) {
			// summary: recieve the tag from the position of the caret
			// return string
			if (this.delimiter) {
				var leftPos = tagList.substr(0, position).lastIndexOf(this.delimiter);
				leftPos = (leftPos == -1 ? 0 : leftPos + 1);
				var rightPos = tagList.substr(position).indexOf(this.delimiter);
				rightPos = (rightPos == -1 ? tagList.length : rightPos + position);
				return tagList.substring(leftPos, rightPos);
			} else {
				return tagList;
			}
		},
		_evaluateInput: function(evt) {
			// summary: handle key input
			this._updatevalue();
			if (this.delimiter && evt.keyCode == dojo.keys.ENTER && this._editAtLastEl) {
				// add delimiter if edited tag was the last one
				this.focusNode.value = this.focusNode.value + this.delimiter+" ";
			}
		},
		_updatevalue: function() {
			// summary: set the current value to make it accessable
			this.value = this._splitTags(this.focusNode.value);
			this.store.setValue(this.id, this.value);
			dojo.publish(this.id + "/onChange", [{ tags: this.value }]);
		},

		_splitTags: function(/*String*/tagList) {
			// summary: split and trim tagList on delimiter
			// return $A
			var finalTagArray = [];
			if (this.delimiter) {
				var tagArray = tagList.split(this.delimiter);
				for( var i=0,iLength=tagArray.length ; i<iLength ; i++ ) {
					var el = tagArray[i];
					el = el.replace(/^\s*/, "");
					el = el.replace(/\s*$/, "");
					if (el != "") {
						finalTagArray.push(el);
					}
				}
			} else {
				tagList = tagList.replace(/^\s*/, "");
				tagList = tagList.replace(/\s*$/, "");
				if (tagList != "") {
					finalTagArray.push(tagList);
				}
			}
			return $A(finalTagArray);
		},

		getValue: function() {
			return this.focusNode.value;
		},

		setValue: function(newValue) {
			if(newValue) {
				this.value = this.focusNode.value = newValue;
			} else {
				this.value = this.focusNode.value = '';
			}
		},

		hide: function(){
			this._hideResultList();
		},

		labelFunc: function(/*item*/ item, /*dojo.data.store*/ store){
			var itemvalue = store.getValue(item, this.searchAttr);
			var result;
			if(typeof(itemvalue) == 'object') {
				result = itemvalue.labelvalue;
			} else {
				result = itemvalue; // String
			}

			// beautify
			if(this.focusNode.value) {
				var fnv = this.focusNode.value; // 'de'
				var regex = new RegExp(fnv, "g");
				result = result.replace(regex, '<strong>'+fnv+'</strong>'); // 'de_asdasfdasdf'
			}
			return result;
		},

		inputLabelFunc: function(/*item*/ item, /*dojo.data.store*/ store){
			var itemvalue = store.getValue(item, this.searchAttr);
			if(typeof(itemvalue) == 'object') {
				return itemvalue.inputvalue;
			}
			return itemvalue; // String
		}
	}
);

dojo.declare("epages.cartridges.de_epages.content.widget._TagEditorStore", null, {
	availableTags: $A(),
	currentValues: {},
	constructor: function(){},

	mergeIn : function(/*String[]E*/tags){
		// summary: add tags to preset tags
		this.availableTags.merge(tags);
		this.availableTags.unique();
	},
	setValue : function(/*String*/id,/*String[]*/tags){
		// summary: set value of one of the tageditors of the group
		if (tags.length) {
			// prevent empty tags
			this.currentValues[id] = tags;
		}
	},
	getValue: function(	/* item */ item,
						/* attribute-name-string */ attribute,
						/* value? */ defaultValue){
		return item;
	},

	isItemLoaded: function(/* anything */ something){
		return true;
	},

	getFeatures: function(){
		return {"dojo.data.api.Read": true, "dojo.data.api.Identity": true};
	},

	_fetchItems: function(	/* Object */ args,
							/* Function */ findCallback,
							/* Function */ errorCallback){
		// summary:
		//		See dojo.data.util.simpleFetch.fetch()
		if(!args.query){ args.query = {}; }
		if(!args.query.name){ args.query.name = ""; }
		if(!args.queryOptions){ args.queryOptions = {}; }
		// merge preset tags and tags from the editors
		var tags = $A();
		for(var v in this.currentValues){
			if (v != args.tagEditorId) {
				tags.merge(this.currentValues[v]);
			}
		}
		tags.merge(this.availableTags);
		tags.unique();
		var matcher = dojo.data.util.filter.patternToRegExp(args.query.name, args.queryOptions.ignoreCase),
		items = tags.match(matcher);
		if(args.sort){
			items.sort(dojo.data.util.sorter.createSortFunction(args.sort, this));
		}
		findCallback(items, args);
	},

	close: function(/*dojo.data.api.Request || args || null */ request){
		return;
	},

	getLabel: function(/* item */ item){
		return item.innerHTML;
	},

	getIdentity: function(/* item */ item){
		return item;
	}
});
//Mix in the simple fetch implementation to this class.
dojo.extend(epages.cartridges.de_epages.content.widget._TagEditorStore,dojo.data.util.simpleFetch);

}

if(!dojo._hasResource["epages.cartridges.de_epages.content.widget.TagInlineEditor"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.content.widget.TagInlineEditor"] = true;
dojo.provide("epages.cartridges.de_epages.content.widget.TagInlineEditor");



dojo.declare(
	"epages.cartridges.de_epages.content.widget.TagInlineEditor",
	[epages.cartridges.de_epages.presentation.widget.InlineEditor],
	{

		availableTags:	'',

		show: function() {
			// TagEditor
			if (!this.isInited) {
				this.object = new epages.cartridges.de_epages.content.widget.TagEditor({
					presetTags: this.availableTags,
					value: this.value,
					name: this.inputName,
					group: 'epages.cartridges.de_epages.content.widget.TagEditor'
				}, this.contentNode);
				this.contentNode = this.object.textbox;
				this.connect(this.object.domNode, 'onblur', 'hide');
				this._copyStyle(this.object.textbox, this._computedStyle);
				// reset color of input text
				this.contentNode.style.color = '';
				if (this.undoObject){ 
					this.undoObject.registerInput(this.contentNode);
				}
				this.connect(this.contentNode, 'onkeyup', 'onChangeContentNode');
				this.connect(this.contentNode, 'onpaste', 'onChangeContentNode');
				this.isInited = true;
			}
			this.displayNode.style.display = 'none';
			this.contentNode.style.display = '';
			this.contentNode.focus();
			this.inherited("show", arguments);
		},

		hide: function() {
			if(this.object){
				this.object.hide();
			}
			if (!this.isInited){ 
				return;
			}
			if (this.contentNode.value == '') {
				this.displayNode.innerHTML = this._placeHolderText;
			} else {
				this.displayNode.innerHTML = this.contentNode.value;
			}
			this.displayNode.style.display = '';
			this.contentNode.style.display = 'none';
			this.inherited("hide", arguments);
		},

		onChangeContentNode: function() {
			this.displayNode.innerHTML = this.object.getValue();
			this.inherited("onChangeContentNode", arguments);
		}

	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.content.widget.JsonTagEditor"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.content.widget.JsonTagEditor"] = true;
dojo.provide("epages.cartridges.de_epages.content.widget.JsonTagEditor");



dojo.declare("epages.cartridges.de_epages.content.widget._JsonTagEditorStore",
			 epages.cartridges.de_epages.content.widget._TagEditorStore, {
	// parent needs to define a string which is used as subscribe/publish key
	unique:			null,

	constructor: function(unique){
		this.unique = unique;
		dojo.subscribe(this.unique + '/onNewSearchResults', this, "_handleJsonResult");
	},

	_fetchItems: function(	/* Object */ args,
							/* Function */ findCallback,
							/* Function */ errorCallback){
		// summary:
		//		See dojo.data.util.simpleFetch.fetch()
		if(!args.origKey){ args.origKey = ""; }
		// async call to json request function epages.cartridges.de_epages.content.widget.SmartSearchInput
		dojo.publish(this.unique + '/onEvaluateInput', [ args.origKey,dojo.mixin(args,{"findCallback":findCallback})]);
	},
	_handleJsonResult : function(items,args){
		// summary: recieve json result, sort and push it to callback
		if(args.sort){
			items.sort(dojo.data.util.sorter.createSortFunction(args.sort, this));
		}
		if (args.findCallback) {
			args.findCallback(items, args);
		}
	},
	getLabel: function(/* item */ item){
		return item.innerHTML;
	}
});

dojo.declare(
	"epages.cartridges.de_epages.content.widget.JsonTagEditor",
	epages.cartridges.de_epages.content.widget.TagEditor,
	{
		/**
		 * public properties
		 */
		//integer - limited by SMART_PRODUCT_SEARCH_RESULT_COUNT Perl constant
		pageSize:    10,

		// searchDelay: Integer
		//		Delay in milliseconds between when user types something and we start
		//		searching based on that value
		searchDelay: 0,
		// disable multiple tags
		delimiter: null,
		placeholder: '',
		storeType: "epages.cartridges.de_epages.content.widget._JsonTagEditorStore",
		labelType: "html",
    	submitOnEnter: true,	// flag that decides if the form is submitted by using the submit-Event (true) or
                          		// by trigger the event using the fire method (false)
		postCreate: function() {
			this.inherited('postCreate', arguments);
      this.submitOnEnter = epages.string.toBoolean(this.submitOnEnter);
    },
		_onKeyPress: function(/*Event*/ evt){
			var key = evt.charOrCode;
			if(evt.keyCode == dojo.keys.ENTER) {
				if(!this._isShowingNow){
          if(this.submitOnEnter){
					this.focusNode.form.submit();
          }else{
            epages.event.fire(dojo.query('input[type=submit]', this.focusNode.form)[0], "click");
          }
				}
			}
			this.inherited("_onKeyPress",arguments);
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.content.widget.SmartSearchInput"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.content.widget.SmartSearchInput"] = true;
dojo.provide("epages.cartridges.de_epages.content.widget.SmartSearchInput");




dojo.declare(
	"epages.cartridges.de_epages.content.widget.SmartSearchInput",
	[dijit._Widget, dijit._Templated],
	{
		/**
		 * public properties
		 */
		url                     : '?',  // url for the json action(s)
		ViewAction              : 'JSONSmartSearchObjects',
		inputName               : 'SmartSearch',
		inputStyle              : 'width: 200px',
		value                   : '',    // last input value (i.e. if formerror)
		objectId                : epages.vars.SiteID || '',

		/**
		 * private properties
		 */
		_lastInputValue         : null,  // the last search value
		_timeoutMarker          : null,
		_lastSeachResultCount   : null,
		_searchStartDelay       : 400,   // delay after which time no key was pressed, the search should be started. In msec.
		_minCharactersForSearch : 1,     // how many characters can a user enter before triggering the search

		/**
		 * dojo widget properties
		 */
		templateString:"<span>\n  <span\n    dojoType=\"epages.cartridges.de_epages.content.widget.JsonTagEditor\"\n    availableTags=\"\"\n    dojoAttachPoint=\"SmartSearchBox\"\n    value=\"${value}\"\n    type=\"text\"\n    name=\"${inputName}\"\n    style=\"${inputStyle}\"\n    group=\"\"\n    description=\"\"\n  ></span>\n</span>\n",
		widgetsInTemplate:  true,

		postCreate: function() {
			this.inherited("postCreate",arguments);
			if(this.value) {
				this.SmartSearchBox.setValue(this.value);
			}
			dojo.subscribe(this.SmartSearchBox.id + '/onEvaluateInput', this, "searchBoxKeyUp");
		},

		searchBoxKeyUp: function(/*String*/textInput,/*Object?*/callbackArgs) {
			// fire keyup evt
			// REMOVED dojo.publish(this.id+'/keyup', [ evt ]);
			// check if value changed
			if(this._lastInputValue == textInput || textInput.length <= this._minCharactersForSearch) {
				return;
			}
			// check if last request returned 0 results and if entered value is not the same string plus more chars
			if(this._lastSeachResultCount !== null && this._lastSeachResultCount != '') {
				if(this._lastSeachResultCount === 0 &&
				   textInput.match(new RegExp('^' + this._lastInputValue))) {
				  this._lastInputValue = textInput;
					return;
				}
			}
			// update values
			this._lastInputValue = textInput;
			this.value = textInput;

			// delay requests if keys pressed too fast
			if(this._timeoutMarker) {
				window.clearTimeout(this._timeoutMarker);
			}
			var self = this;
			this._timeoutMarker = window.setTimeout(function(){
				// do search
				self.queryObjectAliases(callbackArgs);
			}, this._searchStartDelay);
		},

		getValue: function() {
			return this.SmartSearchBox.getValue();
		},

		queryObjectAliases: function(callbackArgs) {
			if(!this._lastInputValue) {
				return;
			}
			var inputValue = this._lastInputValue;
			var me = this;
			var json = new epages.io.Json();
			var result = json.loadAsync(this.url,
			function(result){
				if(result.error || !result.data) {
					return;
				}
				// update tageditor available tags ... result.data
				me._lastSeachResultCount = parseInt(result.data.NumResults);
				dojo.publish(me.SmartSearchBox.id + '/onNewSearchResults', [result.data.Results,callbackArgs]);
			},
			{
				'ObjectID' 			: this.objectId,
				'ViewAction'		: this.ViewAction,
				'SearchString' 	: inputValue
			});
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.content.widget.ShortUrlInput"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.content.widget.ShortUrlInput"] = true;
/*
	Copyright (c) 2006-2009, ePages GmbH
	All Rights Reserved.

*/
dojo.provide("epages.cartridges.de_epages.content.widget.ShortUrlInput");









dojo.declare(
	"epages.cartridges.de_epages.content.widget.ShortUrlInput",
	[epages.widget.LocalizedWidget, dijit._Container, dijit._Contained],
	{
		/**
		 * public properties
		 */
		url           : '?',                 // request url
		name          : '',                  // input name
		value         : '',                  // input value (shorturl)
		disabled      : '',                  // flag: input disabled
		nameInputId   : '',                  // string: id of name input
		parentObjectId: '',                  // epages parent ObjectID
		siteId        : epages.vars.SiteID,  // epages SiteID
		classAlias    : '',                  // epages ClassName of parent object
		languageId    : '',                  // language identifier
		contentObjectId: '',                 // epages ObjectID of current object
		formError     : '',                  // flag: 1 = form error occured
		saveButtonId  : '',                  // string: id of save button (register input node)

		/**
		 * private properties
		 */
		_inputTimeout     : undefined,       // save shorturl input timeout
		_nameInputTimeout : undefined,       // save name input timeout
		_isNew            : false,           // flag: indicates wether there was an inital value or not (don't overwrite inital values on name input changes)
		_lastNameValue    : '',              // save last name (to detect real changes / avoid requests)
		_lastValue        : '',              // save last shorturl (to detect real changes / avoid requests)
		_publishButton    : undefined,       // dom node of publish shortURL link

		/**
		 * widget properties
		 */
		templateString:"<div class=\"ShortUrlInput\">\n  <div class=\"InputWrapper\" dojoAttachPoint=\"inputWrapperNode\" >\n    <div class=\"SetHasLayout\"><input class=\"FullWidth\" name=\"${name}\"\n         dojoAttachPoint=\"inputWidget\"\n         value=\"${value}\" type=\"text\"\n         dojoType=\"epages.widget.FormElement\"\n         maxlength=\"255\"\n          /></div>\n  </div>\n  <div dojoAttachPoint=\"displayUrlWrapperNode\" style=\"display:none\">\n    <div class=\"DisplayUrlNode\" dojoAttachPoint=\"displayUrlNode\" ></div>\n    <span dojoAttachPoint=\"editLinkNode\" class=\"CommandLinkSmall\"><span><span class=\"WithIcon Edit\">{Edit}</span></span></span>\n  </div>\n</div>\n",
		translationName: dojo.moduleUrl('epages.cartridges.de_epages.content.widget', 'templates/translation'),
		widgetsInTemplate : true,

		/**
		 * widget life cycle
		 */
		postCreate: function() {
		// summary: initalize shorturl widget
			this.inherited("postCreate", arguments);
			if(this.siteId === undefined) {
				console.warn("epages.vars.SiteID not defined in "+this.declaredClass);
			}

			// create hash with temporary reserved short url (avoids duplicate shorturl on pages with multiple languages)
			if(epages.vars.TemporaryReservedShortUrl === undefined) {
				epages.vars.TemporaryReservedShortUrl = $H();
			}

			// update value in shorturl preview
			this._updateDisplayUrl(this.value);

			// update display of widget depending on its status
			if(this.value != "" && this.formError =="") {      // has inital value / no form error
				if(this.disabled != "disabled") {                // input is not disabled
					// show shorturl preview instead of shorturl input
					this.inputWrapperNode.style.display="none";
					this.displayUrlWrapperNode.style.display="";

					// (dirty) label formatting
					var labelNode = $('Label'+this.id);
					if(labelNode !== undefined && labelNode != null) {
						dojo.removeClass(labelNode, "InputLabelling");
						var tableNode = labelNode.parentNode.parentNode.parentNode;
						epages.html.replaceClass(tableNode, "InnerGrid", "FormGrid");
					}
				}
			} else if(this.formError =="1") {                  // set form error
				this._setError(true);
			} else {                                           // set flag _isNew
				this._isNew=true;
			}

			if(this.disabled=="disabled") {
				this.inputWidget.domNode.disabled= true;
			} else {
				// attach events
				this.connect(this.displayUrlWrapperNode, "onclick", "onClickEditLinkNode");
				this.connect(this.inputWidget.domNode, "onkeypress", "onKeypressInputNode");
				this.connect(this.inputWidget.domNode, "onchange", "onChangeInputNode");

				if(this.nameInputId != "") {
					var niNode=$(this.nameInputId);
					if(niNode) {
						this._lastNameValue = niNode.value;
						this.connect(niNode, "onchange", "onChangeNameInputNode");
						this.connect(niNode, "onkeypress", "onKeypressNameInputNode");
					}
				}

				// save the "publish short url" button
				var button = $('CommandLink-'+this.id);
				if(button) {
					this._publishButton = button;
				}
				this._updatePublishButton();

				// register input to specified save button
				dojo.addOnLoad(dojo.hitch(this, function() {
					var saveButton = $$(this.saveButtonId);
					if(saveButton !== undefined){
						saveButton.registerInput(this.inputWidget.domNode);
					} else {
						console.warn("Savebutton (id="+this.saveButtonId+") not found in "+this.declaredClass);
					}
				}));
			}
		},

		/**
		 * events
		 */

		onClickEditLinkNode : function(evt) {
		// summary: show short url input node and show info bubble
			this.inputWrapperNode.style.display="";
			this.displayUrlWrapperNode.style.display="none";
			this.inputWidget.domNode.focus();

			// (dirty) label formatting
			var labelNode = $('Label'+this.id);
			if(labelNode !== undefined) {
				dojo.addClass(labelNode, "InputLabelling");
				var tableNode = labelNode.parentNode.parentNode.parentNode;
				epages.html.replaceClass(tableNode, "FormGrid", "InnerGrid");
			}

			//display Info Bubble
				var position = $E(this.inputWidget.domNode).getAbsolutePosition();
				dojo.publish("uimessage/show", ["", this.translation.get('EditShortURLNotification'), "Bubble", {
					typeClass: "",
					sizeClass: "Small",
					x: position.x,
					y: (position.y + this.inputWidget.domNode.clientHeight + 4)
				}]);
		},

		onKeypressInputNode: function(evt) {
		// summary: handle keypress of shorturl input field - trigger onchange event after timeout
			dojo.publish("uimessage/hide", []);
			this._clearTimeouts();

			var _this = this;
			var iNode=this.inputWidget.domNode;
			this._inputTimeout = window.setTimeout( function() {
				epages.event.fire(iNode, "change");
			}, 100);
		},

		onKeypressNameInputNode: function(evt) {
		// summary: handle keypress of name input field - trigger onchange event after timeout
			this._clearTimeouts();

			var _this = this;
			var niNode=$(this.nameInputId);
			this._nameInputTimeout = window.setTimeout( function() {
				epages.event.fire(niNode, "change");
			}, 200);
		},

		onChangeInputNode: function(evt) {
		// summary: handle changes on input node - send request for a valid short url
			var v = this.getValue();
			this._clearTimeouts();
			this._updatePublishButton();
			if(this._lastValue != v) {                      // send request if there were real changes
				var orgName = this.getValue();

				var trimmedName = orgName.replace(/\s/g, ""); // check if string contains only space chars
				if(trimmedName != "") {
					var resShorturlString =	this._getTemporyReservedUrl();

					// build form data
					var request = new epages.io.Json();
					var formData = {
						'ViewAction' : 'JSONValidateShortURL',
						'ObjectID'   : this.siteId,
						'ParentID'   : this.parentObjectId,
						'ShortUrl'   : orgName,
						'ClassName'  : this.classAlias
					};

					// optinal form data
					if(this.contentObjectId != "") {
						formData['ContentObjectID'] = this.contentObjectId;
					}

					if(this.languageId != "") {
						formData['LanguageID'] = this.languageId;
					}

					if(resShorturlString != "") {
						formData['TemporaryReserved']=resShorturlString;
					}

					// send request
					request.loadAsync(this.url,
						epages.lang.hitch(this, function (result) { this._validateShortUrl_requestOk(result);}),
						formData,
						epages.lang.hitch(this, function (result, data) { this._getShortUrl_requestFailed(result, data);})
					);
				} else {
					this._setError(false);
				}
			}
		},

		triggerChangeNameInputNode: function() {
		// summary: public port to trigger new short URl suggest from outside
			this._clearTimeouts();
			this._updatePublishButton();

			var resShorturlString =	this._getTemporyReservedUrl();
			var orgName=$(this.nameInputId).value;

			// build form data
			var request = new epages.io.Json();
			var formData = {
				'ViewAction' : 'JSONGenerateShortURL',
				'ObjectID'   : this.siteId,
				'ParentID'   : this.parentObjectId,
				'Name'       : orgName,
				'ClassName'  : this.classAlias
			};

			// optinal form data
			if(this.languageId != "") {
				formData['LanguageID'] = this.languageId;
			}

			if(resShorturlString != "") {
				formData['TemporaryReserved']=resShorturlString;
			}

			// send request
			request.loadAsync(this.url,
				epages.lang.hitch(this, function (result) { this._getShortUrl_requestOk(result);}),
				formData,
				epages.lang.hitch(this, function (result, data) { this._getShortUrl_requestFailed(result, data);})
			);

			var niNode=$(this.nameInputId);
			this._nameInputTimeout = window.setTimeout( function() {
				epages.event.fire(niNode, "change");
			}, 2000);
		},

		onChangeNameInputNode: function(evt) {
		// summary: handle changes of name input field
			this._clearTimeouts();
			this._updatePublishButton();

			// send request only  if there were real changes and there were no initial value (don't overwrite current value)
			if((this.inputWidget.domNode.value == "" || this._isNew) &&
					this._lastNameValue != this.getNameValue()) {

				var resShorturlString =	this._getTemporyReservedUrl();
				var orgName=$(this.nameInputId).value;

				// build form data
				var request = new epages.io.Json();
				var formData = {
					'ViewAction' : 'JSONGenerateShortURL',
					'ObjectID'   : this.siteId,
					'ParentID'   : this.parentObjectId,
					'Name'       : orgName,
					'ClassName'  : this.classAlias
				};

				// optinal form data
				if(this.languageId != "") {
					formData['LanguageID'] = this.languageId;
				}

				if(resShorturlString != "") {
					formData['TemporaryReserved']=resShorturlString;
				}

				// send request
				request.loadAsync(this.url,
					epages.lang.hitch(this, function (result) { this._getShortUrl_requestOk(result);}),
					formData,
					epages.lang.hitch(this, function (result, data) { this._getShortUrl_requestFailed(result, data);})
				);
			}
		},

		/**
		 * getter, setter, other methods
		 */
		setValue: function(/* string */v, /* boolean? */ isValidated) {
		// summary: setter function - set value of input value
		// v: new value
		// isValidated: indicates if shorturl was validated (eg. proposal from server)
			this.inputWidget.domNode.value = v;
			this._lastValue = v;
			if(isValidated) {
				this._setTemporyReservedUrl();
				this._setError(false);
				dojo.publish("uimessage/hide", []);
			}
		},

		getValue: function() {
		// summary: returns short url input value
			return this.inputWidget.domNode.value;
		},

		getNameValue: function() {
		// summary: returns name input value
			var niNode=$(this.nameInputId);
			if(niNode) {
				return niNode.value;
			} else {
				return false;
			}
		},

		_clearTimeouts: function() {
		// summary: clear all timeouts
			if(this._inputTimeout !== undefined) {
				window.clearTimeout(this._inputTimeout);
			}

			if(this._nameInputTimeout !== undefined) {
				window.clearTimeout(this._nameInputTimeout);
			}
		},

		_setError : function(/* boolean */ setError) {
		// summary: set or remove error class on short url input
			if(setError) {
				dojo.addClass(this.inputWidget.domNode, "DialogError");
			} else {
				dojo.removeClass(this.inputWidget.domNode, "DialogError");
			}
		},

		_setTemporyReservedUrl: function() {
		// summary: set current value as temporaray reserved url
			var v = this.getValue();
			epages.vars.TemporaryReservedShortUrl.set(this.id, v);
		},

		_getTemporyReservedUrl: function() {
		// summary: returns a string with all reserved url (comma seperated)
				var resShorturl = [];
				var id = this.id;
				epages.vars.TemporaryReservedShortUrl.each(function(pair) {
					if(id != pair[0]) {
						resShorturl.push(pair[1]);
					}
				});
				return resShorturl.join(',');
		},


		_updateDisplayUrl : function(/* string */ v) {
		// summary: update shorturl preview div
			this.displayUrlNode.innerHTML = epages.format.scrunch(v,25, 0.4);
			this.displayUrlNode.title=v;
		},

		_validateShortUrl_requestOk : function(/* epages.io.json result */ result) {
		// summary: call back function (short url node change) - insert generated short url or display short url proposal bubble
			this._lastValue = this.getValue();
			this._setTemporyReservedUrl();
			if(result.data && result.data.Valid) {
				this._setError(false);
			} else {
				this.setValue(result.data.ShortURL,true);
			}
		},

		_updatePublishButton : function() {
		// summary: update commandlink "publish short url"
				if(this.getValue() == "") {
					if(this._publishButton){
						dojo.addClass(this._publishButton, "Disabled");
					}
				} else {
					if(this._publishButton && !dojo.hasAttr(this._publishButton, "title")){
						dojo.removeClass(this._publishButton, "Disabled");
					}
				}
		},

		_getShortUrl_requestOk : function(/* epages.io.json result */ result) {
		// summary: call back function (name input change) - insert generated short url and update
			if(result.data && result.data.ShortURL) {
				this.inputWidget.domNode.value=result.data.ShortURL;		// set short url
				// update display and status
				this._updateDisplayUrl(result.data.ShortURL);
				this._setError(false);
				this._setTemporyReservedUrl();
				this._lastNameValue = this.getNameValue();
				this._updatePublishButton();
			}
		},

		_getShortUrl_requestFailed : function(/* epages.io.json result */ result) {
		// summary: error handling request failed
			var errors = result.data.Errors;
			console.error("An error occured in request (function: onChangeNameInputNode, class: "+this.declaredClass+") ", result.data.Errors);
		}

	}
);

}


/* package: ep_shop_upload.js.uncompressed */
/*
	Copyright (c) 2004-2011, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/

/*
	This is an optimized version of Dojo, built for deployment and not for
	development. To get sources and documentation, please visit:

		http://dojotoolkit.org
*/

if(!dojo._hasResource['epages.io.file']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.io.file'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.io.file');


epages.io.File = function() {
	this.files = [];
};

epages.io.File.prototype = {

	boundary: (new Date()).getTime().toString(16), 	// Integer - boundary is hex presentation of timestamp

	// encoding: Object
	//    supported encodings for file transfer, RAW should not be used, due to a bug in
	//    the XMLHTTPRequest object
	encoding: {
		RAW:              undefined,
		BASE64:           'base64',
		QUOTEDPRINTABLE:  'quoted-printable',
		XHR:              'epages-xhr'
	},

	clear: function () {
		this.files = [];
	},

	addFile: function (/*String*/formElement, /*String*/fileName, /*String*/fileContent, /*String?*/encoding) {
		// summary:
		//    Adds a file for upload.
		// formElement: name of the form element
		// fileName: name of the file
		// fileContent: contents of the file;
		this.files.push({
			"file":             fileName,
			"name":             formElement,
			"content":          fileContent,
			"contentType":      "application/octet-stream; charset=utf-8",
			"transferEncoding": encoding != null ? this.encoding[encoding] : this.encoding.BASE64
		});
	},
	
	_getFilePost: function() {
		var post = '';
		for( var i=0,iLength=this.files.length ; i<iLength ; i++ ) {
			var file = this.files[i];
			post += "--" + this.boundary + "\r\n"
						+ 'Content-Disposition: form-data; name="' + file.name + '"; filename="' + file.file + '"\r\n'
						+ 'Content-Type: ' + file.contentType + '\r\n';
			if (file.transferEncoding != '') {
				post += 'Content-Transfer-Encoding: ' + file.transferEncoding + "\r\n";
			}
			post += "\r\n" + file.content + "\r\n";
		}
		post += "--" + this.boundary + "--\r\n";
		return post;
	},

	send: function (/*String*/url) {
		// summary:
		//    uploads file via multipart post and returns the result document.
		// example:
		//  | fileUploader = new epages.io.File();
		//  | fileUploader.addFile("NewFile", "test.txt", "This is a test.");
		//  | result = fileUploader.send('http://www.mydomain.de/form.php');
		var outerData = {};
		dojo.rawXhrPost({
			file:       this.files,
			url:        url,
			sync:       true,
			multipart:  true,
			error:      epages.io.Json.prototype.defaultErrorCallback,
			load:       function(data){ outerData.data = dojo.fromJson(data); },
			headers:    { 
				'Accept':       'text/x-json',
				'Content-Type': 'multipart/form-data; boundary=' + this.boundary
			},
			postData:   this._getFilePost()
		});
		return outerData; // Object
	}
};

}

if(!dojo._hasResource["epages.uploader"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.uploader"] = true;
/*
  Copyright (c) 2006-2010, ePages GmbH
  All Rights Reserved.

  uploader.js
  epages.upload
*/

dojo.provide("epages.uploader");











(function(){

  var _cache = {};

  epages.Uploader = {
    // HTML skeleton snippet to be inserted into the upload dialog
    _DIALOG_TEMPLATE:
  '<div class="Uploader">\
      <div class="FileListContainer"><div class="HideElement"></div></div>\
      <table class="ContentList UploadAddLinkContainer">\
        <tbody>\
          <tr class="NewEntry">\
            <td class="AlignCenter" colspan="2">\
              <span class="UploadAddLink DoActionLink EnableHover">\
                <span class="BigUploadLink">\
                  <i class="Sprite (%add_button_class%)"></i>\
                  <span>(%text_choose_files%)</span>\
                </span>\
                <span class="HideElementSoft SmallUploadLink">\
                  <i class="Sprite (%add_button_class%)"></i>\
                  <span>(%text_add_more_files%)</span>\
                </span>\
              </span>\
            </td>\
          </tr>\
        </tbody>\
      </table>\
      <div class="UploadFormContainer HideElement"></div>\
    </div>\
    <div class="DialogMessage MessageInfo TopMargin HideElement"></div>\
  </div>',

    // template parsed version of _DIALOG_TEMPLATE
    _PARSED_DIALOG_TEMPLATE: 					"",

    // translate string constants
    _DIALOG_TITLE:										"",
    //_SELECT_LINK_LABEL:								"",
    //_SELECT_LINK_MORE_LABEL:							"",
    _UPLOAD_BUTTON_LABEL:								"",
    _CANCEL_BUTTON_LABEL:								"",
    //_CLOSE_BUTTON_LABEL:								"",

    // TODO: translate error codes
    _ERROR_HEADLINE:									"",
    _ERROR_MIMETYPE_NOT_ACCEPT: 						"",
    _MAXCONTENTLENGTH_EXCEEDED_ERROR: 					"",
    _UPLOADSPACE_EXCEEDED_ERROR:      					"",
    _SESSION_ERROR:										"",
    _MAX_PREVIEW_ITEMS:									10,

    // top part of the file list table
    _fileListTopHTML:				"<table class=\"ContentList FileListTable\"><tbody class=\"FileList\">",
    // bottom part of the file list table
    _fileListBottomHTML:		"</tbody></table>",
    // middle part of the file list table represented as array (for the use of join("") later on)
    _fileListHTMLSnippets:	[''],

    // reference to the upload dialog
    _uploadDialog:					null,

    // reference to the node which holds the file list (and the upload <form/> for browsers without binary xhr support)
    _uploadFormContainer:		null,
    // reference to the "add more" link
    _uploadAddLink:					null,
    // reference to the parent node of the "add more" link
    _uploadAddLinkContainer:null,
    // reference to the file list parent
    _fileListContainer:			null,
    // reference to the <input type="file"/> used to select the files
    _uploadInput:						null,

    // array of all files inside the queue
    _uploadCollection:			[],

    // array of all upload responses
    _uploadResponseUploadedFile:			'',

    // array of all files inside the error msg
    _uploadErrorFiles: [],

    // index of the current file to be uploaded
    _uploadIndex:						0,

    // settings of the current Uploader
    _uploadSettings:				{},

    // flags if the uploader is currently in use
    _uploadActive:					false,
    // flags if errors occured on uploading process
    _uploadErrors:					false,

    // equates to "multiple" flag on "settings" object aside from browsers which don't support multiple uploads
    _multipleFileInputEnabled: false,

    // estimated time for a single upload process (will be calculated precisely later on)
    _uploadTimeEstimation:	200,
    // date object used to calculate the estimated upload time
    _uploadOldTime:					null,
    // reference to the node which represents the upload status in percent
    _uploadOldPercentageBar:null,
    // reference the the dojo animation used to smoothly represent the upload status
    _statusBarAni:					null,

    _resetUploadSettings: function(uploadSettings /* Object */) {
      // summary:
      //	set the default settings object for this instance
      // description:
      //	this is called on startup too to initially fill the settings object

      uploadSettings = uploadSettings || {};
      this._uploadSettings = {
        action:      uploadSettings.action || "?ChangeAction=UploadFiles&ObjectID=" + epages.vars.ObjectID,
        directory:   uploadSettings.directory || null,
        multiple:    uploadSettings.multiple ? epages.string.toBoolean(uploadSettings.multiple) : false,
        fileType:    uploadSettings.fileType || "",
        reloadPage:  uploadSettings.reloadPage ? epages.string.toBoolean(uploadSettings.reloadPage) : false,
        callback:    uploadSettings.callback || function() {},
        formElement: uploadSettings.formElement || "NewFile",
        id:          uploadSettings.id || "uploadAppletNodeID",
        acceptGroup: uploadSettings.acceptGroup || '*/*',
        accept:      uploadSettings.acceptGroup ? epages.mimetype.getGroup(uploadSettings.acceptGroup).join(',') : (uploadSettings.accept || '*/*')
      };

      // fix any "amp;"s
      this._uploadSettings.action = this._uploadSettings.action.replace(/&amp;/,'&');

      // we need this in every case since there is no use of text/x-json as a result of a <form/>.submit()
      if(!this._uploadSettings.action.match(/handleashtml/)) {
        this._uploadSettings.action += "&handleashtml=1";
      }

      // default changeaction
      if(!this._uploadSettings.action.match(/ChangeAction/)) {
        this._uploadSettings.action += "&ChangeAction=UploadFiles";
      }

      // default for viewaction
      if(!this._uploadSettings.action.match(/ViewAction/)) {
        this._uploadSettings.action += "&ViewAction=JSONViewResponse";
      }

      if(this._uploadSettings.directory) {
        this._uploadSettings.action += "&Directory=" + this._uploadSettings.directory;
      }
    },

    _initUploadButton: function() {
      // summary:
      //	init the status of disabled for the upload button
      (this._uploadCollection.length ? dojo.removeClass(this._uploadDialog.innerButtonBarNode.firstChild,'Disabled') : dojo.addClass(this._uploadDialog.innerButtonBarNode.firstChild,'Disabled') );

    },

    _showUploadDialog: function() {
      // summary:
      //	wrapper around the native show method of the modaldialog widget

      if(this._uploadDialog) {
        this._uploadDialog.show();
      }
    },

    _hideUploadDialog: function() {
      // summary:
      //	wrapper around the native hide method of the modaldialog widget

      if(this._uploadDialog) {
        this._uploadDialog.hide();
      }
    },

    _repositionUploadDialog: function() {
      // summary:
      //	wrapper around the native show method of the modaldialog widget

      if(this._uploadDialog) {
        this._uploadDialog.layout();
      }
    },

    _maximizeUploadArea: function() {
      // summary:
      //	show the big file selection link (NewEntry area)

      dojo.removeClass(dojo.query(".BigUploadLink", this._uploadAddLink)[0], "HideElementSoft");
      dojo.addClass(dojo.query(".SmallUploadLink", this._uploadAddLink)[0], "HideElementSoft");
    },

    _minimizeUploadArea: function() {
      // summary:
      //	show the tiny file selection link (NewEntry area)

      dojo.addClass(dojo.query(".BigUploadLink", this._uploadAddLink)[0], "HideElementSoft");
      dojo.removeClass(dojo.query(".SmallUploadLink", this._uploadAddLink)[0], "HideElementSoft");
    },

    _cleanUp: function(uploadSettings) {
      // summary:
      //	reset all predefined variables
      // description:
      //	this emulates the constructor since epages.Uploader is called and not instantiated via "new"
      uploadSettings = uploadSettings || this._uploadSettings;

      this._resetUploadSettings(uploadSettings);
      if(this._uploadFormContainer) {
        this._fileListHTMLSnippets = [''];
        this._uploadErrorFiles = [];
        this._uploadCollection = [];
        this._uploadResponseUploadedFile = '';
        this._uploadIndex = 0;
        this._uploadActive = false;
        this._uploadErrors = false;
        this._uploadFormContainer.innerHTML = this._fileListContainer.innerHTML = "<div class=\"HideElement\"></div>";
        dojo.removeClass(this._fileListContainer.parentNode, "FilesSelected");
        dojo.removeClass(this._uploadAddLinkContainer, "HideElement");
        dojo.removeClass(this._uploadDialog.innerButtonBarNode.firstChild, "Active");
        dojo.removeClass(this._uploadDialog.innerButtonBarNode.firstChild, "Disabled");
        this._maximizeUploadArea();
      }
    },

    _onSubmitUploadDialog: function(evt) {
      // summary:
      //	start the uploading process (mapped to "click" event)

      if(dojo.hasClass(evt.currentTarget, "Disabled")) {
        return;
      }

      dojo.removeClass(this._uploadDialog.innerButtonBarNode.firstChild, "Active");
      dojo.addClass(this._uploadDialog.innerButtonBarNode.firstChild, "Disabled");
      dojo.addClass(this._uploadAddLinkContainer, "HideElement");

      this._uploadOldTime = new Date();
      this._uploadActive = true;
      this._uploadNextQueueItem();
    },

    _uploadNextQueueItem: function() {
      // summary:
      //	recursively upload one file after another
      this._updateProgressDisplay();

      // we're uploading the file list in reversed order (top > bottom)
      var file = this._uploadCollection[this._uploadIndex].srcFile;

      if(this._multipleFileInputEnabled) {
        // xhr upload
        var xhr = new XMLHttpRequest(); // a plain xhr object because dojo can't handle binary requests at all
        xhr.open("POST", this._uploadSettings.action);
        xhr.setRequestHeader("Content-Type", "application/octet-stream");
        xhr.setRequestHeader("If-Modified-Since", "Mon, 26 Jul 1997 05:00:00 GMT");
        xhr.setRequestHeader("Cache-Control", "no-cache");

        var contentDisposition = "attachment; ";
        contentDisposition += "filename=\"" + encodeURIComponent(file.fileName || file.name)  + "\"";
        var formElementName = this._uploadSettings.formElement;
        if(formElementName) {
          contentDisposition += "; name=\"" + encodeURIComponent(formElementName)  + "\"";
        }
        xhr.setRequestHeader("content-disposition", contentDisposition);

        if(xhr.sendAsBinary) {
          xhr.sendAsBinary(file.getAsBinary());
        }else {
          xhr.send(file);
        }
        dojo.connect(xhr, "readystatechange", function() { // listening to "onprogress" would be better but is very / too hard to normalize by now
          if(xhr.readyState === 4) {
            epages.Uploader._onResponse(xhr.responseText);
          }
        });
        dojo.connect(xhr, "error", this, "_onResponse");
      }
      else {
        // "classic" upload via <form/>.submit()
        this._uploadFormContainer.innerHTML = "";

        var fileUploadForm = document.createElement("form");
        fileUploadForm.action = this._uploadSettings.action;
        fileUploadForm.method = "POST";
        fileUploadForm.enctype = fileUploadForm.encoding = "multipart/form-data";
        fileUploadForm.target = "fileUploadFrame";
        this._uploadFormContainer.appendChild(fileUploadForm);

        var uploadFrameContainer = document.createElement("div");
        uploadFrameContainer.innerHTML = "<iframe name=\"fileUploadFrame\" onload=\"epages.Uploader._onResponse(this.contentWindow.document.body.innerHTML)\"></iframe>";
        this._uploadFormContainer.appendChild(uploadFrameContainer);

        fileUploadForm.appendChild(file);

        fileUploadForm.submit();
      }
    },

    _updateProgressDisplay: function() {
      // summary:
      //	making the uploading process endurable while showing some nice animations

      var tdNode = this._fileListContainer.getElementsByTagName("tr")[this._uploadIndex+(this._uploadErrorFiles.length ? 1 : 0)].firstChild;

      var statusBar = dojo.query("div.StatusBar", tdNode.parentNode)[0];
      var percentageBar = dojo.query("div.InnerStatusBar > div", statusBar)[0];

      if(this._statusBarAni) {
        this._statusBarAni.stop();
        this._uploadOldPercentageBar.style.width = (statusBar.offsetWidth - 2) + "px";
      }

      this._statusBarAni = dojox.fx.wipeTo({node: percentageBar, width: statusBar.offsetWidth - 2, duration: this._uploadTimeEstimation, easing: dojo.fx.easing.quadIn});
      this._statusBarAni.play();

      var currentDate = new Date();
      this._uploadTimeEstimation = ~~((currentDate - this._uploadOldTime) / 2);
      this._uploadOldTime = currentDate;
      this._uploadOldPercentageBar = percentageBar;

    },

    _throwError: function(errorText /* String */, trEntry /* <tr/> Node */) {
      // summary:
      //	an error occured for a specific upload item

      this._uploadErrors = true;
      var percentageBar = dojo.query(".StatusBar div.InnerStatusBar div", trEntry)[0];
      percentageBar.className = "PercentageCritical";

      // TODO: show some sort of error message
      //top.dojo.publish("uimessage/show", [ "", errorText, "Dialog" , {titleBar: this._ERROR_HEADLINE, typeClass: "Error", sizeClass:"Large"}]);
    },

    _onResponse: function(responseSnippet /* ? */) {
      // summary:
      //	upload finished for a specific file and we (maybe) received a server response

      responseSnippet = responseSnippet || ""; // be sure that it will never be undefined
      var response;

      var trEntry = this._fileListContainer.getElementsByTagName("tr")[this._uploadIndex];

      try {
        // there is a chance that we receive garbage which can't be transformed into an JSON object
        // with that in mind there is no way around the try/catch statement
        response = eval("[" + responseSnippet + "]")[0];
      }catch(e) {}

      if(!response) {
        // hard error
        dojo.addClass(trEntry, "UploadError");
        if(responseSnippet.match("file is too large")) {
          this._throwError(this._MAXCONTENTLENGTH_EXCEEDED_ERROR, trEntry);
        }else {
          //outdated session, false token, something else happened
          this._throwError(this._SESSION_ERROR, trEntry);
        }
        this._uploadActive = false; // stop polling
      } else if(response.Errors) {
        // soft error
        if(response.Errors[0].Message == "FeatureLimitExceeded") {
          this._throwError(this._UPLOADSPACE_EXCEEDED_ERROR, trEntry);
        } else {
          this._throwError(response.Errors[0].Message, trEntry);
        }
        dojo.addClass(trEntry, "UploadError");
        //this._uploadActive = false; // stop polling
      } else {
        // success
        dojo.addClass(trEntry, "UploadSuccess");

        if( response.uploadedFile ) {
          this._uploadResponseUploadedFile = response.uploadedFile;
        }
      }

      this._uploadIndex++;
      if(this._uploadIndex < this._uploadCollection.length && this._uploadActive) {
        this._uploadNextQueueItem();
      }else {
        this._onUploadFinished(response);
      }

      if(trEntry.nextSibling) {
        this._fileListContainer.scrollTop = trEntry.nextSibling.offsetTop - this._fileListContainer.offsetHeight + trEntry.nextSibling.offsetHeight;
      }
    },

    _onUploadFinished: function(response) {
      // summary:
      //	all files are uploaded - now show the user the results and sum it up
      //if(this._uploadErrors) {
        // TODO: show some sort of error message to sum it up and provide a button for closing the dialog the soft way (not via "abort");
      //} else {
      if( this._uploadErrors ) {
        var errorList = [];
        dojo.query(".UploadError", this._fileListContainer).forEach( function( node, i ){
          errorList.push( node.childNodes[1].childNodes[0].nodeValue );
          console.log({log: node.childNodes[1].childNodes[0] });
        });

        alert( this._ERROR_MIMETYPE_NOT_ACCEPT +'\n\n'+ errorList.join('\n') );
      }

        this._hideUploadDialog();
        this._uploadSettings.callback();
        if(this._uploadSettings.reloadPage) {
          var dialogArea = actualDialogArea ? "DialogArea=" + actualDialogArea : "";
          if(location.href.search(/Monitor/) != -1 && epages.vars.BaseUrl && epages.vars.ViewAction && epages.vars.ObjectID){
            var newHref = epages.vars.BaseUrl + '?ViewAction=' + epages.vars.ViewAction + '&ObjectID=' + epages.vars.ObjectID;
            if(dialogArea == ''){
              location.href = newHref;
            }else{
              location.href = newHref + '&'+dialogArea;
            }
          }
          else{
            if(location.href.search(/DialogArea/) != -1){
              var newLocation;
              if (this.useBaseUrlForHref) {
                newLocation = epages.vars.BaseUrl + '?ViewAction=' + epages.vars.ViewAction + '&ObjectID=' + epages.vars.ObjectID;
              } else {
                newLocation = location.href;
              }
              for( var i=0,iLength=epagesDialog.areaName.length ; i<iLength ; i++ ){
                var regEx = new RegExp('DialogArea='+epagesDialog.areaName[i]);
                newLocation = newLocation.replace(regEx,dialogArea);
              }
              location.href = newLocation;
            }else{
              if(dialogArea == ''){
                location.href = location.href;
              }else {
                location.href = location.href + '&'+dialogArea;
              }
            }
          }
        }

        response.uploadedFile = this._uploadResponseUploadedFile;

        dojo.publish(this._uploadSettings.id + '/onUploadFinished', [ response ]);
      //}
    },

    _onCancelUploadDialog: function() {
      // summary:
      //	user pressed "cancel" on the upload dialog

      this._uploadActive = false;
      this._hideUploadDialog();
    },

    _removeFileListRow: function( event, i ) {
      // summary:
      //	remove a file from queue
      var tr = (event.target || event.srcElement).parentNode.parentNode.parentNode;
      var tbody = tr.parentNode;
        tbody.removeChild( tr );

      this._uploadCollection.splice(i,1);
      this._fileListHTMLSnippets.splice(i,1);
      this._refreshZebra();
      this._addDeleteConnects();
      this._initUploadButton();
    },

    _refreshZebra: function() {
      // summary:
      //	refresh alternate color style for table
      var table = this._fileListContainer.childNodes[0].childNodes;
      var trs;
      for( var i=0,l=table.length ; i<l ; i++ ) {
        if( table[i].nodeName == 'TBODY' ){
          trs = table[i].childNodes;
        }
      }
      for( var i=0,l=trs.length ; i<l ; i++ ) {
        if( i % 2) {
          dojo.addClass( trs[i], 'alternate' );
        }
        else {
          dojo.removeClass( trs[i], 'alternate' );
        }
      }
    },

    _addDeleteConnects: function() {
      // summary:
      //	connect a remove event for all remove buttons

      this._deleteHandles = this._deleteHandles || [];

      dojo.forEach(this._deleteHandles, dojo.disconnect);

      var list = dojo.query('a.FileDelete',this._fileListContainer);

        for( var i=0,l=list.length ; i<l ; i++ ) {

          var node = list[i];
          var index = i;

          this._deleteHandles.push(
            dojo.connect( node, 'click', this, function(event) {
              this._removeFileListRow( event, index ) ;
            } )
          );
        }
    },

    _addFileListRow: function( file /* Hash */) {
      // summary:
      //	add a representation of a selected file to the file list

      var snippet = ["<tr" + ((this._fileListHTMLSnippets.length % 2) ? " class=\"alternate\"" : "" ) + "><td class=\""];
      var dict = epages.io.dictionary.translation;
      var translationRemove = dict.get("Remove");

      snippet.push("\"><i class=\"Sprite NoPadding " + file.icon + "\"></i>");
      snippet.push("</td><td>" + file.name + "<div class=\"StatusBar\"><div class=\"InnerStatusBar\"><div class=\"PercentageNormal\" style=\"width:0\"></div></div></div><a href=\"javascript:;\" class=\"FileDelete\" style=\"position: absolute; right: 10px; margin-top: -20px\"><i class=\"Sprite ico_s_remove\" title=\"" + translationRemove + "\"></i></a></td></tr>");

      this._fileListHTMLSnippets.push(snippet.join(""));
    },

    _addFileToUploadQueue: function(file /* file binary */) {
      // summary:
      //	attach a file to be uploaded to the internal upload list

      this._uploadCollection.push(file);
    },

    _addFileErrorRow: function() {
      // summary:
      //	add error msg to FileList
      var length = this._uploadErrorFiles.length;
      if( length > 0 ) {
        var snippet = ['<tr class="ErrorDialog"><td><i class="Sprite NoPadding ico_m_error"></i></td><td>'];
        snippet.push( this._ERROR_MIMETYPE_NOT_ACCEPT +  '<br />' );
        for( var i=0 ; i<length ; i++ ) {
          snippet.push( this._uploadErrorFiles[i] + '<br />' );
        }
        snippet.push('</td></tr>');
        this._fileListHTMLSnippets[0] = snippet.join('');
      }
      else {
        this._fileListHTMLSnippets[0] = '';
      }
    },

    _addFileToErrorList: function(fileName) {
      // summary:
      //	add file with wrong mimetype to error list
      this._uploadErrorFiles.push(fileName);
    },

    _mimetypeHandle: function(srcFile) {
      // summery:
      //   check the mimetype of the file
      var file = {
          srcFile: srcFile
        };
      if( srcFile.value ) {
        file.name = srcFile.value.match(":") ? srcFile.value.match(/(.*)[\/\\]([^\/\\]+\.\w+)$/)[2] : srcFile.value;
        file.type = null;
        file.size = null;
      }
      else {
        file.name = srcFile.name || srcFile.fileName;
        file.type = srcFile.type || srcFile.fileType;
        file.size = srcFile.size || srcFile.fileSize;
      }

      if( file.type ) {
        var instance = new epages.Mimetype(file.type);
      }
      else {
        var instance = new epages.Mimetype();
        file.type = instance.setBySuffix( file.name.substring(file.name.lastIndexOf('.')+1) ).getMime();
      }

      file.allowed = instance.isGroup( this._uploadSettings.acceptGroup );
      file.preview = instance.isPreviewable();
      file.icon = instance.getIcon();

      return file;
    },

    _appendToQueue: function(fileInput /* <input type="file"/> */) {
      // summary:
      //	queue one or more files selected via <input type="file"/>

      // only one file may be selected but the user selected another one
      // so we delete the previous file selection
      if(!this._uploadSettings.multiple) {
        this._cleanUp();
      }

      dojo.addClass(this._fileListContainer.parentNode, "FilesSelected");

      if(fileInput.files) {
        this._multipleFileInputEnabled = true;
        dojo.forEach(fileInput.files, function(file, fileIndex) {
          file = this._mimetypeHandle(file);
          if( file.allowed && (file.size ? file.size/1024 < epages.vars.MaxContentLength ? true : false : true) ) {
            this._addFileListRow(file);
            this._addFileToUploadQueue(file);
          }
          else {
            this._addFileToErrorList(file.name);
          }
        }, this);

      }
      else {
        // i.e. "C:\"
        // the local path is part of the fileAlias (Windows fake path, i.e. "C:\fakepath\ico_64hover_featurepacks_orgRGB.png").
        // We only want the name of the file: (C:\fakepath)[\](ico_64hover_featurepacks_orgRGB.png)
        //fileAlias = fileInput.value.match(":") ? fileInput.value.match(/(.*)[\/\\]([^\/\\]+\.\w+)$/)[2] : fileInput.value;
        var file = this._mimetypeHandle(fileInput);



        if( file.allowed ) {
          this._addFileListRow(file);
          this._addFileToUploadQueue(file);
        }
        else {
          this._addFileToErrorList(file.name);
        }
      }

      fileInput.value='';

      this._initUploadButton();
      this._addFileErrorRow();
      this._fileListContainer.innerHTML = this._fileListTopHTML + this._fileListHTMLSnippets.join("") + this._fileListBottomHTML;
      this._minimizeUploadArea();
      this._insertUploadInput();

      this._addDeleteConnects();

    },

    _queueFiles: function( uploadInput ) {
      // summary:
      //	queue one or more files selected via <input type="file"/> with a certain delay and hide the upload dialog beforehand
      setTimeout(
        dojo.hitch(
          this,
          function() {
            // TODO: _appendToQueue can take a long a time with > 50 files selected at once - we need some sort of becalmer animation for the user
            this._appendToQueue( uploadInput && uploadInput.nodeName ? uploadInput : this._uploadInput );
            setTimeout(
              dojo.hitch(
                this,
                function() {
                  this._repositionUploadDialog();
                  this._fileListContainer.scrollTop = 0;
                }
              ),
              this._uploadDialog.duration);
          }
        ),
        this._uploadDialog.duration + 10);
    },

    _insertUploadInput: function() {
      // summary:
      //	create a <input type="file"/>
      // description:
      //	the created file input will reside on top of the "add more" link on which the user will think he clicks on
      if(this._uploadInput) {
        this._uploadInput.parentNode.removeChild(this._uploadInput);
      }
      this._uploadInput = document.createElement("input");
      this._uploadInput.type = "file";
      this._uploadInput.name = this._uploadSettings.formElement;
      this._uploadInput.accept = this._uploadSettings.accept;
      if(this._uploadSettings.multiple) {
        // this._uploadInput.multiple = true < won't work
        this._uploadInput.setAttribute("multiple", "true");
      }
      this._uploadInput.className = "UploadInputOverlay";
      this._uploadAddLink.appendChild(this._uploadInput);
      dojo.connect(this._uploadInput, "change", this, "_queueFiles");
    },

    _buildDialog: function() {
      // summary:
      //	build up the upload dialog

      var dlgParams = {
        title : this._DIALOG_TITLE,
        width : 450,
        scroll: "hidden",
        content: this._PARSED_DIALOG_TEMPLATE,
        buttons: [{
          label: this._UPLOAD_BUTTON_LABEL,
          onclick: dojo.hitch(this, this._onSubmitUploadDialog)
        },{
          label: this._CANCEL_BUTTON_LABEL,
          onclick: dojo.hitch(this, this._onCancelUploadDialog)
        }]
      };

      if(this._uploadDialog) {
        // update dialog content
        this._fileListContainer = undefined;
        this._uploadDialog.setupContent(dlgParams);
      }
      else {
        this._uploadDialog = new epages.widget.Modaldialog({
          options:{
            title : dlgParams.title,
            width : dlgParams.width,
            scroll: dlgParams.scroll,
            content: dlgParams.content
          },
          buttons: dlgParams.buttons
        });
        dojo.body().appendChild(this._uploadDialog.domNode);
      }
    },

    _mapNodes: function() {
      // summary:
      //	build up references the the importand and most used dialog nodes

      if(this._fileListContainer) {
        return;
      }
      var innerNode = this._uploadDialog.domNode;
      this._fileListContainer = dojo.query(".FileListContainer", innerNode)[0];
      this._uploadFormContainer = dojo.query(".UploadFormContainer", innerNode)[0];
      this._uploadAddLink = dojo.query(".UploadAddLink", innerNode)[0];
      this._uploadAddLinkContainer = dojo.query(".UploadAddLinkContainer", innerNode)[0];
    },

    _applyTranslations: function() {
      // summary:
      //	replaces member variables with caption texts with its correct translation strings
      var dict = epages.io.dictionary.translation;
      var translation = function(string) {
          return _cache[string] = _cache[string] || dict.get(string);
        };

      var uploadText = this._uploadSettings.multiple ? translation("FileUploadMultiple") : translation("FileUploadSingle");

      var templatedDialog = $TMPL(this._DIALOG_TEMPLATE, {
        add_button_class 		: 'ico_s_add',
        text_choose_files 	: uploadText+'...',
        text_add_more_files : this._uploadSettings.multiple ? translation("AddMoreImagesLink") : translation("AddMoreImagesLink")
      }, false);
      this._PARSED_DIALOG_TEMPLATE = templatedDialog.generateOutput();

      this._DIALOG_TITLE = uploadText;
      this._UPLOAD_BUTTON_LABEL = uploadText;
      this._CANCEL_BUTTON_LABEL = translation("Cancel");
      this._MAXCONTENTLENGTH_EXCEEDED_ERROR = translation("FileSizeLimitError");
      this._UPLOADSPACE_EXCEEDED_ERROR = translation("FeatureLimitExceeded");
      this._SESSION_ERROR = translation("InternalServerError");
      this._ERROR_HEADLINE = translation("FileUploadError");
      this._ERROR_MIMETYPE_NOT_ACCEPT = translation("MimetypeNotAcceptError");
    },

    open: function(uploadSettings /* Object */) {
      // summary:
      //	open an upload dialog
      // example:
      //	| onclick="epages.Uploader.open({multiple:true, directory:'#Directory', reloadPage:true})"

      // only one Uploader dialog at once may be active
      // and we have to assume that is was opened before
      this._hideUploadDialog();
      this._cleanUp(uploadSettings);
      this._applyTranslations();
      this._buildDialog();
      this._mapNodes();
      this._insertUploadInput();
      this._maximizeUploadArea();
      this._showUploadDialog();
      this._initUploadButton();
    },

    directOpen: function( node /* node */, uploadSettings /* Object */ ) {
      // summary:
      //	open an upload dialog direct onchange of fileInput
      // example:
      //  | <input type="file" onchange="epages.Uploader.directOpen( this, {directory:'#Directory', reloadPage:true} )" formaction="?ChangeAction=..." multiple="true" />
      //
      // only one Uploader dialog at once may be active
      // and we have to assume that is was opened before

      this.open(uploadSettings);
      this._queueFiles( node );
    }

  };

})();

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.UploadImage"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.UploadImage"] = true;
/*
  Copyright (c) 2006-2007, ePages GmbH
  All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.presentation.widget.UploadImage");









(function(jq){

var jqUploaderReady = !1,
  jqUploaderCreate = function( self ){
    var o = {
        url:		self.url,
        data: {
          ViewAction:			'JSONViewResponse',
          ChangeAction:		self.uploadAction,
          ObjectID:			self.objectId,
          Image:				self.fileAttribute,
          UseMediaGallery:	self.useMediaGallery ? 1 : 0
        },
        accept:		self.fileType,
        callback:	self.reloadPage ? '?ViewAction='+ep.config.viewAction+'&ObjectID='+ep.config.objectId : function( data ){
          dojo.publish( self.uploadAppletNode.id + '/onUploadFinished', [data[0].success || data[0].ERROR || {}] );
        }
      };

    if(self.saveAfterUpload){
      o.callback = function( data ){
        dojo.publish( self.uploadAppletNode.id + '/onUploadFinished', [data[0].success || data[0].ERROR || {}] );
      }
    }

    if( self.doScaleImage ){
      if( self.scaleWidth != '' ){ o.data.Width	= self.scaleWidth; }
      if( self.scaleHeight != '' ){ o.data.Height	= self.scaleHeight; }
      if( self.scaleQuality != '' ){ o.data.Quality = self.scaleQuality; }
    }

    de_epages(self.uploadAppletNode).presentationUiUploader(o);
  };

dojo.declare(
  "epages.cartridges.de_epages.presentation.widget.UploadImage",
  [epages.widget.DeleteFileOnServer, epages.widget.LocalizedWidget ],
  {
    imageWidth :        '',
    imageHeight:        '',
    scaleWidth :        '',
    scaleHeight:        '',
    scaleQuality:       '',
    uploadAction:       'UploadFiles',
    fileType:           'image/*',
    infoText:           '',
    scaleText:          '',
    doScaleImage:       '1',
    onUploaded:         '',
    templateString:     '',
    templateString:"<div>\n  <table class=\"FullWidth\" style=\"border:0\"><tr><td style=\"border:0;width:100px;\">\n    <span dojoAttachPoint=\"displayNode\" dojoType=\"epages.widget.Slides\" imageHeight=\"100px\" imageWidth=\"100px\" stopped=\"true\" showControls=\"false\" showMisc=\"false\" showDescription=\"false\">\n      <ins image=\"${filePath}\"></ins>\n    </span>\n    <span class=\"ToolTip ep-js\" data-js=\".uiTooltip({})\">\n      <div dojoAttachPoint=\"nameNode\" class=\"Bold\">${fileName}</div>\n      <div dojoAttachPoint=\"infoNode\">${infoText}</div>\n    </span>\n  </td>\n  <td style=\"border:0;\">\n    <div class=\"LeftMargin\" style=\"height:100px;position:relative\">\n      <input type=\"file\" class=\"NoButtonTrigger\" dojoAttachpoint=\"uploadAppletNode\"/>\n      <div class=\"ClearLeft\"></div>\n      <div dojoAttachPoint=\"scaleImageNode\" class=\"TopSmallMargin\">\n        <input dojoAttachPoint=\"scaleCheckBoxNode\" type=\"text\" name=\"${scaleCheckboxName}\" id=\"ResizeImageLarge_${id}\" value=\"1\" class=\"Checkbox NoButtonTrigger\" />\n        <label for=\"ResizeImageLarge_${id}\">${scaleText}</label>\n      </div>\n      <div dojoAttachPoint=\"additionalInfoNode\">${additionalInfo}</div>\n    </div>\n  </td></tr>\n  <tr>\n    <td colspan=\"2\">\n      <span\n    dojoType=\"epages.widget.DeleteFileOnServer\"\n    dojoAttachPoint=\"deleteNode\"\n    fileAttribute=\"${fileAttribute}\"\n    filePath=\"${filePath}\"\n    fileName=\"${fileName}\"\n    confirm=\"${confirm}\"\n    objectId=\"${deleteObjectId}\"\n    changeAction=\"${deleteAction}\"\n    altDelete=\"${deleteActionName}\"\n    ></span>\n    </td>\n  </tr>\n  </table>\n</div>\n",
    translationName:    dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget','templates/translation'),
    widgetsInTemplate:  true,
    useMediaGallery:    false,
    fileAttribute:      '',
    fileInputNode:      null,
    fileInputName:      '',
    fileInputValue:     '',
    uploadInputName:    'NewFile',
    _scaleCheckBox:		null,
    scaleCheckboxName:  'ResizeImageLarge',
    showDeleteNode:     true,
    objectId:			epages.vars.ObjectID || '',
    deleteObjectId:		this.objectId || epages.vars.ObjectID || '',
    saveAfterUpload:    false,
    url:                '?',
    saveAction:         'Save',
    saveParameters:     undefined,
    reloadPage:			false,
    deleteAction:		'DeleteFile',
    deleteActionName:	'',

    headlineConfirm:    epages.io.dictionary.get('HeadLineDeleteFile'), // 'Moechten Sie diese Datei wirklich loeschen ?',
    titleConfirm:       epages.io.dictionary.get('TitleDeleteFile'), // 'Datei loeschen',
    altDelete:          epages.io.dictionary.get('TitleDeleteFile'), //'Datei loeschen',
    additionalInfo:     '',

    setUploadUrl: function () {
      var self = this;

      if( jqUploaderReady ){
          jqUploaderCreate( self );
      }
      else{
        jq.ready( 'de_epages.presentation.ui.uploader', function(){
          jqUploaderCreate( self );
          jqUploaderReady = !0;
        });
      }
    },

    postMixInProperties: function () {
      this.inherited("postMixInProperties", arguments);

      this.doScaleImage = epages.string.toBoolean(this.doScaleImage);
      this.useMediaGallery = epages.string.toBoolean(this.useMediaGallery);
      this.fileName = epages.format.slice(this._getFileName(this.fileName), 25);
      this.showDeleteNode = epages.string.toBoolean(this.showDeleteNode);
      if (!this.fileAttribute && this.fileInputName) {
        this.fileAttribute = this.fileInputName;
      }

      // build info text
      this.infoText = '';
      if (this.fileSize != '') {
        this.infoText = epages.localize.formatBytes(this.fileSize, 0);
      }
      if (this.imageWidth != '' && this.imageHeight != '') {
        this.infoText += ' (' + this.imageWidth + ' &times; ' + this.imageHeight + 'px)';
      }

      // build scale text
      if (!this.scaleText) {
        this.scaleText = this.translate('ScaleImage');
      }
      if (this.scaleWidth != '' && this.scaleHeight != '') {
        this.scaleText += "<br /><span class='AdditionalInfo' style='padding-left:22px'>(" + this.translate("maxWidth") + " " + this.scaleWidth + "px &times; " + this.translate("maxHeight") +" "+ this.scaleHeight + "px)</span>";
      } else if(this.scaleWidth) {
        this.scaleText += "<br /><span class='AdditionalInfo' style='padding-left:22px'>(" + this.translate("Width") + ": " + this.scaleWidth + "px)</span>";
      } else if(this.scaleHeight) {
        this.scaleText += "<br /><span class='AdditionalInfo' style='padding-left:22px'>(" + this.translate("Height") + ": " + this.scaleHeight + "px)</span>";
      }
    },

    postCreate: function() {
      this.inherited("postCreate", arguments);
      if (!this.scaleWidth && !this.scaleHeight) {
        this.scaleImageNode.style.display = 'none';
      }
      if (!this.infoText) {
        this.infoNode.style.display = 'none';
      }
      if (!this.additionalInfo) {
        this.additionalInfoNode.style.display = 'none';
      }
      if (!this.showDeleteNode || !this.filePath || !this.fileName) {
        this.deleteNode.domNode.style.display = 'none';
      }
      this._scaleCheckBox = new epages.widget.FormElement({}, this.scaleCheckBoxNode);
      this.scaleCheckBoxNode = this._scaleCheckBox.elementNode;
      if (this.doScaleImage) {
        this._scaleCheckBox.attr('checked',true);
      }
      this.connect(this.scaleCheckBoxNode, "onclick", "toggleDoScale");

      if (this.fileInputName) {
        this.fileInputNode = this.domNode.ownerDocument.createElement('input');
        this.fileInputNode.type = 'hidden';
        this.fileInputNode.name = this.fileInputName;
        this.fileInputNode.value = this.fileInputValue;
        this.domNode.appendChild(this.fileInputNode);
        if(this.saveAfterUpload){
          dojo.addClass(this.fileInputNode, 'NoButtonTrigger');
        }
      }

      // set id for uploader
      dojo.attr(this.uploadAppletNode, 'id', this.id+'_uploader');
      dojo.attr(this.uploadAppletNode, 'name', this.uploadInputName);
      dojo.subscribe(this.uploadAppletNode.id + "/onUploadFinished", this, 'onUpload');
      if (this.showDeleteNode) {
        this.deleteNode.onSuccess = dojo.hitch(this, 'onDelete');
      }

      // build url
      this.setUploadUrl();
    },

    onOpen: function (evt) {
      dojo.stopEvent(evt);
      
      if (this.onPreview == '') {
        openWindow(this.filePath, '', 'open');
        return false;
      }
      return eval(this.onPreview);
    },

    toggleDoScale:function (evt) {
      this.doScaleImage = !this.doScaleImage;
      this.setUploadUrl();
    },

    onUpload: function (opt) {
      var self = this;

      if (this.onUploaded != '') {
        eval(this.onUploaded);
      }
      if( opt.uploadedFile ){
        var image = opt.uploadedFile.toString();
        if(image) {
          this.displayNode.addImage({image: image}, true);
        }
        if (this.fileInputNode) {
          this.fileInputValue = opt.uploadedObjectFile ? opt.uploadedObjectFile : image;
          this.fileInputNode.value = this.fileInputValue;
          epages.event.fire(this.fileInputNode, 'change');
        }
        var imageInfo = opt.imageInfo ? opt.imageInfo : null;
        if (imageInfo) {
          this.filePath = image;
          this.fileName = imageInfo.FileName;
          this.nameNode.innerHTML = imageInfo.FileName;
          this.nameNode.href = image;
          this.infoNode.innerHTML = epages.localize.formatBytes(imageInfo.Size, 0) + ' (' + imageInfo.Width + ' &times; ' + imageInfo.Height +'px)';
          this.infoNode.style.display = '';
          // update file in deletenode
          if(this.deleteNode) {
            this.deleteNode.filePath=image;
                this.deleteNode.fileName=imageInfo.FileName;
              }
        } else {
          this.fileName = this._getFileName(image);
          this.nameNode.innerHTML = this.fileName;
          // update file in deletenode
          if(this.deleteNode) {
            this.deleteNode.filePath = this._getFilePath(image);
                this.deleteNode.fileName = this.fileName;
              }
        }
        this.nameNode.style.display = '';
        this.infoNode.style.display = '';
        if (this.showDeleteNode) {
          this.deleteNode.domNode.style.display = '';
        }
        if(this.saveAfterUpload){
          // move method call to other thread
          setTimeout(function(){
            self._saveAfterUpload();
          },1);
        }
        if( window.pageCache_SetStatus ){
          pageCache_SetStatus(true);
        }
        dojo.publish(this.id + '/upload');
      }
    },

    onDelete: function() {
      this.nameNode.style.display = 'none';
      this.infoNode.style.display = 'none';
      this.removeImage();
      if (this.fileInputNode) {
        this.fileInputValue = '';
        this.fileInputNode.value = '';
        epages.event.fire(this.fileInputNode, 'change');
      }
      dojo.publish(this.id + '/delete');
    },

    removeImage: function() {
      // summary:
      //    set empty image (hide the current image)
      this.displayNode.addImage({image: epages.vars.IconsRoot + "/general_img_transparentpixel.gif"}, true);
    },

    _getFileName: function(path) {
      return path.split('/').pop();
    },

    _getFilePath: function(path) {
      path = path.split('/').pop();
      return path.join('/');
    },

    _saveAfterUpload: function(){
      //summary: save Attribute direct after Upload
      var json = new epages.io.Json;
      var parameters = {
        'ViewAction': 'JSONViewResponse',
        'ObjectID':   this.objectId,
        'ChangeAction':    this.saveAction
      };
      parameters[this.fileInputName] = this.fileInputValue;
      if(this.saveParameters){
        dojo.mixin(parameters,this.saveParameters);
      }

      json.loadAsync(this.url,
      dojo.hitch(this,function(result){
        if(!result.error){
          this.deleteNode.fileName = this.fileName;

          // if location must be reloaded
          if(this.reloadPage){
            location.href = '?ViewAction='+ep.config.viewAction+'&ObjectID='+ep.config.objectId;
          }
        }

      }),parameters);
    }

  }
);

})(jQuery);

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.FilenameInput"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.FilenameInput"] = true;
dojo.provide("epages.cartridges.de_epages.presentation.widget.FilenameInput");



dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.FilenameInput",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * dojo widget properties
		 */
		widgetsInTemplate  : true,
		templateString     : '',
		templateType       : 'normal',
		defaultTemplateType: 'normal',
		templateString:"<table class=\"InnerGrid FilenameInput\"><tr><td class=\"NoPadding\">\n  <span>${filepath}</span>\n  <label dojoAttachPoint=\"nodeTitle\" class=\"Bold\">${filename}</label>\n  <input type=\"text\" dojoAttachPoint=\"nodeInputTitle\" value=\"${filename}\" class=\"HideElementSoft\"/>\n  <i class=\"Sprite ico_s_pencil LinkImage\" dojoAttachPoint=\"noteEditButton\" title=\"{EditFileName}\"></i>\n  <span>${fileext}</span>\n  <input type=\"hidden\" dojoAttachPoint=\"nodeHiddenName\" name=\"${inputname}\" value=\"${filename}\" />\n  <span dojoAttachPoint=\"nodeInputTitleWidthCalculator\" class=\"HideElementSoft\"></span>\n</td></tr></table>\n",
		translationName    : dojo.moduleUrl('epages.cartridges.de_epages.presentation.widget','templates/translation'),

		/**
		 * private properties
		 */
		_currentValue      : '',

		/**
		 * public properties
		 */
		filepath					 : '',
		filename					 : '',
		fileext						 : '',
		inputname					 : '',
		showAsInput				 : false,
		markAsError				 : false,

		postMixInProperties: function() {
			this.inherited("postMixInProperties", arguments);
			// append slash
			if(this.filepath) {
				this.filepath += '/';
			}
		},

		postCreate: function() {
			// summary: Connect to the file name text / input events.
			// description: Connects to the user events for click, blur and keyup. Adds events for
			//		the file name text and the file name input as well as for the little edit icon.
			this.inherited("postCreate", arguments);
			// use the FormElement widget
			nodeInputTitle = new epages.widget.FormElement({}, this.nodeInputTitle).elementNode;
			// change name events
			this.connect(this.nodeTitle,      'click', '_onClickItem');
			this.connect(this.nodeInputTitle, 'blur', '_onLeaveItem');
			this.connect(this.noteEditButton, 'click', '_onClickImage');
			this.connect(this.nodeInputTitle, 'keyup', '_onKeyUp');
			this.connect(this.nodeInputTitle, 'change', '_adjustInputWidth');

			// show the input field instead of the text from the beginning,
			// i.e. when the template caught an FormError
			if(this.showAsInput) {
				this._onClickItem();
				setTimeout(dojo.hitch(this, function() {
					this._adjustInputWidth();
				}), 1);

			}
			// add dialog error, i.e. when the template caught an FormError
			if(this.markAsError) {
				dojo.addClass(this.nodeInputTitle,"DialogError");
			}
		},

		_onKeyUp: function(evt) {
			// summary: Care for DialogError if error present and Copy input value to hidden input.
			// description: Mark dialog field as erroneous if empty value. Copy the updated input
			//		value to the hidden input field.
			if(!this.nodeInputTitle.value){
				dojo.addClass(this.nodeInputTitle,"DialogError");
			} else {
				dojo.removeClass(this.nodeInputTitle,"DialogError");
				if (evt.keyCode == dojo.keys.ENTER) {this._selectItem()}
			}
			this.nodeHiddenName.value = this.nodeInputTitle.value;
			this._adjustInputWidth();
		},

		_onClickImage: function(evt) {
			// summary: Handler for click event on the small edit pen icon.
			// description: Executes same action as click on the filename text does.
			this._onClickItem();
			dojo.stopEvent(evt);
		},

		_onClickItem: function() {
			// summary: Change the file name text span into an input field.
			// description: Hides the file name text and shows a input field with the filename instead.
			this._currentValue = this.filename;
			this._adjustInputWidth();

			if(!this.markAsError) {
				dojo.removeClass(this.nodeInputTitle,"DialogError");
			}
			dojo.addClass(this.nodeTitle, "HideElementSoft");
			dojo.removeClass(this.nodeInputTitle, "HideElementSoft");
			dojo.removeClass(this.nodeInputTitle.parentNode, "HideElementSoft");
			dojo.addClass(this.noteEditButton, "HideElementSoft");

			this.nodeInputTitle.focus();
			this.nodeInputTitle.select();

			setTimeout(dojo.hitch(this, function() {
				this.nodeInputTitle.removeAttribute("focused");
				this.nodeInputTitle.className += '';
			}), 1);
		},

		_onLeaveItem: function() {
			// summary: Event handler for leaving the file name input field.
			// description: If the input value did nit change, hide the file name input field and show
			//		the file name text again. If the value in the input field has changed, keep the input
			//		field and mark it as changed.
			if(this._currentValue == this.nodeInputTitle.value && !this.markAsError) {
				// nothing changed, so hide the input again
				dojo.addClass(this.nodeInputTitle, "HideElementSoft");
				dojo.removeClass(this.nodeTitle, "HideElementSoft");
				dojo.removeClass(this.noteEditButton, "HideElementSoft");
			}
		},

		_adjustInputWidth: function() {
			// summary: Adjust the width of the input element.
			// description: The input width will be recalculated as the user types in a new value.
			this.nodeInputTitleWidthCalculator.innerHTML = this.nodeInputTitle.value || this._currentValue;
			this.nodeInputTitle.style.width = this.nodeInputTitleWidthCalculator.offsetWidth + 10 + "px";
		}

	}
);

}


/* package: ep_mediagallery.js.uncompressed */
/*
	Copyright (c) 2004-2011, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/

/*
	This is an optimized version of Dojo, built for deployment and not for
	development. To get sources and documentation, please visit:

		http://dojotoolkit.org
*/

if(!dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.GallerySizeUsage"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.GallerySizeUsage"] = true;
/*
	Copyright (c) 2006-2010, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.mediagallery.widget.GallerySizeUsage");



dojo.declare(
	"epages.cartridges.de_epages.mediagallery.widget.GallerySizeUsage",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		maxGallerySize         : 0.0,
		currentGallerySize     : 0.0,
		unitString             : 'MB',
		usageTextClass         : undefined,

		/**
		 * widget properties
		 */
		percentageClass        : 'PercentageNormal',
		templateString:"<p>{MemoryUsage}\n    <span dojoAttachPoint=\"statusBar\" class=\"StatusBar LeftMargin TopSmallMargin AlignLeft\" style=\"width: 70px\" title=\"{TotalMemory}: 0 MB / {UsedMemory}: 0 MB\" >\n      <span class=\"InnerStatusBar\">\n      <span dojoAttachPoint=\"percentageClassNode\" class=\"${percentageClass}\" style=\"width:0%\"></span>\n    </span>\n  </span>\n  <span dojoAttachPoint=\"usageTextPercentage\"></span><span dojoAttachPoint=\"usageText\"></span>\n</p>\n",
		translationName        : dojo.moduleUrl('epages.cartridges.de_epages.mediagallery.widget','templates/translation'),

		postCreate: function() {
			this.inherited("postCreate", arguments);
			dojo.subscribe(this.id+'/updateCurrentBytes', this, 'updateCurrentBytes');
		},

		updateUsage : function(/* Object */ usageData) {
		 // summary: Write gallery usage data to class members and update widget.
			this.maxGallerySize     = parseFloat(usageData.maxGallerySize);
			this.currentGallerySize = parseFloat(usageData.currentGallerySize);
			this._updateWidget();
		},

		updateCurrentBytes : function (/* Integer */ kilobytes) {
		 // summary: Change the current gallery usage and update the widget.
			this.currentGallerySize = parseFloat(kilobytes);
			this._updateWidget();
		},

		_updateWidget : function() {
		 // summary: Compose strings with usage percentage, max gallery size and current gallery size
		 //   and update the widget's template attach points.
			var percentage = 100 * this.currentGallerySize / this.maxGallerySize;
			if(percentage > 100) {
				percentage = 100.0;
			}
			var tmpCurrentSize = this.currentGallerySize;
			var tmpMaxSize = this.maxGallerySize;
			if(tmpCurrentSize > tmpMaxSize) {
				tmpCurrentSize = tmpMaxSize;
			}
			var displayPercentageNoDec = dojo.number.round(percentage, 0).toString() + '%';

			var displayCurrentValue = dojo.number.round(tmpCurrentSize/1024,0).toString();
			var displayMaxValue = dojo.number.round(tmpMaxSize/1024,0).toString();
			var displayFreeMemory = dojo.number.round((tmpMaxSize - tmpCurrentSize)/1024,0).toString();

			if(percentage > 90.0) {
				this.percentageClass = 'PercentageCritical';
			} else if(percentage > 60.0) {
				this.percentageClass = 'PercentageMiddle';
			} else {
				this.percentageClass = 'PercentageNormal';
			}

			dojo.attr(this.percentageClassNode, 'class', this.percentageClass);
			dojo.attr(this.percentageClassNode, 'style', { 'width' : displayPercentageNoDec });

			if(this.usageTextClass != undefined) {
				dojo.removeClass(this.usageText);
				dojo.addClass(this.usageText, this.usageTextClass);
			}
			this.statusBar.title = this.translate('TotalMemory') + ': ' + displayMaxValue + ' ' + this.unitString + ' / ' + this.translate('UsedMemory') + ': ' + displayCurrentValue + ' ' + this.unitString;
			this.usageTextPercentage.innerHTML = displayPercentageNoDec + '&nbsp;';
			this.usageText.innerHTML = this.translate('FreeMemory')+ ': ' + displayFreeMemory + ' ' + this.unitString;
		}

});

}

if(!dojo._hasResource['epages.cartridges.de_epages.mediagallery.widget.Filestore']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.mediagallery.widget.Filestore'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.mediagallery.widget.Filestore

*/
dojo.provide('epages.cartridges.de_epages.mediagallery.widget.Filestore');






dojo.declare(
	'epages.cartridges.de_epages.mediagallery.widget.Filestore',
	[dojo.data.api.Identity],
	{
		/**
		 * public properties
		 */
		actionViewResponse : "JSONViewResponse",
		url                : '?',                  // request url like '/epages/DemoShop.admin/?'
		siteId             : '',                   //objectId of the rode node (start page)
		id                 : 'Filestore',
		validFileTypes     : '',              		 // media gallery option: filter file list to show only files with these extensions
		alleryUsage        : {},                   // hash with gallery size usage data
		/**
		 * private properties
		 */
		_directoryTree    : undefined, // epages.lang.Hash includes server data about directories
		_JsonIo           : undefined, // epages.io.Json includes server connection

		constructor: function(keywordParameters){
			dojo.mixin(this,keywordParameters);
			this._directoryTree = $H();
			this._JsonIo = new epages.io.Json();
		},

		postMixInProperties: function() {
		// summary: initalize values - adjust properites
			this.inherited("postMixInProperties", arguments);
		},

		// loads the file and directory list from the server
		_loadList: function(directoryPath) {
			var info =  this._directoryTree.existsKey(directoryPath) ? this._directoryTree.get(directoryPath) : undefined;
			if (info && ! info.dirty) {
				return true;
			}

			// get data from server
			var JsonData = this._JsonIo.loadSync(
				this.url+'ViewAction=JSONGetDirectoryList&ObjectID='+this.siteId+'&directory='+directoryPath+'&IgnoreDirectoryNotFound=1',
				undefined,
				undefined,
				true
			);
			if (JsonData.data.status === 'DirectoryNotFound') {
				return false;
			}

			if (JsonData.error) {
				JsonData = this._JsonIo.loadSync(
					this.url+'ViewAction=JSONGetDirectoryList&ObjectID='+this.siteId
				);
			}
			// build internal structure
			var aDirectory = directoryPath.split('/');

			this._directoryTree.set(directoryPath, {
				directories : $A(JsonData.data.directories),
				files       : JsonData.data.files,
				title       : aDirectory.pop(),
				parent      : aDirectory.join('/'),
				dirty       : false,
				node        : (info ? info.node : undefined)
			});

			// propagate new gallery size data
			this.galleryUsage = JsonData.data.galleryUsage;
			return true;
		},

		_fetch: function (directory) {
			var directores = this._directoryTree.get(directory).directories;
			var items = [];
			var i;
			$A(directores).each( function(el) {
				items.push({
					title   : el.name,
					isFolder: el.hasSub,
					children: el.hasSub == 1 ? [] : undefined,
					directory: directory + '/' + el.name
				});
			});
			return items;
		},

		_fetchItems: function(keywordArgs, findCallback, errorCallback){
			if(this._loadList(keywordArgs.query.id) && typeof findCallback == 'function') {
				findCallback(this._fetch(keywordArgs.query.id), keywordArgs);
			} else {
				errorCallback(true,keywordArgs);
			}
		},

		getFiles: function(directory){
			if(this._loadList(directory)){
				var files = this._directoryTree.get(directory).files;
				if($A(files).length != 0){
					// list of allowed extensions
					var fileTypeArray = this._convertFileTypeArray(this.validFileTypes);

					$A(files).each(function (el) {
						el.title = el.name;
						el.directory = el.directory;
						el.path = el.path;
						el.canDelete='true';
						el.canChangeTitle='true';
						// toggle as disabled file?
						var isValidExt = false;
						var extension = el.extension.replace(/\W/g, ''); // ".gif" => "gif"
						if(fileTypeArray) {
							for( var j=0,jLength=fileTypeArray.length ; j<jLength ; j++ ) {
								if(extension.match(new RegExp(fileTypeArray[j], "i"))) {
									isValidExt = true;
								}
							}
						} else {
							isValidExt = true; //default case
						}
						if(!isValidExt) {
							el.disabled = true;
						} else {
							el.disabled = false;
						}
					});
					return files;
				}
			}
			return;
		},

		hasAttribute: function(node, attributeName){
			return node[attributeName] !== undefined;
		},

		getLabel: function(item){
			if(item.title !== undefined){
				return item.title;
			}
			return undefined;
		},

		getIdentity: function(item){
			if(item.directory !== undefined){
				return item.directory;
			}
			return undefined;
		},

		getValue: function(item, attribute){
			console.warn('getValue %s', attribute);
		},

		getValues: function(item, attribute){
			if (attribute == 'children' && this._loadList(item.directory)) {
				return this._fetch(item.directory);
			}
			else{
				console.error('getValues() unknown attribute', attribute);
			}
		},

		isItemLoaded: function(something){
			//console.debug('isItemLoaded');
			return true;
		},

		resetCache: function (directory) {
			this._directoryTree.get(directory).dirty = true;
		},

		recursiveResetCache: function (directory) {
			var keys = this._directoryTree.keys();
			var dirDel = directory + '/';
			var dirLen = dirDel.length;
			this._directoryTree.remove(directory);
			for( var i=0,iLength=keys.length ; i<iLength ; i++ ) {
				if (keys[i].substr(0, dirLen) == dirDel) {
					this._directoryTree.remove(keys[i]);
				}
			}
		},

		_send: function (params, opt) {
			if(params.ObjectID  == undefined){
				params.ObjectID = this.siteId;
			}
			var result  = this._JsonIo.loadSync(this.url, params);
			return result;

		},

		renameFile: function (directory,SourceFile,TargetFileName) {
			if(TargetFileName == undefined || TargetFileName == '') {
				return false;
			}

			var JsonData = undefined;
			var cleanSourceFile = this.removeMediaGalleryFromString(SourceFile);

			// nothing changed?
			if(TargetFileName === cleanSourceFile) {
				dojo.publish(this.id+'/onSuccess',[]);
				return TargetFileName;
			}

			JsonData = this._send({
				ChangeAction:   "JSONRenameFile",
				SourceFile:     cleanSourceFile,
				TargetFileName: TargetFileName,
				ViewAction:     this.actionViewResponse
			});
			if(typeof JsonData) {
				if(JsonData.data) {
					// filtered file name
					if(JsonData.data.ResultingFilename) {
						TargetFileName = JsonData.data.ResultingFilename;
					}

					this._directoryTree.get(directory).dirty = true;
					dojo.publish(this.id+'/renamedFile',[SourceFile,TargetFileName,directory]);
					dojo.publish(this.id+'/onSuccess',[]);
					return TargetFileName;
				}
				else {
					// error: target file already exists
					if(JsonData.error.data.Errors) {
						dojo.publish(this.id+'/onError',[{Errors: JsonData.error.data.Errors}]);
						return false;
					}
				}
			}
			else{
				return false;
			}
		},

		deleteFiles: function(selectedNodes,directory) {
			var selectedFiles = []; // Array with Filenames
			for( var i=0,iLength=selectedNodes.length ; i<iLength ; i++ ) {
				if(selectedNodes[i].canDelete){
					selectedFiles.push(this.removeMediaGalleryFromString(selectedNodes[i].path));
				}
			}
			if(selectedFiles.length > 0) {
				var jsonResult = this._send({
					ChangeAction: "JSONDeleteFile",
					File:         selectedFiles,
					ViewAction:   this.actionViewResponse
				});

				if(jsonResult) {
					this.resetDirectory(directory);
					dojo.publish(this.id+'/deleteFiles',[selectedFiles]);
					if(jsonResult.data && jsonResult.data.currentGallerySize) {
						dojo.publish(this.id+'/updateCurrentBytes', [ jsonResult.data.currentGallerySize ] );
					}
					return true;
				}
				else{
					return false;
				}
			}
		},

		getInfo: function (directory) {
			if (this._loadList(directory)){ // make sure that node exists
				return this._directoryTree.get(directory);
			}
			return undefined;
		},

		getNode: function(directory) {
			// also dirty infos contains correct node
			if (this._directoryTree.existsKey(directory)) {
				return this.getInfo(directory);
			}
			return undefined;
		},

		getNodeTitle: function (directory) {
			//return this.getNode(directory).title;
		},

		createDirectory: function (name,parentDirectory) {
			var info = this.getInfo(parentDirectory);
			var JsonData = undefined;
			var targetdirectory = this.removeMediaGalleryFromString(parentDirectory);
			JsonData = this._send({
				TargetDirectory: targetdirectory ? targetdirectory : "",
				ChangeAction:   "JSONCreateDirectory",
				DirectoryName:  name,
				ViewAction:     this.actionViewResponse
			});

			// different name was created?
			if(JsonData) {
				if(JsonData.data) {
					if(JsonData.data.ResultingDirectory) {
						name = JsonData.data.ResultingDirectory;
					}
					if(JsonData.data.currentGallerySize) {
						dojo.publish(this.id+'/updateCurrentBytes', [ JsonData.data.currentGallerySize ] );
					}
				}
				else {
					// error creating
					if(JsonData.error.data.Errors) {
						dojo.publish(this.id+'/onError',[{Errors: JsonData.error.data.Errors}]);
						return false;
					}
				}

				if(!info){
					info = this.getInfo(parentDirectory);
				} else {
					// add new directory to parent
					info.hasSub = true;
					info.directories.push({
						name: name,
						hasSub: 0
					});
				}
				// add new directory to cache + add node
				var directory = parentDirectory + '/' + name;
				this._directoryTree.set(directory, {
					directories : $A(),
					files       : [],
					title       : name,
					parent      : parentDirectory,
					node        : directory.node
				});

				dojo.publish(this.id+'/createDirectory',[directory]);
				return true;
			}
			else{
				return false;
			}
		},

		renameDirectory: function (name,oldName,directory) {
			if(name == undefined || name == ''){
				return false;
			}
			var info = this.getInfo(directory);
			var JsonData = undefined;
			JsonData = this._send({
				SourceDirectory: this.removeMediaGalleryFromString(directory),
				ChangeAction:   "JSONRenameDirectory",
				TargetDirectoryName:  name,
				ViewAction:     this.actionViewResponse
			});
			// different name was used for rename?
			if(typeof JsonData) {

				if(JsonData.data) {
					if(JsonData.data.ResultingDirectory) {
						name = JsonData.data.ResultingDirectory;
					}
				}
				else {
					// error : aleady exists!
					if(JsonData.error.data.Errors) {
						dojo.publish(this.id+'/onError',[{Errors: JsonData.error.data.Errors}]);
						return false;
					}
				}

				this.resetCache(info.parent);
				this.recursiveResetCache(oldName);

				dojo.publish(this.id+'/renameDirectory',[name,directory]);
				return name;
			}
			else{
				return false;
			}
		},

		deleteDirectory: function (directory) {
			var info = this.getInfo(directory);
			var jsonResult = this._send({
				Directory:      this.removeMediaGalleryFromString(directory),
				ChangeAction:   "JSONDeleteDirectory",
				ViewAction:     this.actionViewResponse
			});
			if(jsonResult){
				this.resetCache(info.parent);
				this.recursiveResetCache(directory);
				dojo.publish(this.id+'/deleteDirectory',[directory]);
				if(jsonResult.data && jsonResult.data.currentGallerySize) {
					dojo.publish(this.id+'/updateCurrentBytes', [ jsonResult.data.currentGallerySize ] );
				}
				return true;
			}
			else{
				return false;
			}
		},

		resetDirectory: function (directory) {
			var node = this.getNode(directory);
			this.resetCache(directory);
			this._loadList(directory);
			var info = this.getInfo(directory);
			info.node = node;
		},

		copyImageFromImageDb: function (directory, files) {
			var dir = this.removeMediaGalleryFromString(directory);
			var jsonResult = this._send({
				ChangeAction:     "JSONCopyImageFromImageDb",
				TargetDirectory: dir ? dir : "",
				SourceFile:       files,
				ViewAction:       this.viewAction
			});
			if(jsonResult){
				this.resetDirectory(directory);
				if(jsonResult.data && jsonResult.data.currentGallerySize) {
					dojo.publish(this.id+'/updateCurrentBytes', [ jsonResult.data.currentGallerySize ] );
				}
				return true;
			}
			else{
				return false;
			}
		},

		removeMediaGalleryFromString: function (/* String */ directory) {
		   // summary: removes "MediaGallery" string from given directory path
		   // description: If the given directory contains the string "MediaGallery", it removes
		   // 	the string. In addition a leading path slash (slash or backslash) is removed.
		   // example:
		   //    var jailedDir = removeMediaGalleryFromString('MediaGallery/test/mydir');
		   //		 will return 'test/mydir'.
		   // returns: directory name/path without "MediaGallery" | string
			if(!directory){
				return;
			}

			var str = directory.replace(/^MediaGallery/, '');
			str = str.replace(/^[\\\/]/, '');

			return str; // String
		},

		setFileTypes: function(/* String */ fileTypes) {
		   // summary: updates the list of allowed file extensions
			if(typeof(fileTypes) === "string" && (this.validFileTypes != fileTypes)) {
				this.validFileTypes = fileTypes;
			}
		},

		_convertFileTypeArray: function(/* String */ validFileTypeString) {
		   // summary: converts a string with a ";"-seperated list of file extensions into an array
		   // example:
		   //    var fileTypeArray = this._convertFileTypeArray(this.validFileTypes);
		   // returns: array of file extensions | array of string
			var fileTypeArray;
			if(validFileTypeString) {
				fileTypeArray = validFileTypeString.split(";");
			}
			return fileTypeArray;
		}

});

dojo.extend(epages.cartridges.de_epages.mediagallery.widget.Filestore,dojo.data.util.simpleFetch);

}

if(!dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.Filetree"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.Filetree"] = true;
/*
	Copyright (c) 2006-2009, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.mediagallery.widget.Filetree

*/
dojo.provide("epages.cartridges.de_epages.mediagallery.widget.Filetree");






dojo.declare(
	"epages.cartridges.de_epages.mediagallery.widget.Filetree",
	[dijit.Tree],
	{
		/**
		* public properties
		*/
		listId            : "",
		viewAction        : "JSONViewResponse",
		url               : "?",
		directory         : 'MediaGallery',
		label             : 'Files',
		persist            : false,
		/**
		* private properties
		*/
		_currentDirectory : undefined,
		_lastSelectedNode : undefined,
		/**
		* public methods
		*/
		postCreate  : function() {
			this.inherited("postCreate", arguments);
			this._currentDirectory = this.directory;
			this.rootNode.item.id = this.directory;
			this.rootNode.item.directory = this.directory;
			if (this.listId != "") {
				dojo.subscribe(this.listId + '/rename', this.model.store, 'renameFile');
			}
		},

		_getFileList : function(directory) {
			var files =  this.model.store.getFiles(directory);
			return files;
		},

		onClick: function(item, node){
			if(item && item.children !== undefined){
				this._expandNode(node);
			}
			if(this.lastFocused === undefined){ 
				this.lastFocused = node;
			}
			//check if title of tree was clicked and load files if neccessary
			var directory = undefined;
			if(item && item.root == true){
				var files = this._getFileList(this.directory);
				if(this.listId != ""){
					var filelist = $$(this.listId);
					if(files){
					filelist.setChildren(files);
				}
					else{
						filelist.setChildren([]);
					}
				}
				this._lastSelectedNode = node;
				directory = this.directory;
				this._currentDirectory = this.directory;
			}
			if(item && item.root != true){
				directory = item.directory;
				this.model.store._loadList(directory);
				this._lastSelectedNode = node;
				this._currentDirectory = directory;
				var files = this._getFileList(directory);
				if(this.listId != ""){
					var filelist = $$(this.listId);
					if(files){
						filelist.setChildren(files);
					}
					else{
						filelist.setChildren([]);
					}
				}
			}
			//fix for ie without timeout is can not give focus to element
			window.setTimeout(dojo.hitch(this,this.focusNode,node),10);
			dojo.publish(this.id+'/select',[{node:node, currentDirectory: directory}]);
		},

		getCurrentDirectory: function () {
		// summary: get full path name
			return this._currentDirectory; //String?
		},

		getCurrentDirectoryName: function () {
		// summary: get folder name
		// returns: folder name
			if(this._lastSelectedNode == undefined) {
				return false;
			}
			return this._lastSelectedNode.label; //String?
		},

		getLastSelectedNode: function () {
			return this._lastSelectedNode; //String?
		},

		deleteFiles: function(selectedNodes) {
		// summary: delete specified (or selected) files
			if(selectedNodes === undefined && this.listId){
				selectedNodes = $$(this.listId).selectedNodes();
			}
			if(selectedNodes == undefined || selectedNodes.length == 0){
				console.warn('nothing selected');
				return;
			}
			else{
				if(this.model.store.deleteFiles(selectedNodes,this._currentDirectory) == true){
					this.reloadFiles();
				}
				else{
					console.warn('cant delete files');
				}
			}
		},

		createDirectory: function (name) {
			if(this.model.store.createDirectory(name,this._currentDirectory) == true) {
				if(this._lastSelectedNode.item.children == undefined){
					this._lastSelectedNode.item.children = [];
				}
				this._refreshNode(this._lastSelectedNode);
				return true;
			}
			else {
				return false;
			}
		},

		renameDirectory: function (name) {
			if(this._lastSelectedNode == undefined || this._lastSelectedNode.isTree == true){ 
				return;
			}
			var node = this._lastSelectedNode;
			var oldName = node.item.title;
			var newName = this.model.store.renameDirectory(name,oldName,this._currentDirectory);
			if(newName != false)
			{
				// set node elements
				this.setLabelNode(node,newName);
				node.item.directory = node.item.directory.substr(0,node.item.directory.lastIndexOf("/"))+'/'+newName;
				this._collapseNode(node);

				this.onClick(node.item, node);
				return true;
			}
			else {
				return false;
			}
		},

		deleteDirectory: function (directory) {
			//summary: delete given or current directory
			if(directory == undefined){ 
				directory = this._currentDirectory;
			}
			if(this._lastSelectedNode == undefined || this._lastSelectedNode.isTree == true){ 
				return;
			}
			if(this.model.store.deleteDirectory(directory) == true){
				var node = this._lastSelectedNode;
				parentNode = node.getParent();
				var children = parentNode.item.children;
				for( var i=0,iLength=children.length ; i<iLength ; i++ ){
					var child = children[i];
					if(child.directory == directory){
						var deleteIndex = i;
					}
				}
				children.splice(deleteIndex,1);
				if(parentNode.getChildren().length == 1){
					parentNode.isExpandable = false;
				}
				this._refreshNode(parentNode);
				epages.event.fire(parentNode.domNode,'click');
			}
		},


		selectDirectory: function (directory) {
			var node = this._getNodeByDirectory(directory);
			var item = node.item ? node.item : undefined;
			this.onClick(item, node);
		},

		_getNodeByDirectory: function(directory, parentNode) {
			if (parentNode == undefined){ 
				parentNode = this;
			}
			if(directory == this.directory){ 
				return this;
			}
			var nodesWithChildren = [];
			var children = parentNode.getChildren();
			for( var i=0,iLength=children.length ; i<iLength ; i++ ) {
				var node = children[i];
				if (node.item.directory == directory){
					return node;
				}
				if (node.getChildren() && node.getChildren().length > 0){ 
					nodesWithChildren.push(node);
				}
			}
			for( var i=0,iLength=nodesWithChildren.length ; i<iLength ; i++ ) {
				var node = this._getNodeByDirectory(directory, nodesWithChildren[i]);
				if (node != null){ 
					return node;
				}
			}
			return null;
		},

		openNode:function(directory){
			if (directory === undefined || directory == "") {
				directory = this.directory;
			}
			//convert directory from string to array
			var selectedNodePath = new Array();
			var directories = directory.split("/");
			for( var i=0,l=directories.length ; i<l ; i++ ){
				if(i === 0){
					selectedNodePath[i] = directories[i];
				}
				else{
					selectedNodePath[i] = selectedNodePath[i-1]+'/'+directories[i];
				}
			}
			for( var i=0,iLength=selectedNodePath.length ; i<iLength ; i++ ) {
				var directory = selectedNodePath[i];
				var node = this._getNodeByDirectory(directory);
				if(node == undefined){
					this.model.store._loadList(directory);
					node = this._getNodeByDirectory(directory);
				}
				if(node == undefined){
					window.setTimeout(dojo.hitch(this,this.focusNode,this._lastSelectedNode),10);
					return false;
				}
				if (i == selectedNodePath.length - 1) {
					this._lastSelectedNode = node;
					this._currentDirectory = directory;
					//need timeout for ie
					window.setTimeout(dojo.hitch(this,this.focusNode,node),10);
					dojo.publish(this.id+'/select', [{
							node : node,
							currentDirectory : directory
					}]);
					return true;
				}
				else{
					this._lastSelectedNode = node;
					this._currentDirectory = directory;
					this._expandNode(node);
				}
			}
		},

		reloadFiles: function(){
			var files = this._getFileList(this._currentDirectory);
				if(this.listId != ""){
					var filelist = $$(this.listId);
					if(files){
						filelist.setChildren(files);
					}
					else{
						filelist.destroyDescendants();
					}
				}
		},

		getLabelClass: function(/*dojo.data.Item*/ item){
			// summary: user overridable function to return CSS class name to display label
			//if no return value is set dojo adds a class "undefined" to every label in the tree
			return '';
		},

		focusNode: function(node) {
			this._onNodeFocus(node);
		},
		_onNodeFocus: function(/*dijit._Widget*/ node){
			// summary:
			//		Called when a TreeNode gets focus, either by user clicking
			//		it, or programatically by arrow key handling code.
			// description:
			//		It marks that the current node is the selected one, and the previously
			//		selected node no longer is.

			if(node){
				if(node != this.lastFocused && this.lastFocused && !this.lastFocused._destroyed){
					// mark that the previously selected node is no longer the selected one
					this.blurNode();
					if(this.lastFocused){
						this.lastFocused.setSelected(false);
					}
				}

				// mark that the new node is the currently selected one
				dojo.addClass(node.labelNode,"Selected");
				node.setSelected(true);
				this.lastFocused = node;
			}
		},

		blurNode: function() {
			var node = this.lastFocused;
			if(!node){
				return;
			}
			dojo.removeClass(node.labelNode, "Selected");
			var labelNode = node.labelNode;
			dojo.removeClass(labelNode, "dijitTreeLabelFocused");
			labelNode.setAttribute("tabIndex", "-1");
			this.lastFocused = null;
		},

		_refreshNode: function(/*Object*/ node) {
			// summary: Refreshes the given node in the tree.
			// description: There's also a thread on dojo campus:
			//	http://dojocampus.org/content/2008/06/04/refreshing-a-data-store/.
			// example:
			//	_refreshNode(this._lastSelectedNode);
			if(node.isExpanded == true || node.item.children != undefined){
				this._collapseNode(node);
				node.state = "UNCHECKED";
				node.isExpandable = true;
				node._setExpando(false);
				if(node == this.rootNode){
					this.rootNode.item.children = this.model.store.getValues(this.rootNode.item,'children');
				}
				this._expandNode(node);
			}
			else{
				node.state = "UNCHECKED";
				node.isExpandable = false;
				node._setExpando(false);
			}
		},

	setLabelNode: function(node,label){
		node.labelNode.innerHTML = "";
		node.labelNode.appendChild(dojo.doc.createTextNode(label));
	}
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.Imagedbstore"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.Imagedbstore"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.mediagallery.widget.Imagedbstore

*/
dojo.provide("epages.cartridges.de_epages.mediagallery.widget.Imagedbstore");








dojo.declare(
	"epages.cartridges.de_epages.mediagallery.widget.Imagedbstore",
	[dojo.data.api.Identity], {
		/**
		* public properties
		*/
		id                : 'Imagedbstore',
		basePath          : epages.vars.ImageDbRoot,
		originalPath      : epages.vars.ImageDbRoot + "/original",
		previewPath       : epages.vars.ImageDbRoot + "/thumbnail",
		translationFile   : "content",
		contentFileName   :  "content.xml",

		/**
		* private properties
		*/
		_XmlIo:           undefined,
		_translation:     undefined,
		_keywords:        undefined,

		constructor: function(keywordParameters){
			dojo.mixin(this,keywordParameters);
			this._XmlIo = new epages.io.Xml();
			this._translation = new epages.io.Translation();
			this._keywords = $H();
			if(this.basePath){
				this._translation.loadLocale(this.basePath + '/' + this.translationFile);
			}else{
				console.warn("epages.vars.ImageDbRoot not defined in "+this.declaredClass);
			}
		},

		/**
		 * private methods
		 */
		_getCategories: function(parentNode) {
			var categories = [];
			if (parentNode.childNodes.length > 0) {
				var categoryNodes = epages.html.getChildNodesByTagName(parentNode, "category");
				for( var i=0,iLength=categoryNodes.length ; i<iLength ; i++ ) {
					var categoryNode = categoryNodes[i];
					var keyword = categoryNode.getAttribute("name");
					var children = this._getCategories(categoryNode);
					categories.push({
						title: this._translation.get(keyword),
						objectId: keyword,
						children: children.length >0 ? children : undefined,
						isFolder: children.length > 0 ? 1 : 0
					});
				}
			}
			return categories;
		},

		_getCollections: function(collectionsNode) {
			var collectionNodes = epages.html.getChildNodesByTagName(collectionsNode, "collection");
			for( var i=0,iLength=collectionNodes.length ; i<iLength ; i++ ) {
				var collection = {
					directory: collectionNodes[i].getAttribute("dir"),
					content:   collectionNodes[i].getAttribute("content")
				};
				var keywordNodes = epages.html.getChildNodesByTagName(collectionNodes[i], "keyword");
				for( var j=0,jLength=keywordNodes.length ; j<jLength ; j++ ) {
					var keyword = keywordNodes[j].getAttribute("name");
					var keywordInfo = this._keywords.get(keyword);
					if (keywordInfo === undefined) {
						keywordInfo = {
							'files'      : [],
							'collections': []
						};
						this._keywords.set(keyword, keywordInfo);
					}
					keywordInfo.collections.push(collection);
				}
			}
		},

		_parse: function () {
			var contentXml = this._XmlIo.loadSync(this.basePath + '/' + this.contentFileName);
			if (contentXml === undefined){
				throw new Error('no content found');
			}

			var contentNode = contentXml.getElementsByTagName("content")[0];
			if (contentNode === undefined){
				throw new Error('no content node found');
			}

			var categoriesNode = contentNode.getElementsByTagName("categories")[0];
			if (categoriesNode === undefined){
				throw new Error('no categories node found');
			}

			var collectionsNode = contentNode.getElementsByTagName("collections")[0];
			if (collectionsNode === undefined){
				throw new Error('no collections node found');
			}

			var categories = this._getCategories(categoriesNode);
			this._getCollections(collectionsNode);
			return categories;
		},

		_fetchItems: function(keywordArgs, findCallback, errorCallback){

			if(typeof findCallback == 'function') {
				findCallback(this._parse(), keywordArgs);
			} else {
				consoleerror('error while _fetch');
				errorCallback(keywordArgs);
			}
		},

		hasAttribute: function(node, attributeName){
			//check if node has specified attribute
			return node[attributeName] !== undefined;
		},

		getLabel: function(item){
			if(item.title !== undefined){ 
				return item.title;
			}
			return undefined;
		},

		getIdentity: function(item){
			if(item.objectId !== undefined){ 
				return item.objectId;
			}
			return undefined;
		},

		getValues: function(item, attribute){
				return item[attribute];
		},

		isItemLoaded: function(something){
			return true;
		},
		/**
		* public methods
		*/
		parseFiles: function(keyword) {
			var keywordInfo = this._keywords.get(keyword);
			// keyword has no files, possible main category
			if (keywordInfo === undefined){ 
				return [];
			}

			// load file names
			var keywordCollections = $A(keywordInfo.collections).grep( function () {return true;});
			for( var i=0,iLength=keywordCollections.length ; i<iLength ; i++ ) {
				var collection = keywordCollections[i];
				var filedir = collection.directory;
				var content = collection.content;
				var contentXml = this._XmlIo.loadSync(this.basePath + '/' + content);
				if (contentXml === undefined){
					throw new Error('no content found');
				}

				var keywordNodes = contentXml.getElementsByTagName("keyword");
				if (keywordNodes === undefined){
					throw new Error('no keywords node found');
				}

				for( var i=0,iLength=keywordNodes.length ; i<iLength ; i++ ) {
					var locKeyword = keywordNodes[i].getAttribute("name");
					var locInfo = this._keywords.get(locKeyword);
					var locFiles = locInfo.files;
					locInfo.collections = $A(locInfo.collections).grep(function (el) {
						return el.content != content;
					});
					var fileNodes = epages.html.getChildNodesByTagName(keywordNodes[i], "file");
					for( var j=0,jLength=fileNodes.length ; j<jLength ; j++ ) {
						var fileName = fileNodes[j].firstChild.data;
						if (fileName != "") {
							if (fileName.lastIndexOf(".") == -1) {
								var extension = "?";
							} else {
								var extension = fileName.substring(fileName.lastIndexOf(".") + 1);
							}
							locFiles.push({
								objectId:     (this.originalPath + "/" + collection.directory + "/" + fileName),
								title:         fileName,
								fullpath:     (this.originalPath + "/" + collection.directory + "/" + fileName),
								preview:      (this.previewPath + "/" + collection.directory + "/" + fileName),
								extension:    extension,
								size:         0,
								mimetype:     "",
								imagewidth:   "",
								imageheight:  "",
								modified:     0,
								templateType: 'image'
							});
						}
					}
				}
			}
			return keywordInfo.files;
		},

		getCurrentPath: function(node) {
			var path=node.title;
			while(node.parent.title) {
				node=node.parent;
				path = node.title+'/' + path;
			}
			return path;
		}
	}
);

dojo.extend(epages.cartridges.de_epages.mediagallery.widget.Imagedbstore,dojo.data.util.simpleFetch);

}

if(!dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.Imagedbtree"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.Imagedbtree"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.mediagallery.widget.Imagedbtree

*/
dojo.provide("epages.cartridges.de_epages.mediagallery.widget.Imagedbtree");


dojo.declare(
	"epages.cartridges.de_epages.mediagallery.widget.Imagedbtree",
	[dijit.Tree],
	{
		/**
		* public properties
		*/
		listId            : "",
		label             : 'ImageDB',
		persist            : true,
		/**
		* private properties
		*/
		/**
		* public methods
		*/
		postCreate  : function() {
			this.inherited("postCreate", arguments);
		},

		onClick: function(item, node){
			//check if title of tree was clicked and load files if neccessary
			var filelist = $$(this.listId);
			var directory = this.label;
			if(node && node.isTree == true){
				filelist.destroyDescendants();
			}
			if(item){
				directory = item.title;
				if(this.listId != ""){
					var files = this.store.parseFiles(item.objectId);
					if(files){
						filelist.setChildren(files);
					}
					else{
						filelist.destroyDescendants();
					}
				}
			}
			this.focusNode(node);
			dojo.publish(this.id+'/select',[{node:node, currentDirectory: directory}]);
		},

		focusNode: function(node) {
			this.blurNode();
			try{
				node.labelNode.focus();
			}
			catch(e){
				console.error(e);
			}
			dojo.addClass(node.labelNode,"Selected");
			this.lastFocused = node;
		},

		blurNode: function() {
			var node = this.lastFocused;
			if(!node){
				return;
			}
			dojo.removeClass(node.labelNode, "Selected");
			var labelNode = node.labelNode;
			dojo.removeClass(labelNode, "dijitTreeLabelFocused");
			labelNode.setAttribute("tabIndex", "-1");
			this.lastFocused = null;
		},

		getLabelClass: function(/*dojo.data.Item*/ item){
			// summary: user overridable function to return CSS class name to display label
			//if no return value is set dojo adds a class "undefined" to every label in the tree
			return '';
		}
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.Filelistitem"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.Filelistitem"] = true;
dojo.provide("epages.cartridges.de_epages.mediagallery.widget.Filelistitem");





dojo.declare(
	"epages.cartridges.de_epages.mediagallery.widget.Filelistitem",
	[epages.widget.Elementlistitem],
	{

		/**
		 * public properties
		 */

		preview:             '',
		fullpath:            '',                   // full path including filname
		directory:           '',
		size:                '',
		mimetype:            '',
		extension:           '',
		imagewidth:          '',
		imageheight:         '',
		previewwidth:        '48',
		previewheight:       '48',
		modified:            '',
		canChangeTitle:      'false',
		canDelete:           'false',
		canOpen:             'false',
		name:                "",
		parentId:            "",
		store:               undefined,
		siteId:              epages.vars.SiteID,
		disabled:            false,
		fileName:            '',

		/**
		 * dojo widget properties
		 */
		imagePath:        epages.themeUrl('images'),
		storeImgBase:     epages.vars.StoreRoot+'/BO/icons',

		templateString     : '', // override epages.widget.Elementlistitem default, without scrinksafe
		templateType       : 'normal',
		defaultTemplateType: 'normal',
		templateString:"<div class=\"filelistitem\">\n  <span class=\"filelistitempreview\">\n    <table cellpadding=\"0\" cellspacing=\"0\" width=\"100%\" height=\"100%\"><tr><td>\n    <div style=\"width:${previewwidth}px; height: auto; max-height:${previewheight}px; overflow: hidden; margin: 0 auto\">\n      <img src=\"${preview}\" alt=\"${fileName}\" title=\"${fileName}\" width=\"100%\" />\n    </div>\n    </td></tr></table>\n  </span>\n  <span dojoAttachPoint=\"nodeTitle\" class=\"filelistitemtitle\">${fileName}</span>\n  <span class=\"filelistiteminputtitle\"><input dojoAttachPoint=\"nodeInputTitle\" value=\"\" style=\"display:none;\"/></span>\n  <div class=\"FileInfo\">\n    <div class=\"filelistitemattributes\" dojoAttachPoint=\"nodePixel\">${imagewidth} &times; ${imageheight}</div>\n    <div class=\"filelistitemattributes\" dojoAttachPoint=\"nodeSize\">${size}</div>\n  </div>\n  <div class=\"ActionButtons\" dojoAttachpoint=\"actionButtonsNode\">\n    <a href=\"javascript: void(0);\" onclick=\"return false;\"\n       unselectable=\"on\" style=\"display:none\"\n       dojoAttachPoint=\"downloadNode\" class=\"CommandLinkSmall\"\n       ><span><span class=\"WithIcon Download\">{DownloadFile}</span></span><a href=\"#\" class=\"DownloadLinkOver\" dojoAttachPoint=\"downloadLinkOverNode\" onclick=\"return false;\"></a></a>\n    <br />\n    <a href=\"javascript: void(0);\" onclick=\"return false\" unselectable=\"on\" style=\"display:none\"\n       dojoAttachPoint=\"deleteNode\" class=\"CommandLinkSmall\"\n       ><span><span class=\"WithIcon Delete\">{Delete}</span></span></a>\n  </div>\n</div>\n",
		_templateMapping   : {
			'normal' : {templateString:"<div class=\"filelistitem\">\n  <span class=\"filelistitempreview\">\n    <table cellpadding=\"0\" cellspacing=\"0\" width=\"100%\" height=\"100%\"><tr><td>\n    <div style=\"width:${previewwidth}px; height: auto; max-height:${previewheight}px; overflow: hidden; margin: 0 auto\">\n      <img src=\"${preview}\" alt=\"${fileName}\" title=\"${fileName}\" width=\"100%\" />\n    </div>\n    </td></tr></table>\n  </span>\n  <span dojoAttachPoint=\"nodeTitle\" class=\"filelistitemtitle\">${fileName}</span>\n  <span class=\"filelistiteminputtitle\"><input dojoAttachPoint=\"nodeInputTitle\" value=\"\" style=\"display:none;\"/></span>\n  <div class=\"FileInfo\">\n    <div class=\"filelistitemattributes\" dojoAttachPoint=\"nodePixel\">${imagewidth} &times; ${imageheight}</div>\n    <div class=\"filelistitemattributes\" dojoAttachPoint=\"nodeSize\">${size}</div>\n  </div>\n  <div class=\"ActionButtons\" dojoAttachpoint=\"actionButtonsNode\">\n    <a href=\"javascript: void(0);\" onclick=\"return false;\"\n       unselectable=\"on\" style=\"display:none\"\n       dojoAttachPoint=\"downloadNode\" class=\"CommandLinkSmall\"\n       ><span><span class=\"WithIcon Download\">{DownloadFile}</span></span><a href=\"#\" class=\"DownloadLinkOver\" dojoAttachPoint=\"downloadLinkOverNode\" onclick=\"return false;\"></a></a>\n    <br />\n    <a href=\"javascript: void(0);\" onclick=\"return false\" unselectable=\"on\" style=\"display:none\"\n       dojoAttachPoint=\"deleteNode\" class=\"CommandLinkSmall\"\n       ><span><span class=\"WithIcon Delete\">{Delete}</span></span></a>\n  </div>\n</div>\n"},
			'image'  : {templateString:"<div class=\"filelistitemImage\">\n  <table cellpadding=\"0\" cellspacing=\"0\" width=\"100%\" height=\"100%\"><tr><td>\n    <img src=\"${preview}\" alt=\"${fileName}\" title=\"${fileName}\" />\n  </td></tr></table>\n</div>\n"}
		},
		translationName  : dojo.moduleUrl('epages.cartridges.de_epages.mediagallery.widget','templates/translation'),
		widgetsInTemplate : true,

		postMixInProperties: function() {
			this._templateDirectory = dojo.moduleUrl('epages.cartridges.de_epages.mediagallery.widget' , 'templates');
			this.inherited("postMixInProperties", arguments);
			this.fileName = this.title;
			this.title = '';

			if(this.size != '') {
				this.size = epages.localize.formatBytes(this.size, 1);
			}
			// define preview
			if (this.preview == '') {
				this.preview = this.imagePath + '/ico_xl_file_unknown.png';
			}
			else if(this.imagewidth != '' && this.imageheight != '') {
				var ratio = parseInt(this.imagewidth, 10) / parseInt(this.imageheight, 10);
				var previewwidth  = this.previewwidth  != '' ? parseInt(this.previewwidth , 10) : undefined;
				var previewheight = this.previewheight != '' ? parseInt(this.previewheight, 10) : undefined;
				if (previewwidth === undefined && previewheight === undefined){
					previewwidth = parseInt(this.prototype.previewwidth);
				}
				if (previewheight === undefined){
					previewheight = previewwidth;
				}
				if (previewwidth  === undefined){
					previewwidth  = previewheight;
				}

				var calc_previewheight = Math.round(previewwidth / ratio);
				var calc_previewwidth  = Math.round(previewheight * ratio);

				if (previewheight < calc_previewheight){
					previewwidth  = calc_previewwidth;
				}
				if (previewwidth < calc_previewwidth){
					previewheight = calc_previewheight;
				}

				this.previewwidth  = previewwidth;
				this.previewheight = previewheight;
			}

			if(!this.disabled) {
				this.canChangeTitle = this.canChangeTitle == 'true' || this.canChangeTitle == '1' ? true : false;
				this.canDelete = this.canDelete == 'true' || this.canDelete == '1' ? true : false;
				this.canOpen = this.canOpen == 'true' || this.canOpen == '1' ? true : false;
			}

			var extension=this.extension.toLowerCase().replace(/^\./,"");
			if(extension == 'jpg' || extension == 'gif' || extension == 'png' || extension == 'bmp' ||
				 extension == 'tif' || extension == 'ico' || extension == 'swf' || extension == 'pdf' ||
				 extension == 'htm' || extension == 'html'|| extension == 'css' || extension == 'txt'){
				this.canOpen=true;
			}

			if(!epages.vars.BaseUrl) {
				console.warn("epages.vars.BaseUrl not defined in "+this.declaredClass);
			}
		},

		pathFromSite: function() {
			if(epages.vars.SiteRoot!== undefined) {
				return this.fullpath.replace(epages.vars.SiteRoot+"/", "");
			} else {
				return null;
			}
		},

		postCreate: function() {
			this.inherited("postCreate", arguments);

			if (this.nodePixel !== undefined && (this.imagewidth == '' || this.imagewidth == null)){
				this.nodePixel.style.display = 'none';
			}
			if (this.nodeSize !== undefined && (this.size == '' || this.size == null)){
				this.nodeSize.style.display = 'none';
			}

			if(! this.disabled) {
				if (this.canChangeTitle) {
					this.connect(this.domNode,        'ondblclick', '_selectTitle');
					this.connect(this.nodeTitle,      'onclick', '_selectTitle');
					this.connect(this.nodeInputTitle, 'onchange', '_changeTitle');
					this.connect(this.nodeInputTitle, 'onkeydown', '_onKeyDown');
					this.connect(this.nodeInputTitle, 'onkeyup', '_onKeyUp');
					this.connect(this.nodeInputTitle, 'onblur', '_selectItem');
				}
			} else {
				this.domNode.removeChild(this.actionButtonsNode);
				dojo.addClass(this.domNode, "Disabled ToolTipCursor");
				// hide alt+title image tags
				//  this.nodeImage.removeAttribute('alt');
				//  this.nodeImage.removeAttribute('title');
				// show info tooltop
				
				var toolTipNode = document.createElement('tt');
				var toolTipText = document.createElement('div');
				toolTipText.innerHTML = '<strong>'+this.translate('UnsupportedFileFormat')+'</strong>';
				toolTipNode.appendChild(toolTipText);
				this.domNode.appendChild(toolTipNode);

				var toolTipWidget = new epages.widget.Tooltip({
     			tooltipArea: this.domNode,
     			interactive: true,
     			forceOrientation: 'B',
     			'class' : 'Wide'
    		}, toolTipNode);
			}
		},

		_selectTitle: function(){
			this.nodeTitle.style.display="none";
			this.nodeInputTitle.style.display="block";
			this.nodeInputTitle.value = this.nodeTitle.firstChild.nodeValue;
			this.nodeInputTitle.focus();
		},

		_changeTitle: function(){
			var me = this;
			if(this.store){
				if(this.nodeInputTitle.value != ''){
					var newName = this.store.renameFile(this.directory,this.path,this.nodeInputTitle.value);
					if(newName != false) {
						this.nodeTitle.firstChild.nodeValue = newName;
						this.path = this.path.replace((new RegExp(dojo.regexp.escapeString(this.name) + '$')),newName);
						this.fullpath = this.fullpath.replace((new RegExp(dojo.regexp.escapeString(this.name) + '$')),newName);
						this.name = newName;
						// remove error class
						dojo.removeClass(this.nodeInputTitle,"DialogError");
						dojo.removeClass(this.nodeTitle,"DialogError");
						// toggle to text label
						this._selectItem();
						//this.nodeInputTitle.style.display="none";
						//this.nodeTitle.style.display="block";
					} else {
						// error case, fill the string the user entered back into the input
						this.nodeTitle.firstChild.nodeValue = this.nodeInputTitle.value;
						// add error class
						dojo.addClass(this.nodeInputTitle,"DialogError");
						dojo.addClass(this.nodeTitle,"DialogError");
						// toggle to edit box
						this._selectTitle();
					}
				}
			}
		},

		_selectItem: function(){
			this.nodeInputTitle.style.display="none";
			this.nodeTitle.style.display="block";
		},

		_onKeyDown: function(evt) {
			// on enter switch title input with title span, like blur
			if(this.nodeInputTitle.value == '') {
				dojo.addClass(this.nodeInputTitle,"DialogError");
			}else{
				this._updateNodeInputTitle();
				if (evt.keyCode == 13) {
					this._selectItem();
				}
			}
		},

		_onKeyUp: function(evt) {
			this._updateNodeInputTitle();
		},

		_onDownload: function () {
			var TargetFile = this.store.removeMediaGalleryFromString(this.path);
			window.open(epages.vars.BaseUrl+'?ObjectID='+this.siteId+'&ViewAction=View&ChangeAction=ActionDownloadFile&File='+TargetFile,'Download');
		},

		_updateNodeInputTitle: function() {
			if(epages.Browser.engine === "MSIE") {
				this.nodeInputTitle.className += "";
			}
		}
	}
);

}

if(!dojo._hasResource["epages.widget.Dialog"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Dialog"] = true;
/*
Copyright (c) 2006-2007, ePages GmbH
All Rights Reserved.
*/
dojo.provide("epages.widget.Dialog");



dojo.declare(
"epages.widget.Dialog",
	[dijit.Dialog], {
		duration: epages.Browser.engine=="MSIE" ? 10 : 150,

		templateString:
			'<div class="dijitDialog ModalDialog" tabindex="-1">' +
					'<div dojoAttachPoint="titleBar" class="dijitDialogTitleBar" waiRole="dialog">' +
						'<span dojoAttachPoint="titleNode" class="dijitDialogTitle">${title}</span>' +
						'<span dojoAttachPoint="closeButtonNode" class="dijitDialogCloseIcon"  dojoAttachEvent="onclick: onCancel">' +
							'<span dojoAttachPoint="closeText" class="closeText">x</span>' +
						'</span>' +
					'</div>' +
					'<div class="LayerContent Border White">' +
						'<div dojoAttachPoint="containerNode" class="dijitDialogPaneContent"></div>' +
						'<div dojoAttachPoint="innerButtonBarNode" class="LayerInnerButtonBar" style="display:none"></div>' +
					'</div>' +
					'<div dojoAttachPoint="buttonBarNode" class="LayerButtonBar" style="display:none"></div>' +
			'</div>',


		postCreate: function() {
			this.inherited("postCreate",arguments);

			// hack to overlay applets
			if(epages.Browser.engine=="MSIE") {
				this.underlayIframe = document.createElement("iframe");
				this.underlayIframe.className="LayerIframe";
				this.underlayIframe.frameBorder="0";
				this.underlayIframe.src = "javascript:''";
			}
		},

		hide: function() {
			this.inherited("hide", arguments);
			if(epages.Browser.engine=="MSIE") {	// layer display corrections
				this.domNode.style.width="auto";
			}
		},

		show: function() {
			this.inherited("show", arguments);
			if(epages.Browser.engine=="MSIE") {	// layer display corrections
				this.domNode.style.width=this.domNode.offsetWidth+"px";
				this.domNode.style.overflow='hidden';
			}
			if(this.domNode && epages.zIndex){
				this.domNode.style.zIndex = epages.zIndex;
			}
			if(this._underlay){
				this._underlay.domNode.style.zIndex = this.domNode.style.zIndex-1;
			}
			if(epages.zIndex){
				epages.zIndex+=2;
			}
			//check if there is enough space to see the close button
			var popupTop = parseInt(this.domNode.style.top);
			var popupLeft = parseInt(this.domNode.style.left);
			if(popupTop < 0){
				this.domNode.style.top = "0px";
			}
			if(popupLeft < 0){
				this.domNode.style.left = "";
				this.domNode.style.right = "0px";
			}
			else {
				this.domNode.style.right = "";
			}
			//remove dragging
			if(this._moveable){
				this._moveable.destroy();
			}
		},

		_setup: function() {
			this.inherited("_setup", arguments);
			if(this._underlay){
				if(epages.Browser.engine=="MSIE") {
					this._underlay.node.appendChild(this.underlayIframe);
				} else {
					this._underlay.domNode.style.overflow= "auto"; // hack to overlay applets in ff
				}
			}
		}
	}
);



}

if(!dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.Filebrowser"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.Filebrowser"] = true;
dojo.provide("epages.cartridges.de_epages.mediagallery.widget.Filebrowser");


epages.require('ep_shop_tree', 'epages.cartridges.de_epages.mediagallery.widget.Imagedbtree');









epages.require('ep_shop_upload', 'epages.uploader');

(function(jq){

	var jqUploaderReady = !1,
		jqUploaderCreate = function( self, data, exists, callback ){
			de_epages(self.uploadNode)
				.presentationUiUploader({
					data:		data,
					exists:		exists,
					big:		true,
					multiple:	true,
					callback:	callback
				});
		};

	dojo.declare (
		"epages.cartridges.de_epages.mediagallery.widget.Filebrowser",
		[epages.widget.LocalizedWidget],
		{
			/**
			 * public properties
			 */
			siteId          : epages.vars.SiteID,		// Integer - epages SiteID
			url             : '?',						// String - request url
			directory       : 'MediaGallery',			// String - base directory
			multiSelect     : 'true',					// String - multi item selection on or off
			validFileTypes  : '',						// String - show only files with these extensions
			imageDB         : epages.vars.ImageDbRoot,	// String - url to image database
			cssClass        : '',						// String - additional css classes
			opener          : '',						// String - define from where it was opend, is passed to the plugins

			multiSelectString   : "", 					// String - save multiSelect as string ("true" or "false")
			_fileStore          : undefined,			// Object - reference to file store
			_eventHandles       : undefined,			// Object[]- save event connects temporary for oneLineValueNode in this array
			_plugins            : {},					// save loaded plugins and depending nodes
			_visibleLeftBar     : undefined,
			_visibleContent     : undefined,
			_currentActivePlugin: undefined,

			galleryUsage        : {},               // hash with gallery size usage data

			/**
			 * dojo widget properties
			 */

			templateString:"<div class=\"Filebrowser ${cssClass}\">\n  <table class=\"FormGrid\" style=\"width:auto\"><tr>\n  <td class=\"LeftBar\" >\n    <div class=\"Container\" dojoAttachPoint=\"LeftBarContainerNode\">\n      <div class=\"FileTree\">\n        <div dojotype=\"epages.cartridges.de_epages.mediagallery.widget.Filestore\"\n          dojoAttachPoint=\"fileStoreWidget\"\n          jsId=\"${id}Filestore\"\n          url=\"${url}\"\n          id=\"${id}Filestore\"\n          validFileTypes=\"${validFileTypes}\"\n          siteId=\"${siteId}\"></div>\n        <div dojoType=\"dijit.tree.ForestStoreModel\" jsId=\"${id}Filemodel\"\n            store=\"${id}Filestore\" query=\"{id:'${directory}'}\"\n            rootLabel=\"{MediaGallery}\" childrenAttrs=\"children\"></div>\n        <div dojoType=\"epages.cartridges.de_epages.mediagallery.widget.Filetree\"\n             dojoAttachPoint=\"fileTreeWidget\"\n             label=\"{MediaGallery}\"\n             id=\"${id}Filetree\"\n             model=\"${id}Filemodel\"\n             listId=\"${id}Filelist\"\n             directory=\"${directory}\"\n             query=\"{id:'${directory}'}\"\n             ></div>\n        <div dojoAttachPoint=\"PluginLinksNode\">\n          <div dojoAttachPoint=\"selectImageDbNode\" style=\"cursor:pointer;\"><i class=\"Sprite object_ico_s_imagegallery\"></i>{ImageDb}</div>\n        </div>\n      </div>\n      <div class=\"Actions\">\n        <div class=\"Body\">\n          <div>\n            <div class=\"DoActionLink EnableHover\" dojoAttachPoint=\"newFolderButtonNode\" style=\"display:none\">{NewFolder}</div>\n            <div class=\"DoActionLink EnableHover\" dojoAttachPoint=\"renameFolderButtonNode\" style=\"display:none\">{RenameFolder}</div>\n            <div class=\"DoActionLink EnableHover\" dojoAttachPoint=\"deleteFolderButtonNode\" style=\"display:none\">{DeleteFolder}</div>\n          </div>\n\n          <div dojoAttachPoint=\"oneLineFormNode\" style=\"display:none;padding-top:1px;\" class=\"OnLineFormNode\">\n            <div dojoAttachPoint=\"oneLineTextNode\"></div>\n            <div style=\"height:25px; position: relative\">\n              <input class=\"BottomMargin\" dojoAttachPoint=\"oneLineValueNode\"  type=\"text\"   name=\"value\"  value=\"\" />\n            </div>\n            <span class=\"Button FloatLeft RightMargin\" dojoAttachPoint=\"oneLineSaveNode\"><span class=\"ButtonContainer\">{Save}</span></span>\n            <span class=\"Button FloatLeft\" dojoAttachPoint=\"oneLineCancelNode\"          ><span class=\"ButtonContainer\">{Cancel}</span></span>\n          </div>\n        </div>\n      </div>\n      <div class=\"ImageDb\" dojoAttachPoint=\"imageDbAreaNode\">\n        <div dojoAttachPoint=\"selectMediagalleryNode\" style=\"cursor:pointer;\"><i class=\"Sprite ico_s_folder\"></i>{MediaGallery}</div>\n        <div dojotype=\"epages.cartridges.de_epages.mediagallery.widget.Imagedbstore\"\n          jsId=\"${id}Imagedbstore\"\n          id=\"${id}Imagedbstore\"\n          ></div>\n        <div dojotype=\"epages.cartridges.de_epages.mediagallery.widget.Imagedbtree\"\n          dojoAttachPoint=\"imagedbTreeWidget\"\n          id=\"${id}Imagedbtree\"\n          store=\"${id}Imagedbstore\"\n          label=\"{ImageDb}\"\n          listId=\"${id}Filelist\"\n          ></div>\n      </div>\n\n  </td>\n  <td class=\"MainBar\">\n    <div class=\"Container\" dojoAttachPoint=\"ContentNode\">\n      <div class=\"FileList\">\n        <div dojoAttachPoint=\"currentDirectoryNode\" class=\"CurrentDirectory\">{MediaGallery}</div>\n        <div dojoType=\"epages.widget.Elementlist\"\n          dojoAttachPoint=\"fileListWidget\"\n          id=\"${id}Filelist\"\n          store=\"${id}Filestore\"\n          widgetElementType=\"epages.cartridges.de_epages.mediagallery.widget.Filelistitem\"\n          multiSelect=\"${multiSelectString}\"\n          pagging=\"true\"\n          ></div>\n        <div class=\"ClearBoth\"></div>\n        <div dojoAttachPoint=\"MultiselectTipNode\" style=\"padding: 6px; display:none\"><div class=\"DialogMessageSmall MessageTip\">{MultiSelect}</div></div>\n      </div>\n      <div class=\"ActionsBar Upload\">\n        <div class=\"Body\">\n          <input type=\"file\" size=\"1\" class=\"NoButtonTrigger\" dojoAttachpoint=\"uploadNode\" id=\"${id}Upload\"/>\n            <a class=\"CommandLinkSmall LeftMargin\" dojoAttachPoint=\"deleteFilesNode\" unselectable=\"on\"\n               onclick=\"return false\" href=\"javascript: void(0);\"\n               ><span><span class=\"WithIcon Delete\">{DeleteFiles}</span></span></a>\n            <span dojoAttachPoint=\"imageDbActionsNode\" style=\"display:none; padding: 6px 0;\">\n              <span><span class=\"Button Active EnableHover\" dojoAttachPoint=\"copyDBImagesNode\"  ><span class=\"ButtonContainer\" dojoAttachPoint=\"copyDBImagesLabelNode\" >{CopyImages}</span></span></span>\n              <span class=\"CopyToTargetInfo\" style=\"display:inline\"><span style=\"display:block; display: inline-block\">({CopyToTarget}: <span dojoAttachPoint=\"copyToTargetNode\">{MediaGallery}</span>)</span></span>\n            </span>\n          </div>\n        </div>\n      </div>\n    </div>\n  </td></tr>\n  </table>\n</div>\n",
			translationName  : dojo.moduleUrl('epages.cartridges.de_epages.mediagallery.widget','templates/translation'),
			widgetsInTemplate:true,

			/**
			 * widget life cycle
			 */

			postMixInProperties: function() {
			// summary: initalize values - adjust properites
				this.inherited("postMixInProperties", arguments);
				this.multiSelect = epages.string.toBoolean(this.multiSelect);
				this.multiSelectString = this.multiSelect ? "true" : "false";
			},

			setFileTypes: function(/* String */ fileTypes) {
				if(typeof(fileTypes) === "string" && (this.validFileTypes != fileTypes)) {
					this.validFileTypes = fileTypes;
					this._fileStore.setFileTypes(this.validFileTypes);
					this.fileTreeWidget.reloadFiles();
				}
			},

			postCreate: function() {
			// summary: initalize widget - append events, adjust properites
				this.inherited("postCreate", arguments);

				this._appendEvents();

				this._fileStore = (eval(this.id+'Filestore'));
				this._eventHandles = [];

				// gallery usage updater
				this.galleryUsage = this._fileStore.galleryUsage;

				// action event for upload button
				this._changeUploader();

				//register and build plugin connections
				this._registerPlugins();

				//### DEBUG ###

				//### DEBUG ###
			},

			startup: function() {
			// summary: load files of base folder
				this.inherited("startup", arguments);
				this.openRootFolder();
			},

			_appendEvents: function() {
			// summary: register events and subscriptions

				// register events
				this.connect(this.newFolderButtonNode, 'onclick', '_OnNewFolder');
				this.connect(this.renameFolderButtonNode, 'onclick', '_OnRenameFolder');
				this.connect(this.deleteFolderButtonNode, 'onclick', '_OnDeleteFolder');
				this.connect(this.deleteFilesNode, 'onclick', '_OnDeleteFiles');
				this.connect(this.copyDBImagesNode, 'onclick', '_OnCopyFilesFromDB');
				this.connect(this.oneLineValueNode,'onchange', '_removeDialogErrorLineValueNode');
				this.connect(this.oneLineValueNode,'onkeyup', '_removeDialogErrorLineValueNode');
				this.connect(this.selectImageDbNode,'onclick', '_showImageDb');
				this.connect(this.selectMediagalleryNode,'onclick', '_showMediagallery');


				// subscriptions
				dojo.subscribe(this.uploadNode.id + '/onUploadFinished', this, '_OnUploadFinish');	// upload finished
				dojo.subscribe(this.fileTreeWidget.id + '/select', this, '_OnSelectFileTree');				// directory selected
				dojo.subscribe(this.imagedbTreeWidget.id + '/select', this, '_OnSelectDB');						// imagedb directory selected
				dojo.subscribe(this.fileListWidget.id + '/select', this, '_OnSelectFileList');				// file in file list selected
				dojo.subscribe(this.id + 'Filelist/afterSetChildren', this, "_onFileListCreated");		// items in filelist ready
				dojo.subscribe(this.fileListWidget.store.id + '/onError', this, '_OnError');					// error in file store
				dojo.subscribe(this.fileListWidget.store.id + '/onSuccess', this, '_OnSuccess');			// fixed error in file store

				dojo.subscribe(this.fileListWidget.store.id + '/updateCurrentBytes', this, function(kilobytes) {
					dojo.publish(this.id+'/updateCurrentBytes', [kilobytes]);
				});

				dojo.subscribe('Filebrowser/showMediagallery',this,'showMediagallery');
				dojo.subscribe('Filebrowser/showMediagalleryContent',this,'showMediagalleryContent');
				dojo.subscribe('Filebrowser/showMediagalleryLeftBox',this,'showMediagalleryLeftBox');
			},

			/**
			 * getter, setter and other public functions
			 */

			openRootFolder: function() {
			// summary: simulate click on root node
				this.fileTreeWidget.onClick(this.fileTreeWidget.rootNode.item, this.fileTreeWidget.rootNode);
			},

			getSelectedItems : function() {
			// summary: get selected items
			// returns: selected items of file list
				return $$(this.id + 'Filelist').selectedNodes();
			},

			/**
			 * events and subscriptions
			 */

			_onFileListCreated: function(/* object */ opt) {
			// summary: attach button events to file items
			// opt: { source: this, length: elements.length }

				for( var i=0,iLength=opt.length ; i<iLength ; i++ ) {
					var curChild = opt.source.children[i];

					// attach delete button event
					if(curChild.canDelete && curChild.deleteNode) {
						this.connect(curChild.deleteNode, "onclick", "_OnDeleteFilesInline");
						curChild.deleteNode.style.display="";
					}

					// attach download button event
					if(curChild.downloadNode) {
						dojo.connect(curChild.downloadNode, "onmouseup", curChild, "_onDownload");

						curChild.downloadNode.style.display="";
						curChild.downloadNode.href=curChild.fullpath;
						curChild.downloadNode.onclick=function() {
							return false;
						};
					}
				}
			},

			_removeDialogErrorLineValueNode: function(){
			// summary: event function (keyup change, oneLineValueNode) -remove css error class and error message from onLineValueNode
				dojo.publish("uimessage/hide");
				dojo.removeClass(this.oneLineValueNode,'DialogError');
			},

			/**
			* widget button/ display functions
			*/

			_replaceDirectoryName: function(/* string */ directoryName) {
			// summary: replaces "MediaGallery" and "ImageDb" with translations
				if(directoryName) {
					directoryName=directoryName.replace(/^MediaGallery/, this.translate("MediaGallery"));
					directoryName=directoryName.replace(/^ImageDb/, this.translate("ImageDb"));
				}
				return directoryName;
			},

			_setCurrentDirectory: function(/* object */ opt) {
			// summary: updates the currentDirectoryNode (insert current directory)
				var directoryName = this._replaceDirectoryName(opt.currentDirectory);
				if(directoryName){
					this.currentDirectoryNode.firstChild.data = directoryName;
				}
				else{
					this.currentDirectoryNode.firstChild.data = this.translate("MediaGallery");
				}
			},

			_showImageDb: function() {
				dojo.fx.slideTo({ node: this.imageDbAreaNode, left:"0", top:"0", unit:"px" }).play();
				this._visibleLeftBar = this.imageDbAreaNode;
				this._currentActivePlugin = 'ImageDB';
			},

			_showMediagallery: function() {
				if(this._currentActivePlugin){
					this._currentActivePlugin = undefined;
				}
				if(this._visibleLeftBar){
					dojo.fx.slideTo({ node: this._visibleLeftBar, left:"-230", top:"0", unit:"px" }).play();
				}
				this.openRootFolder();
			},
			_showMediagalleryContent: function(){
				if(this._currentActivePlugin){
					this._currentActivePlugin = undefined;
				}
				if(this._visibleContent){
					dojo.fx.slideTo({ node: this._visibleContent, left:"680", top:"0", unit:"px" }).play();
				}
			},

			showMediagallery: function(){
				this._showMediagallery();
				this._showMediagalleryContent();
			},

			showMediagalleryLeftBox: function(){
				this._showMediagallery();
			},

			showMediagalleryContent: function(){
				this._showMediagalleryContent();
			},

			changeOpener: function(opener){
				this.opener = opener;
				dojo.publish('Filebrowser/changeOpener',[opener]);
			},

			_selectFileByName: function(fileName){
				var selectedFile;
				var fileListChildren = this.fileListWidget.children;
				for (var i = 0, l = fileListChildren.length; i < l; i++) {
					if (fileListChildren[i].name == fileName){
						selectedFile = fileListChildren[i];
						break;
					}
				}
				this.fileListWidget.select(selectedFile);
			},

			/**
			* file / folder operations
			*/

			/*  --- NEW FOLDER --- */
			_OnCancelSingleDialog: function (/* event */ evt) {
			// summary: reset function of oneLineValueNode
			// description: resets value, hides the node and removes all connected events
				this.oneLineFormNode.style.display="none";
				this.oneLineValueNode.value="";
				this.newFolderButtonNode.parentNode.style.display="";
				for( var i=0,iLength=this._eventHandles.length ; i<iLength ; i++ ){
					dojo.disconnect(this._eventHandles[i]);
				}
				this._eventHandles = [];
			},

			_OnSaveNewFolder: function(/* event */ evt) {
			// summary: creates a new directory
				if(this.oneLineValueNode.value == ''){
					this._showErrorBubble(this.translate('InsertNewFolderName'));
				} else {
					if(this.fileTreeWidget.createDirectory(this.oneLineValueNode.value) == true) {
						// show buttons, close dialog
						this._OnCancelSingleDialog(evt);
					}
				}
			},

			_OnNewFolderKeyUp: function(/* event */ evt) {
			// summary: event function (keyup, oneLineFormNode) - trigger save function if enter key was pressed
				if(evt.keyCode == 13) {		// enter pressed
					this._OnSaveNewFolder(evt);
				}
			},

			_OnNewFolder: function(/* event */ evt) {
			// summary: event function (onclick, newFolderButtonNode) - initalize elements of "oneLineForm" (form to create a new folder)
				var directory = this.fileTreeWidget.getCurrentDirectory();
				if (directory === undefined) {
					console.warn('_OnNewFolder() -> directory undefined in '+this.declaredClass);
				} else {
					this.newFolderButtonNode.parentNode.style.display="none";
					this.oneLineFormNode.style.display="";
					this.oneLineTextNode.innerHTML=this.translate('NewFolder');
					this.oneLineValueNode.focus();
					this._eventHandles.push(dojo.connect(this.oneLineFormNode,   'onkeyup', this, '_OnNewFolderKeyUp'));
					this._eventHandles.push(dojo.connect(this.oneLineSaveNode,   'onclick', this, '_OnSaveNewFolder'));
					this._eventHandles.push(dojo.connect(this.oneLineCancelNode, 'onclick', this, '_OnCancelSingleDialog'));
				}
			},

			/*  --- DELETE FOLDER --- */
			_OnDeleteFolder: function (/* event */ evt) {
			// summary: event function (click, deleteFolderButtonNode) - delete current directory
				var directory = this.fileTreeWidget.getCurrentDirectory();
				if (directory === undefined) {
					console.warn('_OnDeleteFolder() -> directory undefined in '+this.declaredClass);
				} else {
					var folderName = this.fileTreeWidget.getCurrentDirectoryName();
					// show confirmation message
					
					dojo.publish("uimessage/show", [
						this.translate("HeadLineDeleteFolder"),
						this.translate("DeleteFolderAndSubFolder")+" <br />"+this.translate("SelectedFolder") + ': ' + folderName, 'Dialog', {
							titleBar:  this.translate("DeleteFolder"),
							sizeClass: 'Large',
							typeClass: 'Confirmation',
							onYes:     dojo.hitch(this, function() {
								this.fileTreeWidget.deleteDirectory(directory);
							})
						}]);
				}
			},

			/*  --- RENAME FOLDER --- */
			_OnSaveRenameFolder: function (/* event */ evt) {
			// summary: event function (click, renameFolderButtonNode) - rename current directory
				// save
				if(this.fileTreeWidget.renameDirectory(this.oneLineValueNode.value) == true) {
					// show buttons, close dialog
					this._OnCancelSingleDialog(evt);
				}
			},

			_OnRenameFolderKeyUp: function(/* event */ evt) {
			// summary: event function (keyup, oneLineFormNode) - trigger save function if enter key was pressed
				if(evt.keyCode == 13) {
					this._OnSaveRenameFolder(evt);
				}
			},

			_OnRenameFolder: function (/* event */ evt) {
			// summary: event function (click, renameFolderButtonNode) - initalize elements of "oneLineForm" (form to rename current folder)
				var directory = this.fileTreeWidget.getCurrentDirectory();
				if (directory === undefined) {
					console.warn('_OnRenameFolder() -> directory undefined in '+this.declaredClass);
				} else {
					var node = this.fileTreeWidget.getLastSelectedNode();
					this.newFolderButtonNode.parentNode.style.display="none";
					this.oneLineFormNode.style.display="";
					this.oneLineTextNode.innerHTML=this.translate('RenameFolder');
					this.oneLineValueNode.value = node.labelNode.innerHTML;
					this.oneLineValueNode.focus();
					this._eventHandles.push(dojo.connect(this.oneLineFormNode,   'onkeyup', this, '_OnRenameFolderKeyUp'));
					this._eventHandles.push(dojo.connect(this.oneLineSaveNode,   'onclick', this, '_OnSaveRenameFolder'));
					this._eventHandles.push(dojo.connect(this.oneLineCancelNode, 'onclick', this, '_OnCancelSingleDialog'));
				}
			},


			/*  --- COPY FILES FROM DB TO MediaGallery --- */
			_OnCopyFilesFromDB: function (/* event */ evt) {
			// summary: event function (click, copyDBImagesNode) - copies selected files to last selected dir in mediagallery
				var directory = this.fileTreeWidget.getCurrentDirectory();
				if (directory === undefined) {
						alert(this.translate('NoDirectorySelected'));
				} else {
					var files = this.fileListWidget.selectedItems();
					if (files.length > 0) {
						this._fileStore.copyImageFromImageDb(directory, files);
						var treeNodeWidget =this.fileTreeWidget.getLastSelectedNode();
						epages.event.fire(treeNodeWidget.domNode, "click");
						this._showMediagallery();
						//select last copied image
						for(var i = 0, l = files.length; i < l; i++){
							var currentFile = files[i];
							var currentFileName = currentFile.substring(currentFile.lastIndexOf("/")+1);
							//select file in current Filelist
							this._selectFileByName(currentFileName);
						}
					} else {
						dojo.publish("uimessage/show", [ this.translate('NoFilesSelected'), this.translate('DoSelectFiles'), 'Dialog', {
								titleBar: this.translate('FileRepository')+" &ndash; "+this.translate('Notification'),
								typeClass: 'Notification'
							}
						]);
					}
				}
			},

			_OnDeleteFilesInline: function(evt) {
			// summary: display confirmation dialog

					// look up filename
					var srcNode = evt.currentTarget;
					var node = srcNode;
					while(!node.getAttribute("widgetid") && node.parentNode !== undefined) {
						node = node.parentNode;
					}

					var fileName = "";
					var widgetId = undefined;

					if(node) {
						widgetId = node.getAttribute("widgetid");
					}
					if(widgetId) {
						var fileWidget = $$(widgetId);

						// show confirmation message
						
						dojo.publish("uimessage/show", [
							this.translate("HeadLineDeleteFile"),
							this.translate("File") + ': ' + fileWidget.name, 'Dialog', {
								titleBar:  this.translate("TitleDeleteFile"),
								sizeClass: 'Large',
								typeClass: 'Confirmation',
								onYes:     dojo.hitch(this, function() {
									this.fileTreeWidget.deleteFiles();
								})
						}]);
					}
			},

			_OnDeleteFiles: function() {
			// summary: delete current selected files
				// lookup filenames
				var fileNames = $A([]);
				var deleteTotalSize = 0;
				$A(this.fileListWidget.selectedNodes()).each(function(el) {
					fileNames.push(el.name);
					deleteTotalSize += el.data.size;
				});
				// show confirmation message
				if(fileNames.length) {
					
					dojo.publish("uimessage/show", [
						this.translate("HeadLineDeleteFiles"),
						this.translate("Files") + ': ' + fileNames.join(', ') , 'Dialog', {
							titleBar:  this.translate("TitleDeleteFiles"),
							sizeClass: 'Large',
							typeClass: 'Confirmation',
							onYes:     dojo.hitch(this, function() {
								this.fileTreeWidget.deleteFiles();
							})
						}]);
					}
			},

			_changeUploader: function (params) {
				var self = this,
					exists = [],
					data = {
						ViewAction:			'JSONViewResponse',
						ChangeAction:		'UploadFilesToMediaGallery',
						ObjectID:			epages.vars.SiteID,
						handleashtml:		1,
						Directory:			(params && params.directory) ? params.directory : '/'
					},
					callback = function( data ){
						dojo.publish( self.uploadNode.id + '/onUploadFinished', [data] );
						// refresh uploader settings
						self._changeUploader(params);
					};
					
				dojo.forEach( this.fileListWidget._allChildren, function( file, i ){
					exists.push(file.name);
				});

				if( jqUploaderReady ){
						jqUploaderCreate( self, data, exists, callback );
				}
				else{
					jq.ready( 'de_epages.presentation.ui.uploader', function(){
						jqUploaderReady = !0;
						jqUploaderCreate( self, data, exists, callback );
					});
				}
			},

			/*  --- SELECT A TREE NODE --- */
			_OnSelectFileTree: function (/* Object */ opt) {
			// summary: sets the current directory and shows the right action links
			// opt: {node:node, currentDirectory: directory}
				opt.currentDirectory = this._fileStore.removeMediaGalleryFromString(opt.currentDirectory);
				//this.uploadWidget.setDirectory(opt.currentDirectory);
				this._changeUploader({ directory : opt.currentDirectory });
				this._setCurrentDirectory(opt);

				// show possible directory actions
				this.newFolderButtonNode.style.display="";
				this.deleteFilesNode.style.display="";
				var directory = this.fileTreeWidget.getCurrentDirectory();
				if (directory !== undefined && directory != this.directory) {
					this.renameFolderButtonNode.style.display="";
					this.deleteFolderButtonNode.style.display="";
				} else {
					this.renameFolderButtonNode.style.display="none";
					this.deleteFolderButtonNode.style.display="none";
				}

				// hide image db actions
				this.imageDbActionsNode.style.display="none";
				this.uploadNode.style.display="";
				this.copyToTargetNode.firstChild.data = this._replaceDirectoryName(directory);

				// publish event
				dojo.publish(this.id+'/fileTreeNodeSelected', []);

				this._updateMultiselectTip();
			},

			_OnSelectDB: function (opt) {
			// summary: sets the current image db directory and shows the right action links
				this._setCurrentDirectory(opt);

				// hide directory actions
				this.newFolderButtonNode.style.display="none";
				this.renameFolderButtonNode.style.display="none";
				this.deleteFolderButtonNode.style.display="none";
				this.deleteFilesNode.style.display="none";

				// adjust copy button
				if(epages.Browser.engine == "Gecko") {
					this.imageDbActionsNode.style.display="inline";
				}else {
					this.imageDbActionsNode.style.display="";
				}

				// hide upload widget
				this.uploadNode.style.display="none";

				// publish event
				dojo.publish(this.id+'/imageDBSelected', []);

				this._updateMultiselectTip();
			},

			_updateMultiselectTip : function() {
				// summary: show or hide multi select hint
				if(this.multiSelect && this.fileListWidget.children.length > 1) {
					this.MultiselectTipNode.style.display="";
				} else {
					this.MultiselectTipNode.style.display="none";
				}
			},

			_OnSelectFileList: function(opt){
			// summary: subscription to fileListWidget - publish that files
				var tooMuchItemsSelected = (this.multiSelect == false && this.fileListWidget.selectedNodes().length > 1);
				dojo.publish(this.id+'/filesSelected', [tooMuchItemsSelected]);
			},

			_OnUploadFinish: function (/* object*/opt){
			// summary: subscription to upload widget (upload finished) - refresh file list
			// opt: { result: this._filesUploaded }
				var directory = this.fileTreeWidget.getCurrentDirectory();
				this._fileStore.resetDirectory(directory);
				this.fileTreeWidget.reloadFiles();

				if(opt.length > 0) {
					var lastItem = opt[opt.length-1];
					if(lastItem && lastItem.success && lastItem.success.currentGallerySize) {
						dojo.publish(this.id+'/updateCurrentBytes', [lastItem.success.currentGallerySize]);
					}
				}
			},

			_OnError: function(errorData) {
			// summary: subscription to file store widget - display errors
			// errorData: {Errors: JsonData.error.data.Errors}
				for( var i=0,iLength=errorData.Errors.length ; i<iLength ; i++ ) {
					if(errorData.Errors[i].Reason == 'DirectoryAlreadyExists') {
						this._showErrorBubble(this.translate('DirectoryAlreadyExists'));
					}
					else if(errorData.Errors[i].Reason == 'FileAlreadyExists') {
						this._showErrorBubble(this.translate('FileAlreadyExists'), 'store');
					}
					else if(errorData.Errors[i].Reason == 'GeneralDirectoryCreateError') {
						this._showErrorBubble(this.translate('GeneralDirectoryCreateError'));
					}
				}
			},

			_OnSuccess: function(callerData) {
			// summary: hides the error bubble
			// description:
			//   An action resulted in an error in the first place. A second
			//   user action then leads to success, so no more error should be indicated.
				this._hideErrorBubble();
			},

			_showErrorBubble: function(/* string */ captionText, /* string */ elementLocation) {
			// summary:
			//			shows an error bubble below oneLineValueNode
			// description:
			//			Displays an error bubble at the location of the error throwing dom element containing the
			//			given captionText. If the parameter elementLocation is set to 'store' the function displays
			//			the bubble for the file store - otherwise for the directory tree.

				// bubble in directory tree or in file store?
				var targetElement;
				if(elementLocation == 'store') {
					targetElement = this.getSelectedItems()[0].nodeTitle;
				}
				else {
					targetElement = this.oneLineValueNode;
				}

				var position = $E(targetElement).getAbsolutePosition();
				dojo.publish("uimessage/show", ["", captionText, "Bubble", {
					typeClass: "Warning",
					sizeClass: "Small",
					x: position.x,
					y: position.y + targetElement.offsetHeight
				}]);
				dojo.addClass(targetElement,'DialogError');
			},

			_hideErrorBubble: function(targetElement) {
				this._removeDialogErrorLineValueNode();
			},

			_registerPlugins: function(){
				var mediaGalleryPlugins = epages.vars.MediaGalleryPlugins;
				//check if plugins defined
				if(mediaGalleryPlugins && mediaGalleryPlugins.length){
					for(var i = 0,l = mediaGalleryPlugins.length; i < l;i++){
						var currentPlugin = mediaGalleryPlugins[i];
						//insert Plugin link to link section
						var linkNode = document.createElement('div');
						dojo.style(linkNode,'cursor','pointer');
						linkNode.innerHTML = '<img src="'+currentPlugin.link.iconSrc+'" />'+currentPlugin.link.title;
						this.PluginLinksNode.appendChild(linkNode);
						this.connect(linkNode,'onclick', function(){
							this._OnPluginLinkClick(currentPlugin.id);
						});

						//insert leftBarContainer with widget
						var leftBarPluginNode = document.createElement('div');
						leftBarPluginNode.innerHTML = currentPlugin.leftBarWidget;
						dojo.addClass(leftBarPluginNode,'PluginLeftBar');
						this.LeftBarContainerNode.appendChild(leftBarPluginNode);
						dojo.parser.parse(leftBarPluginNode);
						var mediagalleryNode = this.selectMediagalleryNode.cloneNode(true);
						this.connect(mediagalleryNode,'onclick', 'showMediagallery');
						leftBarPluginNode.insertBefore(mediagalleryNode,leftBarPluginNode.firstChild);

						//insert mainContainer with widget
						var contentPluginNode = document.createElement('div');
						contentPluginNode.innerHTML = currentPlugin.contentWidget;
						dojo.addClass(contentPluginNode,'PluginContent');
						this.ContentNode.appendChild(contentPluginNode);
						dojo.parser.parse(contentPluginNode);


						this._plugins[currentPlugin.id] = {
							'pluginData': currentPlugin,
							'linkNode': linkNode,
							'linkNodeOnClickConnect':'',
							'leftBarNode':leftBarPluginNode,
							'contentNode': contentPluginNode
						};
					}
				}
			},

			_OnPluginLinkClick:function(pluginId){
				if(this._plugins[pluginId]){
					var currentPlugin = this._plugins[pluginId];
					dojo.fx.slideTo({ node: currentPlugin.leftBarNode, left:"0", top:"0", unit:"px" }).play();
					this._visibleLeftBar = currentPlugin.leftBarNode;
					dojo.fx.slideTo({ node: currentPlugin.contentNode, left:"0", top:"0", unit:"px" }).play();
					this._visibleContent = currentPlugin.contentNode;
					dojo.publish('Filebrowser/PluginLinkClick',[{id: pluginId,opener: this.opener}]);
					this._currentActivePlugin = pluginId;
				}
			},

			onApply: function(){
				dojo.publish('Filebrowser/onApply',[this._currentActivePlugin]);
				if(this._currentActivePlugin && this._currentActivePlugin == 'ImageDB'){
					//when ImageDB is activated check if there are files selected and copy them to own images and insert them
					if(this.getSelectedItems()){
						this._OnCopyFilesFromDB();
					}
				}
			},

			pluginActive:function(){
				if(this._currentActivePlugin){
					return this._currentActivePlugin;
				}
				else{
					return false;
				}
			}
		}
	);

})(jQuery);

}

if(!dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.Mediagallery"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.Mediagallery"] = true;
dojo.provide("epages.cartridges.de_epages.mediagallery.widget.Mediagallery");









dojo.declare (
	"epages.cartridges.de_epages.mediagallery.widget.Mediagallery",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		onApply         : '',					// onApply function
		applyButtonLabel: '',					// label of apply button

		// pass properties to filebrowser widget
		siteId          : epages.vars.SiteID,				// epages SiteID
		url             : '?',											// request url
		directory       : 'MediaGallery',						// base directory
		multiSelect     : 'true',										// multi item selection on or off
		validFileTypes  : "",												// show only files with these file extensions
		imageDB         : epages.vars.ImageDbRoot,	// url to image database
		opener          : '',												// string to define from where it was opend, passed to the Filebrowser

		// pass properties to gallery size usage widget
		maxGallerySize      : '',
		currentGallerySize  : '',



		/**
		 * private properties
		 */
		_applyButtonDisabled: true,				// flag: indicates wether the apply button is disabled or not
		_applyButtonActive  : false,			// flag: indicates wether the apply button is active (highlighted) or not

		/**
		 * widget properties
		 */

		templateString:"<div>\n  <div dojoType=\"epages.widget.Dialog\"\n         dojoAttachpoint=\"dialogWidget\"\n         title=\"{FileRepository}\"\n         class=\"MediaGallery\">\n\n    <div dojoType=\"epages.cartridges.de_epages.mediagallery.widget.Filebrowser\"\n      dojoAttachPoint=\"fileBrowserWidget\"\n      siteId=\"${siteId}\"\n      id=\"${id}_Filebrowser\"\n      directory=\"MediaGallery\"\n      url=\"${url}\"\n      multiSelect=\"${multiSelect}\"\n      validFileTypes=\"${validFileTypes}\"\n      imageDB=\"${imageDB}\"\n      opener=\"${opener}\"\n    ></div>\n\n    <div dojoAttachPoint=\"buttonsNode\">\n      <div class=\"FloatLeft\"\n        dojoType=\"epages.cartridges.de_epages.mediagallery.widget.GallerySizeUsage\"\n        dojoAttachPoint=\"gallerySizeUsage\"\n        maxGallerySize=\"${currentGallerySize}\"\n        currentGallerySize=\"${currentGallerySize}\"\n      ></div>\n      <div class=\"FloatRight\">\n        <span class=\"Button Active EnableHover\" dojoAttachPoint=\"applyButtonNode\"  ><span class=\"ButtonContainer\" dojoAttachPoint=\"applyButtonLabelNode\" >{Apply}</span></span>\n        <span class=\"Button EnableHover\" dojoAttachPoint=\"cancelButtonNode\" ><span class=\"ButtonContainer\">{Close}</span></span>\n      </div>\n    </div>\n  </div>\n</div>\n",
		translationName  : dojo.moduleUrl('epages.cartridges.de_epages.mediagallery.widget','templates/translation'),
		widgetsInTemplate:true,

		/**
		 * widget life cycle
		 */
		postMixInProperties: function() {
		// summary: initalize values - adjust properites
			this.inherited("postMixInProperties", arguments);
		},

		postCreate: function() {
		// summary: initalize widget - append events, adjust properites
			this.inherited("postCreate", arguments);
			this.multiSelect = epages.string.toBoolean(this.multiSelect);
			this._appendEvents();
			this._initButtonBar();

			// remove the dialog title
			this.dialogWidget.titleBar.removeAttribute("title");

			// gallery usage updater
			this.gallerySizeUsage.updateUsage(this.fileBrowserWidget.galleryUsage);
		},

		_initButtonBar: function() {
		// summary: move buttons into dialog widget, init apply button
			if(this.applyButtonLabel !=""){
				this.applyButtonLabelNode.firstChild.data = this.applyButtonLabel;
			}
			if(dojo.hasClass(this.applyButtonNode,'Active')){
				this._applyButtonActive = true;
			}
			this._doDisableApplyButton(true);

			// move buttons into the Dialogs button bar
			this.dialogWidget.buttonBarNode.appendChild(this.buttonsNode);
			this.dialogWidget.buttonBarNode.style.display = "block";

			if (this.onApply == ''){
				this._hideApplyButton();
			}else{
				this._showApplyButton();
			}

			var bNode = this.buttonsNode; // silly workaround for msie (force rendering again)
			bNode.style.display="none";
			window.setTimeout(function() {bNode.style.display="block";}, 10);
		},

		_appendEvents: function() {
		// summary: append button events, subscribe to filetree and imagedb
			// events
			this.connect(this.applyButtonNode, 'onclick', '_OnApply');
			this.connect(this.cancelButtonNode, 'onclick', 'hide');

			// subscriptions
			dojo.subscribe(this.id+'_Filebrowser/fileTreeNodeSelected', this, '_enableApplyButton');			// on select folder -> show apply button
			//dojo.subscribe(this.id+'_Filebrowser/imageDBSelected', this, '_disableApplyButton');					// on select imageDB -> hide apply button
			dojo.subscribe('Mediagallery/hide',this,'hide');
			dojo.subscribe('Mediagallery/disableApplyButton',this,'_disableApplyButton');
			dojo.subscribe('Mediagallery/enableApplyButton',this,'_enableApplyButton');

			// propagate upload/delete/create events
			dojo.subscribe(this.id+'_Filebrowser/updateCurrentBytes', this, function(kilobytes) {
				dojo.publish(this.gallerySizeUsage.id+'/updateCurrentBytes', [kilobytes]);
			});
		},

		/**
		 * getter, setter and other public functions
		 */

		hide: function() {
		// summary: hide dialog widget
			this.dialogWidget.hide();
		},

		show: function() {
		// summary: show dialog widget
			this.dialogWidget.show();
		},

		changeOpener: function(opener){
			if(opener){
				this.opener = opener;
				this.fileBrowserWidget.changeOpener(opener);
			}
		},

		setOnApply: function(/* function */ onApply) {
		// summary: setter for onApply function
			if(onApply != '' && onApply != null && onApply !== undefined) {
				this.onApply=onApply;
				this._showApplyButton();
			} else {
				// reset on invalid onApply value
				this.onApply='';
				this._hideApplyButton();
			}
		},

		setFileTypes: function(/* String */ fileTypes) {
			// summary: updates the list of allowed file extensions
			if(typeof(fileTypes) === "string" && (this.validFileTypes != fileTypes)) {
				this.validFileTypes = fileTypes;
				this.fileBrowserWidget.setFileTypes(this.validFileTypes);
			}
		},

		/**
		* widget button/ display functions
		*/

		_showApplyButton: function() {
		// summary: show and enable apply button
			dojo.removeClass(this.applyButtonNode, "HideElementSoft");
			this._doDisableApplyButton(false);
		},

		_hideApplyButton: function() {
		// summary: hide and disable apply button
			dojo.addClass(this.applyButtonNode, "HideElementSoft");
			this._doDisableApplyButton(true);
		},

		_disableApplyButton: function() {
		// summary: disable apply button
			this._doDisableApplyButton(true);
		},

		_enableApplyButton: function() {
		// summary: enable apply button
			this._doDisableApplyButton(false);
		},

		_doDisableApplyButton: function(/* boolean */ doDisable) {
		// summary: disable or enable apply button
			this._applyButtonDisabled = doDisable;
			if(doDisable){
				dojo.addClass(this.applyButtonNode, "Disabled");
				if(this._applyButtonActive){ 
					dojo.removeClass(this.applyButtonNode, "Active");
				}
			} else {
				dojo.removeClass(this.applyButtonNode, "Disabled");
				if(this._applyButtonActive){ 
					dojo.addClass(this.applyButtonNode, "Active");
				}
			}
		},

		_OnApply: function(evt) {
		// summary: call callback function onApply and pass selected items
		//check if apply button is clicked while plugin is open

			if(!this._applyButtonDisabled) {
				this.fileBrowserWidget.onApply();
				if(this.fileBrowserWidget.pluginActive()){
					//if inside the filebrowser a plugin ist still active return and do nothing
					//plugin has to be deactivated or has to close the mediagallery
					return;
				}
				this.dialogWidget.hide();
				var items = this.fileBrowserWidget.getSelectedItems();
				//only do custom onApply if now plugin is active inside filebrowser
				if (typeof(this.onApply) == 'function') {
					this.onApply(items);
				} else {
				 console.warn("Invalid function passed to onApply in "+this.declaredClass);
				}
			}
		}

});

}

if(!dojo._hasResource["epages.cartridges.de_epages.mediagallery.Mimetypehtml"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.mediagallery.Mimetypehtml"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.mediagallery.Mimetypehtml

*/

dojo.provide("epages.cartridges.de_epages.mediagallery.Mimetypehtml");


epages.vars.mimetypeHtmlMap = {
	mimetypes:	{
		'application/x-shockwave-flash' : {
																				classid : 'D27CDB6E-AE6D-11cf-96B8-444553540000',
																				codebase: 'https://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=6,0,40,0',
																				template: 'embed',
																				editorclass: 'mceItemFlash'
																			},
		'application/x-director' 				: {
																				classid : '166B1BCA-3F9C-11CF-8075-444553540000',
																				codebase: 'https://download.macromedia.com/pub/shockwave/cabs/director/sw.cab#version=8,5,1,0',
																				template: 'embed',
																				editorclass: 'mceItemShockWave'
																			},
		'video/quicktime' 							: {
																				classid : '02BF25D5-8C17-4B23-BC80-D3488ABDDC6B',
																				codebase: 'https://www.apple.com/qtactivex/qtplugin.cab#version=6,0,2,0',
																				template: 'embed',
																				editorclass: 'mceItemQuickTime'
																			},
		'audio/x-pn-realaudio-plugin'		: {
																				classid : 'CFCDAA03-8BE4-11cf-B84B-0020AFBBCCFA',
																				codebase: 'https://activex.microsoft.com/activex/controls/mplayer/en/nsmp2inf.cab#Version=5,1,52,701',	// ?? media player
																				template: 'embed',
																				editorclass: 'mceItemRealMedia'
																			},
		'application/vnd.rn-realmedia'	: {
																				classid : 'CFCDAA03-8BE4-11cf-B84B-0020AFBBCCFA',
																				codebase: 'https://activex.microsoft.com/activex/controls/mplayer/en/nsmp2inf.cab#Version=5,1,52,701',	// ?? media player
																				template: 'embed',
																				editorclass: 'mceItemRealMedia'
																			},
		'application/x-mplayer2'				: {
																				classid : '6BF52A52-394A-11D3-B153-00C04F79FAA6', 																									  // (media_wmp6_compatible') ? '05589FA1-C356-11CE-BF01-00AA0055595A' : '6BF52A52-394A-11D3-B153-00C04F79FAA6';
																				codebase: 'https://activex.microsoft.com/activex/controls/mplayer/en/nsmp2inf.cab#Version=5,1,52,701',
																				template: 'embed',
																				editorclass: 'mceItemWindowsMedia'
																			},
		'video/x-msvideo'								: {
																				classid : '6BF52A52-394A-11D3-B153-00C04F79FAA6', 																									  // (media_wmp6_compatible') ? '05589FA1-C356-11CE-BF01-00AA0055595A' : '6BF52A52-394A-11D3-B153-00C04F79FAA6';
																				codebase: 'https://activex.microsoft.com/activex/controls/mplayer/en/nsmp2inf.cab#Version=5,1,52,701',
																				template: 'embed',
																				editorclass: 'mceItemWindowsMedia'
																			},
		'audio/x-ms-wmv'								: {
																				classid : '6BF52A52-394A-11D3-B153-00C04F79FAA6', 																									  // (media_wmp6_compatible') ? '05589FA1-C356-11CE-BF01-00AA0055595A' : '6BF52A52-394A-11D3-B153-00C04F79FAA6';
																				codebase: 'https://activex.microsoft.com/activex/controls/mplayer/en/nsmp2inf.cab#Version=5,1,52,701',
																				template: 'embed',
																				editorclass: 'mceItemWindowsMedia'
																			}
	},

	templates: {
		image: function(mimetype, mimetypemap, params) {
			return '<img mce_src="'+params.src+ '" src="'+params.src+ '" alt="'+params.name+'" style="border: 0px" />';
		},

		link: function(mimetype, mimetypemap, params) {
			return '<a href="'+params.src+ '" target="_blank" >'+params.name+'</a>';
		},

		embed: function(mimetype, mimetypemap, params, insertIntoEditor) {
			if(!insertIntoEditor) {
				var classid = mimetypemap.classid;
				var codebase = mimetypemap.codebase;
				var html = '';

				html += '<object classid="clsid:' + classid + '" codebase="' + codebase + '"';
				html += params.id !== undefined ? ' id="' + params.id + '"' : '';
				html += params.name !== undefined ? ' name="' + params.name + '"' : '';
				html += params.width !== undefined ? ' width="' + params.width + '"' : '';
				html += params.height !== undefined ? ' height="' + params.height + '"' : '';
				html += params.align !== undefined ? ' align="' + params.align + '"' : '';
				html += '>';

				for (var n in params){
					html += '<param name="' + n + '" value="' + params[n] + '">';
				}

				html += '<embed type="' + mimetype + '"';

				for (var n in params){
					html += n + '="' + params[n] + '" ';
				}

				html += '></embed></object>';

				return html;
			} else {
				var html="";
				html += '<img class="'+mimetypemap.editorclass+'" src="'+epages.vars.StoreRoot+'/lib/ckeditor/images/spacer.gif" border="0"';
				html += params.width !== undefined ? ' width="' + params.width + '"' : ' width="200"';
				html += params.height !== undefined ? ' height="' + params.height + '"' : ' height="100"';

				html += ' style="';
				html += params.width  !== undefined ? ' width:'  + params.width  + 'px ;' : ' width: 200px;';
				html += params.height !== undefined ? ' height:' + params.height + 'px; ' : ' height: 100px;';

				html += '" title="';
				var i=0
				for (var n in params) {
					if(i!=0){
						html +=',';
					}
					html += n + ":'" + params[n]+"'";
					i++;
				}
				html += '" />';
				return html;
			}
		}
	}
};

getHtmlByMimeType = function(/* string */mimetype,/* array? */params, /* boolean? */insertIntoEditor) {
	var html="";

	if(mimetype==null){
		mimetype="";
	}
	// adjust url param for windows media player
	if(mimetype=="application/x-mplayer2" || mimetype=="video/x-msvideo" || mimetype=="audio/x-ms-wmv"){
		params.url = params.src;
	}
	var mimetypeVar=epages.vars.mimetypeHtmlMap.mimetypes[mimetype];

	if(mimetype.match(/^image/)){
		html=epages.vars.mimetypeHtmlMap.templates['image'](mimetype, mimetypeVar, params);
	}else if(mimetypeVar !== undefined){
		html= epages.vars.mimetypeHtmlMap.templates[mimetypeVar.template](mimetype, mimetypeVar, params, insertIntoEditor);
	}else{
		html= epages.vars.mimetypeHtmlMap.templates['link'](mimetype, mimetypeVar, params);
	}
	return html;
};

}

if(!dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery"] = true;
/*
  Copyright (c) 2006-2007, ePages GmbH
  All Rights Reserved.

  epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery

*/
dojo.provide("epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery");




dojo.declare(
  "epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery",
  [epages.widget.LocalizedWidget],
  {
    /**
     * public properties
     */
    attributeName   : '',                    // String - Attribute name (still in use???)
    storeRoot       : epages.vars.StoreRoot, // String - epages StoreRoot e.g. /WebRoot/Store
    siteId          : epages.vars.SiteID,    // String - Site id
    url             : '?',                   // String - request url
    isTinyMCE       : "false",               // Boolean - flag: use mediagalllery to insert into tinymce
    multiSelect     : "true",                // Boolean - media gallery option: enable multiselect
    onApply         : "",                    // Function - media gallery option: apply function
    applyButtonLabel: "",                    // String - media gallery option: label text for apply button
    validFileTypes  : "",                    // String - media gallery option: filter file extension list - show only these
    opener          : '',         // String - flag to define where it is opend from , passed to mediagallery

    /**
     * constants
     */
    MEDIAGALLERY_OFFSET_X: 130,              // [const] Integer - X Offset (still in use???)
    MEDIAGALLERY_OFFSET_Y: 130,              // [const] Integer - Y Offset (still in use???)

    /**
     * private properties
     */
    templateType       : "standard",         // String - seleced template
    defaultTemplateType: "standard",         // [readonly] String - default template
    templateString:"<div class=\"CommandSmallWithLink NoPadding\" dojoAttachPoint=\"clickNode\">\n  <i class=\"Sprite ico_s_openfile\"></i>{InsertFile}\n</div>\n",  // String - template path + filename
    translationName    : dojo.moduleUrl('epages.cartridges.de_epages.mediagallery.widget', 'templates/translation'),            // String - translation path + filename (without file extension)
    _templateMapping : {
      'standard'  : {templateString:"<div class=\"CommandSmallWithLink NoPadding\" dojoAttachPoint=\"clickNode\">\n  <i class=\"Sprite ico_s_openfile\"></i>{InsertFile}\n</div>\n"},
      'icon'      : {templateString:"<div dojoAttachPoint=\"clickNode\">\n  <i dojoAttachPoint=\"imageNode\" class=\"Sprite ico_s_openfile\" title=\"{InsertFile}\"></i>\n</div>\n"},
      'button'    : {templateString:"<button class=\"UploadArea\" dojoAttachPoint=\"clickNode\" type=\"button\">\n  <i class=\"Sprite ico_m_folder\"></i>\n  {InsertFile}\n</button>\n"},
      'invisible' : {templateString:"<span dojoAttachPoint=\"clickNode\"></span>\n"}
    },                                       // [protected] Object - hash which associates templateType key with template filename
    _tinyMceSelection   : undefined,         // [protected] TinyMceSelection - current selection in tiny mce editor
    /**
     * widget properties
     */
    imagePath       : dojo.moduleUrl('dijit', 'themes/epages/images'),  // String - image path

    postMixInProperties: function(){
    // summary: initialize values
      this._templateDirectory = dojo.moduleUrl('epages.cartridges.de_epages.mediagallery.widget' , 'templates');

      // toolmediagallery as tiny mce button
      this.isTinyMCE = (this.isTinyMCE == 'true' || this.isTinyMCE == '1');
      this.inherited("postMixInProperties", arguments);
    },

    postCreate  : function() {
    // summary: initialize values / adjust nodes
      this.inherited("postCreate", arguments);
      // tinymce button display settings
      if(this.isTinyMCE && this.imageNode){
        this.imageNode.style.margin="2px";
      }

      this._appendEvents();
    },

    /**
     * private methods
     */

    _appendEvents: function() {
      // summary: open gallery
      // tags: callback

      var self = this;

      require([
        'jquery',
        'ep',
        'de_epages/mediagallery/ui/filemanagerdialog',

        '$ready!'
      ], function($, ep, de_epages) {
        var backImageLink = (self.inputNode !== undefined) ? de_epages($(self.domNode).find("span.Button")) : de_epages(self.domNode),

            changeImage = function(selectedFile){
            	self.onApply("MediaGallery" + selectedFile.get("path"));
            };

        backImageLink.mediagalleryUiFilemanagerdialog({
          dialog: {
            buttons: {
              Ok: {
                cssClass: 'ep-button ep-button-apply',
                click: function(){
                  var item = backImageLink.mediagalleryUiFilemanagerdialog("getSelectedElements")[0];

                  if(item){
                    if(item.get("metadata").type !== "MediaGallery"){
                      ep.ajax({
                        dataType: "json",
                        type : "POST",
                        data : {
                          ChangeAction : "JSONCopyImageFromImageDb",
                          StyleID: epConfig.objectId,
                          ObjectID : epConfig.siteId,
                          SourceFile : item.get("fullpath"),
                          TargetDirectory : "",
                          ViewAction : 'JSONViewResponse'
                        }
                      })
                      .done(function( jsonData, statusText, jqXHR ){
                        item.set({path: jsonData.Files[0].path});
                        changeImage(item);
                      });
                    }
                    else{
                      changeImage(item);
                    }
                  }

                  ep(this).uiDialog("close");
                }
              },
              Cancel:{
                cssClass: 'ep-button ep-button-cancel',
                click: function(){
                  ep(this).uiDialog("close");
                }
              }
            },
            close: function(){
              backImageLink.mediagalleryUiFilemanagerdialog("resetFilemanager");
            }
          },
          filemanager: {
            currentFolder: "BackgroundImages",
            accept: (ep.config.filemanager && ep.config.filemanager.accept && ep.config.filemanager.accept.images)
                    ? ep.config.filemanager.accept.images
                    : "*/*",
            selectable: "image/jpe,image/jpg,image/jpeg,image/gif,image/png"
          }
        });
      });
    },

    setFileTypes: function(/* String */ fileTypes) {
      // summary: updates the list of allowed file extensions

      if(typeof(fileTypes) === "string" && (this.validFileTypes != fileTypes)) {
        this.validFileTypes = fileTypes;
        var MediaGallery = $$('MediaGallery');
        if(MediaGallery !== undefined) {
          MediaGallery.setFileTypes(this.validFileTypes);
        }
      }
    },

    openDialog: function(/*Event*/evt) {
      // summary: Show MediaGallery
      // description: Calls show() of the mediagallery widget (widgetId=MediaGallery)

      if(!this.isMediaSelected && !this.isImageSelected) {
        var MediaGallery = $$('MediaGallery');
        // set onApply function
        var onApply = '';
        if(this.onApply != "") {
          onApply=this.onApply;
        } else if (this.isTinyMCE) {
          var me = this;
          onApply= function(selected) {
            var generatedHtml="";
            $A(selected).each(function (el) {
              generatedHtml+=me.mceGenerateContent(el)+'<br />';
            });
            me.mceInsertContent(generatedHtml);
          };
        }
        if(MediaGallery === undefined) {
          epages.require('ep_shop_tree','dijit.Tree');
          epages.require('ep_shop_upload','epages.uploader');
          epages.require('ep_mediagallery', 'epages.cartridges.de_epages.mediagallery.widget.Mediagallery');
          MediaGallery = new epages.cartridges.de_epages.mediagallery.widget.Mediagallery({
            id:               'MediaGallery',
            siteId:           this.siteId,
            url:              this.url,
            applyButtonLabel: this.applyButtonLabel,
            multiSelect:      this.multiSelect,
            validFileTypes:   this.validFileTypes,
            onApply:          onApply,
            opener:           this.opener
          });

          document.getElementsByTagName("body")[0].appendChild(MediaGallery.domNode);
        } else {
          MediaGallery.setOnApply(onApply);
        }
        MediaGallery.changeOpener(this.opener);
        MediaGallery.show();
      }
    },

    mceGenerateContent: function(el) {
    // summary:
    //      generates the tiny mce code (mimetype dependent)
    // el: epages.cartridges.de_epages.mediagallery.widget.Filelistitem
    //      selected file list item
    // tags:
    //      protected
      epages.require('ep_mediagallery', 'epages.cartridges.de_epages.mediagallery.Mimetypehtml');
      var html= getHtmlByMimeType(el.mimetype, {src: el.fullpath, name: el.fileName}, true);
      return html;
    },

    mceInsertContent: function (/* String */ html) {
    // summary:
    //      insert code into tiny mce
    // html:
    //      this html code will be inserted into tiny mce
    // tags:
    //      protected
      if(tinyMCE && tinyMCE.activeEditor){
        tinyMCE.activeEditor.selection.moveToBookmark(tinymce.WindowManager.bookmark);
        tinyMCE.activeEditor.execCommand('mceInsertContent', false, html);
      }
    }

  }
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.ImageInlineEditor"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.mediagallery.widget.ImageInlineEditor"] = true;
dojo.provide("epages.cartridges.de_epages.mediagallery.widget.ImageInlineEditor");


(function(jq){

  var jqUploaderReady = !1,
      jqUploaderCreate = function( self ){
        var data = {
            ViewAction:		'JSONViewResponse',
            ChangeAction:	self.uploadAction,
            ObjectID:		self.objectId
          };
        if( self.scaleWidth ){ data.Width	= self.scaleWidth; }
        if( self.scaleHeight ){ data.Heigh	= self.scaleHeight; }
        if( self.image ){ data.Image	= self.image; }

        de_epages(self.uploadNode)
          .presentationUiUploader({
            data:			data,
            style:		'big-icon',
            accept:		self.fileType,
            callback:	function( data ){
              if( data = data[ data.length-1 ].success ){
                self.onChange(data.uploadedObjectFile,data.uploadedFile);
              }
            }
          });
      };

  dojo.declare(
    "epages.cartridges.de_epages.mediagallery.widget.ImageInlineEditor",
    [epages.cartridges.de_epages.presentation.widget.InlineEditor],
    {
      /* widget properties */
      templateString		: '',
      templateString:"<div class=\"InlineEditor ImageInlineEditor LinkImage EnableHover\">\n  <img dojoAttachEvent=\"onmousedown:show\" dojoAttachPoint=\"imgNode\" src=\"${value}\" />\n  <div class=\"ImageInlineEditorButton\" style=\"overflow:visible !important;\">\n    <input type=\"file\" dojoAttachPoint=\"uploadNode\"/>\n<!--\n    <div class=\"FloatLeft Button EnableHover Large\" dojoAttachPoint=\"uploadNode\" id=\"InlineEditor_${id}\">\n      <span class=\"ButtonIconContainer\"><i class=\"MultipleUploadFlashButtonBig\"></i></span>\n    </div>\n-->\n  </div>\n  <input type=\"hidden\" dojoAttachPoint=\"contentNode\" name=\"${inputName}\" value=\"${value}\" />\n</div>\n",
      widgetsInTemplate : true,
      objectId          : epages.vars.ObjectID || '',
      uploadAction      : 'UploadImages',
      scaleWidth        : null,
      scaleHeight       : null,

      /* public properties */
      permanent: true,
      image: null,

      postCreate: function(){
        if(this.value == ''){
          this.imgNode.src = epages.themeUrl('images') + "/plain.gif";
          this.imgNode.width= 50;
          this.imgNode.height = 50;
        }

        if(this.scaleWidth != null) {
          this.scaleWidth = parseInt(this.scaleWidth, 10);
        }
        if(this.scaleHeight != null) {
          this.scaleHeight = parseInt(this.scaleHeight, 10);
        }

        // modify changeaction
        this._changeUploader();

        this.inherited('postCreate', arguments);
      },

      startup: function() {
        this.inherited('startup', arguments);
        this.domNode.title = "";

      },

      _changeUploader: function () {
        var self = this;

        if( jqUploaderReady ){
            jqUploaderCreate( self );
        }
        else{
          jq.ready( 'de_epages.presentation.ui.uploader', function(){
            jqUploaderReady = !0;
            jqUploaderCreate( self );
          });
        }
      },

      onChange: function(value,imgSrc) {
        this.imgNode.src = imgSrc;
        // write contents back to hidden input
        this.contentNode.value = value;
        //this.undoObject.addInput(this.contentNode);
      },

      show: function(evt) {
        // Upload widget
        //this.uploadNode.uploadFiles(evt);
      },

      hide: function() {
        // this is a permanent widget, so it never hides
      },

      _copyStyle: function(){
        //description: empty function from parent widget is not used in this widget
      }

    }
  );

})(jQuery);

}

if(!dojo._hasResource['epages.cartridges.de_epages.mediagallery.widget.MediagalleryInput']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.mediagallery.widget.MediagalleryInput'] = true;
/*
	Copyright (c) 2006-2010, epages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.mediagallery.widget.MediagalleryInput

*/
dojo.provide('epages.cartridges.de_epages.mediagallery.widget.MediagalleryInput');



dojo.declare("epages.cartridges.de_epages.mediagallery.widget.MediagalleryInput",
	[epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery],
	{
		value              : '',	       // String - input field value
		name               : '',         // String - name of input field
		multiSelect        : "false",    // [readonly] Boolean - media gallery option: enable multiselect
		onApply            : undefined , // [protected] Function - media gallery onapply callback
		relativeToSiteRoot : 'false',    // Boolean - input value will be relative to the site path (epages.vars.SiteRoot)
		'class'            : '',

		templateString:"<span class=\"MediaGalleryInput ${class}\">\n  <input type=\"text\" readonly=\"readonly\" name=\"${name}\" value=\"${value}\" dojoAttachPoint=\"inputNode\" />\n  <span class=\"Button EnableHover\" dojoAttachPoint=\"clickNode\">\n    <span class=\"ButtonContainer\">{SelectFile}</span>\n  </span>\n  <i class=\"Sprite ico_s_remove ClickIcon\" dojoAttachPoint=\"removeNode\" style=\"visibility:hidden\"></i>\n</span>\n",
		_templateMapping : {
			'standard' : {templateString:"<span class=\"MediaGalleryInput ${class}\">\n  <input type=\"text\" readonly=\"readonly\" name=\"${name}\" value=\"${value}\" dojoAttachPoint=\"inputNode\" />\n  <span class=\"Button EnableHover\" dojoAttachPoint=\"clickNode\">\n    <span class=\"ButtonContainer\">{SelectFile}</span>\n  </span>\n  <i class=\"Sprite ico_s_remove ClickIcon\" dojoAttachPoint=\"removeNode\" style=\"visibility:hidden\"></i>\n</span>\n"}
		},                               // [protected] Object - hash which associates templateType key with template filename

		postMixInProperties: function() {
		// summary: initalize values - adjust properites
			this.inherited("postMixInProperties", arguments);
			var mediagalleryInputScope = this;
			this.relativeToSiteRoot =  epages.string.toBoolean(this.relativeToSiteRoot);

			this.onApply = function(path) {
			// summary:
			//			media gallery onapply callback
			// items : epages.cartridges.de_epages.mediagallery.widget.Filelistitem[]
			//			list with possible itens
			// tags:
			//			callback
				mediagalleryInputScope.inputNode.value = path;
				epages.event.fire(mediagalleryInputScope.inputNode, 'change');
			};
		},

		postCreate: function() {
		// summary: adjust nodes and events
			this.inherited("postCreate", arguments);
			this.adjustRemoveNodeDisplay();
			this.connect(this.removeNode, 'onclick', 'removeValue');
			this.connect(this.inputNode, 'onchange', 'onChange');
		},

		onChange : function() {
		// summary: adjust display of remove node
			this.syncValue();
			this.adjustRemoveNodeDisplay();
		},

		adjustRemoveNodeDisplay: function() {
		// summary: adjust display of remove node
		// tags: protected
			if(this.value == "") {
				this.removeNode.style.visibility = "hidden";
			} else {
				this.removeNode.style.visibility = "";
			}
		},

		syncValue : function() {
		// summary: synch input value and this.value
		// tags: protected
			this.value = this.inputNode.value;
		},

		removeValue : function() {
		// summary: adjust display of remove node
		// tags: callback
			this.inputNode.value = "";
			epages.event.fire(this.inputNode, 'change');
		}

});

}


/* package: ep_product.js.uncompressed */
/*
	Copyright (c) 2004-2011, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/

/*
	This is an optimized version of Dojo, built for deployment and not for
	development. To get sources and documentation, please visit:

		http://dojotoolkit.org
*/

if(!dojo._hasResource['epages.cartridges.de_epages.product.widget.ProductImages']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.product.widget.ProductImages'] = true;
/*
  Copyright (c) 2006-2009, ePages GmbH
  All Rights Reserved.

  epages.cartridges.de_epages.design.widget.ProductImages

*/

dojo.provide('epages.cartridges.de_epages.product.widget.ProductImages');



epages.require('ep_mediagallery', 'epages.cartridges.de_epages.mediagallery.widget.Mediagallery');

(function(jq){

dojo.declare(
  "epages.cartridges.de_epages.product.widget.ProductImages",
  [epages.widget.LocalizedWidget],
  {
    /**
     * public properties
     */
    objectId            : "",
    uploadAction        : "",
    scaleParams         : "",
    siteId              : epages.vars.SiteID,
    url                 : '?',
    setProductImages    : true,
    multiSelect         : "true",
    big                 : "true",
    reloadAfterUpload   : "true",
    filePath            : "",
    fileAttribute       : "",
    fileName            : "",
    infoText            : "",
    confirm             : "",
    objectId            : epages.vars.ObjectID || '',

    deleteAction        : undefined,
    deleteWidgetDojoType: 'epages.widget.DeleteFileAttributesOnServer',

    /**
     * template properties
     */

    templateType       : 'default',
    defaultTemplateType: 'default',
    _templateMapping: {
      'default'     : {templateString:"<div class=\"ProductImages\">\n  <div class=\"ClearBoth\">\n    <input type=\"file\" class=\"NoButtonTrigger\" dojoAttachpoint=\"uploadAppletNode\"/>\n  </div>\n</div>\n"},
      'withpreview' : {templateString:"<div class=\"ProductImages WithPreview\">\n  <table style=\"border:0\">\n    <tr>\n      <td style=\"border:0;width:100px;\">\n        <span dojoAttachPoint=\"slidesWidget\"\n              dojoType=\"epages.widget.Slides\"\n              imageHeight=\"100px\" imageWidth=\"100px\"\n              stopped=\"true\"\n              showControls=\"false\"\n              showMisc=\"false\"\n              showDescription=\"false\">\n          <ins dojoAttachPoint=\"slidesWidgetIns\" image=\"\"></ins>\n        </span>\n        <span class=\"ToolTip ep-js\" data-js=\".uiTooltip({})\">\n          <div dojoAttachPoint=\"nameNode\" class=\"Bold\">${fileName}</div>\n          <div dojoAttachPoint=\"infoNode\">${infoText}</div>\n        </span>\n      </td>\n      <td style=\"border:0;\">\n        <div class=\"LeftMargin\" style=\"height:100px;position:relative\">\n          <div class=\"ClearBoth\">\n          <input type=\"file\" class=\"NoButtonTrigger\" dojoAttachpoint=\"uploadAppletNode\"/>\n          </div>\n          <div dojoAttachEvent=\"onclick:_openMediaGallery\" class=\"ClearBoth HideElement\">\n            <span class=\"FloatLeft Button EnableHover\">\n              <span class=\"ButtonIconContainer\">\n                <i class=\"Sprite ico_s_openfile\"></i>\n              </span>\n              <u class=\"ButtonContainer ButtonIconPadding\">{MediaGallery}...</u>\n            </span>\n          </div>\n      <div class=\"ClearBoth\"></div>\n          <span dojoType=\"${deleteWidgetDojoType}\"\n            dojoAttachPoint=\"deleteNode\"\n            fileAttribute=\"${fileAttribute}\"\n            filePath=\"${filePath}\"\n            fileName=\"${fileName}\"\n            confirm=\"true\"\n            objectId=\"${objectId}\"\n            style=\"position:relative;top:60px;\"\n            changeAction=\"DeleteMultipleFiles\"\n            class=\"ChangeLink HideElement\"\n          ></span>\n        </div>\n      </td>\n    </tr>\n  </table>\n</div>\n"}
    },

    templateString:"<div class=\"ProductImages\">\n  <div class=\"ClearBoth\">\n    <input type=\"file\" class=\"NoButtonTrigger\" dojoAttachpoint=\"uploadAppletNode\"/>\n  </div>\n</div>\n",
    translationName    : dojo.moduleUrl('epages.cartridges.de_epages.product.widget' , 'templates/translation'),
    /**
     * widget properties
     */
    imagePath         : epages.themeUrl('images'),
    widgetsInTemplate : true,

    postMixInProperties: function() {
      this._templateDirectory = dojo.moduleUrl('epages.cartridges.de_epages.product.widget','templates');
      this.inherited("postMixInProperties", arguments);
      this.uploadAction = this.uploadAction+'&'+this.scaleParams;
      this.setProductImages = epages.string.toBoolean(this.setProductImages);
    },

    postCreate: function() {
      this.inherited("postCreate", arguments);

       if(this.slidesWidgetIns && this.filePath && this.fileName) {
         this.slidesWidgetIns.image = this.filePath + this.fileName;
       }

      if (this.deleteNode) {
         this.deleteNode.onSuccess = dojo.hitch(this, 'onDelete');
          if(this.deleteAction) {
            this.deleteNode.changeAction = deleteAction;
          }
      }

        // set id for uploader
        this.uploadAppletNode.id = this.id+'_uploader';
        dojo.subscribe(this.uploadAppletNode.id + "/onUploadFinished", this, 'onUploadProductImage');
        if (this.deleteNode) {
          this.deleteNode.onSuccess = dojo.hitch(this, 'onDelete');
        }

        var self = this,
          ViewAction = /(?:^|\?|&)ViewAction=(.*?)(?:&|$)/.exec(this.uploadAction);

	      if(!this.hideUploader){
	        de_epages(this.uploadAppletNode)
	          .presentationUiUploader({
	            url:    this.uploadAction+'&'+this.scaleParams,
	            data:   {
	              'ViewAction': ViewAction ? ViewAction[1] : 'JSONViewResponse'
	            },
	            multiple: this.multiSelect,
	            accept:   'image/*',
	            callback: this.reloadAfterUpload==='true' || this.reloadAfterUpload===true ? '?ViewAction='+ep.config.viewAction+'&ObjectID='+ep.config.objectId : function( data ){
	              dojo.publish( self.uploadAppletNode.id + '/onUploadFinished', [data[0].success || data[0].ERROR || {}] );
	            }
	          });
	      }

    },

    onDelete: function() {
      this.nameNode.style.display = 'none';
      this.infoNode.style.display = 'none';
      this.removeImage();
      if (this.fileInputNode) {
        this.fileInputValue = '';
        this.fileInputNode.value = '';
        epages.event.fire(this.fileInputNode, 'change');
      }
      if(this.deleteNode) {
        dojo.addClass(this.deleteNode.domNode, 'HideElement');
      }
      dojo.publish(this.id + '/delete');
    },

    removeImage: function() {
      // summary:
      //    set empty image (hide the current image)
      if(this.slidesWidget) {
        this.slidesWidget.addImage({image: epages.vars.IconsRoot + "/general_img_transparentpixel.gif"}, true);
      }
    },


    _openMediaGallery: function(/*Event*/evt) {
      var MediaGallery = $$('MediaGallery');
      // set onApply function
      var me = this;
      var onApply = function(selectedElements) {
        if(selectedElements.length>0) {
          me._setFileForProduct(selectedElements);
        }
        };
      if(MediaGallery === undefined) {
        MediaGallery = new epages.cartridges.de_epages.mediagallery.widget.Mediagallery({
          id:               'MediaGallery',
          siteId:           this.siteId,
          url:              this.url,
          applyButtonLabel: this.translate('Apply'),
          multiSelect:      this.multiSelect,
          onApply:          onApply
        });
        document.getElementsByTagName("body")[0].appendChild(MediaGallery.domNode);
      } else {
        MediaGallery.multiSelect = this.multiSelect;
        MediaGallery.setOnApply(onApply);
      }
      MediaGallery.show();
    },

    /**
     * events & messages
     */

    onUploadProductImage: function(response) {
      if(this.slidesWidget && response.uploadedFile) {
        var slidesFile;
        slidesFile = response.uploadedFile;

        if(this.filePath && slidesFile) {
          var responseFullFilename = this.filePath + slidesFile;
          this.slidesWidget.addImage({image: responseFullFilename}, true);
          if(this.nameNode) {
            this.nameNode.innerHTML = slidesFile;
          }
          if(this.deleteNode) {
            this.deleteNode.fileName = slidesFile;
            this.deleteNode.filePath = this.filePath;
            this.deleteNode.domNode.style.display = '';
            dojo.removeClass(this.deleteNode.domNode, 'HideElement');
          }
        }
      }
    },

    /**
     * private methods
     */
    _setFileForProduct: function(filesArray){
      dojo.publish("uimessage/startBusy", ["Toolproductimages", this.translate('CopyImageFromMediagallery')]);
      for( var i=0,iLength=filesArray.length ; i<iLength ; i++ ){
        if(this.setProductImages && filesArray[i].mimetype.search(/image/) == -1){
          dojo.publish("uimessage/stopBusy", ["Toolproductimages"]);
          //check if file is an image if setProductImages is activated
          dojo.publish("uimessage/show", [ this.translate('FileNoImage'), this.translate('SelectImage'), 'Dialog', {
              titleBar: this.translate('MediaGallery')+" &ndash; "+this.translate('Notification'),
              typeClass: 'Warning'
            }
          ]);
          return;
        }
        var json = new epages.io.Json;
        var tempParams = this.scaleParams.split('&');
        var scaleParams = {};
        for( var j=0,jLength=tempParams.length ; j<jLength ; j++ ){
          var el = tempParams[j].split('=');
          scaleParams[el[0]] = el[1];
        }
        var params = {
          'ChangeAction': 'MoveAndScaleImage',
          'ObjectID':   this.objectId,
          'File':  filesArray[i].path
        };
        if(this.setProductImages){
          params['SetFilesForProduct'] = true;
        }
        var result = json.loadSync(this.url,dojo.mixin(params,scaleParams));
      }
      dojo.publish("uimessage/stopBusy", ["Toolproductimages"]);
      if (epages.string.toBoolean(this.reloadAfterUpload)){
        var dialogArea = actualDialogArea ? "DialogArea=" + actualDialogArea : "";
        if(location.href.search(/DialogArea/) != -1){
          var newLocation = location.href;
          for( var i=0,iLength=epagesDialog.areaName.length ; i<iLength ; i++ ){
            var regEx = new RegExp('DialogArea='+epagesDialog.areaName[i]);
            newLocation = newLocation.replace(regEx,dialogArea);
          }
          location.href = newLocation;
        }
        else{
          if(dialogArea == ''){
            location.href = location.href;
          }
          else{
            location.href = location.href + '&'+dialogArea;
          }
        }
      }
    }
});

})(jQuery);

}

if(!dojo._hasResource['epages.validate.string']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.validate.string'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.validate.string');

epages.validate.string.isXMLAttribute = function(attributeName) {
	if (attributeName == ''){
		return false;
	}

	// reference http://www.w3.org/TR/REC-xml/#NT-Name
	var XML_SYNTAX_BaseChar      = "[\u0041-\u005A\u0061-\u007A\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF\u0100-\u0131\u0134-\u013E\u0141-\u0148\u014A-\u017E\u0180-\u01C3\u01CD-\u01F0\u01F4-\u01F5\u01FA-\u0217\u0250-\u02A8\u02BB-\u02C1\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03CE\u03D0-\u03D6\u03DA\u03DC\u03DE\u03E0\u03E2-\u03F3\u0401-\u040C\u040E-\u044F\u0451-\u045C\u045E-\u0481\u0490-\u04C4\u04C7-\u04C8\u04CB-\u04CC\u04D0-\u04EB\u04EE-\u04F5\u04F8-\u04F9\u0531-\u0556\u0559\u0561-\u0586\u05D0-\u05EA\u05F0-\u05F2\u0621-\u063A\u0641-\u064A\u0671-\u06B7\u06BA-\u06BE\u06C0-\u06CE\u06D0-\u06D3\u06D5\u06E5-\u06E6\u0905-\u0939\u093D\u0958-\u0961\u0985-\u098C\u098F-\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09DC-\u09DD\u09DF-\u09E1\u09F0-\u09F1\u0A05-\u0A0A\u0A0F-\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32-\u0A33\u0A35-\u0A36\u0A38-\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8B\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2-\u0AB3\u0AB5-\u0AB9\u0ABD\u0AE0\u0B05-\u0B0C\u0B0F-\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32-\u0B33\u0B36-\u0B39\u0B3D\u0B5C-\u0B5D\u0B5F-\u0B61\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99-\u0B9A\u0B9C\u0B9E-\u0B9F\u0BA3-\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB5\u0BB7-\u0BB9\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C33\u0C35-\u0C39\u0C60-\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CDE\u0CE0-\u0CE1\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D28\u0D2A-\u0D39\u0D60-\u0D61\u0E01-\u0E2E\u0E30\u0E32-\u0E33\u0E40-\u0E45\u0E81-\u0E82\u0E84\u0E87-\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA-\u0EAB\u0EAD-\u0EAE\u0EB0\u0EB2-\u0EB3\u0EBD\u0EC0-\u0EC4\u0F40-\u0F47\u0F49-\u0F69\u10A0-\u10C5\u10D0-\u10F6\u1100\u1102-\u1103\u1105-\u1107\u1109\u110B-\u110C\u110E-\u1112\u113C\u113E\u1140\u114C\u114E\u1150\u1154-\u1155\u1159\u115F-\u1161\u1163\u1165\u1167\u1169\u116D-\u116E\u1172-\u1173\u1175\u119E\u11A8\u11AB\u11AE-\u11AF\u11B7-\u11B8\u11BA\u11BC-\u11C2\u11EB\u11F0\u11F9\u1E00-\u1E9B\u1EA0-\u1EF9\u1F00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2126\u212A-\u212B\u212E\u2180-\u2182\u3041-\u3094\u30A1-\u30FA\u3105-\u312C\uAC00-\uD7A3]";
	var XML_SYNTAX_Ideographic   = "[\u4E00-\u9FA5\u3007\u3021-\u3029]";
	var XML_SYNTAX_CombiningChar = "[\u0300-\u0345\u0360-\u0361\u0483-\u0486\u0591-\u05A1\u05A3-\u05B9\u05BB-\u05BD\u05BF\u05C1-\u05C2\u05C4\u064B-\u0652\u0670\u06D6-\u06DC\u06DD-\u06DF\u06E0-\u06E4\u06E7-\u06E8\u06EA-\u06ED\u0901-\u0903\u093C\u093E-\u094C\u094D\u0951-\u0954\u0962-\u0963\u0981-\u0983\u09BC\u09BE\u09BF\u09C0-\u09C4\u09C7-\u09C8\u09CB-\u09CD\u09D7\u09E2-\u09E3\u0A02\u0A3C\u0A3E\u0A3F\u0A40-\u0A42\u0A47-\u0A48\u0A4B-\u0A4D\u0A70-\u0A71\u0A81-\u0A83\u0ABC\u0ABE-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0B01-\u0B03\u0B3C\u0B3E-\u0B43\u0B47-\u0B48\u0B4B-\u0B4D\u0B56-\u0B57\u0B82-\u0B83\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD7\u0C01-\u0C03\u0C3E-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55-\u0C56\u0C82-\u0C83\u0CBE-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5-\u0CD6\u0D02-\u0D03\u0D3E-\u0D43\u0D46-\u0D48\u0D4A-\u0D4D\u0D57\u0E31\u0E34-\u0E3A\u0E47-\u0E4E\u0EB1\u0EB4-\u0EB9\u0EBB-\u0EBC\u0EC8-\u0ECD\u0F18-\u0F19\u0F35\u0F37\u0F39\u0F3E\u0F3F\u0F71-\u0F84\u0F86-\u0F8B\u0F90-\u0F95\u0F97\u0F99-\u0FAD\u0FB1-\u0FB7\u0FB9\u20D0-\u20DC\u20E1\u302A-\u302F\u3099\u309A]";
	var XML_SYNTAX_Digit         = "[\u0030-\u0039\u0660-\u0669\u06F0-\u06F9\u0966-\u096F\u09E6-\u09EF\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0BE7-\u0BEF\u0C66-\u0C6F\u0CE6-\u0CEF\u0D66-\u0D6F\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F29]";
	var XML_SYNTAX_Extender      = "[\u00B7\u02D0\u02D1\u0387\u0640\u0E46\u0EC6\u3005\u3031-\u3035\u309D-\u309E\u30FC-\u30FE]";
	var XML_SYNTAX_Letter        = XML_SYNTAX_BaseChar + "|" + XML_SYNTAX_Ideographic;
	var XML_SYNTAX_NameChar      = XML_SYNTAX_Letter + "|" + XML_SYNTAX_Digit + "|[-._:]|" + XML_SYNTAX_CombiningChar + "|" + XML_SYNTAX_Extender;
	var XML_SYNTAX_Name          = "^(" + XML_SYNTAX_Letter + "|[_:])" + "(" + XML_SYNTAX_NameChar + ")*$";

	return attributeName.match( new RegExp( XML_SYNTAX_Name ) ) ? true : false;
};
epages.validate.string.filterInvalidChars = function(/*string*/ insertString){
	// summary: removes invalid chars from given string
   // description: function removes invalid chars or combination of chars from given string
   // remove all backslashes can cause errors on the server
   // example:
   //    var result = epages.validate.string.filterInvalidChars('Affe/\Ente');
   // returns:  Affe/Ente
	var regExpString = /%5C/gi;
	insertString = encodeURIComponent(insertString);
	var returnString = insertString.replace(regExpString,'');
	returnString = decodeURIComponent(returnString);
	return returnString;
};

}

if(!dojo._hasResource["epages.cartridges.de_epages.product.widget.VariationAttributeList"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.product.widget.VariationAttributeList"] = true;
/*
    Copyright (c) 2006-2007, ePages GmbH
    All Rights Reserved.

    epages.cartridges.de_epages.product.widget.VariationAttributeList

*/
dojo.provide("epages.cartridges.de_epages.product.widget.VariationAttributeList");







dojo.declare("epages.cartridges.de_epages.product.widget.VariationAttributeList", [epages.widget.LocalizedWidget], {
	/**
	 * public properties
	 */
	allowDuplicates: "false",
	attributeAlias: "",
	autoEmptyRow: "true",
	emptyInputNamePrefix: "EmptyValue",
	isLocalized: djConfig.ecms?"false":"true",
	isNew: "false",
	isUsed: "false",
	isPreSelected: "true",
	newInputNamePrefix: "VariationAttributeValues",
	maxAttributeValues: 10,
	maxAttributeCount: 5,
	nextButtonId: '',

	/**
	 * private properties
	 */
	_attributeCounter: '', // String - remember counter to set input names
	_oldValues: undefined, // String[] - array of old values
	_widgetsOfClass: [], // dijit._Widget[] - list of widgets (used by all widgets of this class)
	_existingAttributes: [], // String[] - list of all existing attribute alias of product type

	// unity flag
	unity: (djConfig.unity !== undefined && djConfig.unity === true) ? true : false,

	/**
	 * widget properties
	 */
	templateString: undefined,
	_templateMapping: {
		'ep6core' : {templateString:"<div class=\"VariationAttributeList\">\n\n<h2><span dojoAttachPoint=\"headlineNode\">X</span>. {Attribute}</h2>\n\n<!-- ErrorMessages -->\n<div class=\"HideElement\">\n  <div dojoAttachPoint=\"DuplicateAttributeValueAlias\">\n    <p>{DuplicateAttributeValueAlias}</p>\n  </div>\n  <div dojoAttachPoint=\"AttributeAliasNoXMLName\">\n    <p>{AttributeAliasNoXMLName}</p>\n  </div>\n  <div dojoAttachPoint=\"ProductAttributeExists\">\n    <p>{ProductAttributeExists}</p>\n  </div>\n  <div dojoAttachPoint=\"EmptyAttributeAlias\">\n    <p>{EmptyAttributeAlias}</p>\n  </div>\n</div>\n\n<!-- AttributeAlias, Localize Checkbox, DeleteAttributeLink -->\n<div class=\"TopSmallPadding BottomSmallPadding\" >\n  <div class=\"FloatLeft\">\n    <input type=\"text\" size=\"33\" maxlength=\"30\" disabled=\"disabled\" class=\"Disabled RightMargin\"\n           dojoAttachPoint=\"attributeAliasNode\"\n           name=\"VariationAttributeAliasX\"\n           value=\"${attributeAlias}\"\n           placeholder=\"{Example}: {Color}\" />\n    <input type=\"hidden\" dojoAttachPoint=\"attributeAliasHiddenNode\" name=\"VariationAttributeAliasX\" value=\"${attributeAlias}\" />\n    <input dojoAttachPoint=\"typePackageNode\" type=\"hidden\" name=\"TypePackageX\" value=\"\" />\n\n    <input dojotype=\"epages.widget.FormElement\"\n           dojoAttachPoint=\"localizableNode\"\n           type=\"text\" class=\"Checkbox AlignMiddle\"\n           value=\"1\"\n           disabled=\"disabled\"\n           id=\"Localizable_${id}\"\n    />\n    <label for=\"Localizable_${id}\">{MulitiLingualAttribute}</label>\n    <img src=\"${imagePath}/ico_s_bubblehelp.png\" alt=\"\" class=\"BubbleHelp\" />\n    <span class=\"ToolTip ep-js\" data-js=\".uiTooltip({})\">{BubblehelpMulitiLingualAttribute}</span>\n  </div>\n  <div class=\"FloatRight\">\n    <span class=\"CommandLinkSmall LeftMargin HideElement\"\n          dojoAttachPoint=\"deleteAttributeNode\"><span>\n      <i class=\"RightMargin Sprite ico_s_delete\"></i>{DeleteAttribute}\n    </span></span>\n  </div>\n  <div class=\"ClearBoth\"></div>\n</div>\n<!-- use Attribute as Variation Attribute  -->\n<div class=\"BottomSmallPadding\" dojoAttachPoint=\"isUsedBlockNode\">\n  <p class=\"NoMargin\">{AttributeIsDefinedButNotUsed}</p>\n  <input type=\"hidden\" dojoAttachPoint=\"isUsedValueNode\" name=\"UseAttributeX\" value=\"1\" />\n  <input type=\"text\" checked=\"checked\" class=\"Checkbox AlignMiddle\"\n         dojoType=\"epages.widget.FormElement\"\n         dojoAttachPoint=\"isUsedFormNode\"\n         id=\"DoUseAttribute_${id}\"\n   />\n  <label for=\"DoUseAttribute_${id}\" >{UseThisAttribute}</label>\n</div>\n<!-- attribute value table -->\n<table class=\"ContentList BottomMargin\">\n  <thead><tr><td>{Value}</td><td class=\"ExtraSlimColumn\"></td></tr></thead>\n  <tfoot><tr><td colspan=\"2\"></td></tr></tfoot>\n  <tbody dojoAttachPoint=\"tableBodyNode\">\n    <tr class=\"HideElement\"><td>RowTemplate</td><td>&nbsp;</td></tr>\n    <tr class=\"HideElement\">\n      <td><input class=\"jsInput TextSlim\" type=\"text\" name=\"\" value=\"\" placeholder=\"{Example}: {Red}\"></td>\n      <td class=\"AlignCenter\"><i class=\"jsAnchor LinkImage HideElement Sprite ico_s_delete\" title=\"{DeleteAttributeValue}\"></i></td>\n    </tr>\n  </tbody>\n</table>\n\n<div>\n"},
		'unity'   : {templateString:"<div class=\"ui-helper-clearfix ep-variationassistant-attributesection\">\n  <span class=\"HideElement\" dojoAttachPoint=\"headlineNode\">X</span>\n  \n  <div class=\"HideElement\">\n    <div dojoAttachPoint=\"DuplicateAttributeValueAlias\">\n      <p>{DuplicateAttributeValueAlias}</p>\n    </div>\n    <div dojoAttachPoint=\"AttributeAliasNoXMLName\">\n      <p>{AttributeAliasNoXMLName}</p>\n    </div>\n    <div dojoAttachPoint=\"ProductAttributeExists\">\n      <p>{ProductAttributeExists}</p>\n    </div>\n    <div dojoAttachPoint=\"EmptyAttributeAlias\">\n      <p>{EmptyAttributeAlias}</p>\n    </div>\n  </div>\n\n  <!-- AttributeAlias, Localize Checkbox, DeleteAttributeLink -->\n  <div class=\"TopWidePadding TopWideMargin ui-helper-clearfix\" >\n    <div class=\"row \">\n      <div class=\"col-xs-4\">\n        <div class=\"DisplayInlineBlock FloatLeft WideRightMargin ep-variationassistant-isusedcheckbox\" dojoAttachPoint=\"isUsedBlockNode\" title=\"{UnityUseThisAttribute}\">\n          <input type=\"hidden\" dojoAttachPoint=\"isUsedValueNode\" name=\"UseAttributeX\" value=\"1\" />\n          <input type=\"text\" checked=\"checked\" class=\"Checkbox AlignMiddle\" dojoType=\"epages.widget.FormElement\" dojoAttachPoint=\"isUsedFormNode\" id=\"DoUseAttribute_${id}\" />\n        </div>\n        <h5 class=\"DisplayInlineBlock\">{UnityAttributeName}</h5>\n        <span class=\"LeftMargin FloatRight HideElement\" dojoAttachPoint=\"deleteAttributeNode\">\n          <span>\n            <i class=\"fa fa-trash fa-lg CommandLinkSmall\" title=\"{DeleteAttribute}\"></i>\n          </span>\n        </span>\n      </div>\n      <div class=\"col-xs-12\"></div>\n    </div>\n    <div class=\"row\">\n      <div class=\"col-xs-4 SmallBottomMargin\">\n        <input type=\"text\" size=\"33\" maxlength=\"30\" disabled=\"disabled\" class=\"Disabled FullWidth RightMargin\" dojoAttachPoint=\"attributeAliasNode\" name=\"VariationAttributeAliasX\" value=\"${attributeAlias}\" placeholder=\"{Example}:&nbsp;{Color}\" />\n        <input type=\"hidden\" dojoAttachPoint=\"attributeAliasHiddenNode\" name=\"VariationAttributeAliasX\" value=\"${attributeAlias}\" />\n        <input dojoAttachPoint=\"typePackageNode\" type=\"hidden\" name=\"TypePackageX\" value=\"\" />\n        <input dojotype=\"epages.widget.FormElement\" dojoAttachPoint=\"localizableNode\" type=\"hidden\" class=\"Checkbox AlignMiddle HideElement\" value=\"1\" disabled=\"disabled\" id=\"Localizable_${id}\"/>\n      </div>\n    </div>\n  </div>\n\n  <!-- attribute value table -->\n  <div class=\"row attributeTable ui-helper-clearfix\">\n    <div class=\"col-xs-12 WideTopMargin\">\n      <h5>{UnityAttributeValues}</h5>\n    </div>\n    <div class=\"col-xs-12\">\n      <table class=\"BottomMargin FullWidth\">\n        <thead><tr><td></td></tr></thead>\n        <tfoot><tr><td></td></tr></tfoot>\n        <tbody dojoAttachPoint=\"tableBodyNode\">\n          <tr class=\"HideElement\">\n            <td>RowTemplate</td>\n          </tr>\n          <tr class=\"HideElement\">\n            <td>\n              <div class=\"row\">\n                <div class=\"col-xs-4 SmallTopMargin\">\n                  <input class=\"jsInput TextSlim FullWidth\" type=\"text\" name=\"\" value=\"\" placeholder=\"{Example}:&nbsp;{Red}\"><i class=\"jsAnchor LinkImage ep-placeInsideInput HideElement fa fa-trash fa-lg\" title=\"{DeleteAttributeValue}\"></i>\n                </div>\n              </div>\n            </td>\n          </tr>\n        </tbody>\n      </table>\n    </div>\n  </div>\n</div>\n"},
        'ecms'    : {templateString:"<div class=\"VariationAttributeList\">\n\n<h2><span dojoAttachPoint=\"headlineNode\">X</span>. {Attribute}</h2>\n\n<!-- ErrorMessages -->\n<div class=\"HideElement\">\n  <div dojoAttachPoint=\"DuplicateAttributeValueAlias\">\n    <p>{DuplicateAttributeValueAlias}</p>\n  </div>\n  <div dojoAttachPoint=\"AttributeAliasNoXMLName\">\n    <p>{AttributeAliasNoXMLName}</p>\n  </div>\n  <div dojoAttachPoint=\"ProductAttributeExists\">\n    <p>{ProductAttributeExists}</p>\n  </div>\n  <div dojoAttachPoint=\"EmptyAttributeAlias\">\n    <p>{EmptyAttributeAlias}</p>\n  </div>\n</div>\n\n<!-- AttributeAlias, Localize Checkbox, DeleteAttributeLink -->\n<div class=\"TopSmallPadding BottomSmallPadding\" >\n  <div class=\"FloatLeft\">\n    <input type=\"text\" size=\"33\" maxlength=\"30\" disabled=\"disabled\" class=\"Disabled RightMargin\"\n           dojoAttachPoint=\"attributeAliasNode\"\n           name=\"VariationAttributeAliasX\"\n           value=\"${attributeAlias}\"\n           placeholder=\"{Example}: {Color}\" />\n    <input type=\"hidden\" dojoAttachPoint=\"attributeAliasHiddenNode\" name=\"VariationAttributeAliasX\" value=\"${attributeAlias}\" />\n    <input dojoAttachPoint=\"typePackageNode\" type=\"hidden\" name=\"TypePackageX\" value=\"\" />\n\n    <div style=\"display:none\">\n\t    <input dojotype=\"epages.widget.FormElement\"\n\t           dojoAttachPoint=\"localizableNode\"\n\t           type=\"text\" class=\"Checkbox AlignMiddle\"\n\t           value=\"1\"\n\t           disabled=\"disabled\"\n\t           id=\"Localizable_${id}\"\n\t    />\n\t    <label for=\"Localizable_${id}\">{MulitiLingualAttribute}</label>\n\t    <img src=\"${imagePath}/ico_s_bubblehelp.png\" alt=\"\" class=\"BubbleHelp\" />\n\t    <span class=\"ToolTip ep-js\" data-js=\".uiTooltip({})\">{BubblehelpMulitiLingualAttribute}</span>\n    </div>\n  </div>\n  <div class=\"FloatRight\">\n    <span class=\"CommandLinkSmall LeftMargin HideElement\"\n          dojoAttachPoint=\"deleteAttributeNode\"><span>\n      <i class=\"RightMargin Sprite ico_s_delete\"></i>{DeleteAttribute}\n    </span></span>\n  </div>\n  <div class=\"ClearBoth\"></div>\n</div>\n<!-- use Attribute as Variation Attribute  -->\n<div class=\"BottomSmallPadding\" dojoAttachPoint=\"isUsedBlockNode\">\n  <p class=\"NoMargin\">{AttributeIsDefinedButNotUsed}</p>\n  <input type=\"hidden\" dojoAttachPoint=\"isUsedValueNode\" name=\"UseAttributeX\" value=\"1\" />\n  <input type=\"text\" checked=\"checked\" class=\"Checkbox AlignMiddle\"\n         dojoType=\"epages.widget.FormElement\"\n         dojoAttachPoint=\"isUsedFormNode\"\n         id=\"DoUseAttribute_${id}\"\n   />\n  <label for=\"DoUseAttribute_${id}\" >{UseThisAttribute}</label>\n</div>\n<!-- attribute value table -->\n<table class=\"ContentList BottomMargin\">\n  <thead><tr><td>{Value}</td><td class=\"ExtraSlimColumn\"></td></tr></thead>\n  <tfoot><tr><td colspan=\"2\"></td></tr></tfoot>\n  <tbody dojoAttachPoint=\"tableBodyNode\">\n    <tr class=\"HideElement\"><td>RowTemplate</td><td>&nbsp;</td></tr>\n    <tr class=\"HideElement\">\n      <td><input class=\"jsInput TextSlim\" type=\"text\" name=\"\" value=\"\" placeholder=\"{Example}: {Red}\"></td>\n      <td class=\"AlignCenter\"><i class=\"jsAnchor LinkImage HideElement Sprite ico_s_delete\" title=\"{DeleteAttributeValue}\"></i></td>\n    </tr>\n  </tbody>\n</table>\n\n<div>\n"}
	},
	translationName: dojo.moduleUrl('epages.cartridges.de_epages.product.widget', 'templates/translation'),
	imagePath: epages.themeUrl('images'),
	widgetsInTemplate: true,

	postMixInProperties: function () {
        // set correct template string
        this.templateString = this.unity ? this._templateMapping.unity.templateString : this._templateMapping.ep6core.templateString;
        if (djConfig.ecms){
            this.templateString = this._templateMapping.ecms.templateString;
        }

		this.inherited("postMixInProperties", arguments);
		this.autoEmptyRow = epages.string.toBoolean(this.autoEmptyRow);
		this.allowDuplicates = epages.string.toBoolean(this.allowDuplicates);
		this.isLocalized = epages.string.toBoolean(this.isLocalized);
		this.isNew = epages.string.toBoolean(this.isNew);
		this.isUsed = epages.string.toBoolean(this.isUsed);
		this.isPreSelected = epages.string.toBoolean(this.isPreSelected);
		this._oldValues = [];
		this._attributeCounter = this._widgetsOfClass.length;
		this._widgetsOfClass.push(this);
	},

	setAttributeCounter: function (counter) {
		this.typePackageNode.name = "TypePackage" + counter;
		this.attributeAliasNode.name = "VariationAttributeAlias" + counter;
		this.attributeAliasHiddenNode.name = "VariationAttributeAlias" + counter;
		this.isUsedValueNode.name = "UseAttribute" + counter;
		this.headlineNode.innerHTML = "" + (Number(counter) + 1);
		this._attributeCounter = counter;
		this.reorgInputs();
	},

	startup: function () {
		this.inherited("startup", arguments);
		if (this.autoEmptyRow) {
			this.addNewRow();
			if (this.isNew && this.unity) {
				this.addNewRow(this.translate('Example') + ': ' + this.translate('Blue'));
			}
		}
		this.setAttributeCounter(this._attributeCounter);
		// set initial values for localized
		this.localizableNode.attr('checked', this.isLocalized);
		this._onLocalizedClick();
		if (this.isNew) {
			this.attributeAliasHiddenNode.parentNode.removeChild(this.attributeAliasHiddenNode);

			// activate attribute alias
			this.connect(this.attributeAliasNode, 'onchange', '_onChangeAttributeAlias');
			this.connect(this.attributeAliasNode, 'onkeyup', '_onChangeAttributeAlias');
			this.connect(this.attributeAliasNode, 'onclick', '_onChangeAttributeAlias');
			this.attributeAliasNode.disabled = false;
			dojo.removeClass(this.attributeAliasNode, 'Disabled');

			// activate localized checkbox
			this.connect(this.localizableNode.elementNode, 'onclick', '_onLocalizedClick');
			this.localizableNode.attr('disabled', false);

			// activate delete attribute link
			this.connect(this.deleteAttributeNode, 'onclick', '_onClickDeleteAttribute');
			dojo.removeClass(this.deleteAttributeNode, 'HideElement');
		}
		// active use variation attribute checkout
		if (this.isUsed || this.isNew) {
			if (!this.unity) {
				dojo.addClass(this.isUsedBlockNode, 'HideElement');
			}
			this.isUsedFormNode.attr('disabled', true);
		} else {
			if(!this.isPreSelected) {
				this.isUsedFormNode.attr('checked', false);
				this._onIsUsedClick()
			}
			this.connect(this.isUsedFormNode.elementNode, 'onclick', '_onIsUsedClick');
		}
	},

	rows: function () {
		return dojo.filter(this.tableBodyNode.childNodes, function (el) {
			return el.nodeName == 'TR';
		});
	},

	_setAlternateClass: function () {
		var alternate = true;
		dojo.forEach(this.rows(), function (el) {
			alternate = !alternate;
			if (alternate) {
				dojo.addClass(el, 'alternate');
			} else {
				dojo.removeClass(el, 'alternate');
			}
		});
	},

	getInput: function (row) {
		var inputs = dojo.query('.jsInput', row);
		return inputs.length > 0 ? inputs[0] : undefined;
	},

	getInputs: function () {
		var inputs = [];
		dojo.forEach(this.rows(), function (row) {
			var r = dojo.query('.jsInput', row);
			if (r.length > 0) {
				inputs.push(r[0]);
			}
		});
		return inputs;
	},

	getAnchor: function (row) {
		return dojo.query('.jsAnchor', row)[0];
	},

	addValue: function ( /*String*/ alias) {
		// get existing rows and template
		var rows = this.rows();
		var template = rows[rows.length - 2];
		// create new row
		var newRow = template.cloneNode(true);
		var cells = dojo.filter(newRow.childNodes, function (el) {
			return el.nodeName == 'TD';
		});
		cells[0].innerHTML = this.unity ? '<div class="row"><div class="col-xs-4"><span class="ep-input-style-disabled">' + alias + '</span></div></div>' : alias;
		dojo.removeClass(newRow, 'HideElement');
		// insert before template and new elements
		this.tableBodyNode.insertBefore(newRow, rows[this._oldValues.length]);
		// add to internal values
		this._oldValues.push(alias);
		this._setAlternateClass();
	},

	addNewRow: function (placeholder) {
		if (this.getInputs().length + this._oldValues.length > this.maxAttributeValues) {
			return;
		}
		// get existing rows and template
		var rows = this.rows();
		var template = rows[rows.length - 1];
		// create new row
		var row = template.cloneNode(true);
		var input = this.getInput(row);
		if (placeholder) {
			input.placeholder = placeholder;
		}
		input.name = this.emptyInputNamePrefix;
		var anchor = this.getAnchor(row);

		this.connect(anchor, 'onclick', function () {
			input.value = '';
			this.onChangeInput(input, anchor);
			this.onDeleteInput(row);
		});
		var f = function () {
			this.onChangeInput(input, anchor);
		};
		this.connect(input, 'onchange', f);
		this.connect(input, 'onkeyup', f);
		this.connect(input, 'onclick', f);
		this.connect(input, 'onblur', function () {
			if (this.isInputEmpty(input)) {
				this.onDeleteInput(row);
			}
		});
		dojo.removeClass(row, 'HideElement');
		// insert before templates
		this.tableBodyNode.insertBefore(row, rows[rows.length - 2]);
		this._setAlternateClass();
	},

	isInputEmpty: function (input) {
		return input.value == '';
	},

	_changeErrorMessage: function (isValid, errorNode, inputNode) {
		if (!isValid) {
			var absolutePositionY = (this.unity) ? (inputNode.getBoundingClientRect().top + inputNode.getBoundingClientRect().height + window.scrollY) : ($E(inputNode).getAbsolutePosition(dojo.body()).y + inputNode.offsetHeight);
			dojo.publish("uimessage/show", ["", errorNode.innerHTML, "Bubble", {
					typeClass: "Warning",
					sizeClass: "Small",
					x: $E(inputNode).getAbsolutePosition(dojo.body()).x,
					y: absolutePositionY
                }]);
		} else {
			dojo.publish("uimessage/hide", []);
		}
		return isValid;
	},

	onChangeInput: function (input, anchor) {
		if (!this.isInputEmpty(input) && dojo.hasClass(anchor, 'HideElement')) {
			dojo.removeClass(anchor, 'HideElement');
		}
		if (!this.attributeAlias.length && this.unity) {
			this._onChangeAttributeAlias();
		}
		if (!this.allowDuplicates) {
			if (this.isInputEmpty(input)) {
				dojo.removeClass(input, 'DialogError');
			} else {
				//check if value only consists of whitespace chars
				var whitespaceCleared = input.value.replace(/\s/g, '');
				if (whitespaceCleared.length == 0) {
					dojo.addClass(input, 'DialogError');
				} else {
					dojo.removeClass(input, 'DialogError');
					var value = input.value;
					var lcValue = value.toLowerCase();
					var oldValues = dojo.filter(this._oldValues, function (el) {
						return el.toLowerCase() == lcValue;
					});
					if (oldValues.length) {
						dojo.addClass(input, 'DialogError');
					} else {
						var inputs = dojo.filter(this.getInputs(), function (el) {
							return input != el && lcValue == el.value.toLowerCase();
						});
						this._changeErrorMessage(inputs.length == 0, this.DuplicateAttributeValueAlias, input);
						if (inputs.length != 0) {
							dojo.addClass(input, 'DialogError');
						}
					}
				}
			}
		}
		this.reorgInputs();
	},

	onDeleteInput: function (row) {
		row.parentNode.removeChild(row);
		this.reorgInputs();
	},

	reorgInputs: function () {
		var countEmptyRows = 0;
		var rows = this.rows();
		dojo.forEach(rows, function (row) {
			if (!dojo.hasClass(row, 'HideElement')) {
				var input = this.getInput(row);
				if (input === undefined) {
					return;
				}
				if (this.isInputEmpty(input)) {
					countEmptyRows++;
				} else {
					input.name = this.newInputNamePrefix + this._attributeCounter;
				}
			}
		}, this);
		if (this.autoEmptyRow && countEmptyRows == 0) {
			this.addNewRow();
		}
		this._setAlternateClass();
		if (this.unity) {
			this._onChangeAttributeAlias();
		}
		//need little timeout to set existing rows correct
		window.setTimeout(dojo.hitch(this, function () {
			this.enableNextButton();
		}), 1);
	},

	_onLocalizedClick: function () {
		this.isLocalized = this.localizableNode.elementNode.checked;
		this.typePackageNode.value = (this.isLocalized ? "PreDefLocalizedString" : "PreDefString");
	},

	_onIsUsedClick: function () {
		var inputs = this.getInputs();

		if (this.isUsedFormNode.elementNode.checked) {
			// hide text in information element
			jq(this.isUsedFormNode.elementNode).closest('div').children('p:first').slideUp(500);

			if (this.unity) {
				jq(this.tableBodyNode.parentNode).closest('.attributeTable').removeClass('HideElement');

				dojo.forEach(inputs, function (input) {
					dojo.attr(input, 'disabled', false);
				}, this);
			}
			dojo.removeClass(this.tableBodyNode.parentNode, 'HideElement');
			this.isUsedValueNode.value = "1";
			var isAllreadyInside = false;
			for (var i = 0, iLength = this._widgetsOfClass.length; i < iLength; i++) {
				if (this._widgetsOfClass[i] == this) {
					isAllreadyInside = true;
				}
			}
			if (!isAllreadyInside) {
				$A(this._widgetsOfClass).push(this);
			}
		} else {
			// show text in information element
			jq(this.isUsedFormNode.elementNode).closest('div').children('p:first').slideDown(500);
			dojo.addClass(this.tableBodyNode.parentNode, 'HideElement');
			if (this.unity) {
				jq(this.tableBodyNode.parentNode).closest('.attributeTable').addClass('HideElement');

				dojo.forEach(inputs, function (input) {
					dojo.attr(input, 'disabled', true);
				}, this);
			}
			this.isUsedValueNode.value = "0";
		}
		this._checkNextButton();
	},

	_checkNextButton: function () {
		var allWidgets = this._widgetsOfClass,
			usedWidgets = dojo.filter(allWidgets, function (el) {
				return el.isInUse();
			}),
			validWidgets = dojo.filter( (this.unity ? usedWidgets : allWidgets), function (el) {
				return el.isValid();
			}),
			valid = (this.unity ? usedWidgets.length : allWidgets.length) === validWidgets.length,
			b = $$(this.nextButtonId);

		if (!valid || usedWidgets.length == 0  || (this.unity && usedWidgets.length > this.params.maxAttributeCount)) {
			if (b === undefined) {
				$(this.nextButtonId).disabled = "disabled";
			} else {
				b.disable();
			}
		} else {
			if (b === undefined) {
				$(this.nextButtonId).disabled = "";
			} else {
				b.enable();
			}
		}
	},

	_onChangeAttributeAlias: function () {
		var inputNode = this.attributeAliasNode;
		var value = inputNode.value;
		if (value == this.attributeAlias && (!this.unity || this.attributeAlias != '')) {
			if (dojo.hasClass(inputNode, 'DialogError')) {
				dojo.removeClass(inputNode, 'DialogError');
				dojo.publish("uimessage/hide", []);
			}
			if (!(this.unity && this.attributeAliasError)) {
				return;
			}
		}
		// test if alias is empty
		var isOk = true,
			nonEmptyInputCount = this.getInputs().filter(function(input) {return input.value.length}).length,
			isEmpty = this.isInputEmpty(inputNode),
			errorCondition = this.unity ? !(isEmpty && nonEmptyInputCount) : !isEmpty;


		if (!this._changeErrorMessage(errorCondition, this.EmptyAttributeAlias, inputNode)) {
			isOk = false;
			dojo.addClass(inputNode, 'DialogError');
		}

		if (!isEmpty || !this.unity) {
			// test if xml complaint
			if (isOk) {
				if (!this._changeErrorMessage(epages.validate.string.isXMLAttribute(value), this.AttributeAliasNoXMLName, inputNode)) {
					isOk = false;
					if (this.unity) {
						dojo.addClass(inputNode, 'DialogError');
					}
				}
			}
			// test duplicate alias
			var lcValue = value.toLowerCase();
			if (isOk) {
				var aliases = dojo.filter(this._widgetsOfClass, function (el) {
					return el.attributeAlias.toLowerCase() == lcValue;
				});
				if (!this._changeErrorMessage(aliases.length == 0, this.ProductAttributeExists, inputNode)) {
					isOk = false;
					dojo.addClass(inputNode, 'DialogError');
				}
			}
			if (isOk) {
				var aliases = dojo.filter(this._existingAttributes, function (el) {
					return el.toLowerCase() == lcValue;
				});
				if (!this._changeErrorMessage(aliases.length == 0, this.ProductAttributeExists, inputNode)) {
					isOk = false;
					dojo.addClass(inputNode, 'DialogError');
				}
			}
			if (isOk) {
				this.attributeAlias = value;
				if (this.unity && this.attributeAliasError) {
					this.attributeAliasError = false;
					if (dojo.hasClass(inputNode, 'DialogError')) {
						dojo.removeClass(inputNode, 'DialogError');
						dojo.publish("uimessage/hide", []);
					}
				}
			} else if (this.unity) {
				this.attributeAlias = '';
				this.attributeAliasError = true;
			}
		}
		if (isOk && this.unity) {
			if (dojo.hasClass(inputNode, 'DialogError')) {
				dojo.removeClass(inputNode, 'DialogError');
				dojo.publish("uimessage/hide", []);
			}
		}
		this.enableNextButton();
	},

	_onClickDeleteAttribute: function () {
		// remove from list
		var allWidgets = this._widgetsOfClass;
		epages.cartridges.de_epages.product.widget.VariationAttributeList.prototype._widgetsOfClass = [];
		dojo.forEach(allWidgets, function (el) {
			if (el == this) {
				return;
			}
			el.setAttributeCounter(this._widgetsOfClass.length);
			this._widgetsOfClass.push(el);
		}, this);
		this.enableNextButton();
		dojo.publish(this.id + '/onClickDeleteAttribute', [this]);
		if (this.unity) {
			dojo.publish("uimessage/hide", []);
		}
	},

	isEmpty: function () {
		//summary: check if current Attribute is unused
		var inputs = this.getInputs(),
			emptyInputs = dojo.filter(inputs, function (el) {
				return (el.value.length === 0);
			});

		return (this.attributeAlias == '' && emptyInputs.length === inputs.length);
	},

	isValid: function () {
		//summary: check if current Attribute is valid
		//description: check if alias of attribute is defined, if values are set
		//and if there are no DialogErrors inside the inputs
		var inputs = this.getInputs();

		if (!this.unity && inputs.length == 2 && this._oldValues.length == 0) {
			return false; // Boolean
		}
		if (this.attributeAlias == '' && (!this.unity || (inputs.some(function(el) { return el.value.length })) )) {
			return false;
		}
		if (dojo.hasClass(this.attributeAliasNode, 'DialogError')) {
			return false;
		}
		var invalidInputs = dojo.filter(inputs, function (el) {
			return dojo.hasClass(el, 'DialogError');
		});
		if (invalidInputs.length) {
			return false;
		}
		if (this.unity) {
			if (this.attributeAlias != '' && !this._oldValues.length && inputs.length > 1 && !inputs[0].value.length) {
				return false;
			}
		}
		return true; // Boolean
	},

	isInUse: function () {
		//summary: check if current Attribute is used
		//description: check if variation will be created with this attribute
		if (!this.useAttribute()) {
			return false; // Boolean
		}
		return true; // Boolean
	},

	enableNextButton: function () {
		// summary: send message to enable next button (if validation is ok)
		dojo.publish("step1/checkNextButton", []);
	},

	useAttribute: function () {
		return this.isUsed || this.isUsedFormNode.elementNode.checked;
	},

	getValues: function () {
		var values = [];
		for (var i = 0, length = this._oldValues.length; i < length; i++) {
			values.push(this._oldValues[i]);
		}
		dojo.forEach(this.getInputs(), function (input) {
			if (!this.isInputEmpty(input)) {
				values.push(input.value);
			}
		}, this);
		return values;
	},

	hasNewAttributes: function () {
		var allWidgets = epages.cartridges.de_epages.product.widget.VariationAttributeList.prototype._widgetsOfClass;
		if (allWidgets.length == 0) {
			return false;
		}
		var newWidgets = dojo.filter(allWidgets, function (el) {
			return el.isNew;
		});
		return newWidgets.length > 0;
	},

	getAttributeCounter: function () {
		return this._attributeCounter;
	}

});

}

if(!dojo._hasResource["epages.cartridges.de_epages.product.widget.VariationProductList"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.product.widget.VariationProductList"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.product.widget.VariationProductList

*/
dojo.provide("epages.cartridges.de_epages.product.widget.VariationProductList");




dojo.declare("epages.cartridges.de_epages.product.widget.VariationProductList",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		productAlias:        "",
		productName: 		 "",
		maxListedProducts:   400,
		maxSelectedProducts: 200, // feature ProductMaxSubProducts
		nextButtonId:        "",

		/**
		 * private properties
		 */
		_attributeAliases: undefined,
		_existingProducts: undefined,
		_newProducts:      undefined,
		_existingProductsKey: undefined,
		_newProductsKey:      undefined,
		_currentTable:     undefined,
		_counterExistingProducts: 0,
		_counterNewProductAlias: 0,
		_maxExistingProductReached: false,
		_maxNewProductReached: false,
		_inputs: undefined,

		// unity flag
		unity: (djConfig.unity !== undefined && djConfig.unity === true) ? true : false,

		/**
		 * widget properties
		 */
		templateString: undefined,
		_templateMapping: {
			'ep6core' : {templateString:"<div class=\"VariationProductList\">\n\n<!-- ErrorMessages -->\n<div>\n  <div class=\"DialogMessage MessageInfo HideElement\"  dojoAttachPoint=\"ErrorNewProductsNode\">\n    <h3>{Notification}</h3>\n    <p class=\"HideElement\" dojoAttachPoint=\"ErrorNotAllNewProductsInListNode\">{NotAllNewProductsInList}</p>\n    <p class=\"HideElement\" dojoAttachPoint=\"ErrorMoreNewProductsAsPossibleNode\">{MoreNewProductsAsPossible}</p>\n  </div>\n  <div class=\"DialogMessage MessageInfo HideElement\" dojoAttachPoint=\"ErrorMaxSubProductsReachedNode\">\n    <h3>{Notification}</h3>\n    <p>{MaxSubProductsReached}</p>\n  </div>\n  <div class=\"DialogMessage MessageWarning HideElement\" dojoAttachPoint=\"ErrorDuplicateProductAliasNode\">\n    <h3>{InputError}</h3>\n    <p>{DuplicateProductAlias}</p>\n  </div>\n</div>\n\n<!-- product table -->\n<div dojoAttachPoint=\"targetNode\">\n</div>\n\n<div>\n"},
			'unity'   : {templateString:"<div class=\"VariationProductList\">\n\n<!-- ErrorMessages -->\n<div>\n  <div class=\"ep-notification-info BottomMarginWide HideElement\"  dojoAttachPoint=\"ErrorNewProductsNode\">\n    <h3>{Notification}</h3>\n    <p class=\"HideElement\" dojoAttachPoint=\"ErrorNotAllNewProductsInListNode\">{NotAllNewProductsInList}</p>\n    <p class=\"HideElement\" dojoAttachPoint=\"ErrorMoreNewProductsAsPossibleNode\">{MoreNewProductsAsPossible}</p>\n  </div>\n  <div class=\"ep-notification-info BottomMarginWide HideElement\" dojoAttachPoint=\"ErrorMaxSubProductsReachedNode\">\n    <h3>{Notification}</h3>\n    <p>{MaxSubProductsReached}</p>\n  </div>\n  <div class=\"ep-notification-warning BottomMarginWide HideElement\" dojoAttachPoint=\"ErrorDuplicateProductAliasNode\">\n    <h3>{InputError}</h3>\n    <p>{UnityDuplicateProductAlias}</p>\n  </div>\n  <div class=\"ep-notification-warning BottomMarginWide HideElement\" dojoAttachPoint=\"ErrorNoProductAliasNode\">\n    <h3>{InputError}</h3>\n    <p>{NoProductAlias}</p>\n  </div>\n</div>\n\n<!-- product table -->\n<div dojoAttachPoint=\"targetNode\">\n</div>\n\n<div>\n"}
		},
		translationName: dojo.moduleUrl('epages.cartridges.de_epages.product.widget', 'templates/translation'),
		imagePath:       epages.themeUrl('images'),

		templateTable: 	['<table class="ContentList BottomMargin">'+
							'<thead><tr><td class="Checkbox"><input checked="checked" class="Checkbox" dojotype="epages.widget.FormElement" name="selector" value="checkbox" onclick="OnCheckAll(this.form, \'ListItem\', this.checked);" type="text" /></td>', // 0
							'<td>','</td>', // 1 + 2
							'</tr></thead>'+
							'<tfoot><tr><td colspan="','"></tr></tfoot><tbody>','</tbody>'+ // 3+4+5
						'</table>' // 5
					 	],
		templateOldRowUnity: ['<tr class="ep-product-variation-wizard-disabled-row"','>'+
									'<td class="Checkbox"><input disabled="disabled" class="Checked Checkbox Disabled" type="text" checked="checked" name="ListItem" value="" /></td>' +
									'<td class="MediumSlimColumn NoWrap RightMarginWide"><span class="ep-input-style-disabled">','</span></td>' +
									'<td class="MediumColumn NoWrap">','</td>',
									'<td>','</td>',
									'</tr>'
									],
		templateOldRow: ['<tr','>'+
									'<td class="Checkbox"><input disabled="disabled" class="Checked Checkbox Disabled" type="text" checked="checked" name="ListItem" value="" /></td>'+
									'<td class="MediumColumn NoWrap"><img title="" alt="" src="'+epages.vars.IconsRoot+'/object_ico_s_product.png" />','</td>',
									'<td>','</td>',
									'</tr>'
									],
		templateNewRow: ['<tr','>'+
									'<td class="Checkbox"><input type="text" checked="checked" name="ListItem" value="','" class="Checked Checkbox Disabled" dojotype="epages.widget.FormElement" /></td>' +
									'<td class="MediumColumn NoWrap"><img title="" alt="" src="'+epages.vars.IconsRoot+'/object_ico_s_product.png" /><input class="jsInput" type="text" name="VariationAlias','" value="','" /></td>',
									'<td>','<input type="hidden" name="NewVariationAttributeValues','" value="','" /></td>',
									'</tr>'
									],
		templateNewRowUnity: ['<tr','>'+
									'<td class="Checkbox"><input type="text" checked="checked" name="ListItem" value="','" class="Checked Checkbox Disabled" dojotype="epages.widget.FormElement" /></td>' +
									'<td class="MediumSlimColumn NoWrap RightMarginWide"><input class="jsInput border-box" type="text" name="VariationAlias','" value="','" /></td><td class="MediumColumn NoWrap">','</td>',
									'<td>','<input type="hidden" name="NewVariationAttributeValues','" value="','" /></td>',
									'</tr>'
									],

		postMixInProperties: function() {
			// set correct template string
			this.templateString = this.unity ? this._templateMapping.unity.templateString : this._templateMapping.ep6core.templateString;

			this.inherited("postMixInProperties", arguments);
			this.maxListedProducts   = Number(this.maxListedProducts);
			this.maxSelectedProducts = Number(this.maxSelectedProducts);
			this._attributeAliases = [];
			this._existingProducts    = {};
			this._existingProductsKey = {};
			this._newProducts    = {};
			this._newProductsKey = {};
		},

		postCreate: function() {
			this.inherited("postCreate", arguments);
			var node = this.targetNode;
			this.connect(node,'onchange', '_onListEvent');
			this.connect(node,'onkeyup', '_onListEvent');
			this.connect(node,'onclick', '_onListEvent');
		},

		addAttribute: function (alias) {
			this._attributeAliases.push(alias);
		},

		buildKey: function(data) {
			return dojo.map(this._attributeAliases, function (el) { return data[el]; }).join("\n");
		},

		addExistingProduct: function (alias, productData) {
			this._existingProducts[alias] = productData;
			this._existingProductsKey[this.buildKey(productData)] = alias;
			this._counterExistingProducts++;
			if (this._counterExistingProducts >= this.maxSelectedProducts) {
				this._maxExistingProductReached = true;
				dojo.removeClass(this.ErrorMaxSubProductsReachedNode,'HideElement');
				return;
			}
		},

		buildNewAlias: function () {
			this._counterNewProductAlias++;
			var s = this._counterNewProductAlias.toString();
			if(s.length==1){
				s="000"+s;
			}
			if(s.length==2){
				s="00"+s;
			}
			if(s.length==3){
				s="0"+s;
			}
			return this.productAlias+'-'+s;
		},

		addNewProduct: function (productData) {
			if(this._maxExistingProductReached){
				return true;
			}
			if(this._counterNewProductAlias >= this.maxListedProducts) {
				if (this._maxNewProductReached){
					return true;
				}
				this._maxNewProductReached = true;
				dojo.removeClass(this.ErrorNewProductsNode,'HideElement');
				dojo.removeClass(this.ErrorNotAllNewProductsInListNode,'HideElement');
				return true;
			}
			var key = this.buildKey(productData);
			if(this._existingProductsKey[key] || this._newProductsKey[key]) {
				return false;
			}
			// find new alias
			var alias = this.buildNewAlias();
			while (this._newProducts[alias] !== undefined || this._existingProducts[alias] !== undefined) {
				alias = this.buildNewAlias();
			}

			// register new product
			this._existingProductsKey[key] = alias;
			this._newProducts[alias] = productData;
			return false;
		},

		showTable: function () {
			// show error MoreNewProductsAsPossible
			if(this._counterNewProductAlias > this.maxSelectedProducts) {
				dojo.removeClass(this.ErrorNewProductsNode,'HideElement');
				dojo.removeClass(this.ErrorMoreNewProductsAsPossibleNode,'HideElement');
			}
			// **** build table ****
			var rows = [];
			var template = this.templateTable;
			rows.push(template[0]);

			// build header
			if (this.unity) {
				rows.push(template[1]+this.translate('SKU')+template[2]);
				rows.push(template[1]+this.translate('Name')+template[2]);
			} else {
				rows.push(template[1]+this.translate('SKU')+template[2]);
			}
			dojo.forEach(this._attributeAliases, function (el) {
				rows.push(template[1]+el+template[2]);
			}, this);

			// colspan footer
			rows.push(template[3] + (this._attributeAliases.length + (this.unity ? 3 : 2)) + template[4]);

			// build existing products
			template = (this.unity) ? this.templateOldRowUnity : this.templateOldRow;
			var isAlternate = true;
			for (var alias in this._existingProducts) {
				isAlternate = !isAlternate;
				data = this._existingProducts[alias];
				if (this.unity) {
					rows.push(template[0] + (isAlternate ? ' class="alternate" ' : '') + template[1] + alias + template[2] + data.productNameOrAlias + template[3]);
					dojo.forEach(this._attributeAliases, function (el) {
						if(data[el]){
							rows.push(template[4]+ epages.string.escapeXml(data[el]) + template[5]);
						}
					});
					rows.push(template[6]);
				} else {
					rows.push(template[0] + (isAlternate ? ' class="alternate" ' : '') + template[1]+alias+template[2]);
					dojo.forEach(this._attributeAliases, function (el) {
						if(data[el]){
							rows.push(template[3]+ epages.string.escapeXml(data[el]) + template[4]);
						}
					});
					rows.push(template[5]);
				}
			}
			// build new products
			var counter = 0;
			if (this.unity) {
				template = this.templateNewRowUnity;
				for(var alias in this._newProducts) {
					isAlternate = !isAlternate;
					data = this._newProducts[alias];
					rows.push(template[0] + (isAlternate ? ' class="alternate" ' : '') + template[1]+counter+template[2]+counter+template[3]+alias+template[4]+this.productName+template[5]);
					dojo.forEach(this._attributeAliases, function (el) {
						if(data[el]){
							rows.push(template[6]+epages.string.escapeXml(data[el])+template[7]+counter+template[8]+epages.string.escapeXml(data[el])+template[9]);
						}
					});
					rows.push(template[10]);
					counter++;
				}
				rows.push(this.templateTable[6]);
			} else {
				template = this.templateNewRow;
				for(var alias in this._newProducts) {
					isAlternate = !isAlternate;
					data = this._newProducts[alias];
					rows.push(template[0] + (isAlternate ? ' class="alternate" ' : '') + template[1]+counter+template[2]+counter+template[3]+alias+template[4]);
					dojo.forEach(this._attributeAliases, function (el) {
						if(data[el]){
							rows.push(template[5]+epages.string.escapeXml(data[el])+template[6]+counter+template[7]+epages.string.escapeXml(data[el])+template[8]);
						}
					});
					rows.push(template[9]);
					counter++;
				}
				rows.push(this.templateTable[5]);
			}
			this.targetNode.innerHTML = rows.join("\n");
			dojo.parser.parse(this.targetNode);
			// clear temp new products, because aliases can be changed, so they can not used longer
			this._existingProductsKey = {};
			this._newProducts = {};
		},

		checkInputAlias: function (input) {
			var v = input.value.toLowerCase();

			if (this.unity && !v.length && !dojo.hasClass(input,'DialogError')) {
				dojo.addClass(input,'DialogError');
				dojo.removeClass(this.ErrorNoProductAliasNode,'HideElement');
				this.enableNextButton();
				return;

			} else if (this.unity && this._areInputsValid()) {
				dojo.addClass(this.ErrorNoProductAliasNode,'HideElement');
			}

			var nodes = dojo.filter(dojo.query(".jsInput", this.targetNode), function (el) {
				var checkBoxNode = dojo.query('input[name="ListItem"]',el.parentNode.parentNode)[0];
				if(checkBoxNode && !checkBoxNode.checked){
					return false;
				}
				else{
					return el.value.toLowerCase() == v;
				}
			});
			if (this._existingProducts[v] || nodes.length > 1) {
				if (!dojo.hasClass(input,'DialogError')) {
					dojo.addClass(input,'DialogError');
					this.enableNextButton();
					dojo.removeClass(this.ErrorDuplicateProductAliasNode,'HideElement');
				}
			} else {
				if (dojo.hasClass(input,'DialogError')) {
					dojo.removeClass(input,'DialogError');
					dojo.forEach(dojo.query(".DialogError", this.targetNode), this.checkInputAlias, this);
					if (this._areInputsValid()) {
						dojo.addClass(this.ErrorDuplicateProductAliasNode,'HideElement');
						this.enableNextButton();
					}
				}
			}
		},

		_onListEvent: function (evt) {
			if (evt.target.nodeName != 'INPUT'){
				return;
			}
			var input = evt.target;
			if (input.type == 'text') {
				var checkBoxNode = dojo.query('input[name="ListItem"]',input.parentNode.parentNode)[0];
				if(checkBoxNode && checkBoxNode.checked){
					this.checkInputAlias(input);
				}
			}
			else if(input.type =='checkbox' && input.checked){
				var aliasInput = document.getElementsByName('VariationAlias' + input.value)[0];
				if(aliasInput){
					this.checkInputAlias(aliasInput);
				}
			}
		},

		_areInputsValid: function () {
			var nodes = dojo.query(".DialogError", this.targetNode);
			return nodes.length == 0;
		},

		_areCheckboxesValid: function () {
			return true;
		},

		enableNextButton: function () {
			if (this.nextButtonId == ''){
				return;
			}
			var valid = this._areInputsValid() && this._areCheckboxesValid();

			var b = $$(this.nextButtonId);
			if (b === undefined){
				$(this.nextButtonId).disabled=!valid;
			}else if (valid){
				b.enable();
			}else{
				b.disable();
			}
		},

		resetAttributesList: function () {
			this._attributeAliases = [];
		},

		resetExistingProductKeys: function () {
			this._existingProductsKey = {};
			for (var alias in this._existingProducts) {
				var productData = this._existingProducts[alias];
				this._existingProductsKey[this.buildKey(productData)] = alias;
			}
		},

		resetNewProductList: function () {
			this._counterNewProductAlias = 0;
			this.resetExistingProductKeys();
			this._newProducts = {};
			this._newProductsKey = {};
		},

		createNewProducts: function (attributeWidgets, data) {
			var widgets = [];
			for (var i = 0, length = attributeWidgets.length; i < length; i++){
				if(attributeWidgets[i].useAttribute()){
					widgets.push(attributeWidgets[i]);
				}
			}
			var widget = widgets.shift();
			if (!widget) {
    			return true;
			}
			var values = widget.getValues();
			if (widget.useAttribute() && values.length) {
				var alias = widget.attributeAlias;
				var abort = false;
				dojo.forEach(values, function (value) {
					if (abort){
						return;
					}
					data[alias] = value;
					if (widgets.length) {
						abort = this.createNewProducts(widgets, data);
					} else {
						var copy = {};
						for (var key in data){
							copy[key] = data[key];
						}
						abort = this.addNewProduct(copy);
					}
				}, this);
				return abort;
			}
			if (widgets.length){
				return this.createNewProducts(widgets, data);
			}
			return this.addNewProduct(data);
		},

		buildTable: function (widgets) {
			if (widgets === undefined) {
				widgets = epages.cartridges.de_epages.product.widget.VariationAttributeList.prototype._widgetsOfClass;
			}
			this.resetAttributesList();
			dojo.forEach(widgets, function (el) {
				if(el.useAttribute()){
					this.addAttribute(el.attributeAlias);
				}
			}, this);
			this.resetNewProductList();
			this.createNewProducts(widgets, {});
		},

		setOnExistingProducts: function (alias, value) {
			for (var key in this._existingProducts) {
				var data = this._existingProducts[key];
				data[alias]=value;
			}
		},

		getCountExistingProducts: function () {
			return this._counterExistingProducts;
		}
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.product.widget.VariationDefaultList"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.product.widget.VariationDefaultList"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.product.widget.VariationDefaultList

*/
dojo.provide("epages.cartridges.de_epages.product.widget.VariationDefaultList");




dojo.declare("epages.cartridges.de_epages.product.widget.VariationDefaultList",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		attributeAlias: "",
		nextButtonId:   "",
		inputName:      "DefaultAttributeValue",

		/**
		 * private properties
		 */
		_values:         undefined,
		_widgetsOfClass: [], // list of widgets (used by all widgets of this class)

		/**
		 * widget properties
		 */
		templateString:"<div class=\"VariationDefaultList\">\n\n<!-- HeadLine -->\n<h3>{PredefinedValueForAttribute}: ${attributeAlias}</h3>\n\n<!-- product table -->\n<div dojoAttachPoint=\"targetNode\" class=\"TopMargin\">\n</div>\n\n<div>\n",
		translationName: dojo.moduleUrl('epages.cartridges.de_epages.product.widget', 'templates/translation'),

		templateTable: ['<table class="ContentList BottomMargin">'+
											'<tbody>','</tbody>'+ // 0+1
										'</table>' // 1
									],
		templateRow: ['<tr','>'+ // 0+1
									'<td class="Checkbox"><input class="jsInput ep-js" data-js="ep.uiInput()" type="radio" name="','" value="','" /></td><td>','</td>'+ // 1+2+3+4
									'</tr>' // 4
									],

		postMixInProperties: function() {
			this.inherited("postMixInProperties", arguments);
			this._values = [];
			this._widgetsOfClass.push(this);
		},

		postCreate: function() {
			this.inherited("postCreate", arguments);
			var node = this.targetNode;
			this.connect(node,'onclick', '_onListEvent');
		},

		addValue: function (value) {
			this._values.push(value);
		},

		showTable: function () {
			// **** build table ****
			var template = this.templateTable;
			var rows = [template[0]];

			// build tbody (rows)
			template=this.templateRow;
			var isAlternate = true;
			dojo.forEach(this._values, function (value) {
				isAlternate = !isAlternate;
				rows.push(template[0] + (isAlternate ? ' class="alternate" ' : '') + template[1]+this.inputName+template[2]+value+template[3]+value+template[4]);
			}, this);
			rows.push(this.templateTable[1]);
			this.targetNode.innerHTML = rows.join("\n");
			dojo.parser.parse(this.targetNode);
		},

		_onListEvent: function (evt) {
			if (evt.target.nodeName != 'INPUT'){
				return;
			}
			this.enableNextButton();
		},

		getInputs: function () {
			return dojo.filter(dojo.query('.jsInput', this.domNode), function (el) { return el.nodeName == 'INPUT'; });
		},

		isValid: function () {
			var radios = dojo.filter(this.getInputs(), function (el) { return el.checked; });
			return radios.length > 0;
		},

		getValue: function () {
			var radios = dojo.filter(this.getInputs(), function (el) { return el.checked; });
			if (radios.length == 0){
				return undefined;
			}
			return radios[0].value;
		},

		selectFirst: function () {
			var radios = this.getInputs();
			if (radios.length > 0){
				radios[0].checked = true;
			}
		},

		areAllValid: function () {
			var allWidgets = epages.cartridges.de_epages.product.widget.VariationDefaultList.prototype._widgetsOfClass;
			if (allWidgets.length == 0){
				return true;
			}
			var validWidgets = dojo.filter(allWidgets, function (el) { return el.isValid(); });
			return allWidgets.length == validWidgets.length;
		},

		enableNextButton: function () {
			if (this.nextButtonId == ''){
				return;
			}
			var valid = this.areAllValid();
			var b = $$(this.nextButtonId);

			if (b === undefined){
				$(this.nextButtonId).disabled=!valid;
			}else if (valid){
				b.enable();
			}else{
				b.disable();
			}
		}

});

}

if(!dojo._hasResource["epages.cartridges.de_epages.order.sendorderdocument"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.order.sendorderdocument"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.order.sendorderdocument

*/

dojo.provide("epages.cartridges.de_epages.order.sendorderdocument");







epages.cartridges.de_epages.order.SendOrderDocument = {

	errorMap: {
		EMAIL_MISSING:															"",
		InvalidMailAddress:													"",
		SUBJECT_MISSING:														"",
		MISSING_FROM:																"",
		No_Recipients:															"",
		Invalid_Recipient:													"",
		ERROR_CREATING_PDF:													""
	},

	localizedStrings: {
		sendDocumentAsPDF:													"",
		waitWhilePDFGenerating:											"",
		documentSentHeadline:												"",
		documentSentText:														"",
		sendMail:																		"",
		cancel:																			"",
		error:																			""
	},
	unity: (djConfig.unity) ? djConfig.unity : false,

	sendDocumentAsMailDialog: null,
	_translateStrings: function(dialogContent) {
        // summary:
	//	Retrieve all the errorMap / localizedStrings properties.
		if(this.errorMap.EMAIL_MISSING.length < 2) { // do this only once
			var tmpContainer = document.createElement("div");
			tmpContainer.className = "HideElement";
			tmpContainer.innerHTML = dialogContent;
			eval(tmpContainer.getElementsByTagName("script")[0].innerHTML);
		}
	},

	_showBusyLayer: function() {
		dojo.publish("uimessage/startBusy", ["sendorderdocument_busy", this.localizedStrings.waitWhilePDFGenerating]);
	},

	_hideBusyLayer: function() {
		dojo.publish("uimessage/stopBusy", ["sendorderdocument_busy"]);
	},
	_insertDialogMessage: function(isError, messageHeadline, messageText) {
        // summary:
	//		Pass the status message of this module to the user via .DialogMessage.
	// description:
	//		Can be the error or success message.
		// this is tricky because dialog areas don't have a fixed id
		// we're using the <form> (which has to be there in every case) as fallback
		var dialogNode = dojo.query("div.TabPage > form > div.Dialog")[0] || dojo.query("div.TabPage > form")[0];

		var messageNode = $("SendOrderDocumentResult") || document.createElement("div");
		messageNode.id = "SendOrderDocumentResult"
		if(this.unity) {messageNode.className = "ep-notification-" + (isError ? "warning" : "success") + " BottomWideMargin";}
		else {messageNode.className = "DialogMessage " + (isError ? "MessageWarning" : "MessagePositiveResult");}
		messageNode.innerHTML = "<h3>" + messageHeadline + "</h3><p>" + messageText + "</p>";

		dialogNode.insertBefore(messageNode, dialogNode.firstChild);
	},

	_throwError: function(errorMessage) {
		this._insertDialogMessage(true, this.localizedStrings.error, errorMessage || this.errorMap.ERROR_CREATING_PDF);
		this._hideBusyLayer();
	},

	_onMailSent: function() {
		this._insertDialogMessage(false, this.localizedStrings.documentSentHeadline, this.localizedStrings.documentSentText);
		this._hideBusyLayer();
	},

	_onResponse: function(response) {
		if(!response || response.error) {
			// hard error with no further information
			this._throwError(this.errorMap.ERROR_CREATING_PDF);
		}else if(response.data.mailSent) {
			if(epages.string.toBoolean(response.data.mailSent)) {
				// everything fine
				this._onMailSent();
			}else {
				// soft error with description
				this._throwError(this.errorMap[response.data.reason]);
			}
		}
	},

	_removeErrorMessageFromInput: function(evt) {
			dojo.removeClass(evt.currentTarget, "DialogError");
			dojo.publish("uimessage/hide");
	},

	_onSendButtonClicked: function(objectID) {
        // summary:
	//		Trigger the xhr process or init error handling.
		var sendOrderDocumentForm = $("sendOrderDocumentForm");
		var inputPosition = $E(sendOrderDocumentForm.To).getAbsolutePosition(dojo.body());

		if(!sendOrderDocumentForm.To.value) {
			dojo.publish("uimessage/show", [this.localizedStrings.error, this.errorMap.EMAIL_MISSING, "Bubble", {
				x:					inputPosition.x,
				y:					inputPosition.y + sendOrderDocumentForm.To.offsetHeight - 5,
				sizeClass:	"Small"
			}]);
			dojo.addClass(sendOrderDocumentForm.To, "DialogError");
			dojo.connect(sendOrderDocumentForm.To, "focus", this, "_removeErrorMessageFromInput");
			return;
		}else if(!sendOrderDocumentForm.To.value.match("@") || sendOrderDocumentForm.To.value.length < 3) {
			dojo.publish("uimessage/show", [this.localizedStrings.error, this.errorMap.InvalidMailAddress, "Bubble", {
				x:					inputPosition.x,
				y:					inputPosition.y + sendOrderDocumentForm.To.offsetHeight - 5,
				sizeClass:	"Small"
			}]);
			dojo.addClass(sendOrderDocumentForm.To, "DialogError");
			dojo.connect(sendOrderDocumentForm.To, "focus", this, "_removeErrorMessageFromInput");
			return;
		}
		if(!sendOrderDocumentForm.Subject.value) {
			inputPosition = $E(sendOrderDocumentForm.Subject).getAbsolutePosition(dojo.body());

			dojo.publish("uimessage/show", [this.localizedStrings.error, this.errorMap.SUBJECT_MISSING, "Bubble", {
				x:					inputPosition.x,
				y:					inputPosition.y + sendOrderDocumentForm.Subject.offsetHeight - 5,
				sizeClass:	"Small"
			}]);
			dojo.addClass(sendOrderDocumentForm.Subject, "DialogError");
			dojo.connect(sendOrderDocumentForm.Subject, "focus", this, "_removeErrorMessageFromInput");
			return;
		}

		this._showBusyLayer();

		var msgElements = new Object();
		dojo.forEach(dojo.query("[name]", sendOrderDocumentForm), function(item) {
			if(item.value) {
				// collect all form values and append them to the message object
				msgElements[item.name] = item.value;
			}
		});

		var _this = this;
		jQuery.ajax({
			type: "POST",
			url: "?ObjectID=" + objectID,
			data: msgElements,
			dataType: "json"
			})
			.done(function( response ) {
				_this._onResponse({ "data": response });
			})
			.fail(function(error){
				_this._throwError(_this.errorMap.ERROR_CREATING_PDF);
			});

		this.sendDocumentAsMailDialog.hide();
	},

	openDialog: function(docAlias /* String */, objectID /* String */, languageID /* String */, TemplateAction /* String */) {
        // summary:
        //		Open the dialog for sending a mail with pdf attached.
        // description:
        //		The opened dialog triggers the method which will generate the pdf equivalent to the current order document.
        // docAlias:
        //		The alias (TLE) for the document.
        // objectID:
        //		The ObjectID (TLE) for the document.
        // languageID:
        //		The LanguageID (TLE) for the document.
		this.sendDocumentAsMailDialog = $$("sendDocumentAsMailDialog");
		if(this.sendDocumentAsMailDialog) {this.sendDocumentAsMailDialog.destroy()} // the dialog was opened before

		var existWidget = $$('sendOrderDocumentForm');
		if( existWidget ){ existWidget.destroy(); } // the dialog was opened before, destroy form

		var dialogContent = (new epages.io.Json()).loadSync("?", { // maybe async would do? Sync frezes the UI.
				ViewAction:         "JSONSnippet",
				TemplateAction:     (TemplateAction || "MBO-ViewSendOrderDocumentAsPDFMailDialog"),
				TemplateLanguageID: (languageID || ""),
				ObjectID:           (objectID || ""),
				Doc:                (docAlias || "")
			});

		dialogContent = dialogContent.data.snippet;
		this._translateStrings(dialogContent);

		this.sendDocumentAsMailDialog = new epages.widget.Modaldialog({
			id: "sendDocumentAsMailDialog",
			options: {
				title : this.localizedStrings.sendDocumentAsPDF,
				width : 450,
				scroll: "hidden",
				content: dialogContent
			},
			buttons: [{
				label: this.localizedStrings.sendMail,
				onclick: dojo.hitch(this, function(){this._onSendButtonClicked(objectID)})
			},{
				label: this.localizedStrings.cancel,
				onclick: dojo.hitch(this, function() {
					this.sendDocumentAsMailDialog.hide();
				})
			}]
		});

		dojo.connect(this.sendDocumentAsMailDialog.domNode, "mouseup", function() {
			// hide all error messages
			dojo.publish("uimessage/hide");
		});

		dojo.connect(this.sendDocumentAsMailDialog.domNode, "keypress", dojo.hitch(this, function(evt) {
			if(evt.keyCode === dojo.keys.ENTER && evt.target.tagName !== "TEXTAREA") {
				// enable the user to submit the form via keyboard
				this._onSendButtonClicked(objectID);
			}
		}));

		dojo.body().appendChild(this.sendDocumentAsMailDialog.domNode);
		this.sendDocumentAsMailDialog.show();

		// for usability enhancements we select the content of the first input element
		var firstInput = dojo.query("input[type=text]", this.sendDocumentAsMailDialog.domNode)[0];
		setTimeout(dojo.hitch(this, function() {
			epages.event.fire(firstInput, "mouseup");
			try {
				firstInput.focus();
				firstInput.select();
			}catch(e) {}
		}), this.sendDocumentAsMailDialog.duration * 1.2); // the animation resets the focus, so we have to wait until it finished
	}
};

}

if(!dojo._hasResource["epages.cartridges.de_epages.product.widget.DeleteSlideshowImage"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.product.widget.DeleteSlideshowImage"] = true;
/*
	Copyright (c) 2006-2010, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.product.widget.DeleteSlideshowImage");


dojo.declare(
	"epages.cartridges.de_epages.product.widget.DeleteSlideshowImage",
	[ epages.widget.DeleteFileOnServer ],
	{
		onExecute: function () {
			

			var params = {
				'ObjectID'			: this.objectId,
				'ChangeAction' 	: 'SaveFiles',
				'Delete' 				: '1',
				'DeleteFile'		: this.fileName,
				'ACCEPT'				: this.confirm ? 1 : 0
			};
			var json = new epages.io.Json();
			json.loadAsync(this.url, dojo.hitch(this, 'onExecution'), params);
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.product.widget.ProductPickerList"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.product.widget.ProductPickerList"] = true;
/*
  Copyright (c) 2006-2010, ePages GmbH
  All Rights Reserved.

  +-----+---------------+--------------------
  |  _  |               |
  | |_| | tableHead[0]  | tableHead[1]  ...
  |_____|_______________|____________________
  |     |               |
  | |x| | content[0][0] | content[0][1] ...
  |_____|_______________|____________________
  |  .
  |  .
  |  .
  |__________________________________________
  |
  | Page x of y  |<  < 1 2 3 >  >|   Count: z
  +------------------------------------------

*/
dojo.provide("epages.cartridges.de_epages.product.widget.ProductPickerList");//an dieser Stelle wird das neue Widget registriert

dojo.declare("epages.cartridges.de_epages.product.widget.ProductPickerList", [epages.widget.LocalizedWidget], {
    /**
     * public properties
     */
    tableHead            : ["Name"],   // captions of columns
    columnNames          : ["NameOrAlias"], //object attribute name for each column
    displayCheckbox      : true,       //display a checkbox in front of each item and a check-all checkbox
    requestObjectID      : undefined,  //#Shop.ProductFolder.ID
		maxPagerNumberButtons: 5,					//choose only even numbers

    /**
     * widget settings
     */
    widgetsInTemplate : true,
    templateString:"<div dojoAttachPoint=\"widgetRoot\" style=\"z-Index:10001;\">\n  <form>\n  <table dojoType=\"epages.widget.ContentList\" class=\"ContentList\">\n    <thead>\n      <tr dojoAttachPoint=\"tableHeadLine\">\n        <td class=\"Checkbox\" dojoAttachPoint=\"checkAllCheckbox\">\n          <input type=\"text\" class=\"Checkbox RunButtonTrigger\" value=\"Checkbox\" dojoType=\"epages.widget.FormElement\" />\n        </td>\n      </tr>\n    </thead>\n    <tfoot>\n      <tr>\n       <td dojoAttachPoint=\"pagerSizeNode\" colspan=\"${_cols}\">\n        <div class=\"Pager\" dojoAttachPoint=\"pagerBar\" style=\"position:relative\">\n       \n        </div>\n       </td>\n      </tr>\n    </tfoot>\n    <tbody dojoAttachPoint=\"containerNode\">\n    </tbody>\n  </table>\n  </form>\n</div>\n",
    translationName   : dojo.moduleUrl('epages.cartridges.de_epages.product.widget', "templates/translation"),

    /**
     * private properties
     */
    _cols              : 0,
    _pageChangeRequest : {
        'ObjectID'          : '', // Product folder
        'ViewAction'        : 'JSONSearchProducts',
        'WildSearchString'  : '',
        'IsAppointment'     : '',
        'PageSize'          : 10,
        'OrderBy'           : 'NameOrAlias',
        'OrderDesc'         : 0,
        'IsNotSubProduct'   : 1
    },
    _checkAllCheckbox : [], // array of all check-all checkboxes (one item for each page)
    _childsOnPage     : [], // items on the currently visible page
    _pager: {
      currentPage : 0,
      itemCount: 0,
      maxPage: 0,
      bufferedPages : [], // one item for each page of the current search which was already visible
      connects : []
    },

    postMixInProperties: function() {
    	this.inherited("postMixInProperties", arguments);
    	this._cols = this.tableHead.length;
    	// calculate column count of the table and set pager cell to fit it
    	if(this.displayCheckbox) {
    		this._cols++;
    	}
    },

    postCreate: function() {
      // summary: create table column headlines, calculate column count and show an empty page
      this.inherited("postCreate", arguments);
      this._pageChangeRequest.ObjectID = this.requestObjectID;
      dojo.forEach(this.tableHead,function(el){
        var tdNode = document.createElement("td");
        tdNode.innerHTML = el;
        this.tableHeadLine.appendChild(tdNode);
      },this);

      // show an empty page
      this._createVisibleChildren(0);
    },
    requestPage : function(/*Integer*/ page,/*Boolean?*/ isNewSearch){
      // summary: request the content of a page of the current page from server or buffer
      if(!this._pageChangeRequest.ObjectID){
        console.error("Shop.PrductFolder.ID is missing");
        return;
      }
      if(this._pager.bufferedPages[page]){
        // page of the result was displayed before --> load saved page
        this._childsOnPage = this._pager.bufferedPages[page];
        this._setPagerButtons({"currentPage":page});
        this._createVisibleChildren(page);
      } else {
        // show loading image over table
        dojo.publish("interactionRestrictor/suspend", ["ProductPickerLoadPage", this.widgetRoot]);
        var json = new epages.io.Json();
        // request search results on current page
        json.loadAsync("?",
                       dojo.hitch(this,this.handleRequest,page),
                       dojo.mixin(this._pageChangeRequest,{'PagerPage': page+1}));
      }
    },
    handleRequest : function(/*Integer*/page,/*Object*/requestResult){
      // summary: set pager values for the requestet page, show pager and load content
      epages.vars.requestResult = requestResult;
      dojo.publish("interactionRestrictor/permit", ["ProductPickerLoadPage"]);
      if(requestResult.error || !requestResult.data) {
        this._setPagerButtons({"itemCount":0,"maxPage":0});
        var errorMessage = "";
        if(requestResult.error.data.Errors.length == 1 &&
           requestResult.error.data.Errors[0].Name == "WildSearchString" &&
           requestResult.error.data.Errors[0].Reason == "STRING_EMPTY"){
           // user simply missed to put a search string in the textbox
           errorMessage = this.translate('noResults');
        } else {
           errorMessage = "An error occured while trying to retrieve search results.";
        }
        this._createfullTableRow(errorMessage);
        return;
      }
      // show pager
      this._setPagerButtons({"currentPage":page,
                             "maxPage":requestResult.data.CountOfPages,
                             "itemCount":requestResult.data.CountOfItems});

      // create table content
      this._childsOnPage = dojo.map(requestResult.data.SearchResults,function(el){
        return {_data:el,_node:{}};
      },this);
      this._createVisibleChildren(page);
    },
    pageUp:function(evt){
        // summary: changes the visible elemnts by paging one page up
    	dojo.stopEvent(evt);
      if(this._pager.currentPage+1 != this._pager.maxPage){
        var page = this._pager.currentPage + 1;
        this.requestPage(page);
      }
    },

    pageDown:function(evt){
        // summary: changes the visible elemnts by paging one page down
    	dojo.stopEvent(evt);
      if(this._pager.currentPage > 0){
        var page = this._pager.currentPage - 1;
        this.requestPage(page);
      }
    },

    pageTo: function(evt,/*Integer*/ page){
        // summary: changes the visible elemnts by paging to the given page
    	dojo.stopEvent(evt);
      if(page >= 0 && page < this._pager.maxPage){
        this.requestPage(page);
      }
    },
    _setPagerButtons: function(/*Object*/pagerValues){
      // summary: create the pager elements and display them
      // example: this._setPagerButtons({"currentPage":0,"maxPage":2,"itemCount":12})
      dojo.mixin(this._pager,pagerValues);
      var pagerHTML = "";
      var linknode = undefined;
      var linkNodePattern = document.createElement("a");
      linkNodePattern.href = "#";

      // clean up
      dojo.forEach(this._pager.connects,function(el){
        dojo.disconnect(el);
      });
      dojo.empty(this.pagerBar);
      // count of items is always displayed
      var node = dojo.create("div",{
        "class"     : "PagerCountOfItems",
        "innerHTML" : this.translate('Count')+': '+this._pager.itemCount
      },this.pagerBar);
      // create the whole page control elements and add them to dom
      if(this._pager.maxPage>1){
        dojo.create("div",{
          "class"     : "PagerAdditionalInfo",
          "innerHTML" : this.translate("Site")+' '+(this._pager.currentPage+1)+' '+this.translate("of")+' '+this._pager.maxPage
        },this.pagerBar);
        //go first and go previous page buttons
        if(this._pager.currentPage == 0){
          dojo.create("span",{
            "innerHTML" : '<i class="Opacity30 Sprite list_ico_s_paging_first" title="'+this.translate("FirstPage")+'"></i>',
            "class"     : "NoLink"
          },this.pagerBar);

          dojo.create("span",{
            innerHTML :'<i class="Opacity30 Sprite list_ico_s_paging_backward" title="'+this.translate("Back")+'"></i>',
            "class"   : "NoLink"
          },this.pagerBar);
        } else {
          linkNode = dojo.attr(linkNodePattern.cloneNode(true),{
            title     : this.translate("FirstPage"),
            innerHTML : '<i class="Sprite list_ico_s_paging_first" title="'+this.translate("FirstPage")+'"></i>'
          });
          this.pagerBar.appendChild(linkNode);
          this._pager.connects.push(dojo.connect(linkNode, 'onclick', this,function(evt){
            this.pageTo(evt,0);
          }));

          linkNode = dojo.attr(linkNodePattern.cloneNode(true),{
            title     : this.translate("Back"),
            innerHTML : '<i class="Sprite list_ico_s_paging_backward" title="'+this.translate("Back")+'"></i>'
          });
          this.pagerBar.appendChild(linkNode);
          this._pager.connects.push(dojo.connect(linkNode, 'onclick', this,'pageDown'));
        }
        // create numbers to navigate to a specific page
        var overhead = Math.floor(this._pager.currentPage+(this.maxPagerNumberButtons+1)/2)-this._pager.maxPage;
        overhead = Math.max(overhead,0);
        var startIndex = Math.floor(this._pager.currentPage-(this.maxPagerNumberButtons-1)/2)-overhead;
        startIndex = Math.max(startIndex,0);
        for(var i=startIndex;i<startIndex+this.maxPagerNumberButtons &&
        										 i<this._pager.maxPage;i++){
          if(i==this._pager.currentPage){
            linkNode = dojo.attr(linkNodePattern.cloneNode(true),{
              "class"     : 'SelectedItem',
              "innerHTML" : '<span>'+(i+1)+'</span>'
            });
            this.pagerBar.appendChild(linkNode);
          } else {
            linkNode = dojo.attr(linkNodePattern.cloneNode(true),"innerHTML",(i+1));
            this.pagerBar.appendChild(linkNode);
            this._pager.connects.push(dojo.connect(linkNode, 'onclick', this,function(evt){
              this.pageTo(evt,parseInt(evt.target.innerHTML)-1);
            }));
          }
        }
        // go next and go last page buttons
        if(this._pager.currentPage == this._pager.maxPage-1){
          dojo.create("span",{
            "class"     : 'NoLink',
            "innerHTML" : '<i class="Opacity30 Sprite list_ico_s_paging_forward" title="'+this.translate("Next")+'"></i>'
          },this.pagerBar);

          dojo.create("span",{
            "class"     : 'NoLink',
            "innerHTML" : '<i class="Opacity30 Sprite list_ico_s_paging_last" title="'+this.translate("LastPage")+'"></i>'
          },this.pagerBar);
        } else {
          linkNode = dojo.attr(linkNodePattern.cloneNode(true),{
            title     : this.translate("Next"),
            innerHTML : '<i class="Sprite list_ico_s_paging_forward" title="'+this.translate("Next")+'"></i>'
          });
          this.pagerBar.appendChild(linkNode);
          this._pager.connects.push(dojo.connect(linkNode, 'onclick', this, "pageUp"));

          linkNode = dojo.attr(linkNodePattern.cloneNode(true),{
            title     : this.translate("LastPage"),
            innerHTML : '<i class="Sprite list_ico_s_paging_last" title="'+this.translate("LastPage")+'"></i>'
          });
          this.pagerBar.appendChild(linkNode);
          this._pager.connects.push(dojo.connect(linkNode, 'onclick', this,function(evt){
            this.pageTo(evt,this._pager.maxPage-1);
          }));
        }
      }
    },
    _displayCheckAllOnPage : function(/*Integer*/ page){
      // summary: display a checkbox which checks all item checkboxes at once
      dojo.empty(this.checkAllCheckbox);
      // checkbox is only created if it page was not shown before
      if(!this._checkAllCheckbox[page]){
        var inputNode = dojo.create("input",{
          "type"  : "checkbox",
          "value" : "Checkbox",
          "class" : "Checkbox RunButtonTrigger"
        });
        // checkboxes are always widgets
        inputNode = new epages.widget.FormElement({ },inputNode).elementNode;
        this._checkAllCheckbox[page] = inputNode;
        this.connect(inputNode,"onclick", "_setAllVisible");
      }
      this.checkAllCheckbox.appendChild(this._checkAllCheckbox[page]);
    },

		_createfullTableRow : function(/*String*/ message){
			dojo.empty(this.containerNode);
			if(epages.Browser.engine=="MSIE"){
      	dojo.create("tr",{innerHTML:"<td colspan="+this._cols+">"+message+"</td>"},this.containerNode);
    	} else {
    		this.containerNode.innerHTML = "<tr><td colspan="+this._cols+">"+message+"</td>";
    	}
		},
    _createVisibleChildren: function(/*Integer*/ page){
      // summary: creates table rows for the current on this page of list visible children
      // save items and destroy old visible Children
      if(this.displayCheckbox){
        this._displayCheckAllOnPage(page);
      }
      //remove old content
      //dojo.empty(this.containerNode);
      // IE can't handle dojo.empty
      while(this.containerNode.childNodes.length>0){
      	this.containerNode.removeChild(this.containerNode.childNodes[0]);
      }
      // save content for later use
      this._pager.bufferedPages[page] = this._childsOnPage;
      //create visible items
      if(this._childsOnPage.length == 0){
      	this._createfullTableRow(this.translate('noResults'));
      } else {
        for( var i=0,iLength=this._childsOnPage.length ; i<iLength ; i++ ) {
          var elm = this._childsOnPage[i];
          if(elm){
            if(!elm._node.trNode){
              // calculate item content
              var contentHTML = "";
              var attr = {};
              if(i%2==0){
              	attr["class"] = "alternate";
              }
              elm._node.trNode = dojo.create("tr",attr);
              // add item content
              var timestamp = (new Date()).getTime(); // make it unique
              // column cell content
              for( var j=0,jLength=this.columnNames.length ; j<jLength ; j++ ){
                dojo.create("td",{innerHTML: '<label style="#display:inline-block;#width:300px;" for="checkbox'+elm._data.ObjectID+""+timestamp+'">'+elm._data[this.columnNames[j]]+'</label>'},elm._node.trNode);
              }
              // create checkbox
              var tdNode = dojo.create("td",{
                "class" : "Checkbox"
              },elm._node.trNode,"first");
              elm._node.inputNode = dojo.create("input",{
                "type"  : "text",
                "id"    : "checkbox"+elm._data.ObjectID+""+timestamp,
                "value" : "Checkbox",
                "class" : "Checkbox RunButtonTrigger"
              },tdNode);
              // create checkbox widget
              elm._node.inputNode = new epages.widget.FormElement({ },elm._node.inputNode).elementNode;
            }
            // add item to dom
            this.containerNode.appendChild(elm._node.trNode);
          }
        }
      }
    },

    selectedItems: function () {
      // summary: returns an object array of currently selected items
      var result = {};
      for( var i=0,l=this._pager.bufferedPages.length ; i<l ; i++ ){
        var pageChilds = this._pager.bufferedPages[i];
        // get checked items
        dojo.forEach(pageChilds,function(el){
          if(el._node.inputNode.checked){
            result[el._data.ObjectID]=el._data;
          }
        });
      }
      return result; // Object[]
    },

    _setCheckedStatus: function(/*FormElement*/ input,/*boolean*/ checked,/*boolean?*/skipHighlight) {
      // summary: sets checked status on input field and highlights changes
      var statusChanged = input.checked != checked;
      input.checked = checked;
      // needed that for the ContentList widget (row selection)
      if($$(input.id)) {
        $$(input.id).setChecked(checked);
      }
      if(!skipHighlight) {
        // always remove highlight!
        if(checked && statusChanged) {
          dojo.addClass(input.parentNode.parentNode, "RowSelected");
        }else {
          dojo.removeClass(input.parentNode.parentNode, "RowSelected");
        }
      }
    },

    _setAllVisible: function(/*Object*/ evt) {
      // summary: sets all currently shown item checkboxes to the
      // same checked-state as the check-all checkbox
      var checked = evt.target.checked;
      var items = this._childsOnPage;
      for( var i=0,iLength=items.length ; i<iLength ; i++ ) {
        var item = items[i];
        this._setCheckedStatus(item._node.inputNode,checked);
      }
    },

    uncheckAll : function(){
      // summary: remove checked flag from all checkbox widgets on the widget
      // remove checked from check-all checkboxes
      dojo.forEach(this._checkAllCheckbox,function(el){
        this._setCheckedStatus(el, false,true);
      },this);
      // remove checked from item checkboxes
      for( var i=0,l=this._pager.bufferedPages.length ; i<l ; i++ ){
        var pageChilds = this._pager.bufferedPages[i];
        dojo.forEach(pageChilds,function(el){
          this._setCheckedStatus(el._node.inputNode, false);
        },this);
      }
    },
    startSearch : function(/*String*/searchString,/*String*/isAppointment){
      // summary: start search process and show the first page
      // initialize values
      this._pager.bufferedPages = [];
      this._checkAllCheckbox = [];
      this._pageChangeRequest.WildSearchString = searchString;
      this._pageChangeRequest.IsAppointment = isAppointment;
      this.requestPage(0,true);
    }
  }
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.product.widget.ProductPickerTree"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.product.widget.ProductPickerTree"] = true;
/* Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
	epages.cartridges.de_epages.presentation.widget.ProductPickerTree
*/
dojo.provide("epages.cartridges.de_epages.product.widget.ProductPickerTree");







dojo.declare("epages.cartridges.de_epages.product.widget.ProductPickerTree",
	[epages.widget.LocalizedWidget],
	{
		/**
		* public properties
		*/
		query								: '',
		widgetsInTemplate		: true,
		templateString:"<div class=\"Linkcreator\">\n  <div class=\"TreeContainer\">\n    <div dojoType=\"dijit.tree.ForestStoreModel\" jsId=\"productPickerTreeModel\"\n            store=\"objectStore\" query=\"${query}\"\n            rootLabel=\"Startseite\" childrenAttrs=\"children\"></div>\n    <div dojoType=\"epages.cartridges.de_epages.presentation.widget.Objecttree\"\n         dojoAttachPoint=\"tree\"\n    \n         model=\"productPickerTreeModel\"\n         query=\"${query}\"\n         label=\"{StartPage}\"\n     ></div>\n  </div>\n</div>\n",
		translationName			: dojo.moduleUrl('epages.cartridges.de_epages.product.widget','templates/translation'),
		useAbsolutePath			: false,
		url									: '?',
		selectedProduct				: undefined,

		/*
		 * private properties
		 */
		_timestamp : undefined, // make something unique

		postMixInProperties: function() {
			// summary: create object store if not already present
			// override
			this._timestamp = (new Date()).getTime();
			if(window.objectStore === undefined){
				
				window.objectStore = new epages.cartridges.de_epages.presentation.widget.Objectstore({
					jsId:      "objectStore",
					id:        "objectStore",
					queryClasses: "Product,Category",
					ignoreSubproducts: "1"
				});
			}
			if (this.query == '') {
				if(epages.topWindow && epages.topWindow.objectStore && epages.topWindow.objectStore.objectId != null){
					this.query = "{id:" + epages.topWindow.objectStore.objectId + "}";
				}else{
					this.query = "{id:" + epages.vars.CategoriesID + "}";
				}
			}
			this.inherited('postMixInProperties', arguments);
		},

		postCreate: function() {
			// summary: connect to events
			// override
			this.inherited("postCreate", arguments);
			dojo.subscribe(this.tree.id+'/select', this, function(selectedNode,a) {
				this.onSelectItem(selectedNode.item,selectedNode,a);
			});
		},
		selectedItem : function(){
			// summary: return currently selected item
			return this.selectedProduct;
		},
		onSelectItem: function(/*object*/data,item,a) {
			// summary: keep in mind which item is currently selected
			if(data.isProduct){
				this.selectedProduct = data;
			} else {
				//selected item is a folder --> no valid product
				this.selectedProduct = undefined;
			}
			dojo.publish(this.id+'/select',[this.selectedProduct]);
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.product.widget.ProductPicker"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.product.widget.ProductPicker"] = true;
/*
	Copyright (c) 2006-2010, ePages GmbH
	All Rights Reserved.

*/
dojo.provide("epages.cartridges.de_epages.product.widget.ProductPicker");//an dieser Stelle wird das neue Widget registriert




dojo.declare("epages.cartridges.de_epages.product.widget.ProductPicker", [epages.widget.Modaldialog], {
		innerTemplatePath : dojo.moduleUrl('epages.cartridges.de_epages.product.widget', "templates/ProductPicker.html"),
		translationName   : dojo.moduleUrl('epages.cartridges.de_epages.product.widget', "templates/translation"),

		/*
		 * public properties
		*/

		searchTableHead          : undefined,  // String - column headlines
		onSubmitHandler          : undefined,  // function - custom handler which will be called when the modaldialog is going to get submitted
		requestObjectID          : undefined,  // String - #Shop.ProductFolder.ID
		options:{
				title                : '',
				width                : 450,
				height               : 250,
				content              : undefined,
				destroyWidgetOnClose : true
		}, // object - modaldialog settings

		/*
		 * private properties
		*/
		buttons                  : [], // [] - modaldialog buttons
		widgetsInTemplate        : true,

		// widget references
		_productList             : undefined,
		_productTree             : undefined,

		_viewIsTree              : true,
		_modalDialogSubmitButton : undefined, // DomNode - dom node of add button

		postMixInProperties: function() {
			// summary: set up modaldialog buttons
			this.buttons = [{
				label: '{Apply}',
				cssClass: 'Active',
				buttonId : 'modalDialogAddProductButton',
				onclick: dojo.hitch(this,this.onSubmitClick)
			 },{
				label: '{Cancel}',
				onclick: dojo.hitch(this,this.onCancelClick)
			}];
			if(this.searchTableHead === undefined) {
			this.searchTableHead = [this.translate('Name')];
			}
			dijit.Dialog.prototype.postMixInProperties.apply(this, arguments);
			this.inherited("postMixInProperties", arguments);
		},

		postCreate  : function() {
			// summary: Connect to events and create widgets
			dijit.Dialog.prototype.postCreate.apply(this, arguments);
			this.inherited("postCreate", arguments);

			this.connect(this.chooseTypeProduct.domNode,"onclick", "selectType");
			this.connect(this.chooseTypeAppointment.domNode,"onclick", "selectType");
			dojo.subscribe(this.id+"/tabChange",this,"onTabChange");

			// create search widget
			this._productList = new epages.cartridges.de_epages.product.widget.ProductPickerList({
				tableHead       : this.searchTableHead,
				requestObjectID : this.requestObjectID
			});
			// create tree widget
			this._productTree = new epages.cartridges.de_epages.product.widget.ProductPickerTree();
			// listen on select to disable submit button of modaldialog if selected item is not valid
			dojo.subscribe(this._productTree.id+'/select',this,"toggleAddButton");
			// add widgets to dom
			this.listNode.appendChild(this._productList.domNode);
			this.treeNode.appendChild(this._productTree.domNode);
		},
		show : function(){
			// summary: clean up all checkboxes
			this._productList.uncheckAll();
			this.inherited("show", arguments);
		},
		startSearch : function(evt){
			// summary: start search of productList widget
			dojo.stopEvent(evt);
			evt.returnValue = false;
			var isAppointment = this.chooseTypeAppointment.isChecked()?'1':'0';
			this._productList.startSearch(this.searchString.value,isAppointment);
		},
		selectedItems : function(){
			// summary: retrieve selected items on the current visible tab
			if(this._viewIsTree){
				var selectedItem = this._productTree.selectedItem();
				if(selectedItem){
					// convert result to look like the _productList.selectedItems() result
					var obj = {};
					obj[selectedItem.objectId] = {
						"Alias":selectedItem.alias,
						"ObjectID": selectedItem.objectId,
						"NameOrAlias":selectedItem.nameOrAlias
					};
					return obj; //Object
				} else {
					return {}; //Object
				}
			} else {
				return this._productList.selectedItems(); //Object
			}
		},
		toggleAddButton : function(/*Object*/ currentSelectedItem){
			// summary: disable submit button if selected item is not valid
			if(!this.buttons || !this.buttons[0] || !this.buttons[0].buttonId){
				return;
			}
			if(currentSelectedItem === undefined){
				this.disableButton(this.buttons[0].buttonId);
			} else  {
				this.enableButton(this.buttons[0].buttonId);
			}
		},
		onTabChange : function(/*DOMNode*/ targetTab){
			// summary: keep in mind which tab is selected to submit the correct selected items
			this._viewIsTree = targetTab==this.treeTab;
		},
		onSubmitClick : function(/*Object*/ evt){
			// summary: call custom handler and hide dialog
			if(!evt.currentTarget.className.match("Disabled")) {
				// if a custom handler is specified call it
				if(this.onSubmitHandler){
					this.onSubmitHandler(evt,this.selectedItems());
				}
				this.hide();
			}
		},
		onCancelClick : function(/*Object*/ evt){
			// summary: hide modaldialog
			this.hide();
		},
		selectType : function(/*Object*/ evt){
			// summary: change displayed text of search label
			this.searchLabel.innerHTML = evt.target.value;
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.product.widget.ProductTypeAttribute"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.product.widget.ProductTypeAttribute"] = true;
/*
  Copyright (c) 2006-2010, ePages GmbH
  All Rights Reserved.

  epages.cartridges.de_epages.product.widget.ProductTypeAttributeList

*/
dojo.provide("epages.cartridges.de_epages.product.widget.ProductTypeAttribute");


epages.require('ep_shop_upload', 'epages.uploader');

dojo.declare("epages.cartridges.de_epages.product.widget.ProductTypeAttribute",
  [epages.widget.LocalizedWidget], {

    /**
     * public properties
     */
    alias             : "",											// string - attribute alias
    name              : "",											// string - attribute name (current language)
    data              : undefined,							// hash   - attribute data (very complex)
    attributeListId   : "",											// string - widget id of attribute list widget
    attributeNumber   : undefined,							// integer - number indentifier for the attribute
    productObjectID   : '',											// integer - object id of the product/resource

    /**
     * widget properties
     */
    templateString:"<div class=\"ProductTypeAttribute\">\n  <table class=\"InnerGrid\">\n    <tr>\n      <td class=\"Label\">\n        {Attribute}:\n      </td>\n      <td>\n        <div dojoAttachPoint=\"existingAttributeViewNode\" class=\"existingAttribute\">\n          ${name}\n        </div>\n        <div dojoAttachPoint=\"newAttributeViewNode\" class=\"newAttribute\" style=\"display:none\">\n          <input name=\"Name\"\n                 dojoAttachPoint=\"newAttributeNameNode\"\n                 disabled=\"disabled\"\n                 type=\"text\"\n                 value=\"\" />\n          <input dojoAttachPoint=\"newAttributeUsageNode\" type=\"hidden\" name=\"UseAttribute\" value=\"1\" />\n          <input dojoAttachPoint=\"newAttributeIsVisibleNode\" type=\"hidden\" name=\"VariationAttributeIsVisible\" value=\"1\" />\n          <span class=\"Type\">{Type}</span>\n          <select name=\"TypePackage\"\n                  dojoAttachPoint=\"newAttributeTypeNode\"\n                  dojoAttachEvent=\"onchange: _onAttributTypeChange\"\n                  disabled=\"disabled\"\n                  >\n            <option selected=\"selected\">{EmptyEntry}</option>\n          </select>\n          <i class=\"Sprite ico_m_delete ClickIcon\"\n             dojoAttachPoint=\"deleteNode\"\n             dojoAttachEvent=\"onclick: _onDelete\"\n             title=\"{DeleteAttribute}\"\n            ></i>\n        </div>\n      </td>\n    </tr>\n    <tr>\n      <td></td>\n      <td>\n        <div class=\"ValueContainer\" dojoAttachPoint=\"valueContainerNode\"></div>\n        <span class=\"Smaller\"\n              dojoAttachPoint=\"addNewPredefValueNode\"\n              dojoAttachEvent=\"onclick: _createNewRow\"\n              style=\"display:none\"\n              >\n        <i class=\"LeftSmallMargin Sprite ico_s_add\"></i>\n        <a href=\"#\" onclick=\"return false;\" >{addNewPredefValue}</a>\n          </span>\n      </td>\n    </tr>\n  </table>\n</div>\n",
    translationName   : dojo.moduleUrl('epages.cartridges.de_epages.product.widget', 'templates/translation'),

    /**
     * private properties
     */
    _attributeContainerTemplate    : '',         // string - attribute value container template
    _attributeTemplateMapping      : undefined,  // object - attribute value template mapping (will be filled later onPostMixInProperies)
    _deleteRowTemplate             : '',         // string - delete icon of a row template
    _fileValueTemplate             : '',         // string - template for file values
    _moreLanguagesContent          : '',         // string - more languages link template

    _rowNodes                      : undefined,  // hash - hash with row dom nodes e.g. { <rowid> : <domnode> }
    _languageContainerNodes        : undefined,  // hash - hash with language container dom nodes e.g. { <rowid> : <domnode> }
    _moreLaguagesNodes             : undefined,  // hash - hash with more languages link dom nodes e.g. { <rowid> : <domnode> }
    _deleteRowNodes                : undefined,  // hash - hash with delte row dom nodes e.g. { <rowid> : <domnode> }

    _rowCount                      : 0,          // integer - count of attribute value rows (consecutive  number / delteting a row won't decrease this number)

    _ep_connects                   : undefined,  // hash   - collection of connected events e.g. { <rowid> : <connected_event> }
    _ep_childWidgets               : undefined,  // hash   - collection of inner widgets e.g. { <rowid> : <widgets> }


    /**
     * widget life cycle
     */

    postMixInProperties: function(){
      this.inherited("postMixInProperties", arguments);
      // throw warnings
      if(!epages.vars.languages) {
        console.warn("epages.vars.languages not defined in "+this.declaredClass );
      }

      if(!epages.vars.Locale.languageId) {
        console.warn("epages.vars.Locale.languageId not defined in "+this.declaredClass );
      }

      if(epages.vars.features) {
        if(! epages.vars.features.ProductTypes) {
          console.warn("epages.vars.features.ProductTypes not defined in "+this.declaredClass );
        }
      } else {
        console.warn("epages.vars.features not defined in "+this.declaredClass );
      }

      if(! epages.vars.maxFileSize) {
        console.warn("epages.vars.maxFileSize not defined in "+this.declaredClass);
      }

      if(! epages.vars.defaultTypePackage) {
        console.warn("epages.vars.defaultTypePackage not defined in "+this.declaredClass);
      }

      // prepare templates / init vars
      this._setTemplates();
      this._ep_connects = {};
      this._ep_childWidgets = {};
      this._moreLaguagesNodes = {};
      this._languageContainerNodes = {};
      this._deleteRowNodes = {};
      this._rowNodes = {};
    },

    postCreate: function(){
      this.inherited("postCreate", arguments);

      if(this.productObjectID && (this.attributeNumber !== undefined)) {
        this.newAttributeNameNode.name = this.productObjectID + ':VariationAttributeName'+this.attributeNumber;
        this.newAttributeUsageNode.name = this.productObjectID + ':UseAttribute'+this.attributeNumber;
        this.newAttributeTypeNode.name = this.productObjectID + ':TypePackage'+this.attributeNumber;
        this.newAttributeIsVisibleNode.name = this.productObjectID + ':VariationAttributeIsVisible'+this.attributeNumber;
      }

      var attrData = this.data;

      if(attrData) {
        this._createAttributeValueNodes(attrData, true);

        if(attrData.isPreDefAttributesContainer) {																				// append new editable entry for new attribute values
          this._createNewRow();
          this.addNewPredefValueNode.style.display="";
        }
        // change type package option and select it
        this.newAttributeTypeNode.children[0].value = attrData.type;
        this.newAttributeNameNode.value = this.alias;
      } else { // attribute is new
        this.existingAttributeViewNode.style.display="none";
        this.newAttributeNameNode.disabled=false;
        this.newAttributeTypeNode.disabled=false;

        // fill attribute types
        for(var el in epages.vars.defaultTypePackage) {
          var data = epages.vars.defaultTypePackage[el];
          var selectNode= document.createElement("option");
          selectNode.value = el;
          selectNode.innerHTML = data.type_name;
          this.newAttributeTypeNode.appendChild(selectNode);
        }
        this.newAttributeViewNode.style.display="block";
      }


    },

    destroy: function() {
      this._destroyAttributeValues();
      dojo.publish(this.attributeListId+'/attributeRemoved', []);
      this.inherited("destroy", arguments);
    },

    /**
     * init functions
     */

    _setTemplates : function() {
    // summary: set template strings
    // description:
      /**
       * ==============================
       * this._attributeTemplateMapping
       * ==============================
       *
       * hash properties
       * locked       - only attribute values can be edited / predefined values can not be edited -> locked
       * lockedTransl - display translation only / can not be edited
       * edit - attribute values and predefined values can be edited
       * editTransl - attribute values and predefined values can be edited (other languages)
       *
       * placeholders
       * (%attribute_value%)   -> value of attribute
       * (%attribute_name%)    -> inputfield name for attribute (<attribute alias>:<langid>)
       * (%attribute_checked1%)-> inputfield checked string for yes radio buttons (Boolean)
       * (%attribute_checked0%)-> inputfield checked string for no radio buttons (Boolean)
       * (%attribute_file%)    -> link html for uploaded files (File, LocalizedFile)
       * (%predef_name%)       -> inputfield name for predfined choice (alias of predef choice)
       * (%predef_value%)      -> value of predef choice (e.g. name of choice)
       * (%predef_id%)         -> ObjectID of predefined choice
       * (%predef_checked%)    -> predefined choice is selected
       */

      this._attributeTemplateMapping = {
        'String'                     :	{	edit          : '<input type="text" name="AttributeName" value="(%attribute_value%)" />',
                                          locked        : '<input type="text" name="AttributeName" value="(%attribute_value%)" />'
                                        },
        'LocalizedString'            : 	{	edit          : '<input type="text" name="AttributeName:(%langid%)" value="(%attribute_value%)" /> (%native%)',
                                          locked        : '<input type="text" name="AttributeName:(%langid%)" value="(%attribute_value%)" /> (%native%)'
                                        },
        'PreDefString'               :	{	edit          : '<input type="radio" name="RadioAttributeName" value="(%attribute_value%)" (%predef_checked%) /> <input type="text" name="AttributeName" value="(%predef_value%)" />',
                                          locked        : '<input type="radio" name="RadioAttributeName" value="(%attribute_value%)" (%predef_checked%) id="(%attribute_name%)(%predef_id%)" /> <label for="(%attribute_name%)(%predef_id%)">(%predef_value%)</label>'
                                        },
        'PreDefLocalizedString'      :	{	edit          : '<input type="radio" name="RadioAttributeName:(%langid%)" value="(%attribute_value%)" (%predef_checked%) /> <input type="text" name="AttributeName:(%langid%)" value="(%predef_value%)" /> (%native%)',
                                          editTransl    : '<span class="RadioSpacer"></span> <input type="text" name="AttributeName:(%langid%)" value="(%predef_value%)" /> (%native%)',
                                          locked        : '<input type="radio" name="RadioAttributeName:(%langid%)" value="(%attribute_value%)" (%predef_checked%) id="(%attribute_name%)(%predef_id%)" /> <label for="(%attribute_name%)(%predef_id%)">(%predef_value%)</label>'
                                        },
        'PreDefMultiString'          :	{	edit          : '<input type="checkbox" name="CheckboxAttributeName:(%langid%)" value="(%attribute_value%)" (%predef_checked%) /> <input type="text" name="AttributeName" value="(%predef_value%)" />',
                                          editTransl    : '<span class="CheckboxSpacer"></span> <input type="text" name="AttributeName" value="(%predef_value%)" />',
                                          locked        : '<input type="checkbox" name="CheckboxAttributeName:(%langid%)" value="(%attribute_value%)" (%predef_checked%) id="(%attribute_name%)(%predef_id%)" /> <label for="(%attribute_name%)(%predef_id%)">(%predef_value%)</label>'
                                        },
        'PreDefMultiLocalizedString' :	{	edit          : '<input type="checkbox" name="CheckboxAttributeName" value="(%attribute_value%)" (%predef_checked%) /> <input type="text" name="AttributeName:(%langid%)" value="(%predef_value%)" /> (%native%)',
                                          editTransl    : '<span class="CheckboxSpacer"></span> <input type="text" name="AttributeName:(%langid%)" value="(%predef_value%)" />',
                                          locked        : '<input type="checkbox" name="CheckboxAttributeName" value="(%attribute_value%)" (%predef_checked%) id="(%attribute_name%)(%predef_id%)" /> <label for="(%attribute_name%)(%predef_id%)">(%predef_value%)</label>'
                                        },
        'PreDefCustomerString'       :	{	edit          : '<input type="checkbox" name="CheckboxAttributeName" value="(%attribute_value%)" (%predef_checked%) /> <input type="text" name="AttributeName:(%langid%)" value="(%predef_value%)" /> (%native%)',
                                          editTransl    : '<span class="RadioSpacer"></span> <input type="text" name="AttributeName:(%langid%)" value="(%predef_value%)" />',
                                          locked        : '<input type="checkbox" name="CheckboxAttributeName" value="(%attribute_value%)" (%predef_checked%) id="(%attribute_name%)(%predef_id%)" /> <label>(%predef_value%)</label>'
                                        },
        'Integer'                    :	{	edit          : '<input type="text" name="AttributeName" value="(%attribute_value%)" />',
                                          locked        : '<input type="text" name="AttributeName" value="(%attribute_value%)" />'
                                        },
        'Float'                      :	{	edit          : '<input type="text" name="AttributeName" value="(%attribute_value%)" />',
                                          locked        : '<input type="text" name="AttributeName" value="(%attribute_value%)" />'
                                        },
        'Boolean'                    :	{	edit          : '<input type="radio" name="AttributeName_'+this.attributeNumber+'" value="1" id="BoolAttr_'+this.attributeNumber+'_1" (%attribute_checked1%) /><label for="BoolAttr_'+this.attributeNumber+'_1">'+this.translate("Yes")+'</label><input type="radio" name="AttributeName_'+this.attributeNumber+'" value="0" id="BoolAttr_'+this.attributeNumber+'_0" (%attribute_checked0%) /><label for="BoolAttr_'+this.attributeNumber+'_0">'+this.translate("No")+'</label>',
                                          locked        : '<input type="radio" name="AttributeName_'+this.attributeNumber+'" value="1" id="BoolAttr_'+this.attributeNumber+'_1" (%attribute_checked1%) /><label for="BoolAttr_'+this.attributeNumber+'_1">'+this.translate("Yes")+'</label><input type="radio" name="AttributeName_'+this.attributeNumber+'" value="0" id="BoolAttr_'+this.attributeNumber+'_0" (%attribute_checked0%) /><label for="BoolAttr_'+this.attributeNumber+'_0">'+this.translate("No")+'</label>'
                                        },
        'Money'                      :	{	edit          : '<input type="text" name="AttributeName" value="(%attribute_value%)" />',
                                          locked        : '<input type="text" name="AttributeName" value="(%attribute_value%)" />'
                                        },
        'DateTime'                   :	{	edit          : '<input type="text" name="AttributeName" value="(%attribute_value%)" class="ep-date-time-input" selector="datetime" />',
                                          locked        : '<input type="text" name="AttributeName" value="(%attribute_value%)" class="ep-date-time-input" selector="datetime" />'
                                        },
        'Date'                       :	{	edit          : '<input type="text" name="AttributeName" value="(%attribute_value%)" class="ep-date-input" selector="date" />',
                                          locked        : '<input type="text" name="AttributeName" value="(%attribute_value%)" class="ep-date-input" selector="date" />'
                                        },
        'Time'                       :	{	edit          : '<input type="text" name="AttributeName" value="(%attribute_value%)" class="ep-time-input" selector="time" />',
                                          locked        : '<input type="text" name="AttributeName" value="(%attribute_value%)" class="ep-time-input" selector="time" />'
                                        },
        'File'                       :	{	edit          : '(%attribute_file%) <input type="text" name="AttributeName" id="DisplayFileName_Attr'+this.attributeNumber+'_(%langid%)" class="Disabled FloatLeft" value="" /> (%attribute_uploader%) <div class="Smaller AdditionalInfo">'+this.translate("MaxFileSize")+': '+epages.vars.maxFileSize+' MByte</div>',
                                          locked        : '(%attribute_file%) <input type="text" name="AttributeName" id="DisplayFileName_Attr'+this.attributeNumber+'_(%langid%)" class="Disabled FloatLeft" value="" /> (%attribute_uploader%) <div class="Smaller AdditionalInfo">'+this.translate("MaxFileSize")+': '+epages.vars.maxFileSize+' MByte</div>'
                                        },
        'LocalizedFile'              :	{	edit          : '(%attribute_file%) <input type="text" name="AttributeName:(%langid%)" id="DisplayFileName_Attr'+this.attributeNumber+'_(%langid%)" class="Disabled FloatLeft" value="" /> (%attribute_uploader%) (%native%) <div class="Smaller AdditionalInfo BottomMarginWide">'+this.translate("MaxFileSize")+': '+epages.vars.maxFileSize+' MByte</div>',
                                          locked        : '(%attribute_file%) <input type="text" name="AttributeName:(%langid%)" id="DisplayFileName_Attr'+this.attributeNumber+'_(%langid%)" class="Disabled FloatLeft" value="" /> (%attribute_uploader%) (%native%) <div class="Smaller AdditionalInfo BottomMarginWide">'+this.translate("MaxFileSize")+': '+epages.vars.maxFileSize+' MByte</div>'
                                        }
      };

      this._attributeContainerTemplate    = '(%inputhtml%) (%deleteRowTemplate%) (%moreLanguagesContent%)';
      this._deleteRowTemplate             = '<i class="Sprite ico_s_delete ClickIcon" epAttachPoint="deleteRowNode" title="'+this.translate('DeleteRow')+'"></i>';
      this._moreLanguagesContent          = '<span class="ChangeLink Smaller" epAttachPoint="moreLaguagesNode">(<a href="#" onclick="return false">'+this.translate("MoreLanguages")+'</a>)</span><div epAttachPoint="languageContainerNode" style="display:none"></div>';
      this._fileUploadTemplate            = '<input type="file" dojoAttachpoint="uploadAppletNode" id="'+this.attributeNumber+'_(%langid%)" class="ep-js" data-js="'+
                          "de_epages.presentationUiUploader({"+
                            "data:{"+
                              "ChangeAction:'UploadFiles',"+
                              "UseMediaGallery:0,"+
                              "ObjectID:"+this.productObjectID+
                            "},"+
                            "callback:function(data){"+
                              "if( data = data[ data.length-1 ].success ){"+
                                "jQuery('#DisplayFileName_Attr"+this.attributeNumber+"_(%langid%)')"+
                                  ".val(data.uploadedObjectFile);"+
                              "}"+
                            "}"+
                          "})"+
                          ".parent()"+
                          ".addClass('FloatLeft EnableHover')"+
                          '"/>';
      this._fileValueTemplate             = '<span class="Smaller" id="Link_Attr'+this.attributeNumber+'_(%langid%)"><a target="_blank" href="(%file%)">(%value%)</a>'+
                                            '<span dojoType="epages.widget.DeleteFileOnServer" '+
                                            '      class="LeftMarginWide"'+
                                            '      fileAttribute="(%attribute_alias%)"'+
                                            '      languageId="(%langid%)"'+
                                            '      filePath="(%file%)"'+
                                            '      fileName="(%value%)"'+
                                            '      confirm="1"'+
                                            '      objectId="(%product_id%)"'+
                                            '      onsuccess="dojo.addClass($(\'Link_Attr'+this.attributeNumber+'_(%langid%)\'),\'HideElement\');" ></span></span><br />';
    },

    /**
     * build functions
     */

    _createAttributeValueNodes : function(attributeData, islocked) {
    // summary: generate nodes and event handler of attribute values
      if(attributeData.preDefAttributes !== undefined || !attributeData.isPreDefAttributesContainer) {	// skip PreDefAttributesContainer without predefined attributes
        // init vars
        var currentLanguageId = epages.vars.Locale.languageId;
        var attrValueHtml = "";

        // choose template version (locked or edit version)
        var attrValueTemplate = (islocked) ? this._attributeTemplateMapping[attributeData.type].locked :	this._attributeTemplateMapping[attributeData.type].edit;

        // calculate number of iterations
        var numberOfLoops = 1;
        var countPredefAttributes = 0;
        if(attributeData.preDefAttributes) {
          countPredefAttributes = attributeData.preDefAttributes.length;
          numberOfLoops = countPredefAttributes;																					// change number of iterations to number of predfined attribute values
        }

        // iterate
        for(var i = 0; i< numberOfLoops; i++) {																						// multiple choices are needed by any preDefAttribute type
          // prepare container template (localized or not)

          attrValueHtml = this._attributeContainerTemplate;

          // generate input html code for current language
          var predefined = (countPredefAttributes) ? attributeData.preDefAttributes[i] : undefined;
          var predefValueKey = "value"+':'+currentLanguageId;
          var attributeValue= "";
          var attributeIsChecked1 = "";
          var attributeIsChecked0 = "";

          if(attributeData.value !== undefined) {
            attributeValue = attributeData.value;

            if(attributeData.value) {
              attributeIsChecked1 = 'checked="checked"';
            } else {
              attributeIsChecked0 = 'checked="checked"';
            }

          } else if(attributeData['value:'+currentLanguageId]) {
            attributeValue = attributeData['value:'+currentLanguageId];
          }

          var predefIsChecked = "";
          if(attributeData.values) {
            for(var el in attributeData.values) {
              if(attributeData.values[el] == predefined.id) {
                predefIsChecked='checked="checked"';
              }
            }
          }

          var attributeFile = "";
          if(attributeData.file) {
            var fileTmpl = $TMPL(this._fileValueTemplate, {
              attribute_alias : this.alias,
              attribute_id    : attributeData.id,
              langid          : currentLanguageId,
              file            : attributeData.file,
              value           : attributeData.value,
              product_id      : attributeData.productId
            }, false);
            attributeFile = fileTmpl.generateOutput();
          }

          var uploader = "";
          var uploadTmpl = $TMPL(this._fileUploadTemplate, {
            attribute_alias : this.alias,
            attribute_id    : attributeData.id,
            langid          : currentLanguageId,
            file            : attributeData.file,
            value           : attributeData.value,
            product_id      : attributeData.productId
          }, false);
          uploader = uploadTmpl.generateOutput();

          if(attributeData['file:'+currentLanguageId]) {
            var fileTmpl = $TMPL(this._fileValueTemplate, {
              attribute_alias : this.alias,
              attribute_id    : attributeData.id,
              langid          : currentLanguageId,
              file            : attributeData['file:'+currentLanguageId],
              value           : attributeData['value:'+currentLanguageId],
              product_id      : attributeData.productId
            }, false);
            attributeFile = fileTmpl.generateOutput();
          }

          var inputHtml = this._createInput({
            templatestring    : attrValueTemplate,
            alias             : this.alias,
            langid            : currentLanguageId,
            predef_name       : (predefined) ? predefined.alias : undefined,
            predef_id         : (predefined) ? predefined.id : undefined,
            predef_value      : (predefined) ? predefined[predefValueKey] : undefined,
            predef_checked    : predefIsChecked,
            attribute_value   : attributeValue,
            attribute_checked1: attributeIsChecked1,
            attribute_checked0: attributeIsChecked0,
            attribute_file    : attributeFile,
            attribute_id      : attributeData.id,
            attribute_uploader: uploader
          });

          var moreLanguagesContentHtml = (attributeData.isLocalized && !(attributeData.isPreDefAttributesContainer && islocked)) ? this._moreLanguagesContent : "";		// don't show translations on locked predfined rows
          var deleteRowTemplateHtml = (!islocked) ? this._deleteRowTemplate : "";																				// don't show delete button on locked rows

          var attrValueHtml = $TMPL(attrValueHtml , {
            inputhtml : inputHtml,
            moreLanguagesContent : moreLanguagesContentHtml,
            deleteRowTemplate: deleteRowTemplateHtml
          }, false).generateOutput();

          // generate and insert as node (insert row)
          var attributeValueNode = document.createElement("div");
          attributeValueNode.innerHTML = attrValueHtml;
          if(islocked && predefined && predefined.id) {
            dojo.attr(attributeValueNode, "predefobjectid", predefined.id);
          }
          this._rowNodes[this._rowCount] = attributeValueNode;																													// save row dom node refernce
          this.valueContainerNode.appendChild(attributeValueNode);																											// append

          // append events (delete button)
          this._ep_connects[this._rowCount] = {};
          if(!islocked) {																																																//  locked rows can not be deleted
            var deleteRowNodeNodeArray= dojo.query('[epAttachPoint=deleteRowNode]',attributeValueNode);
            if(deleteRowNodeNodeArray.length) {
              this._deleteRowNodes[this._rowCount] = deleteRowNodeNodeArray[0];
              this._deleteRowNodes[this._rowCount].setAttribute("ep_rowcount", this._rowCount);
              this._ep_connects[this._rowCount]['deleteRowNode'] = dojo.connect(this._deleteRowNodes[this._rowCount], "onclick", this, "_onDeleteRow");
            }
          }

          // generate inputs -> other languages (except predefined locked rows)
          if(attributeData.isLocalized && !(attributeData.isPreDefAttributesContainer && islocked)) {
            var nodeArray= dojo.query('[epAttachPoint=languageContainerNode]', attributeValueNode);
            if(nodeArray.length) {
              this._languageContainerNodes[this._rowCount] = nodeArray[0];
              var languageInputs = "";
              for(var langkey in epages.vars.languages) {
                if(langkey != currentLanguageId) {

                  // template switch - use template version for translations
                  var tempAttrValueTemplate = "";
                  if(islocked) {
                    tempAttrValueTemplate = attrValueTemplate;
                  } else {
                    tempAttrValueTemplate = (this._attributeTemplateMapping[attributeData.type].editTransl) ? this._attributeTemplateMapping[attributeData.type].editTransl : attrValueTemplate;
                  }
                  predefValueKey = "value"+':'+langkey; 																	// use current langkey in predefValueKey
                  var attributeValue= "";
                  if(attributeData.value) {
                    attributeValue = attributeData.value;
                  } else if(attributeData['value:'+langkey]) {
                    attributeValue = attributeData['value:'+langkey];
                  }

                  var uploader = "";
                  var uploadTmpl = $TMPL(this._fileUploadTemplate, {
                    attribute_alias : this.alias,
                    attribute_id    : attributeData.id,
                    langid          : langkey,
                    file            : attributeData.file,
                    value           : attributeData.value,
                    product_id      : attributeData.productId
                  }, false);
                  uploader = uploadTmpl.generateOutput();

                  var attributeFile = "";
                  if(attributeData['file:'+langkey]) {
                    var fileTmpl = $TMPL(this._fileValueTemplate, {
                      attribute_alias : this.alias,
                      attribute_id    : attributeData.id,
                      langid          : langkey,
                      file            : attributeData['file:'+langkey],
                      value           : attributeData['value:'+langkey],
                      product_id      : attributeData.productId
                    }, false);
                    attributeFile = fileTmpl.generateOutput();
                  }

                  var langData = epages.vars.languages[langkey];
                  var inputHtml = this._createInput({
                    templatestring: tempAttrValueTemplate,
                    alias           : this.alias,
                    langid          : langkey,
                    'native'        : '<span class="Smaller">(' + langData['native'] + ')</span>',
                    predef_name     : (predefined) ? predefined.alias : undefined,
                    predef_id       : (predefined) ? predefined.id : undefined,
                    predef_value    : (predefined) ? predefined[predefValueKey] : undefined,
                    attribute_value : attributeValue,
                    attribute_file  : attributeFile,
                    predef_checked  : predefIsChecked,
                    attribute_id    : attributeData.id,
                    attribute_uploader : uploader
                  });
                  languageInputs += '<div class="LanguageInput">'+inputHtml+'</div>';
                }
              }
              this._languageContainerNodes[this._rowCount].innerHTML=languageInputs;
            }

            // append events (more languages link)
            var mLanguagesNodeArray= dojo.query('[epAttachPoint=moreLaguagesNode]',attributeValueNode);
            if(mLanguagesNodeArray.length) {
              this._moreLaguagesNodes[this._rowCount] = mLanguagesNodeArray[0];
              this._moreLaguagesNodes[this._rowCount].setAttribute("ep_rowcount", this._rowCount);
              this._ep_connects[this._rowCount]['languagesNode'] = dojo.connect(this._moreLaguagesNodes[this._rowCount], "onclick", this, "_onShowLanguages");
            }
          }
          var innerWidgets = dojo.parser.parse(this.valueContainerNode);	//create inner widgets
          this._ep_childWidgets[this._rowCount] = [];
          var _this = this;
          dojo.forEach(innerWidgets, function(el) {
            _this._ep_childWidgets[_this._rowCount].push(el);
          });

          this._rowCount++;
        }

        var self = this;

        require([
            "jquery",

            "ep/ui/datepicker",
            "$ready!"
        ], function ($) {
            var domNode = $(self.domNode);
            var dateInputs = domNode.find('.ep-date-input');
            var dateTimeInputs = domNode.find('.ep-date-time-input');
            var timeInputs = domNode.find('.ep-time-input');

            if (dateInputs.length){
                dateInputs.uiDatepicker({'type':'date','format':'d','time':false});
            }
           
            if (dateTimeInputs.length){
                dateTimeInputs.uiDatepicker({'type':'date','format':'l','time':true});
            }
            
            if (timeInputs.length) {
                timeInputs.uiSpinner({type: 'date', format: 't'});
            }    
        });

      }
    },

    _createInput : function(/* object */opt) {
      // summary: creates a single input element
      // opt: {
      //         templatestring    - input template string
      //         alias             - alias of attribute
      //         langid            - languageid of input field
      //         native            - native name of language
      //         predef_name       - name for predefined choice input field
      //         predef_id         - ObjectID of predefined choice
      //         predef_value      - value of predefined choice (e.g. name of choice)
      //         predef_checked    - predefined choice is selected
      //         attribute_value   - value of attribute
      //         attribute_name    - inputfield name for attribute (<attribute alias>:<langid>)
      //         attribute_checked1- inputfield checked string for yes radio buttons (Boolean)
      //         attribute_checked0- inputfield checked string for no radio buttons (Boolean)
      //         attribute_file    - link html for uploaded files (File, LocalizedFile)
      //      }
      var inputTmpl = $TMPL(opt.templatestring , {
          langid            : opt.langid,
          attribute_name    : opt.alias+':'+opt.langid,
          'native'          : (opt['native']) ? opt['native'] : "",
          predef_name       : (opt.predef_name) ? opt.predef_name : "",
          predef_id         : (opt.predef_id) ? opt.predef_id : "",
          predef_value      : (opt.predef_value) ? opt.predef_value : "",
          predef_checked    : (opt.predef_checked) ? opt.predef_checked : "",
          attribute_value   : (opt.attribute_value) ? opt.attribute_value : "",
          attribute_checked1: (opt.attribute_checked1) ? opt.attribute_checked1 : "",
          attribute_checked0: (opt.attribute_checked0) ? opt.attribute_checked0 : "",
          attribute_file    : (opt.attribute_file) ? opt.attribute_file : "",
          attribute_uploader: (opt.attribute_uploader) ? opt.attribute_uploader : "",
          attribute_id      : (opt.attribute_id) ? opt.attribute_id : ""
      }, false);
      return inputTmpl.generateOutput();
    },

    /**
     * events
     */

    _onAttributTypeChange: function(evt) {
      var selectNode = evt.currentTarget;
      var defaultTypePackage = epages.vars.defaultTypePackage;
      if(defaultTypePackage[selectNode.value]) {
        // destory old content
        this._destroyAttributeValues();

        this.data = defaultTypePackage[selectNode.value];
        // create new value nodes / rows
        this._createAttributeValueNodes(this.data, true);
        if(this.data.isPreDefAttributesContainer) {								// append new editable entry for new attribute values
          this._createNewRow();
          this.addNewPredefValueNode.style.display="";
        } else {
          this.addNewPredefValueNode.style.display="none";
        }
      }
    },

    _onShowLanguages: function(evt) {
      // summary: change display of languages nodes
      var myIndex = evt.currentTarget.getAttribute("ep_rowcount");
      evt.currentTarget.style.display="none";
      dojo.fx.wipeIn({ node: this._languageContainerNodes[myIndex],  duration: 200}).play();
    },

    _onDeleteRow: function(evt) {
      // summary: delete specific row
      var myRowIndex = evt.currentTarget.getAttribute("ep_rowcount");
      var rowNode = this._rowNodes[myRowIndex];

      // detach events
      for(var el in this._ep_connects[myRowIndex]) {
        dojo.disconnect(this._ep_connects[myRowIndex][el]);
      }
      delete this._ep_connects[myRowIndex];

      // destroy inner widgets
      var rowWidgets = this._ep_childWidgets[myRowIndex];
      for(var el in rowWidgets) {
        var widget = rowWidgets[el];
        if(widget) {
          widget.destroy();
        }
        delete this._ep_childWidgets[myRowIndex];
      }

      // remove row dom node
      rowNode.parentNode.removeChild(rowNode);
    },

    _onDelete: function(evt) {
      // summary: delete / destroy widget
      this.destroy();
    },

    /**
     * other functions
     */

    _createNewRow: function() {
    // summary: create a new row with empty input fields for new predef attribute choices
      var attrData = this.data;
      var currentLanguageId = epages.vars.Locale.languageId;
      var attrOptions = {
        type                        : attrData.type,
        isLocalized                 : attrData.isLocalized,
        isPreDefAttributesContainer : true,
        preDefAttributes            : []
      };

      var emptyPredefAttr = {
        alias: '-alias:new-',
        id: '-id:new-'
      };

      for(var langkey in epages.vars.languages) {
        attrOptions['name:'+langkey] = "";
        if(currentLanguageId != langkey && attrData.isLocalized) {
          emptyPredefAttr['value:'+langkey] = "";
        }
      }
      attrOptions.preDefAttributes.push(emptyPredefAttr);
      this._createAttributeValueNodes(attrOptions, false);

    },

    _destroyAttributeValues : function() {
    // summary: detach all connects / destroy all value nodes
      for(var el in this._ep_connects) {
        var rowconnects = this._ep_connects[el];
        for(var connection in rowconnects) {
          dojo.disconnect(rowconnects[connection]);
        }
        delete this._ep_connects[el];
      }

      // destroy inner widgets
      for(var key in this._ep_childWidgets) {
        var cWidgets = this._ep_childWidgets[key];
        for(var el in cWidgets) {
          var widget = cWidgets[el];
          if(widget) {
            widget.destroy();
          }
          delete this._ep_childWidgets[key];
        }
      }

      // destroy dom nodes
      this.valueContainerNode.innerHTML="";
    }

});

}

if(!dojo._hasResource["epages.cartridges.de_epages.product.widget.ProductTypeAttributeList"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.product.widget.ProductTypeAttributeList"] = true;
/*
	Copyright (c) 2006-2010, ePages GmbH
	All Rights Reserved.

	epages.cartridges.de_epages.product.widget.ProductTypeAttributeList

*/
dojo.provide("epages.cartridges.de_epages.product.widget.ProductTypeAttributeList");



dojo.declare("epages.cartridges.de_epages.product.widget.ProductTypeAttributeList",
	[epages.widget.LocalizedWidget], {

		/**
		 * public properties
		 */
		productTypeId     : '',														// string - id of product type
		productTypeName   : '',														// string - name of product type
		productTypeData   : undefined,										// object - product type data
		url               : '?',													//
		changeAction      : 'SaveProductType',						// string - name of change action
		viewAction        : 'View-JSON-ProductTypeData',	// string - name of view action
		objectId          : '',														// string - id of ressource
		currentLanguageId : '',					// string - id of current (display) language
		showVisibileOnly  : '0',				// string - flag to hide not visible attributes
		maxCountAttributes: 0,					// integer - numer of max possible attributes


		/**
		 * public properties
		 */
		_ep_childWidgets  : undefined,	// array   - array with child widgets
		_countAttributes  : 0,					// integer - current count attributes


		/**
		 * widget properties
		 */
		templateString:"<div class=\"ProductTypeAttributeList\">\n  <h2>{ProductType} \"<span dojoAttachPoint=\"nameNode\">{NewSetName}</span>\"</h2>\n  <div class=\"DialogMessage MessageInfo\" id=\"AttributeNameWarning\">\n  \t{AttributeNameWarning}\n  </div>\n  <div dojoAttachPoint=\"containerNode\" ></div>\n  <div dojoAttachEvent=\"onclick:onAddNewAttribute\"\n        dojoAttachPoint=\"newAttributeNode\"\n        class=\"AddNewAttribute ClickIcon EnableHover\"><i class=\"Sprite ico_s_add\"></i><a href=\"#\" onclick=\"return false;\">{AddNewAttribute}</a></div>\n  <div class=\"DialogMessage MessageInfo\" style=\"display:none;\" dojoAttachPoint=\"featureLimitExeededNode\">\n    <h3>{Notification}</h3>\n    <p class=\"Smaller\">{AttributesFeatureLimitExeeded}<br />\n      {MaxCountAttributes}: ${maxCountAttributes}\n    </p>\n  </div>\n</div>\n",
		translationName: dojo.moduleUrl('epages.cartridges.de_epages.product.widget', 'templates/translation'),

		postMixInProperties: function(){
			this.inherited("postMixInProperties", arguments);
			this._ep_childWidgets = [];
			this.productTypeData = window.epages.vars.productTypeData;
			this.productTypeName = this.productTypeData.name;
			this.showVisibileOnly = epages.string.toBoolean(this.showVisibileOnly);

			if(epages.vars.features) {
				if(! epages.vars.features.ProductTypeAttributes) {
					console.warn("epages.vars.features.ProductTypeAttributes not defined in "+this.declaredClass );
				}
			} else {
				console.warn("epages.vars.features not defined in "+this.declaredClass );
			}
			this.maxCountAttributes = parseInt(epages.vars.features.ProductTypeAttributes.FeatureMaxValue);
		},

		postCreate: function(){
			this.inherited("postCreate", arguments);
			if(window.epages.vars.productTypeData) {
				console.warn('epages.vars.productTypeData not defined in '+this.declaredClass);
				this.productTypeData = window.epages.vars.productTypeData;
				this.productTypeName = this.productTypeData.name;
				this._setUpContent();
			}	else {
				this.onChangeProductType(this.productTypeId);
			}

			dojo.subscribe(this.id+"/attributeRemoved", this, "onAttributeRemoved");
			dojo.subscribe(this.id+"/changeProductType", this, "onChangeProductType");
			dojo.subscribe(this.id+'/changeProductTypeName', this, 'onChangeProductTypeName');
		},

		_setUpContent: function() {
		// summary: create attribute widgets / display feature count message
			for(var key in this.productTypeData.attributes) {
				var data = this.productTypeData.attributes[key];
				if(data.isVisible == "1" || !this.showVisibileOnly) {
					var attributeWidget = new epages.cartridges.de_epages.product.widget.ProductTypeAttribute({
						name : data['name:'+this.currentLanguageId],
						alias : key,
						data: data,
						attributeListId : this.id,
						productObjectID : this.objectId,
						attributeNumber : this._countAttributes
					});
					if(attributeWidget) {
						this.containerNode.appendChild(attributeWidget.domNode);
						this._ep_childWidgets.push(attributeWidget);
					}
				}
				this._countAttributes++;
				if(this._countAttributes >= this.maxCountAttributes ) {
					this.newAttributeNode.style.display="none";
					this.featureLimitExeededNode.style.display = "";
				} else {
					this.newAttributeNode.style.display="";
					this.featureLimitExeededNode.style.display = "none";
				}
			}
		},

		onChangeProductTypeName: function(/* string */name ) {
		// summary: change the name node of productype
			this.nameNode.innerHTML = name;
			document.getElementById("AttributeNameWarning").style.display="none";
		},

		onAddNewAttribute: function() {
		// summary: add ne (empty) attribute widget
			var attributeWidget = new epages.cartridges.de_epages.product.widget.ProductTypeAttribute({
				attributeListId : this.id,
				attributeNumber : this._countAttributes,
				productObjectID : this.objectId
			});
			if(attributeWidget) {
				this._ep_childWidgets.push(attributeWidget);
				this.containerNode.appendChild(attributeWidget.domNode);
				this._countAttributes++;
				if(this._countAttributes >= this.maxCountAttributes ) {
					this.newAttributeNode.style.display="none";
					this.featureLimitExeededNode.style.display = "";
				} else {
					this.newAttributeNode.style.display="";
					this.featureLimitExeededNode.style.display = "none";
				}
			}
		},

		onAttributeRemoved: function(/* object */ opt) {
		// summary: message function - decrease counter ( show / hide feature limit message)
			this._countAttributes--;
			if(this._countAttributes >= this.maxCountAttributes ) {
				this.newAttributeNode.style.display="none";
				this.featureLimitExeededNode.style.display = "";
			} else {
				this.newAttributeNode.style.display="";
				this.featureLimitExeededNode.style.display = "none";
			}
		},

		onChangeProductType : function(/* string*/ productTypeId) {
		// summary: load new product type data by product type id
			var formData = {
				'ChangeAction' : this.changeAction,
				'ViewAction' : this.viewAction,
				'ObjectID' : this.objectId,
				'Class' : productTypeId
			};

			var _this = this;
			var request = new dojo.xhrPost({
				url     : this.url,
				Accept  : 'text/x-json',
				content : formData,
				load    : function(response, args) {
					_this._setNewProductType(response, args);
				},
				error   : this._loadError
			});
		},

		_loadError: function (response, args) {
		// summary: error callback / displays an error message
			var rm = response.message;
			var rn = response.name;
			dojo.publish("uimessage/showErrors", ["IO ERROR", 'loading product type data', [{
				Message : 'Could not load product type data.('+rm+')',
				Reason  : rn
			}
			]]);
			console.error(response, args);
		},

		_setNewProductType : function(response, args) {
		// summary: prepare and setup new prdouctype data / widgets
			this._destroyChildWidgets();
			response = response.replace(/<!--.*-->/g, "");		// remove comments from pagetype
			this.productTypeData = dojo.fromJson(response);
			this._setUpContent();
		},

		_destroyChildWidgets : function() {
		// summary: destroys all childwidgets
			for(var el in this._ep_childWidgets) {
				this._ep_childWidgets[el].destroy();
				delete this._ep_childWidgets[el];
			}
			this._ep_childWidgets = [];
		},

		step: function( step , ObjectID ){
			var saveSubscribe;
			if(step && step.stepData && step.stepData.TemplateName == "Content-Attributes") {
				saveSubscribe = dojo.subscribe( 'ResourceWizard/saveFinished', dojo.hitch( this, function(resultData){
					if(resultData && resultData.Attributes) {
						var attributeWidgets = this._ep_childWidgets;
						var preDefValueObjects = {};
						if(attributeWidgets) {
							// for all attributes that were created by the wizard's changeaction
							dojo.forEach(resultData.Attributes, function(att){
								// for all widgets related to each attribute
								dojo.forEach(attributeWidgets, function(widget){
									var attrType = widget.data.type;
									// depending on the attribute type
									if(widget.newAttributeNameNode.value == att.Alias) {
										// found the correct correlated attribute
										// update widget data (for later value-assignment to resource object)
										widget.data.id = att.ObjectID;
										widget.alias = att.Alias;

										var result; // JSON result
										if(attrType == "PreDefString") {
											// get value nodes of this attribute
											dojo.forEach(widget.valueContainerNode.children, function(divNode) {
												// all inputs in that div
												dojo.query("input[name^='AttributeName'][type$='text']", divNode).forEach(function(input) {
													// send save request for this attribute containing the values
													var params = {
														'ChangeAction'	 : 'SavePreDefAttributes',
														'ObjectID'			 : att.ObjectID,
														'NewAlias'			 : att.Alias,
														'NewPosition'		: 9999,
														'NewValueString' : input.value,
														'Save'					 : 1
													};
													var result = new epages.io.Json().loadSync('?', params);
													if(result && result.error && result.error.data){
														console.warn("todo: handle error", result.error.data);
													} else {
														if(result && result.data) {
															preDefValueObjects[input.value] = result.data.PreDefAttributeChildren[input.value];
															dojo.attr(divNode, "predefobjectid", result.data.PreDefAttributeChildren[input.value]);
														}
													}
												});
											});
										}
										else if (attrType == "PreDefMultiString") {
											// get value nodes of this attribute
											// foreach value block of the attributewidget
											dojo.forEach(widget.valueContainerNode.children, function(divNode) {
												dojo.query("input[name^='AttributeName'][type$='text']", divNode).forEach(function(inputNode) {
													// request skeleton
													var params = {
														'ChangeAction'	 : 'SavePreDefAttributes',
														'ObjectID'			 : att.ObjectID,
														'NewAlias'			 : inputNode.value,
														'NewValueString' : inputNode.value, // only one value for both in wizard
														'NewPosition'		: 9999,
														'Save'					 : 1,
														'ErrorAction'		: 'JSONViewResponse'
													};
													// send save request for this attribute containing the values
													var result = new epages.io.Json().loadSync('?', params);
													if(result && result.error && result.error.data){
														console.warn("todo: handle error", result.error.data);
													} else {
														if(result && result.data) {
															preDefValueObjects[params.NewAlias] = result.data.PreDefAttributeChildren[params.NewAlias];
															dojo.attr(divNode, "predefobjectid", result.data.PreDefAttributeChildren[params.NewAlias]);
														}
													}
												});
											});
										}
										else if (attrType == "PreDefLocalizedString" || attrType == "PreDefMultiLocalizedString" || attrType == "PreDefCustomerString") {
											// get value nodes of this attribute
											// foreach value block of the attributewidget
											dojo.forEach(widget.valueContainerNode.children, function(divNode) {
												var inputNodes = dojo.query("input[name^='AttributeName'][type$='text']", divNode);
												// primary language input
												var firstInputNode = inputNodes.shift();
												var nameValues = firstInputNode.name.split(':');
												if(nameValues[0] != "AttributeName") {
													console.warn("error: attribute name did not match", nameValues[0]);
													return;
												}
												// request skeleton
												var params = {
													'ChangeAction'	 : 'SavePreDefAttributes',
													'ObjectID'			 : att.ObjectID,
													'NewAlias'			 : undefined,
													'NewPosition'		: 9999,
													'Save'					 : 1,
													'ErrorAction'		: 'JSONViewResponse'
												};
												// multiple value fields as arrays
												var NewValueLocStrings = [];
												var NewLanguageIDs = [];
												// fetch langid
												NewLanguageIDs.push(nameValues[1]);
												// assign value to alias (first language-assigned name used as alias) and push value (for primary lang value)
												NewValueLocStrings.push(firstInputNode.value);
												params.NewAlias = firstInputNode.value;

												// all further inputs for all the other languages:
												inputNodes.forEach(function(input) {
													var nameValues = input.name.split(':');
													if(nameValues[0] == "AttributeName") {
														var valueLangId = nameValues[1];
														NewValueLocStrings.push(input.value);
														NewLanguageIDs.push(valueLangId);
													}
												});
												params.NewValueLocString = NewValueLocStrings;
												params.NewLanguageID = NewLanguageIDs;
												// send save request for this attribute containing the values
												var result = new epages.io.Json().loadSync('?', params);
												if(result && result.error && result.error.data){
													console.warn("todo: handle error", result.error.data);
												} else {
													if(result && result.data) {
														preDefValueObjects[params.NewAlias] = result.data.PreDefAttributeChildren[params.NewAlias];
														dojo.attr(divNode, "predefobjectid", result.data.PreDefAttributeChildren[params.NewAlias]);
													}
												}
											});
										}
									} // end if attr type
								});
							});
						}
						// assign selected values to the resource
						if(this.containerNode.children && this.containerNode.children.length > 0) {
							var params = {
								'ChangeAction'	 : 'Save',
								'ObjectID'			 : ObjectID,
								'ErrorAction'		: 'JSONViewResponse',
								'HandleFilesAsStrings' : 1
							};
							var altAttributeIDs = [];
							dojo.forEach(this.containerNode.children, function(widgetNode) {
								var widget = $$(widgetNode.id);
								if(widget && widget.alias && widget.data && widget.data.id) {
									var attrType = widget.data.type;
									// fetch the selected / entered value and assign it to the resource object
									if (attrType == "String" || attrType == "Money" ||
											attrType == "Integer" || attrType == "Float" ||
											attrType == "DateTime" || attrType == "Date" || attrType == "Time" || attrType == "File") {
										params[widget.alias] = [];
										dojo.forEach(widget.valueContainerNode.children, function(divNode) {
											dojo.query("input[name^='AttributeName'][type$='text']", divNode).forEach(function(input) {
												params[widget.alias].push(input.value);
											});
										});
									}
									else if (attrType == "Boolean") {
										params[widget.alias] = [];
										dojo.forEach(widget.valueContainerNode.children, function(divNode) {
											dojo.query("input[name^='AttributeName'][type$='radio']", divNode).forEach(function(input) {
												if(input.checked) {
													params[widget.alias].push(input.value);
												}
											});
										});
									}
									else if(attrType == "LocalizedString"	|| attrType == "LocalizedFile") {
										// needs LanguageID value for each string!
										params[widget.alias] = [];
										params['LanguageID'] = [];
										dojo.forEach(widget.valueContainerNode.children, function(divNode) {
											dojo.query("input[name^='AttributeName'][type$='text']", divNode).forEach(function(input) {

												var nameValues = input.name.split(':');
												if(nameValues[0] != "AttributeName") {
													console.warn("error: attribute name did not match", nameValues[0]);
													return;
												}
												var valueLangId = nameValues[1];
												params[widget.alias].push(input.value);
												params['LanguageID'].push(valueLangId);
											});
										});
									}
									// predef radio values: we need the object ids of the predefattributes
									else if(attrType == "PreDefString" || attrType == "PreDefLocalizedString") {
										// needs LanguageID value for each string!
										params[widget.alias] = [];
										dojo.forEach(widget.valueContainerNode.children, function(divNode) {
											dojo.query("input[name^='RadioAttributeName'][type$='radio']", divNode).forEach(function(radioInput) {
												var preDefObjectID = dojo.attr(divNode, "predefobjectid");
												if(radioInput.checked && preDefObjectID) {
													params[widget.alias].push(preDefObjectID);
												}
											});
										});
									}
									// predef multi values with checkboxes
									else if(attrType == "PreDefCustomerString" || attrType == "PreDefMultiLocalizedString" || attrType == "PreDefMultiString") {
										params[widget.alias] = [];
										dojo.forEach(widget.valueContainerNode.children, function(divNode) {
											dojo.query("input[name^='CheckboxAttributeName'][type$='checkbox']", divNode).forEach(function(cbInput) {
												var preDefObjectID = dojo.attr(divNode, "predefobjectid");
												if(cbInput.checked && preDefObjectID) {
													params[widget.alias].push(preDefObjectID);
												} else {
													params[widget.alias].push('');
												}
											});
										});
									}

									// only add change attribute id if value will be assigned
									if(params[widget.alias] != undefined) {
										altAttributeIDs.push(widget.data.id);
									}

								} else {
									console.warn("error while assigning attribute values", "attr alias", widget.alias, "attr objectid", widget.data.id);
								}
							});
							if(altAttributeIDs.length > 0) {
								params['AltAttributeID'] = altAttributeIDs;
								// send one request for all values
								var result = new epages.io.Json().loadSync('?', params);
								if(result && result.error && result.error.data){
									console.warn("todo: handle error", result.error.data);
								}
							}
						}
					} // end if json result data
					if(saveSubscribe) {
						dojo.unsubscribe(saveSubscribe);
					}
				}));
			}
			else if(saveSubscribe) {
				dojo.unsubscribe(saveSubscribe);
			}

		}
	});


}

if(!dojo._hasResource["epages.cartridges.de_epages.product.EnableOwnPrices"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.product.EnableOwnPrices"] = true;
/*
    Copyright (c) 2006-2011, ePages GmbH
    All Rights Reserved.

    epages.cartridges.de_epages.product.EnableOwnPrices
 */

dojo.provide("epages.cartridges.de_epages.product.EnableOwnPrices");

window.disablePrices = function() {
// disables all visible input fields
// enables all hidden input fields

  var priceinputs = document.getElementsByName("Price");
  var input;
  for (var i = 0; i < priceinputs.length; i++) {
    input = priceinputs[i];
    if(input.type=="hidden") {
      input.disabled=false;
    } else {
      input.disabled=true;
      input.className="Price Disabled";
    }
  }

  priceinputs = document.getElementsByName("ManufacturerPrice");
  for (var i = 0; i < priceinputs.length; i++) {
    input = priceinputs[i];
    if(input.type=="hidden") {
      input.disabled=false;
    } else {
      input.disabled=true;
    }
  }

 // EPG-4144: disable taxclass select box
  taxelement = document.getElementById("TaxClass");
  if (taxelement != null) {
    taxelement.disabled=true;
    dojo.addClass(taxelement.parentNode, "Disabled");
  }

  // disable ecopart settings
  dojo.publish("EcoParticipation/disable", []);
};

window.enablePrices = function() {
// enables all visible input fields
// disables all hidden input fields

  var priceinputs = document.getElementsByName("Price");
  var input;
  for (var i = 0; i < priceinputs.length; i++) {
    input = priceinputs[i];
    if(input.type=="hidden") {
      input.disabled=true;
    } else {
      input.disabled=false;
      input.className="Price";
    }
  }

  priceinputs = document.getElementsByName("ManufacturerPrice");
  for (var i = 0; i < priceinputs.length; i++) {
    input = priceinputs[i];
    if(input.type=="hidden") {
      input.disabled=true;
    } else {
      input.disabled=false;
    }
  }

  // EPG-4144: enable taxclass select box
  taxelement = document.getElementById("TaxClass");
  if (taxelement != null) {
    taxelement.disabled=false;
    dojo.removeClass(taxelement.parentNode, "Disabled");
  }

  // enable ecopart settings
  dojo.publish("EcoParticipation/enable", []);
};

}


/* package: ep_design.js.uncompressed */
/*
	Copyright (c) 2004-2011, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/

/*
	This is an optimized version of Dojo, built for deployment and not for
	development. To get sources and documentation, please visit:

		http://dojotoolkit.org
*/

if(!dojo._hasResource['epages.style.processor']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.style.processor'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.style.processor');






epages.style.Processor = function (/*DomNode */container,/*String*/imageBaseUrl, /*Boolean*/ cachePrevention, /*Document?*/doc) {
	// summary:
	//    initialize the style processor.
	//    all changes of input and select elements of the given container starts the style processing.
	// container: DomNode [deprecated] - no longer in use (!!!fixme) -> just pass undefined
	// imageBaseUrl: String - object (current object) related base url e.g. /WebRoot/Store/Shops/DemoShop/Styles/Milestones
	// cachePrevention: Boolean - append cache prevention string (timestamp) to file refernces e.g. WebRoot/[..]/MediaGallery/CampingSite.gif?CachePrevention=1282899274013
	// doc: Document? - target document for style rules
	// example:
	//  |  var styleProcessor = new epages.style.Processor($('myform'),'/WebRoot/Store/Shops/DemoShop/');
	//  | styleProcessor.addRule(
	//  |    'NavBarFont',
	//  |    ".(%Class%) div, .(%Class%) span, .(%Class%) table, .(%Class%) td, .(%Class%) p, .(%Class%) ul li, .(%Class%) ol li, .(%Class%) blockquote, .(%Class%) input"
	//  |  );
	//  |  styleProcessor.addInput(
	//  |    'NavBarFont',                   // rule name
	//  |    'NavBarTop',                    // CSS ClassName
	//  |    'font-family',                  // CSS AttributeName
	//  |    $('TopFontFamily'),             // input
	//  |    function(el) {                  // callback
	//  |      if(el.value="") { alert("new value is empty"); }
	//  |    }
	//  |  );
	//  |  styleProcessor.fill();
	this.rules  = new epages.lang.Hash();
	this.inputs = new epages.lang.Hash();
	this.imageBaseUrl = imageBaseUrl;
	this.cachePrevention = cachePrevention;
	this.doc = doc || dojo.doc;
};

epages.style.Processor.prototype = {
	rules       : undefined,    // epages.lang.Hash - registerd css rules -> key: <css-selector:String> value <css-attributes:String>
	inputs      : undefined,    // epages.lang.Hash - registerd input elements (event trigger) e.g. {}
	imageBaseUrl: undefined,    // String - base url of file location
	cachePrevention: undefined, // Boolean - append cache prevention string on file url or not
	doc         : undefined,    // window.document - document to work on
	defaults    : {
		'text-decoration' : function (Value) { return 'text-decoration: '  + (Value == "1" ? 'underline' : 'none'  ); },
		'font-style' :      function (Value) { return 'font-style: '       + (Value == "1" ? 'italic'    : 'normal') + ' !important'; },
		'font-weight':      function (Value) { return 'font-weight: '      + (Value == "1" ? 'bold'      : 'normal') + ' !important'; },
		'color':            function (Value) { return 'color: ' + Value + ' !important';},
		'navbar-horizontalalign':   function (Value) {
			if(Value == "left") {
				return 'text-align:'+Value+'; margin: 0 auto 0 0; float: none;';
			} else if(Value == "right") {
				return 'text-align:'+Value+'; margin: 0 0 0 auto; float: none;' ;
			} else if(Value == "custom") { // Added "custom" for EPG-26482
				return 'text-align: left' + '; margin: 0 auto 0 0; float: left;';
			} else {
				return 'text-align:'+Value+'; margin: 0 auto 0 auto; float: none;';
			}
		},
		'box-horizontalalign':   function (Value) {
			if(Value == "left") {
				return 'margin-left:0!important; margin-right:auto!important';
			} else if(Value == "right") {
				return 'margin-right:0!important; margin-left:auto!important';
			} else {
				return 'margin-left:auto!important; margin-right:auto!important';
			}
		},
		'background-image':       function(Value, Owner) {
			if(Value!="none" && Value!="") {
				var myBaseURL = epages.lang.uri.isAbsolute(Value) ? '' : Owner.imageBaseUrl;
				return 'background-image: url(' + myBaseURL+ Value+Owner.attachCachePrevention()+')';
			} else {
			 return 'background-image: none';
			}
		},
		'background-image-right': function(Value, Owner) {
			if(Value!="none" && Value!="") {
				var myBaseURL = epages.lang.uri.isAbsolute(Value) ? '' : Owner.imageBaseUrl;
				return 'background-image: url(' + myBaseURL+ Value+Owner.attachCachePrevention()+') !important; background-position: top right';
			} else {
			 return 'background-image: none';
			}
		},
		'background-image-right-norepeat': function(Value, Owner) {
			if(Value!="none" && Value!="") {
				var myBaseURL = epages.lang.uri.isAbsolute(Value) ? '' : Owner.imageBaseUrl;
				return 'background-image: url(' + myBaseURL+ Value+Owner.attachCachePrevention()+') !important; background-position: top right !important; background-repeat: no-repeat';
			} else {
			 return 'background-image: none';
			}
		},
		'background-image-left': function(Value, Owner) {
			if(Value!="none" && Value!="") {
				var myBaseURL = epages.lang.uri.isAbsolute(Value) ? '' : Owner.imageBaseUrl;
				return 'background-image: url(' + myBaseURL+ Value+Owner.attachCachePrevention()+') !important; background-position: top left';
			} else {
			 return 'background-image: none';
			}
		},
		'background-image-left-norepeat': function(Value, Owner) {
			if(Value!="none" && Value!="") {
				var myBaseURL = epages.lang.uri.isAbsolute(Value) ? '' : Owner.imageBaseUrl;
				return 'background-image: url(' + myBaseURL+ Value+Owner.attachCachePrevention()+') !important; background-position: top left !important; background-repeat: no-repeat';
			} else {
			 return 'background-image: none';
			}
		},
		'background-image-bottom-right-norepeat': function(Value, Owner) {
			if(Value!="none" && Value!="") {
				var myBaseURL = epages.lang.uri.isAbsolute(Value) ? '' : Owner.imageBaseUrl;
				return 'background-image: url(' + myBaseURL+ Value+Owner.attachCachePrevention()+') !important; background-position: bottom right !important; background-repeat: no-repeat';
			} else {
			 return 'background-image: none';
			}
		},
		'background-image-bottom-left-norepeat':  function(Value, Owner) {
			if(Value!="none" && Value!="") {
				var myBaseURL = epages.lang.uri.isAbsolute(Value) ? '' : Owner.imageBaseUrl;
				return 'background-image: url(' + myBaseURL+ Value+Owner.attachCachePrevention()+') !important; background-position: bottom left !important; background-repeat: no-repeat';
			} else {
			 return 'background-image: none';
			}
		},
		'background-image-clear':   function(Value) {
			 return 'background-image: none';
		},
		'background-repeat': function(Value) {
			return 'background-repeat: '+ (Value=='1' ? 'repeat' : 'no-repeat');
		},
		'width-and-max-width': function(Value) {
			 return 'width:'+Value+' !important; max-width:'+Value;
		}
	},    // Object - hash with default css attribute function -> key <css-attribute> value <function>

	defaultCallbacks : {
		'update-button-active' : function (object, navbar) {
			this.updateButtonStyle(navbar.replace(/^NavBar/,''), 'ButtonActive');
		},
		'update-button-both' : function (object, navbar) {
			navbar = navbar.replace(/^NavBar/,'');
			this.updateButtonStyle(navbar, 'Button');
			this.updateButtonStyle(navbar, 'ButtonActive');
		},
		'set-imageset-left-backgound' : function (object, navbar) {
			if (object.value=="0") {
				this.set($('ImageSetLeft'+navbar.replace(/^NavBar/,'')+'BackgroundImage'));
			}
		},
		'set-imageset-right-backgound' : function (object, navbar) {
			this.set($('ImageSetRight'+navbar.replace(/^NavBar/,'')+'BackgroundImage'));
		},
		'set-imageset-right-boxbody' : function (object, navbar) {
			this.set($('ImageSetRight'+navbar.replace(/^NavBar/,'')+'BoxBodyImage'));
		},
		'set-imageset-right-box' : function (object, navbar) {
			this.set($('ImageSetRight'+navbar.replace(/^NavBar/,'')+'BoxImage'));
		},
		'set-imageset-boxbody-both' : function (object, navbar) {
			if(object.value=='0') {
				navbar = navbar.replace(/^NavBar/,'');
				this.set($('ImageSetRight'+navbar+'BoxBodyImage'));
				this.set($('ImageSetLeft'+navbar+'BoxBodyImage'));
			}
		},
		'set-imageset-box-both' : function (object, navbar) {
			if(object.value=='0') {
				navbar = navbar.replace(/^NavBar/,'');
				this.set($('ImageSetRight'+navbar+'BoxImage'));
				this.set($('ImageSetLeft'+navbar+'BoxImage'));
			}
		},
		'set-imageset-background-both' : function (object, navbar) {
			if(object.value=='0') {
				navbar = navbar.replace(/^NavBar/,'');
				this.set($('ImageSetRight'+navbar+'BackgroundImage'));
				this.set($('ImageSetLeft'+navbar+'BackgroundImage'));
			}
		},
		'set-boximage' : function (object, navbar) {
			navbar = navbar.replace(/^NavBar/,'');
			// clear background image
			this.set($(navbar+'BoxImageHidden')); // clear imageset floatin image
			this.set($(navbar+'BoxImage')); // set uploaded image again
			if(object.value=="") {
				this.set($('ImageSetRight'+navbar+'BoxImage'));
				this.set($('ImageSetLeft'+navbar+'BoxImage'));
			} else {
				this.set($(navbar+'BoxImageTiling')); // set tiling (repeat)
			}
		},
		'set-boxbodyimage' : function (object, navbar) {
			navbar = navbar.replace(/^NavBar/,'');
			// clear background image
			this.set($(navbar+'BoxBodyImageHidden')); // clear imageset floatin image
			this.set($(navbar+'BoxBodyImage')); // set uploaded image again
			if(object.value=="") {
				this.set($('ImageSetRight'+navbar+'BoxBodyImage'));
				this.set($('ImageSetLeft'+navbar+'BoxBodyImage'));
			} else {
				this.set($(navbar+'BoxBodyImageTiling')); // set tiling (repeat)
			}
		},
		'set-backgroundimage' : function (object, navbar) {
			navbar = navbar.replace(/^NavBar/,'');
			// clear background image
			this.set($(navbar+'BackgroundImageHidden')); // clear imageset floatin image
			this.set($(navbar+'BackgroundImage')); // set uploaded image again
			if(object.value=="") {
				if ($('ImageSetRight'+navbar+'BackgroundImage') != null){
					this.set($('ImageSetRight'+navbar+'BackgroundImage'));
				}
				this.set($('ImageSetLeft'+navbar+'BackgroundImage'));
			} else {
				this.set($(navbar+'BackgroundImageTiling')); // set tiling (repeat)
			}
		}
	},	// Object - hash with default callback functions to set css to a designable element -> key <set-elmentname> value <function>

	attachCachePrevention: function() {
	// summary: generate cache prevention string e.g. "?CachePrevention=1234567890"
		var date = new Date();
		return (this.cachePrevention) ? "?CachePrevention="+date.getTime() : "";	// String
	},

	addRule: function(/*String*/ruleName, /*String*/CSSKey, /*Object*/CSSAttributes) {
		// summary:
		//    Adds a style rule to the processor.
		//    The rule name is a short keyword for a CSS key.
		//    The CSSKey can include a placeholder '(%Class)' (also multiple times) for a CSS class,
		//    which will be defined via the 'addInput' method.
		// example:
		//  |  var styleProcessor = new epages.style.Processor();
		//  |  styleProcessor.addRule(
		//  |    'NavBarFont',
		//  |    ".(%Class%) div, .(%Class%) span, .(%Class%) table, .(%Class%) td, .(%Class%) p, .(%Class%) ul li, .(%Class%) ol li, .(%Class%) blockquote, .(%Class%) input"
		//  |  );
		//  |  styleProcessor.addRule('ContentPadding', ".ContentArea");
		//  |  styleProcessor.addRule('NavBarContainer', ".(%Class%) .PropertyContainer");
		//  |  styleProcessor.addRule('ThisClass', ".(%Class%)");
		if (CSSAttributes === undefined) {
			CSSAttributes = {};
		}
		var rule = new epages.lang.Hash();
		rule.set('Key', CSSKey);
		rule.set('Attributes', CSSAttributes);
		this.rules.set(ruleName, rule);
	},

	addInput: function(/*String*/ruleName, /*String*/className, /*String*/attributeName, /*Object|String*/inputObject, /*Function?*/callback) {
		// summary:
		//    Adds a input element to the processor.
		//    Attention: The name of input fields has to be unique.
		// example:
		//  |  var styleProcessor = new epages.style.Processor();
		//  |  styleProcessor.addInput(
		//  |    'NavBarFont',                   // rule name
		//  |    'NavBarTop',                    // CSS ClassName
		//  |    'font-family',                  // CSS AttributeName
		//  |    $('TopFontFamily'),             // input
		//  |  );
		//  |  styleProcessor.addInput('NavBarContainer', 'NavBarLeft', 'width', $('BoxWidth'), function (el) {
		//  |    $('LeftNavBarWidth').value = (parseInt($('BoxWidth').getValue().replace(/px/, '')) + parseInt($('LeftPaddingRight').getValue().replace(/px/, '')) + parseInt($('LeftPaddingLeft').getValue().replace(/px/, ''))) + 'px';
		//  |    styleProcessor.set($('LeftNavBarWidth'));
		//  |  });
		if (typeof inputObject == 'string') {
			var inputObjectId = inputObject;
			inputObject = $(inputObjectId);
			if (inputObject == null) {
				//console.debug('epages.style.Processor.addInput: could not find input with id ' + inputObjectId + ', ruleName:' + ruleName);
				return;
			}
		} else if (inputObject == null) {
			//console.debug('epages.style.Processor.addInput cant add undefined object, rulename: ' + ruleName + '. attributeName:' + attributeName);
			return;
		}
		if (callback !== undefined && typeof callback != 'function') {
			callback = this.defaultCallbacks[callback];
		}
		// console.debug('epages.style.Processor.addInput add object for rule: ' + ruleName + '.');
		// console.debug(inputObject);
		// console.debug('epages.style.Processor.addInput add object: ' + inputObject.name + '.');
		dojo.connect(inputObject, 'onchange', this, '_set');
		this.inputs.set(inputObject.name, {
			rule:       ruleName,
			className:  className,
			attribute:  attributeName,
			target:     inputObject,
			callback:   callback
		});
	},

	deleteStyleRule: function(/*String*/ruleName){
		//summary:
		//remove all entrys of a given style rule from the set of rules
		var styleRuleId = '.StyleRule-' + ruleName;
		var styleRules = this.doc.defaultView ? this.doc.defaultView.dojo.query(styleRuleId) : [];
		for(var i = 0, iLength = styleRules.length; i < iLength; i++){
			dojo.destroy(styleRules[i]);
		}
	},

	_updateStyleSheet: function(/* String */ rule, /*String*/ text,/*String*/ruleName) {
		// summary:
		//    add a CSS rule with given text.
		// rule: String - CSS Selector
		// rule: String - CSS Text (Attributes) e.g. color: red;
		// example:
		//  |  var styleProcessor = new epages.style.Processor();
		//  |  styleProcessor._updateStyleSheet('.NavBarTop div, .NavBarTop span', 'padding-left: 5px');

		// we have to be sure that we don't conflict with pseudo classes like :hover
		if(!rule.match("html")) {
			rule = "html body " + rule.replace(/,/g, " , html body");
		}
		if(!rule.match(" a") && !/important/.test(text)) {
			text += ' !important';
		}
		if (epages.Browser.engine == 'MSIE') {
			var rules = rule.split(/,\s+/);
			var sheet = this.doc.styleSheets[this.doc.styleSheets.length-1];
			for( var i=0,l=rules.length ; i<l ; i++ ) {
				sheet.addRule(rules[i], text);
			}
		} else {
			var styleRules = this.doc.getElementById('StyleRules');
			if(!styleRules){
				styleRules = this.doc.createElement("div");
				styleRules.id = "StyleRules";
				this.doc.body.appendChild(styleRules);
			}
			var styleContainer = this.doc.createElement("div");
			var styleRuleId = 'StyleRule-' + ruleName;
			styleContainer.innerHTML = "<div class='HideElement " + styleRuleId + "'>.<style type='text/css'>" + rule + '{' + text + '}' + "</style></div>";
			styleRules.appendChild(styleContainer);
		}
	},

	_set: function (/*Event*/evt) {
		// summary:
		//    call back function for event observer.
		var inputNode = evt.target;
		if (inputNode.name.match(/image/i) && inputNode.value.match(/^MediaGallery\//)) {
			inputNode.value = epages.lang.uri.getRelative(this.imageBaseUrl, epages.vars.SiteRoot + '/' + inputNode.value);
		}
		var isError=inputNode.getAttribute("ep_error");
		if (isError != 1){
			this.set(inputNode, true);
		}
	},

	set: function (/*Object*/inputObject, /*Boolean?*/doCallback) {
		// summary:
		//    set style sheet information for this input element.
		//    Returns true if input rule was processed.
		if (doCallback === undefined) {
			doCallback = false;
		}
		var value = $E(inputObject).get();
		if(value === undefined) {
			console.warn('Value is undefined in '+this.declaredClass+'. inputObject:', inputObject);
		}
		var ruleInput = this.inputs.get(inputObject.name);
		if (ruleInput === undefined) {
			//console.debug('no rule for inputfield "' + inputObject.id + '" (' + inputObject.name + ')');
			return 0; // Boolean
		}
		var ruleName      = ruleInput.rule;      // eg: NavBarFont
		var className     = ruleInput.className; // eg: NavBarTop
		var attributeName = ruleInput.attribute; // eg: font-family
		var KeyTemplate = this.rules.get(ruleName).get('Key');
		var CSSKey = KeyTemplate.replace( /\(%Class%\)/g , className);
		// get value definition, could be a function/string/undefined
		var attributeDefinition = this.rules.get(ruleName).get('Attributes')[attributeName];
		if (attributeDefinition === undefined) {
			attributeDefinition = this.defaults[attributeName];
		}

		// get real css value
		var CSSValue = undefined;
		switch (typeof attributeDefinition) {
			case 'function':
				CSSValue = attributeDefinition(value, this);
				break;
			case 'string':
				CSSValue = attributeDefinition.replace( /\(%Value%\)/gi , value);
				break;
			default:
				CSSValue = attributeName + ': ' + value;
				break;
		}

		this._updateStyleSheet(CSSKey, CSSValue,ruleName);
		if (doCallback && ruleInput.callback !== undefined) {
			ruleInput.callback.call(this, inputObject, className);
		}
		return 1; // Boolean
	},

	fill: function () {
		// summary:
		//    calls processor rules for each input (set stylesheet info to input field values).
		var currentThis = this;
		var iterator = function(el) {
			currentThis.set(el.target, true);
		};
		var values = this.inputs.values();
		$A(values).each(iterator);
	},

	updateButtonStyle: function (navBar, buttonType) {
		// summary: helper function for button style rule update
		// description: Sets or clears the current and the opposite button image. Furthermore it sets the
		//              left and right ImageSet images on demand and activates image tiling.
		// example:
		// | styleProcessor.addInput('NavigationElement','Header','background-image-left-norepeat',$('HeaderButton'),function(el) {
		// |   updateButtonStyle('Header','Button');
		// | });
		this.set($(navBar+buttonType));
		this.set($(navBar+"Right"+buttonType));
		if(($(navBar+buttonType+'Hidden').value=="0" || $(navBar+buttonType+'Hidden').value=="") &&
			 $(navBar+buttonType).value=="" &&
			 $(navBar+"Right"+buttonType).value=="") {
			// (hide ImageSet=0 or empty) && (no left image) && (no right image) --> show ImageSet images
			this.set($('ImageSetLeft'+navBar+buttonType));
			this.set($('ImageSetRight'+navBar+buttonType));
		} else {
			// set image tiling style (background-repeat)
			// this is only possible with uploaded images - not with image set images
			this.set($(navBar+buttonType+'Tiling'));
		}
	}
};

}

if(!dojo._hasResource['epages.cartridges.de_epages.design.widget.Toolbackgroundimage']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.design.widget.Toolbackgroundimage'] = true;
/*
	Copyright (c) 2006-2010, ePages GmbH
	All Rights Reserved.
*/

dojo.provide('epages.cartridges.de_epages.design.widget.Toolbackgroundimage');




epages.require('ep_shop_upload', 'epages.uploader');


dojo['require']('epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery');

dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolbackgroundimage",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		label               : "",
		fileName            : "",
		imageType           : "",
		imageSetHidden      : "",
		imagesetLeft        : "",
		imagesetRight       : "",
		imageTiling         : "",
		disableTiling       : "0",
		allowImageSetTiling : "0",
		disableImageSet     : "0",
		objectId            : "",
		'class'             : "",
		uploadAction      	: "UploadFiles",
		fileNameNode        : null,
		formElement					: 'NewFile',
		userConfirmation		: false,
		/**
		 * template properties
		 */
		templateType        : "tablerow",
		defaultTemplateType : "tablerow",
		templateString:"<tr class=\"ToolbackgroundImage\">\n  <td class=\"InputLabelling\">\n    <span class=\"Label\">${label}</span><br />\n    <div class=\"UploadArea AlignCenter\">\n    </div>\n  </td>\n  <td class=\"BackgroundImageUploadSettings\">\n\n      <input dojoAttachPoint=\"fileNameNode\"\n             id=\"${imageType}\"\n             name=\"${imageType}\"\n             value=\"${fileName}\"\n             type=\"hidden\"\n             />\n\n      <!-- buttons -->\n      <div dojoAttachPoint=\"clearImageNode\"\n            class=\"CommandSmallWithLink NoPadding\"\n            style=\"display:none\"\n            >\n            <i class=\"Sprite ico_s_delete\"></i>{Delete}\n      </div>\n      <div dojoAttachPoint=\"clearImageSetNode\"\n            class=\"CommandSmallWithLink NoPadding\"\n            style=\"display:none\"\n            >\n        <i class=\"Sprite ico_s_delete\"></i>{ClearImageSet}\n      </div>\n\n      <div dojoAttachPoint=\"restoreImageSetNode\"\n            class=\"CommandSmallWithLink NoPadding\"\n            style=\"display:none\"\n            >\n        <i class=\"Sprite ico_s_redo\"></i>{RestoreImageSet}\n      </div>\n\n      <div dojoType=\"epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery\"\n           dojoAttachPoint=\"toolMediaGalleryWidget\"\n           validFileTypes=\"jpe;jpg;jpeg;gif;png\"\n           multiSelect=\"false\"\n           webImagesOnly=\"true\"\n           opener=\"Toolbackgroundimage\"\n           ></div>\n\n      <div class=\"ClearBoth\"></div>\n      <div dojoAttachPoint=\"tilingAreaNode\" class=\"LeftSmallMargin\">\n        <input dojoAttachPoint=\"tilingCheckboxNode\"\n               name=\"TilingCheckBox\"\n               class=\"Checkbox AlignMiddle\"\n               type=\"text\"\n               ep_noundo=\"1\"\n               />{Tiling}\n\n        <input dojoAttachPoint=\"imageTilingNode\"\n               type=\"hidden\"\n               name=\"${objectId}:${imageType}Tiling\"\n               id=\"${imageType}Tiling\"\n               value=\"${imageTiling}\" />\n      </div>\n\n    <!-- clear image set -->\n    <input dojoAttachPoint=\"imageHiddenNode\"\n           id=\"${imageType}Hidden\"\n           name=\"${objectId}:${imageType}Hidden\"\n           value=\"${imageSetHidden}\"\n           type=\"hidden\"\n           />\n\n    <!-- style rule container for image set names -->\n    <input dojoAttachPoint=\"imageSetNode\"\n           id=\"ImageSetLeft${imageType}\"\n           name=\"ImageSetLeft${imageType}\"\n           value=\"${imagesetLeft}\"\n           type=\"hidden\"\n           ep_noundo=\"1\"\n           />\n    <input dojoAttachPoint=\"imageSetRightNode\"\n           id=\"ImageSetRight${imageType}\"\n           name=\"ImageSetRight${imageType}\"\n           value=\"${imagesetRight}\"\n           type=\"hidden\"\n           ep_noundo=\"1\"\n           />\n  </td>\n</tr>\n",
		translationName    : dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates/translation'),

		_templateMapping:{
			'tablerow' : {templateString:"<tr class=\"ToolbackgroundImage\">\n  <td class=\"InputLabelling\">\n    <span class=\"Label\">${label}</span><br />\n    <div class=\"UploadArea AlignCenter\">\n    </div>\n  </td>\n  <td class=\"BackgroundImageUploadSettings\">\n\n      <input dojoAttachPoint=\"fileNameNode\"\n             id=\"${imageType}\"\n             name=\"${imageType}\"\n             value=\"${fileName}\"\n             type=\"hidden\"\n             />\n\n      <!-- buttons -->\n      <div dojoAttachPoint=\"clearImageNode\"\n            class=\"CommandSmallWithLink NoPadding\"\n            style=\"display:none\"\n            >\n            <i class=\"Sprite ico_s_delete\"></i>{Delete}\n      </div>\n      <div dojoAttachPoint=\"clearImageSetNode\"\n            class=\"CommandSmallWithLink NoPadding\"\n            style=\"display:none\"\n            >\n        <i class=\"Sprite ico_s_delete\"></i>{ClearImageSet}\n      </div>\n\n      <div dojoAttachPoint=\"restoreImageSetNode\"\n            class=\"CommandSmallWithLink NoPadding\"\n            style=\"display:none\"\n            >\n        <i class=\"Sprite ico_s_redo\"></i>{RestoreImageSet}\n      </div>\n\n      <div dojoType=\"epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery\"\n           dojoAttachPoint=\"toolMediaGalleryWidget\"\n           validFileTypes=\"jpe;jpg;jpeg;gif;png\"\n           multiSelect=\"false\"\n           webImagesOnly=\"true\"\n           opener=\"Toolbackgroundimage\"\n           ></div>\n\n      <div class=\"ClearBoth\"></div>\n      <div dojoAttachPoint=\"tilingAreaNode\" class=\"LeftSmallMargin\">\n        <input dojoAttachPoint=\"tilingCheckboxNode\"\n               name=\"TilingCheckBox\"\n               class=\"Checkbox AlignMiddle\"\n               type=\"text\"\n               ep_noundo=\"1\"\n               />{Tiling}\n\n        <input dojoAttachPoint=\"imageTilingNode\"\n               type=\"hidden\"\n               name=\"${objectId}:${imageType}Tiling\"\n               id=\"${imageType}Tiling\"\n               value=\"${imageTiling}\" />\n      </div>\n\n    <!-- clear image set -->\n    <input dojoAttachPoint=\"imageHiddenNode\"\n           id=\"${imageType}Hidden\"\n           name=\"${objectId}:${imageType}Hidden\"\n           value=\"${imageSetHidden}\"\n           type=\"hidden\"\n           />\n\n    <!-- style rule container for image set names -->\n    <input dojoAttachPoint=\"imageSetNode\"\n           id=\"ImageSetLeft${imageType}\"\n           name=\"ImageSetLeft${imageType}\"\n           value=\"${imagesetLeft}\"\n           type=\"hidden\"\n           ep_noundo=\"1\"\n           />\n    <input dojoAttachPoint=\"imageSetRightNode\"\n           id=\"ImageSetRight${imageType}\"\n           name=\"ImageSetRight${imageType}\"\n           value=\"${imagesetRight}\"\n           type=\"hidden\"\n           ep_noundo=\"1\"\n           />\n  </td>\n</tr>\n"},
			'xlicon'   : {templateString:"<div class=\"NavbarPreviewLayout1 ${cssClass}\">\n  <div dojoAttachpoint=\"roofNode\" class=\"NavbarPreviewRoof EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"headerNode\" class=\"NavbarPreviewHeader EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"topNode\" class=\"NavbarPreviewTop EnableHover\" style=\"display:none\"></div>\n  <div class=\"NavbarPreviewThreeColumns\">\n    <div class=\"NavbarPreviewContent\"></div>\n    <div dojoAttachpoint=\"leftNode\" class=\"NavbarPreviewLeft EnableHover\" style=\"display:none\"></div>\n    <div dojoAttachpoint=\"rightNode\" class=\"NavbarPreviewRight EnableHover\" style=\"display:none\"></div>\n  </div>\n  <div dojoAttachpoint=\"bottomNode\" class=\"NavbarPreviewBottom EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"footerNode\" class=\"NavbarPreviewFooter EnableHover\" style=\"display:none\"></div>\n</div>\n"}
		},

		/**
		 * widget properties
		 */
		imagePath         : epages.themeUrl('images'),
		widgetsInTemplate : true,

		postMixInProperties: function(){
			this._templateDirectory = dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates');
			this.inherited("postMixInProperties", arguments);
		},

		postCreate  : function() {
			this.inherited("postCreate", arguments);
			dojo.addClass(this.domNode,this['class']);

			if(this.objectId != '') {
				this.fileNameNode.name=this.objectId+":"+this.fileNameNode.name;
			}


			// pass callback function to toolMediaGalleryWidget
			this.toolMediaGalleryWidget.fileNameNode = this.fileNameNode;
			this.toolMediaGalleryWidget.onApply = dojo.hitch(this, function(pathFromSite) {
				this.setFileName(pathFromSite);
			});

			if(this.disableTiling=="1") {
				this.tilingAreaNode.style.display='none';
			}

			this.tilingCheckboxNode = new epages.widget.FormElement({}, this.tilingCheckboxNode).elementNode;

			// check tiling checkbox if necessary
			if(this.imageTiling == "1"){
				epages.event.fire(this.tilingCheckboxNode,"click");
			}

			// init events
			this._appendEvents();
			// init buttons
			this._showButtons();
		},

		/**
		 * public methods
		 */

		setFileName: function(pathFromSite) {
			this.fileNameNode.value = pathFromSite;
			epages.event.fire(this.fileNameNode, "change");
		},

		/**
		 * private methods
		 */

		_appendEvents: function() {
		// summary: append onclick and onchange events

			// add value handler
			this.connect(this.clearImageNode,      'onclick', '_clearImage');
			this.connect(this.clearImageSetNode,   'onclick', '_clearImageSet');
			this.connect(this.restoreImageSetNode, 'onclick', '_restoreImageSet');
			this.connect(this.tilingCheckboxNode,  'onclick', '_toggleImageTiling');

			this.connect(this.fileNameNode,        'onchange', '_showButtons');
			this.connect(this.imageHiddenNode,     'onchange', '_showButtons');
			this.connect(this.imageTilingNode,     'onchange', '_showButtons');
		},

		_clearImage: function(evt) {
		// summary: clears the value of "image file name" input and throws change event
			if(this.userConfirmation){
				var me = this;
				dojo.publish("uimessage/show", [
					this.translation.get("HeadLineDeleteFile"),
					this.translation.get("File") + ': ' + me.label,
					'Dialog',
					{
						titleBar: this.translation.get("TitleDeleteFile"),
						sizeClass:"Large",
						typeClass:"Confirmation",
						buttons: [{
							cssClass: 'Active ep-button ep-button-cta',
							label: this.translation.get("Delete"),
							onclick: function() {
								this._modalDialogWidget.hide();
								me.fileNameNode.value="";
								epages.event.fire(me.fileNameNode, "change");
							}
						},
						{
							cssClass: 'ep-button ep-button-cancel',
							label: this.translation.get("Cancel"),
							onclick: function() {
								this._modalDialogWidget.hide();
							}
						}]
					}
				]);
			}
			else{
				this.fileNameNode.value="";
				epages.event.fire(this.fileNameNode, "change");
				/*
				if(this.imageHiddenNode.value=="1") {
					epages.event.fire(this.noUndoImageHiddenNode,"change");
				}
				*/
			}
		},

		_clearImageSet: function(evt) {
		// summary: set value of "imageHidden" input to "1" and throw change event
			this.imageHiddenNode.value="1";
			epages.event.fire(this.imageHiddenNode,"change");
		},

		_restoreImageSet: function(evt) {
		// summary: set value of "imageHidden" input to "0" and throw change events
			this.imageHiddenNode.value="0";
			epages.event.fire(this.imageHiddenNode,"change");
			epages.event.fire(this.imageSetNode,"change");
		},

		_showButtons: function() {
		// summary: decides which button is visible
			if(this.imageTilingNode.value=='1') {
				this.tilingCheckboxNode.checked=true;
			} else {
				this.tilingCheckboxNode.checked=false;
			}

			if(this.fileNameNode.value!="") {						// image uploaded
				this.clearImageNode.style.display="";
				this.clearImageSetNode.style.display="none";
				this.restoreImageSetNode.style.display="none";
				if(this.disableTiling!="1") {
					this.tilingAreaNode.style.display="";
				}
			} else if(this.imageHiddenNode.value!="1"){ // show image set
				this.clearImageNode.style.display="none";
				if(this.disableImageSet=="0") {
					this.clearImageSetNode.style.display="";
				}
				else {
					this.clearImageSetNode.style.display="none";
				}
				this.restoreImageSetNode.style.display="none";
				if(this.allowImageSetTiling=="0" || this.disableTiling=="1") {
					this.tilingAreaNode.style.display="none";
				} else {
					this.tilingAreaNode.style.display="";
				}
			} else {																		// no image/ image set hidden
				this.clearImageNode.style.display="none";
				this.clearImageSetNode.style.display="none";
				this.restoreImageSetNode.style.display="";
				this.tilingAreaNode.style.display="none";
			}
		},

		_toggleImageTiling: function(evt) {
		// summary: hidden input / checkbox handler set
		// description: Handles the value of the hidden input element which depends on the visible checkbox.
		//		Afterwards it fires an change event to trigger the display handler (_showButtons).
			if(this.tilingCheckboxNode.checked==true) {
				this.imageTilingNode.value=1;
			} else {
				this.imageTilingNode.value=0;
			}
			epages.event.fire(this.imageTilingNode,"change");
		}
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolfontfamily"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolfontfamily"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.design.widget.Toolfontfamily");





dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolfontfamily",
	[epages.widget.LocalizedWidget, dijit._Contained],
	{
		/**
		 * public properties
		 */
		label               : '',
		fontFamily          : '',
		fontType            : '', /* Headline, Paragraph, Link, ... */
		objectId            : '',

		/**
		 * private properties
		 */
		templateType        : "tablerow",
		defaultTemplateTyp  : "tablerow",
		_templateMapping:{
			'tablerow' : {templateString:"<tr class=\"Toolfontfamily\">\n  <td class=\"InputLabelling NoWrap\">${label}</td>\n  <td class=\"FontSize\">\n      <select dojoAttachPoint=\"fontSelectNode\"\n              id=\"${fontType}\"\n              name=\"${objectId}:${fontType}\"\n              >\n        <option style=\"font-family:Arial, Verdana, Helvetica\"                                value=\"Arial, Verdana, Helvetica\"                            >Arial</option>\n        <option style=\"font-family:'Courier New', Verdana, Helvetica\"                        value=\"Courier New, Verdana, Helvetica\"                      >Courier New</option>\n        <option style=\"font-family:georgia, 'Times New Roman', arial, sans-serif\"            value=\"georgia, Times New Roman, arial, sans-serif\"          >Georgia</option>\n        <option style=\"font-family:'Lucida Sans Unicode', 'Lucida Sans', Verdana, Helvetica\" value=\"Lucida Sans Unicode, Lucida Sans, Verdana, Helvetica\" >Lucida Sans</option>\n        <option style=\"font-family:Tahoma, Verdana, Helvetica\"                               value=\"Tahoma, Verdana, Helvetica\"                           >Tahoma</option>\n        <option style=\"font-family:'Times New Roman', Times\"                                 value=\"Times New Roman, Times\"                               >Times New Roman</option>\n        <option style=\"font-family:'Trebuchet MS', Verdana, Arial, Helvetica\"                value=\"Trebuchet MS, Verdana, Arial, Helvetica\"              >Trebuchet MS</option>\n        <option style=\"font-family:Verdana, Arial, Helvetica\"                                value=\"Verdana, Arial, Helvetica\"                            >Verdana</option>\n      </select>\n  </td>\n</tr>\n"},
			'xlicon'   : {templateString:"<div class=\"Toolfontfamily WithXLIcon\">\n  <div class=\"CommandPane ExtraLarge\" dojoAttachPoint=\"clickNode\" dojoAttachEvent=\"onclick:showFontMenu\">\n    <i class=\"Sprite ico_xl_font\" title=\"{SelectFont}\"></i><br />\n    ${label}<br />\n    <img src=\"${imagePath}/img_extend.png\"\n     alt=\"{SelectFont}\" title=\"{SelectFont}\" />\n  </div>\n  <input type=\"hidden\"\n         dojoAttachPoint=\"fontSelectNode\"\n         id=\"${fontType}\"\n         name=\"${objectId}:${fontType}\" >\n  <div dojoAttachPoint=\"menuContainerNode\"></div>\n</div>\n"}
		},

		_lastSelected       : null,
		_menuWidget         : null,
		_popup              : null,
		_fonts: {
			'Arial'         : { fontfamily : "Arial, Verdana, Helvetica",                            webfont : '' },
			'Baumans'       : { fontfamily : "Baumans",                                              webfont : 'Baumans' },
			'ComingSoon'    : { fontfamily : "Coming Soon",                                          webfont : 'Coming+Soon' },
			'CourierNew'    : { fontfamily : "Courier New, Verdana, Helvetica",                      webfont : '' },
			'Cutive'        : { fontfamily : "Cutive",                                               webfont : 'Cutive' },
			'DroidSerif'    : { fontfamily : "Droid Serif",                                          webfont : 'Droid+Serif:400,700,400italic,700italic' },
			'ExpletusSans'  : { fontfamily : "Expletus Sans",                                        webfont : 'Expletus+Sans:400,700,400italic,700italic' },
			'Georgia'       : { fontfamily : "georgia, Times New Roman, arial, sans-serif",          webfont : '' },
			'Iceberg'       : { fontfamily : "Iceberg",                                              webfont : 'Iceberg' },
			'LucidaSans'    : { fontfamily : "Lucida Sans Unicode, Lucida Sans, Verdana, Helvetica", webfont : '' },
			'Marmelad'      : { fontfamily : "Marmelad",                                             webfont : 'Marmelad' },
			'Metamorphous'  : { fontfamily : "Metamorphous",                                         webfont : 'Metamorphous' },
			'NovaCut'       : { fontfamily : "Nova Cut",                                             webfont : 'Nova+Cut' },
			'RopaSans'      : { fontfamily : "Ropa Sans",                                            webfont : 'Ropa+Sans:400,400italic' },
			'Tahoma'        : { fontfamily : "Tahoma, Verdana, Helvetica",                           webfont : '' },
			'TimesNewRoman' : { fontfamily : "Times New Roman, Times",                               webfont : '' },
			'TrebuchetMS'   : { fontfamily : "Trebuchet MS, Verdana, Arial, Helvetica",              webfont : '' },
			'Verdana'       : { fontfamily : "Verdana, Arial, Helvetica",                            webfont : '' }
		},

		/**
		 * widget properties
		 */
		widgetType      : 'Toolfontfamily',
		templateString:"<tr class=\"Toolfontfamily\">\n  <td class=\"InputLabelling NoWrap\">${label}</td>\n  <td class=\"FontSize\">\n      <select dojoAttachPoint=\"fontSelectNode\"\n              id=\"${fontType}\"\n              name=\"${objectId}:${fontType}\"\n              >\n        <option style=\"font-family:Arial, Verdana, Helvetica\"                                value=\"Arial, Verdana, Helvetica\"                            >Arial</option>\n        <option style=\"font-family:'Courier New', Verdana, Helvetica\"                        value=\"Courier New, Verdana, Helvetica\"                      >Courier New</option>\n        <option style=\"font-family:georgia, 'Times New Roman', arial, sans-serif\"            value=\"georgia, Times New Roman, arial, sans-serif\"          >Georgia</option>\n        <option style=\"font-family:'Lucida Sans Unicode', 'Lucida Sans', Verdana, Helvetica\" value=\"Lucida Sans Unicode, Lucida Sans, Verdana, Helvetica\" >Lucida Sans</option>\n        <option style=\"font-family:Tahoma, Verdana, Helvetica\"                               value=\"Tahoma, Verdana, Helvetica\"                           >Tahoma</option>\n        <option style=\"font-family:'Times New Roman', Times\"                                 value=\"Times New Roman, Times\"                               >Times New Roman</option>\n        <option style=\"font-family:'Trebuchet MS', Verdana, Arial, Helvetica\"                value=\"Trebuchet MS, Verdana, Arial, Helvetica\"              >Trebuchet MS</option>\n        <option style=\"font-family:Verdana, Arial, Helvetica\"                                value=\"Verdana, Arial, Helvetica\"                            >Verdana</option>\n      </select>\n  </td>\n</tr>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates/translation'),
		imagePath       : epages.themeUrl('images'),

		postMixInProperties: function(){
			this._templateDirectory = dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates');
			this.inherited("postMixInProperties", arguments);
		},

		postCreate  : function() {
			this.inherited("postCreate", arguments);
			this.fontSelectNode.value=this.fontFamily;
      if (!/Arial|Courier\sNew|georgia|Lucida\sSans\sUnicode|Tahoma|Times\sNew\sRoman|Trebuchet\sMS|Verdana/i.test(this.fontFamily)) {
        var newElement = document.createElement('option');
        newElement.innerHTML = this.fontFamily;
        this.fontSelectNode.insertBefore(newElement, this.fontSelectNode.firstChild);
        this.fontSelectNode.selectedIndex = 0;
      }
			if(this.clickNode) {
				this._menuWidget= new epages.widget.Menu({
				'class': 'FontfamilyChooser'
			});

				for(var i in this._fonts){
					this._addFontRow(i);
				}
				this._menuWidget.startup();
			}
		},

		_addFontRow: function(/*integer*/i) {
		// summary: add menu entry (link)
			var parentWidget=this;
			var entry= new dijit.MenuItem({
				label: i,
				iconClass: 'MinimizeIcon',
				onClick: function() {
					parentWidget.switchFont(i);
					dijit.popup.close(parentWidget._menuWidget);
				},
				id: 'font'+i
			});

			entry.containerNode.style.fontFamily= this._fonts[i].fontfamily;
			entry.containerNode.style.fontSize= '12px';
			this._menuWidget.addChild(entry);

			if(this.fontFamily == this._fonts[i].fontfamily) {
				this._lastSelected=entry.domNode;
				dojo.addClass(this._lastSelected, "Selected" );
			}

		},

		showFontMenu:	function()	{
		// summary: show menu
		// summary: open the popup to the side of the current menu item
			dijit.popup.open({
				parent:this.domNode,
				popup:this._menuWidget,
				orient: {'BL':'TL', 'BR':'TR', 'TL':'BL', 'TR':'BR'},
				around: this.domNode
			});
		},

		_onBlur: function () {
			dijit.popup.close(this._menuWidget);
		},

		switchFont: function(/*ObjectIndex*/fontIndex) {
			this.fontSelectNode.value=this._fonts[fontIndex].fontfamily;
			$('ContentWebfont').value = this._fonts[fontIndex].webfont;
			epages.event.fire(this.fontSelectNode,"change");
			if(this._lastSelected) {
				dojo.removeClass(this._lastSelected, "Selected" );
			}
			this._lastSelected=$$('font'+fontIndex).domNode;
			dojo.addClass(this._lastSelected, "Selected" );
		}
	});


}

if(!dojo._hasResource["epages.event.sensitiveborders"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.event.sensitiveborders"] = true;
dojo.provide("epages.event.sensitiveborders");


epages.event.sensitiveBorders = {
	// summary: Enable the user to scroll the page by mouse position.
	// description: With this enabled the user can scroll the page by moving the cursor to the particular border in which direction he wants the page to move.
	// example: epages.event.sensitiveBorders.enable(window);
	//          epages.event.sensitiveBorders.disable();

	_SENSITIVE_WIDTH: 80, // px
	_SCROLL_DELAY: 150, // ms
	_SCROLL_SPEED: 2, // ms
	_SCROLL_AMOUNT: 6, // px

	_topInterval: null,
	_leftInterval: null,
	_rightInterval: null,
	_bottomInterval: null,
	_scrollTimeout: null,

	_mouseMoveHandle: null,
	_localDojo: null,
	_localWindow: null,

	maxScrollRight: 0,
	maxScrollBottom: 0,

	_resetTimers: function() {
		clearInterval(this._topInterval);
		clearInterval(this._leftInterval);
		clearInterval(this._rightInterval);
		clearInterval(this._bottomInterval);
		clearTimeout(this._scrollTimeout);
		this._topInterval = null;
		this._leftInterval = null;
		this._rightInterval = null;
		this._bottomInterval = null;
		this._scrollTimeout = null;
	},

	_checkSensitiveArea: function(evt) {
		var moveLeft = evt.clientX < this._SENSITIVE_WIDTH;
		var moveRight = evt.clientX > this.maxScrollRight - this._SENSITIVE_WIDTH;
		var moveTop = evt.clientY < this._SENSITIVE_WIDTH;
		var moveBottom = evt.clientY > this.maxScrollBottom - this._SENSITIVE_WIDTH;
		if(!(moveLeft || moveRight || moveTop || moveBottom)) {
			this._resetTimers();
		}else if(!this._scrollTimeout) {
			this._scrollTimeout = setTimeout(dojo.hitch(this, function() {
				this._resetTimers();
				if(moveLeft) {
					this._leftInterval = setInterval(dojo.hitch(this, function() {
						this._localWindow.scrollBy("-" + this._SCROLL_AMOUNT, 0);
					}), this._SCROLL_SPEED);
				}
				if(moveRight) {
					this._rightInterval = setInterval(dojo.hitch(this, function() {
						// prevent the browser from scrolling into nirvana (especially if user is currently using d&d)
						if((this._localDojo.body().parentNode.scrollLeft || this._localDojo.body().scrollLeft) <= (this._localDojo.body().offsetWidth - this.maxScrollRight)) {
							this._localWindow.scrollBy(this._SCROLL_AMOUNT, 0);
						}
					}), this._SCROLL_SPEED);
				}
				if(moveTop) {
					this._topInterval = setInterval(dojo.hitch(this, function() {
						this._localWindow.scrollBy(0, "-" + this._SCROLL_AMOUNT);
					}), this._SCROLL_SPEED);
				}
				if(moveBottom) {
					this._bottomInterval = setInterval(dojo.hitch(this, function() {
						// prevent the browser from scrolling into nirvana (especially if user is currently using d&d)
						if((this._localDojo.body().parentNode.scrollTop || this._localDojo.body().scrollTop) <= (this._localDojo.body().offsetHeight - this.maxScrollBottom)) {
							this._localWindow.scrollBy(0, this._SCROLL_AMOUNT);
						}
					}), this._SCROLL_SPEED);
				}
			}), this._SCROLL_DELAY);
		}
	},

	enable: function(windowRef /* window reference (optional) */) {
		this._localWindow = windowRef || window;
		this._localDojo = this._localWindow.dojo;
		var bodyNode = this._localDojo.body();

		this.maxScrollRight = (epages.Browser.engine == "WebKit" ? bodyNode.clientWidth : bodyNode.parentNode.clientWidth);
		this.maxScrollBottom = (epages.Browser.engine == "WebKit" ? bodyNode.clientHeight : bodyNode.parentNode.clientHeight);

		if(!bodyNode.parentNode.className.match("SensitiveBorders")) {
			this._localDojo.addClass(bodyNode.parentNode, "SensitiveBorders");
			this._mouseMoveHandle = this._localDojo.connect(bodyNode, "mousemove", this, "_checkSensitiveArea");
		}
	},

	disable: function() {
		this._resetTimers();
		this._localDojo.disconnect(this._mouseMoveHandle);
		this._localDojo.removeClass(this._localDojo.body().parentNode, "SensitiveBorders");
	}
}

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.dragdrop"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.dragdrop"] = true;
dojo.provide("epages.cartridges.de_epages.presentation.dragdrop");




$DND = /*epages.cartridges.de_epages.presentation.Dragdrop*/function (/* string */ handlerId,/* array? */ elements, /* object?*/ screenContainer) {
	return new epages.cartridges.de_epages.presentation.Dragdrop(handlerId,elements, screenContainer);
};

epages.cartridges.de_epages.presentation.Dragdrop = function(/* string */ handlerId,/* array? */ elements, /* object?*/ screenContainer) {
	this.elements = [];

	this.screenContainer=(screenContainer) ? screenContainer : (epages.Browser.engine == "WebKit" ? document.documentElement : dojo.body());

	if(elements !== undefined){
		for(var el in elements){
			this.addElement(elements[el]);
		}
	}

	this.handlerId=handlerId;
	this.isDragging = false;
	this._appendBodyEvents();
};

epages.cartridges.de_epages.presentation.Dragdrop.prototype = {
	dragObject : undefined,
	isDragging : undefined,
	handlerId  : undefined,
	elements   : undefined,
	screenContainer : undefined,

	addElement: function(el) {
		if(el.clickNode) {  // is object
			var clickEl = el.clickNode;
			var moveEl  = el.clickNode;
			if(el.moveNode){
				moveEl = el.moveNode;
			}else{
				el.moveNode = moveEl;
			}
			this.elements.push(el);
		} else {            // is DOM node
			var clickEl = el;
			var moveEl  = el;
			// transform to object
			this.elements.push({
				clickNode: el,
				moveNode: el
			});
		}

		//get drag drop element
		dojo.connect(clickEl,'onmousedown', this, '_startDragging');
		dojo.connect(moveEl, 'onmousedown', this, '_setMoveTarget');

		clickEl.style.cursor="move";
		moveEl.style.position="relative";
	},

	_appendBodyEvents: function() {
		dojo.connect(document, 'onmousemove', this, '_onmousemove');
		dojo.connect(document, 'onmouseup', this, '_onmouseup');
	},

	_getCurrentElement: function(node) {
		for(el in this.elements) {
			if(node===this.elements[el].moveNode) {
				return this.elements[el];
			}
		}
		return false;
	},

	_getScreenContainerOffset: function() {
		if(this.screenContainer.nodeName!="BODY"){
			var pos=$E(this.screenContainer).getAbsolutePosition();
		} else {
			var pos = {};
			pos.y=0;
			pos.x=0;
		}
		return pos;
	},

	_getScrollOffset: function() {
		var pos = {};

		var relativeScrollParent = (epages.Browser.engine == "MSIE" && this.screenContainer.tagName == "BODY") ? this.screenContainer.parentNode : this.screenContainer;
		pos.y = relativeScrollParent.scrollTop;
		pos.x = relativeScrollParent.scrollLeft;

		return pos;
	},

	_setNodeSize: function(node) {
		var nodeWidth=node.clientWidth;
		if(nodeWidth == 0){
			nodeWidth=node.offsetWidth;
		}
		node.style.width = nodeWidth+"px";
		if (node.outerHeight) {
			node.style.height = node.outerHeight+"px";
		} else {
			node.style.height = node.clientHeight+"px";
		}
	},

	_clearNodeSize: function(node) {
		node.style.width= "";
		node.style.height= "";
	},

	_getPositionOnScreenContainer: function(evt) {
		var scrollOffset=this._getScrollOffset();
		if(epages.Browser.engine=="MSIE") {
			var x= evt.clientX-this.dragObject.offsetX+scrollOffset.x;
			var y= evt.clientY-this.dragObject.offsetY+scrollOffset.y;
		} else {
			var x= evt.pageX-this.dragObject.offsetX+scrollOffset.x;
			var y= evt.pageY-this.dragObject.offsetY+scrollOffset.y;
		}
		return { x:x, y:y };
	},

	_onmousemove: function(evt) {
		if(this.dragObject && this.isDragging) {
			dojo.addClass(this.dragObject.domElement,"IsDragging");

			dojo.addClass(document.getElementsByTagName("body")[0],"IsDropArea");

			// get coordinates
			var screenOffset = this._getScreenContainerOffset();
			var pos=this._getPositionOnScreenContainer(evt);
			// set position
			this._setPosition(pos.x-screenOffset.x,pos.y-screenOffset.y);
			this.dragObject.domElement.style.position="absolute";
			this.dragObject.domElement.style.zIndex="100000";

			var currentElement=this._getCurrentElement(this.dragObject.domElement);
			// publish event
			dojo.publish('dragdrop'+this.handlerId+'/move', [{
				// element relative to screenContainer
				x: pos.x,
				y: pos.y,
				// mouse relative to screenContainer
				mouseX: pos.x+this.dragObject.offsetX-((epages.Browser.engine != "WebKit")?window.pageXOffset:0),
				mouseY: pos.y+this.dragObject.offsetY-((epages.Browser.engine != "WebKit")?window.pageYOffset:0),
				// dragged node
				node: this.dragObject.domElement,
				element: currentElement
			}]);

			// EPG-30563: Quick and dirty fix to get rid of the element being dragged on the ui.
			// see `_onmouseup`.
			if(this.dragObject.domElement.parentNode.nodeName.toLowerCase() == "td") {
				this.dragObject.domElement.parentNode.style.width = '0';
				this.dragObject.domElement.parentNode.style.height = '0';
			}

		}
	},

	_onmouseup: function(evt) {
		if(this.isDragging) {

			epages.event.sensitiveBorders.disable();

			// get coordinates
			var screenOffset = this._getScreenContainerOffset();
			var pos=this._getPositionOnScreenContainer(evt);

			var currentElement=this._getCurrentElement(this.dragObject.domElement);

			// publish event
			dojo.publish('dragdrop'+this.handlerId+'/drop', [{
				// element relative to screenContainer
				x: pos.x,
				y: pos.y,
				// mouse relative to screenContainer
				mouseX: pos.x+this.dragObject.offsetX,
				mouseY: pos.y+this.dragObject.offsetY,
				// dragged node
				node: this.dragObject.domElement,
				element: currentElement
			}]);


			// EPG-30563: Quick and dirty fix to get rid of the element being dragged on the ui.
			// see `_onmousemove`.
			if(this.dragObject.domElement.parentNode.nodeName.toLowerCase() == "td") {
				this.dragObject.domElement.parentNode.style.width = 'auto';
				this.dragObject.domElement.parentNode.style.height = 'auto';
			}

			// resize the parent cell (if webkit-engine)
			if((epages.Browser.engine == "WebKit") && (this.dragObject.domElement.parentNode.nodeName.toLowerCase() == "td")){
				this.dragObject.domElement.parentNode.style.width = this.dragObject.domElement.style.width;
			}

			// execute elements onDrop function
			if(currentElement && currentElement.onDrop){
				currentElement.onDrop();
			}
			// reset
			this._clearNodeSize(this.dragObject.domElement);

			dojo.removeClass(this.dragObject.domElement,"IsDragging");

			dojo.removeClass(document.getElementsByTagName("body")[0],"IsDropArea");

			this.isDragging = false;
			this.dragObject.domElement.style.position="relative";
			this.dragObject.domElement.style.left="";
			this.dragObject.domElement.style.top="";
			this.dragObject.domElement.style.zIndex="";
			this.dragObject.domElement.style.zoom="1";
			this.dragObject = undefined;

			document.body.onselectstart = function(){};
			document.body.style.MozUserSelect = "";
		}
	},

	_startDragging: function(evt) {
		document.body.onselectstart = function() {
			return false;
		};
		document.body.style.MozUserSelect = "none";
		epages.event.sensitiveBorders.enable();
		this.isDragging = true;
		dojo.publish('dragdrop'+this.handlerId+'/beforeStart',[{
			event: evt
		}]);
	},

	_setMoveTarget: function(evt) {
	// _startDragging() should always be executed before _setMoveTarget()
		var moveNode = evt.target;
		var dragNode = evt.currentTarget;

		var distance = {};
		if(dragNode !== moveNode) {
			distance = $E(moveNode).getPositionToParent(dragNode);
		} else {
			distance.x = 0;
			distance.y = 0;
		}

		this.dragObject = {
			domElement: dragNode,
			offsetX   : (epages.Browser.engine.match("MSIE")) ? evt.offsetX: evt.layerX + distance.x,
			offsetY   : (epages.Browser.engine.match("MSIE")) ? evt.offsetY: evt.layerY  + distance.y
		};
		// debug offset coordinates & domElement
		// console.debug(this.dragObject.offsetX + " ; "+ this.dragObject.offsetY + " / "+ this.dragObject.domElement.style.position);

		if(this.isDragging) {
			var currentElement=this._getCurrentElement(this.dragObject.domElement);
			if(currentElement.forceSize){
				this._setNodeSize(this.dragObject.domElement);
			}

			var pos=this._getPositionOnScreenContainer(evt);

			dojo.publish('dragdrop'+this.handlerId+'/start', [{
				// element relative to screenContainer
				x: pos.x,
				y: pos.y,
				// mouse relative to screenContainer
				mouseX: pos.x+this.dragObject.offsetX,
				mouseY: pos.y+this.dragObject.offsetY,
				// dragged node
				node: this.dragObject.domElement,
				element: this.dragObject
			}]);
		}
	},

	_setPosition: function(x,y) {
		var posCorrection = {x: 0, y: 0};

		var parentDomNode = this.dragObject.domElement.parentNode;

		// get the first relative positioned element or the body
		while(parentDomNode.nodeName.toLowerCase()!="body" && (dojo.style(parentDomNode, 'position')!="relative")){  // alternative: && !dojo.hasClass(parentDomNode, 'PropertyContainer')
			parentDomNode = parentDomNode.parentNode;
		}

		posCorrection = $E(parentDomNode).getAbsolutePosition();

		this.dragObject.domElement.style.left = (x-posCorrection.x-((epages.Browser.engine == "WebKit")? 0 : window.pageXOffset))+'px';
		this.dragObject.domElement.style.top = (y-posCorrection.y-((epages.Browser.engine == "WebKit")? 0 : window.pageYOffset))+'px';
	}

};

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Tooliconset"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Tooliconset"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.design.widget.Tooliconset");






dojo.declare(
	"epages.cartridges.de_epages.design.widget.Tooliconset",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		url             : '?',
		objectId        : epages.vars.ObjectID,
		languageId      : epages.vars.Locale.languageId,
		iconset         : '',
		undoWidget      : undefined,
		undoWidgetId    : 'undoWidget',
		objectId        : '',
		imagePath       : epages.themeUrl('images'),

		/**
		 * private properties
		 */
		_dialogWidget   : undefined,
		_htmlUndo       : undefined,
		_oldIconset     : undefined,
		//these are the css-classes that have an icon from the iconset as background-image
		_cssClassesWithIcon : {
			'LinkPrintView'   : 'ico_s_printer.png',
			'LinkBasket'      : 'ico_s_basket.png',
			'Action'          : 'img_actionlink.png',
			'TreeNode'        : {
				'NoSubCategories'       : 'img_tree_empty.png',
				'HasSubCategories'      : 'img_tree_plus.png',
				'HasSubCategoriesMinus' : 'img_tree_minus.png'
			}
		},
		/**
		 * constants
		 */
		 //css class for elements that have an icon from the iconset inside
		CSSCLASS: 'Icon',

		/**
		 * widget properties
		 */
		templateType       : 'default',
		defaultTemplateType: 'default',
		templateString:"<div class=\"WithXLIcon\" dojoAttachPoint=\"iconNode\">\n  <div class=\"Pane AlignCenter CommandPane\">\n  <i class=\"Sprite ico_xl_iconset\" title=\"{ChangeIconset}\"></i>\n  <br/>{ChangeIconset}\n  <input dojoAttachPoint=\"hiddenInput\" type=\"hidden\" name=\"${objectId}:LayoutIconSet\" id=\"inputIconset\" value=\"${iconset}\" />\n</div>\n</div>\n",
		translationName    : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'),
		_templateMapping: {
			'default' : {templateString:"<div class=\"WithXLIcon\" dojoAttachPoint=\"iconNode\">\n  <div class=\"Pane AlignCenter CommandPane\">\n  <i class=\"Sprite ico_xl_iconset\" title=\"{ChangeIconset}\"></i>\n  <br/>{ChangeIconset}\n  <input dojoAttachPoint=\"hiddenInput\" type=\"hidden\" name=\"${objectId}:LayoutIconSet\" id=\"inputIconset\" value=\"${iconset}\" />\n</div>\n</div>\n"},
			'xlicon'  : {templateString:"<div class=\"XLIconWidget WithXLIcon\" dojoAttachPoint=\"iconNode\">\n  <div class=\"Pane AlignCenter CommandPane\">\n  <i class=\"Sprite ico_xl_iconset\" title=\"{ChangeIconset}\" ></i>\n  <br />{Iconset}\n  <input dojoAttachPoint=\"hiddenInput\" type=\"hidden\" name=\"${objectId}:LayoutIconSet\" id=\"inputIconset\" value=\"${iconset}\" />\n</div>\n</div>\n"}
		},

		postMixInProperties: function() {
			this._templateDirectory = dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates');
			this.inherited("postMixInProperties", arguments);
			if(epages.vars.Iconset){
				this.iconset = epages.vars.Iconset;
			}else{
				console.warn("epages.vars.Iconset not defined in "+this.declaredClass);
			}
		},

		postCreate  : function() {
			this.inherited("postCreate", arguments);
			this.connect(this.iconNode,'onclick', '_onClickIconNode');
			this.undoWidget = $$(this.undoWidgetId);
			if (this.undoWidget === undefined) {
				console.warn(this.id+' : undo widget not found in '+this.declaredClass);
			} else {
				this._htmlUndo = this.undoWidget.getUndoObject();
				this._htmlUndo.setDefaultValue(this.hiddenInput);
				this.connect(this.hiddenInput,'onchange', '_onChangeHiddenInput');
			}
		} ,

		_createDialog:function(){
			 var json = new epages.io.Json();
			var params = {
				'ViewAction': 'JSONSnippet',
					'TemplateAction': 'IconsetSnippet',
					'TemplateLanguageID': this.languageId,
					'ObjectID': this.objectId,
					'TemplateLanguageID': this.languageId
			};
			var output = json.loadSync(this.url, params);
			var me = this;
			var buttons = [{
				label: this.translation.get("Apply"),
				cssClass: 'Active',
				onclick: function(evt) {
					// get Undo-Widget
					var u = $$(me.undoWidgetId);

					if(u){
						// if already changes was made -> open ConfirmSaveDialog
						if(u.existsChanges()){
							if(!me._createConfirmSaveWidget){
								 me._createConfirmSaveDialog();
							}

							me._dialogWidgetTarget = evt.currentTarget;
							me._createConfirmSaveWidget.show();
						}else{
							this._modalDialogWidget.hide();
							me._onApplyClick();
						}
					}else{
						this._modalDialogWidget.hide();
						me._onApplyClick();
					}

				}
			},
			{
				label: this.translation.get("Cancel"),
				onclick: function() {
					this._modalDialogWidget.hide();
				}
			}];
			this._dialogWidget = new epages.widget.Modaldialog({
				id: "Tooliconset_DialogWidget",
				options:{
					title : this.translation.get("ChangeIconset"),
					width : 620,
					height: 200,
					content: output.data.snippet
				},
				buttons : buttons
			});
			document.body.appendChild(this._dialogWidget.domNode);

			var nodeList = dojo.query('img',this._dialogWidget.domNode);
			var img = new Image();
				img.onload = dojo.hitch(this,function(){ this._dialogWidget.layout(); });
				img.src = dojo.attr( nodeList[nodeList.length-1] , 'src');
			//we need the timeout to avoid a wrong position
			window.setTimeout(function(){
				me._dialogWidget.layout();
			},1);
		},

		_createConfirmSaveDialog: function(){
			var messageWidget = new epages.widget.Message({
				headline:this.translation.get("SaveQuestion"),
				message: this.translation.get("ChangeNavbarsDescription"),
				sizeClass:"Large",
				typeClass:"Warning"
			});

			var me =this;
			var buttons = [{
				label: this.translation.get("Save"),
				cssClass: 'Active',
				onclick: function() {
					me._onApplyClick();
					me._modalDialogWidget.hide();
					me._createConfirmSaveWidget.hide();
				}
			},
			{
				label: this.translation.get("Cancel"),
				onclick: function() {
					me._undoChange(me._dialogWidgetTarget);
				}
			}];
			this._createConfirmSaveWidget = new epages.widget.Modaldialog({
				id: "Designtoolcontroller_DialogWidget",
				options:{
					title : this.translation.get("ChangeOnNavbars"),
					width : 400,
					height: 120,
					content: messageWidget
				},
				buttons : buttons

			});

			document.body.appendChild(this._createConfirmSaveWidget.domNode);
		},

		_onClickIconNode: function(){
			if(!this._dialogWidget){
				this._createDialog();
			}
			this._dialogWidget.show();
		},

		_onApplyClick:function(){
			var newIconset = '';
			var radioButtons = document.getElementsByName('LayoutIconSet');

			for( var i=0,iLength=radioButtons.length ; i<iLength ; i++ ){
				if(radioButtons[i].checked){
					newIconset = radioButtons[i].value;
				}
			}

			if(newIconset != '' && newIconset != this.iconset){
				if(this.undoWidget){
					this.hiddenInput.value = newIconset;
					this._htmlUndo.addInput(this.hiddenInput);
				}
				this._oldIconset = this.iconset;
				this.iconset = newIconset;
				this._changeIconsInPage(this._oldIconset,this.iconset);
				dojo.publish("Tooliconsset/IconsetChanged",[]);
			}

			// trigger click on save button
			epages.event.fire(jq('#undoWidget').find("button.SaveButton")[0], 'click');
		},

		_changeIconsInPage:function(oldIconset,newIconset){
			var iframeDoc = $('EmbeddedStorefront').contentDocument || $('EmbeddedStorefront').contentWindow.document;
			var iframeWin = $('EmbeddedStorefront').contentWindow;
			for(var el in this._cssClassesWithIcon){
				var cssClass = el;
				var elementsArray = iframeWin.epages.html.getElementsByClassName(cssClass,iframeDoc);
				for( var i=0,iLength=elementsArray.length ; i<iLength ; i++ ){
					if(typeof this._cssClassesWithIcon[cssClass] == 'string'){
						var icon = this._cssClassesWithIcon[cssClass];
						if (dojo.style(elementsArray[i],'background-image') !== 'none') {
							elementsArray[i].style.cssText = 'background-image: url('+epages.vars.StoreRoot+'/'+newIconset+'/'+icon+') !important';
						}
					}
					else if(typeof this._cssClassesWithIcon[cssClass] =='object'){
						for(var elm in this._cssClassesWithIcon[cssClass]){
							var cssSubClass = elm;
							var subIcon = this._cssClassesWithIcon[cssClass][elm];
							if(dojo.hasClass(elementsArray[i],cssSubClass)){
								elementsArray[i].style.cssText = 'background: url('+epages.vars.StoreRoot+'/'+newIconset+'/'+subIcon+')0px 3px no-repeat !important';
							}
						}
					}
				}
			}
			var elementsArray = iframeWin.epages.html.getElementsByClassName(this.CSSCLASS, iframeDoc);
			for( var i=0,iLength=elementsArray.length ; i<iLength ; i++ ){
				if(elementsArray[i].filters) {
					elementsArray[i].filters(0).src = elementsArray[i].filters(0).src.replace(oldIconset, newIconset);
				}else{
					elementsArray[i].style.cssText = "background-image: " + $('EmbeddedStorefront').contentWindow.dojo.getComputedStyle(elementsArray[i]).backgroundImage.replace(oldIconset, newIconset) + " !important";
				}
			}
		},

		_onChangeHiddenInput:function(evt){
			var iconset = evt.currentTarget.value;
			this._oldIconset = this.iconset;
			this.iconset = iconset;
			this._changeIconsInPage(this._oldIconset,this.iconset);
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Switchcontentpreview"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Switchcontentpreview"] = true;
/*
	Copyright (c) 2006-2008, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.design.widget.Switchcontentpreview");






dojo.declare(
	"epages.cartridges.de_epages.design.widget.Switchcontentpreview",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */

		/**
		 * private properties
		 */
		_previews     : null,
		_menuWidget   : null,
		_lastPreview : null,

		/**
		 * widget properties
		 */
		templateString:"<div class=\"Switchcontentpreview EnableHover\">\n  {Preview} <br />\n  <div class=\"PreviewSelector\"\n       dojoAttachPoint=\"previewSelectorNode\"\n       dojoAttachEvent=\"onclick:showPreviewMenu\">\n    <div class=\"PreviewLabel\" dojoAttachPoint=\"previewLabelNode\"></div>\n    <div class=\"DropDownArrow\"></div>\n  </div>\n  <div dojoAttachPoint=\"menuContainerNode\"></div>\n</div>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'),

		postCreate  : function() {
			this.inherited("postCreate", arguments);
			this._menuWidget= new epages.widget.Menu();
			this._previews = $H({});
		},

		switchPreview: function(id) {
			var newPreview = this._previews.get(id);
			var lastPreviewNode = (this._lastPreview) ? this._lastPreview.previewNode : undefined;
			var lastToolsNode = (this._lastPreview) ? $(this._lastPreview.toolsNodeId) : undefined;
			var toolsNode = $(newPreview.toolsNodeId);

			if(this._lastPreview == null || lastPreviewNode != newPreview.previewNode) {
				// preview node
				if(lastPreviewNode){
					lastPreviewNode.style.display = "none";
				}
				var formatted_label = epages.format.slice(newPreview.label, 15);

				this.previewLabelNode.innerHTML=formatted_label;
				if(newPreview.label !== formatted_label){
					this.previewLabelNode.title = newPreview.label;
				}else{
					this.previewLabelNode.title = "";
				}
				this.previewSelectorNode.style.backgroundImage = 'url('+newPreview.imageUrl+')';
				newPreview.previewNode.style.display="";
				// tools node
				if(lastToolsNode){
					lastToolsNode.style.display="none";
				}
				if(toolsNode){
					toolsNode.style.display="";
				}

				this._lastPreview = newPreview;
				dojo.publish("switchcontentpreview/switchPreview", [id]);
			}
		},

		addPreview: function(id, opt) {
			var parentWidget=this;
			var entry= new dijit.MenuItem({
				label: opt.label,
				iconClass: '',
				onClick: function() {
					parentWidget.switchPreview(id);
					dijit.popup.close(parentWidget._menuWidget);
				}
			});
			entry.iconNode.style.background = 'url('+document.location.protocol + '//' + document.location.hostname + '/' + opt.imageUrl+') no-repeat top left';
			this._menuWidget.addChild(entry);

			this._previews.set(id, opt);
		},

		showPreviewMenu:	function()	{
		// summary: show menu
		// open the popup to the side of the current menu item
			dijit.popup.open({
				parent:this.domNode,
				orient: {'BL':'TL', 'BR':'TR', 'TL':'BL', 'TR':'BR'},
				popup:this._menuWidget,
				around: this.domNode
			});
		},

		_onBlur: function () {
			dijit.popup.close(this._menuWidget);
		}
	}
);

}

if(!dojo._hasResource['epages.cartridges.de_epages.presentation.widget.EditorPlaceholder']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.presentation.widget.EditorPlaceholder'] = true;
dojo.provide('epages.cartridges.de_epages.presentation.widget.EditorPlaceholder');




dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.EditorPlaceholder",
	[dijit._Widget, dijit._Templated],
	{
		ep_info: '',
		_info: undefined,
		base64: new epages.string.Base64,
		src : epages.vars.StoreRoot + '/BO/icons/general_img_transparentpixel.gif',

		templateString: '<img width="" height="" ep_group="" ep_info="${ep_info}" title="" alt="" style="" class="epItemContent" src="${src}" />',

		decodeInfo: function(string) {
			if(string && string != ''){
				var info = eval("(" + this.base64.decode(string) + ")");
				if (info.formData !== undefined){ 
					info.formData = $H(info.formData);
				}
				return info;
			}
	},

		postMixInProperties:function(){
			this.inherited("postMixInProperties", arguments);
			this._info = this.decodeInfo(this.ep_info);
		},
		postCreate: function(){
			this.inherited("postCreate", arguments);
			if(this._info && this._info != ''){
				if(this._info.width == "100%") {
					this.domNode.setAttribute('width',this.domNode.parentNode.offsetWidth);
				}else {
					this.domNode.setAttribute('width',this._info.width);
				}
				if(this._info.height == "100%") {
					this.domNode.setAttribute('height',this.domNode.parentNode.offsetHeight);
				}else {
					this.domNode.setAttribute('height',this._info.height);
				}
				this.domNode.setAttribute('alt',this._info.title);
				this.domNode.setAttribute('title',this._info.title);
				this.domNode.style.backgroundImage = 'url('+epages.locationWebRoot(this._info.preview)+')';
				this.domNode.setAttribute('ep_group',this._info.group);
				var width = (this._info.width.toString().match(/%/)) ? this._info.width : this._info.width+'px';
				var height = (this._info.height.toString().match(/%/)) ? this._info.height : this._info.height+'px';
				var epStyle="background:url('"+this._info.preview+"'); width:"+width+"; height:"+height+";";
				this.domNode.setAttribute('ep_style',epStyle);
			}
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.droplist"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.droplist"] = true;
dojo.provide("epages.cartridges.de_epages.presentation.droplist");



epages.cartridges.de_epages.presentation.Droplist = function(opt) {
// summary: droplist constructor / initialize droplist
	this._setOptions(opt);

	var doc = document;

	// set up ghost
	this.ghostNode=doc.createElement((this.options.ghostNodeName !== undefined) ? this.options.ghostNodeName : "div");
	this.ghostNode.className=(this.options.ghostCssClass !== undefined) ? this.options.ghostCssClass : "Ghost";
	this.isGhostInList = false;

	// set up empty ghost
	this.emptyNode=doc.createElement((this.options.ghostNodeName !== undefined) ? this.options.ghostNodeName : "div");
	this.emptyNode.className=(this.options.ghostCssClass !== undefined) ? this.options.ghostCssClass+" Empty" : "Ghost Empty";
	this.emptyNode.appendChild(doc.createTextNode(this.options.listEmptyString));

	// set up new ghost
	this.newNode=doc.createElement((this.options.ghostNodeName !== undefined) ? this.options.ghostNodeName : "div");
	this.newNode.className=(this.options.ghostCssClass !== undefined) ? this.options.ghostCssClass+" New" : "Ghost New";
	this.newNode.innerHTML='<div class="ClickContainer"><div class="Container">'+this.options.addNewItemString+'</div></div>';
	if(this.options.newItemOnClick !== undefined) {
		this.newNode.firstChild.onclick = dojo.hitch(this, function() {
			dojo.publish("interactionRestrictor/suspend", ["newGhostRestrictor", this.newNode]);
			setTimeout(dojo.hitch(this, function() {
				this.options.newItemOnClick();
				setTimeout(function(){
					dojo.publish("interactionRestrictor/permit", ["newGhostRestrictor"])}, 400);
			}), 10);
		});
	}

	// dnd handler
	this.dndHandlerId=this.options.dndHandlerId;
	// listContainer
	this.listContainer = this.options.listContainer;
	this.sensitiveArea = (this.options.sensitiveArea) ? this.options.sensitiveArea : this.options.listContainer;

	this.listId=this.listContainer.id;

	// clean up list
	this._cleanUpList();

	// show empty Node
	this._insertEmptyGhost();

	// show new Node
	if(this.options.addNewItemString != ""){
		this._insertNewGhost();
	}

	// mark existing wrappers
	if(this.options.wrapperNodeName){
		this._markWrapper();
	}

	this._appendListeners();
};

epages.cartridges.de_epages.presentation.Droplist.prototype = {
	listContainer  : undefined,			// domnode   contains all the draggable nodes
	sensitiveArea  : undefined,			// domnode   draggables can be dropped inside the coordinates of this node
	listId         : undefined,			// string    id of listContainer node
	options        : undefined,			// object    options for constructor (see below)
	ghostNode      : undefined,			// domnode   node for dropghost
	isGhostInList  : undefined,			// boolean   indicates if the ghost / current drop target exsits in the list
	_isGhostSizeSet: undefined,			// boolean   inidcates if the ghost needs to be reszied / renderd again
	emptyNode      : undefined,			// domnode   will be inserted into empty list (show the user some text that he can insert something here)
	newNode        : undefined,			// domnode   add new item button

	_setOptions: function(options) {
		// summary: mix in options
		this.options = {
			// defaults
			dndHandlerId    : undefined,	// string    id of the main dnd handler (Dragdrop instance) / subscribe listeners to that id
			listContainer   : undefined,	// domnode   contains all the draggable nodes
			orientation     : undefined,  // string    orientation of list ("UpDown" or "LeftRight")
			wrapperNodeName : undefined,  // domnode   wrap dnd node nodename eg. div, td
			listEmptyString : '',					// string    this string will be inserted as text into empty node
			addNewItemString: '',					// string    this string will be used as label text for the emptyNode
			newItemOnClick  : undefined		// function  will be applied as click function on the newNode
		};
		dojo.mixin(this.options, options);
	},

	_appendListeners: function() {
	// summary: subscribe listeners to Dragdrop instance
		dojo.subscribe('dragdrop'+this.dndHandlerId+'/move',  this, "_move");
		dojo.subscribe('dragdrop'+this.dndHandlerId+'/drop',  this, "_drop");
		dojo.subscribe('dragdrop'+this.dndHandlerId+'/start', this, "_startDragging");

		dojo.subscribe('droplist'+this.listId+'/change', this, "_listChange");
	},

	_isInsideSensitiveArea: function(/* object */ dndPos) {
	// summary: returns true if mouse coordinates are inside the sensitive area
		var containerElement = this.sensitiveArea;
		var listContPos = $E(containerElement).getAbsolutePosition();
		if(dndPos.mouseY >= listContPos.y && dndPos.mouseY <= listContPos.y + containerElement.clientHeight &&
			 dndPos.mouseX >= listContPos.x && dndPos.mouseX <= listContPos.x + containerElement.clientWidth) {
			return true;
		}else {
			return false;
		}
	},

	_canInsertBefore: function(/* domnode */ node, /* object */ dndPos) {
	// summary: returns true if an element can be inserted before
		var curPos = $E(node).getAbsolutePosition();

		// --> Hopefully this fixes EPG-30002.
		if (node === dndPos.node.parentNode) {
			return false;
		}
		// and does not cause too many other bugs <--


		// --> Hopefully this fixes EPG-29068 once
		var toleranz = 5;
		// and for all (styles), and does not cause too many other bugs <--

		if(this.options.orientation == "UpDown") {
			return (curPos.y > dndPos.mouseY - toleranz);
		}else {
			return (curPos.x > dndPos.mouseX - toleranz);
		}
	},

	_startDragging: function(opt) {
	// summary: event function dragrop/start - initaliaze dragging
		this._isGhostSizeSet = false;
		if(this._isInsideSensitiveArea(opt)) {
			opt.node.ep_droplistid = this.listId;
		}
	},

	_move: function(opt) {
	// summary: event function dragrop/move - show ghost
		if(this._isInsideSensitiveArea(opt)) {
			// position in list
			var node = this.listContainer.firstChild;
			while(node != null) {
				if(node.nodeType != 3 && opt.node !== node.firstChild && this._canInsertBefore(node,opt)) {
					break;
				}
				if(node.className == "Ghost New") {
					break;
				}
				node = node.nextSibling;
			}

			// set ghost
			if(!this._isGhostSizeSet) {
				this._setGhostSize(opt.node);
			}

			if(node != null) {
				this._insertGhostBefore(node);
			}else {
				this._insertGhostEol();
			}
		}else {
			this._removeGhost();
		}
	},

	_drop: function(opt) {
	// summary: event function dragrop/drop - finish dragging / publish drop in list event / insert node
		if(this.isGhostInList) {
			// find insertBefore node
			if(opt.element.onDropInList) {
				var insertBefore = null;
				if(this.options.wrapperNodeName) {
					if(this.ghostNode.nextSibling && this.ghostNode.nextSibling.firstChild && this.ghostNode.nextSibling.className != "Ghost New") {
						var insertBefore = this.ghostNode.nextSibling.firstChild;
						while(insertBefore != null && insertBefore.nodeType != 1) {
							insertBefore=insertBefore.nextSibling;
						}
						if(insertBefore.nodeType != 1)	{
							insertBefore = null;
							console.warn("Droplist._drop: no valid successor node found");
						}
					}
				} else {
					insertBefore = this.ghostNode.nextSibling;
				}

				// external handler
				opt.element.onDropInList({
					listObject: this,            // list object
					insertBefore: insertBefore,  // dom object or null
					oldWrapper: (opt.node.parentNode.ep_isWrapper) ? opt.node.parentNode : undefined,
					newWrapperNodeName: (this.options.wrapperNodeName) ? this.options.wrapperNodeName : undefined
				});
			} else {
				// standard handler
				this._insertNode(opt);
			}

			if(opt.node.ep_droplistid){
				dojo.publish('droplist'+opt.node.ep_droplistid+'/change', []);
			}

			//set reference to new list
			opt.node.ep_droplistid=this.listId;

			// remove ghost
			this._removeGhost();
			this._isGhostSizeSet=false;

			// remove empty Node
			this._removeEmptyGhost();
		}
		else {
			if ((this.newNode.parentNode === this.listContainer) && (this.listContainer.childNodes.length === 1)) {
				this.listContainer.insertBefore(this.emptyNode, this.newNode);
			}
		}
	},

	_insertNode: function(/* object */ opt) {
	// summary: insert dragged node
		// save old wrapper
		var oldwrapper = (opt.node.parentNode.ep_isWrapper) ? opt.node.parentNode : undefined;

		// create new wrapper
		if(this.options.wrapperNodeName !== undefined) {
			var wrapperNode=this._createWrapper();
			this.listContainer.insertBefore(wrapperNode, this.ghostNode);
			wrapperNode.appendChild(opt.node);
		} else {
			this.listContainer.insertBefore(opt.node, this.ghostNode);
		}

		// remove old wrapper
		if(oldwrapper){
			this._removeWrapper(oldwrapper);
		}
	},

	_setGhostSize: function(/* domnode */ srcNode) {
	// summary: resize ghost node
		if(this.options.orientation == "UpDown") {
			this.ghostNode.style.width=this.listContainer.offsetWidth+"px";
			if(srcNode.clientHeight!=0 && srcNode.offsetHeight!="0"){
				this.ghostNode.style.height=srcNode.offsetHeight+"px";
			}else{
				this.ghostNode.style.height="27px";	// dirty fix for problem with dragelements whithout height (floated content)
			}
		} else {
			this.ghostNode.style.height=this.listContainer.offsetHeight+"px";
			this.ghostNode.style.width=srcNode.offsetWidth+"px";
		}
		this._isGhostSizeSet=true;
	},

	_insertGhostBefore: function(/* domnode */ node) {
	// summary: insert ghost node before a list element
		this.listContainer.insertBefore(this.ghostNode, node);
		this.isGhostInList = true;
		this._removeEmptyGhost();
	},

	_insertGhostEol: function() {
	// summary: insert ghost node before at the end of list
		this.listContainer.appendChild(this.ghostNode);
		this.isGhostInList = true;
		this._removeEmptyGhost();
	},

	_removeGhost: function() {
	// summary: remove ghostnode
		if(this.isGhostInList) {
			this.listContainer.removeChild(this.ghostNode);
			this.isGhostInList = false;
			this._insertEmptyGhost();
		}
	},

	_insertEmptyGhost: function() {
	// summary: show empty Node
		if(!this._hasElements()) {
			try {
				this.listContainer.appendChild(this.emptyNode);
			} catch(e) {
				// IE - can not add TD in an empty TR
				if (this.emptyNode.nodeName.match(/TD/i)) {
					var table = this.listContainer.parentNode.parentNode;
					table.outerHTML = table.outerHTML.replace(/<\/TR>/i, this.emptyNode.outerHTML + '$1');
				} else {
					new Error('droplist._insertEmptyGhost: could not append node, reason: ' + e.message);
				}
			}
		}
		else {
			if ((this.newNode.parentNode === this.listContainer) && (this.listContainer.childNodes.length === 1)) {
				this.listContainer.insertBefore(this.emptyNode, this.newNode);
			}
		}
	},

	_insertNewGhost: function() {
	// summary: insert button for new items
		// show new Node
			try {
				this.listContainer.appendChild(this.newNode);
			} catch(e) {
				// IE - can not add TD in an empty TR
				if (this.emptyNode.nodeName.match(/TD/i)) {
					var table = this.listContainer.parentNode.parentNode;
					table.outerHTML = table.outerHTML.replace(/<\/TR>/i, this.emptyNode.outerHTML + '$1');
				} else {
					new Error('droplist._insertNewGhost: could not append node, reason: ' + e.message);
				}
			}
	},

	_removeEmptyGhost: function() {
	// summary: remove node with empty ghost (empty droplist hint)
		if(this._hasElements() && this.emptyNode.parentNode == this.listContainer){
			this.listContainer.removeChild(this.emptyNode);
		}
	},

	_createWrapper: function(/* domnode */ targetNode) {
	// summary: create a wrapper node
		var wrapper=document.createElement(this.options.wrapperNodeName);
		wrapper.className = "Wrapper";
		wrapper.ep_isWrapper = true;
		return wrapper;
	},

	_removeWrapper: function(/* domnode */ obj) {
	// summary: remove wrapper node
		obj.parentNode.removeChild(obj);
	},

	_markWrapper: function() {
	// summary: mark child nodes in listContainer as wrapper nodes
		var node = this.listContainer.firstChild;

		while(node != null) {
			if(node.nodeType == 1) {
				node.ep_isWrapper = true;
			}
			node=node.nextSibling;
		}
	},

	_listChange: function() {
	// summary: event function - droplist/change - update the emptyGhost
		if(!this._hasElements()) {
			this._insertEmptyGhost();
		}else {
			this._removeEmptyGhost();
		}
		if ((this.newNode.parentNode === this.listContainer) && (this.listContainer.childNodes.length === 1)) {
			this.listContainer.insertBefore(this.emptyNode, this.newNode);
		}
	},

	_cleanUpList: function() {
	// summary: remove all nodes which are no real nodes
			var node = this.listContainer.firstChild;
			while(node != null) {
				var deleteNode=undefined;
				if(node.nodeType != 1) {
					deleteNode = node;
				}
				node=node.nextSibling;
				if(deleteNode) {
					this.listContainer.removeChild(deleteNode);
				}
			}
	},

	_hasElements: function() {
	// summary: returns if childNodes exist
		return this.listContainer.hasChildNodes();
	}

};

}

if(!dojo._hasResource["epages.widget.Saveinput"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Saveinput"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.widget.Saveinput");



(function(dj){

	var _saveInput = {
		//paramString: '', // eg. "{ StyleName : 'MyDesign' }"
		buttonLabel : "",
		buttonNode : undefined,
		buttonWidget : undefined,
		previewNode : undefined,

		postCreate: function() {
		
			this.buttonLabel = 	this.domNode.getAttribute("buttonLabel") || "";
			this.url =			this.domNode.getAttribute("url") || "?";
			this.viewAction = 	this.domNode.getAttribute("viewAction") || "JSONViewResponse";
			this.changeAction =	this.domNode.getAttribute("changeAction") || "Save";
			this.objectId =		this.domNode.getAttribute("objectId") || '';
			this.attribute =	this.domNode.getAttribute("attribute") || '';
		
			// postMixInProperties
			this._request = dojo.fromJson(this.paramString) || {};
			this._request['ViewAction'] = this.viewAction;
			this._request['ChangeAction'] = this.changeAction;
			this._request['ObjectID'] = this.objectId;

			this.previewNode = document.createElement("span");
			this.previewNode.className = "SaveInputPreview ClickIcon";
			this.setPreviewContent();

			var bNode = document.createElement("input");
			bNode.type = "button";
			bNode.value= (this.buttonLabel != "") ? buttonLabel : this.dictionary.get("Save");
			dojo.addClass(this.domNode,"Saveinput");

			var nextSib = this.domNode.nextSibling;
			var parentNode = this.domNode.parentNode;

			if(nextSib) {
				parentNode.insertBefore(bNode,nextSib);
				parentNode.insertBefore(this.previewNode,nextSib);
			} else {
				parentNode.appendChild(bNode);
				parentNode.appendChild(this.previewNode);
			}
			this.buttonNode = bNode;

			var bWidget= new epages.widget.Button({},bNode);
			this.buttonWidget = bWidget;
			this.buttonWidget.hide();
			dojo.addClass(bWidget.domNode,"SaveinputButton");

			this.hideInput();

			this.connect(this.previewNode, "onclick", "showInput");
			this.connect(this.domNode, "onkeyup", "triggerButton");
			this.connect(bWidget.domNode, "onclick", "doSave");
		},
		
		_validate: function(){
			return true;
		},

		setPreviewContent : function() {
			this.previewNode.innerHTML = this.domNode.value+'<i class="Sprite ico_s_edit"></i>';
		},

		showInput: function(evt) {
			this.domNode.style.display="";
			this.previewNode.style.display="none";
		},

		hideInput: function(evt) {
			this.domNode.style.display="none";
			this.previewNode.style.display="";
		},

		triggerButton: function(evt) {
			this.buttonWidget.show();
			this.buttonWidget.enable();
			if(this.getValue() != this._lastErrorValue){
				this._removeError();
			}else{
				this._setError();
			}
			if(evt.keyCode === dojo.keys.ENTER){
				this.doSave();
			}
		},

		getValue: function() {
			return this.domNode.value;
		},

		doSave: function() {
			var v=this.getValue();
			this._request[this.attribute] = v;
			if(v) {
				this.buttonWidget.disable();
				var request = new epages.io.Json();

				request.loadAsync(this.url,
					epages.lang.hitch(this, function (result) { this.requestOk(result);}),
					this._request,
					epages.lang.hitch(this, function (result, data) { this.requestFailed(result, data);})
				);
			}
		},

		requestOk: function(result) {
			var v = this.getValue();
			if(result.error) {
				var errors = result.error.data.Errors;
				this._setError();
				this.domNode.focus();
				this._lastErrorValue=v;
				dojo.publish("uimessage/showErrorBubble",[
					this.dictionary.get('Error'),
					this.domNode,
					errors ,
					 (errors[0].Reason=="OBJECT_EXISTS") ? "Warning" : undefined]
				);
			} else {
				this.setStartUpValue(v);
				this._lastErrorValue=undefined;
				this.buttonWidget.hide();
				this._removeError();
				this.setPreviewContent();
				this.hideInput();
			}
		},

		requestFailed: function(result) {
			var errors = result.data.Errors;
			if(errors) {
				dojo.publish("uimessage/showErrors", [
					this.dictionary.get('Error'),
					this.dictionary.get('Save'),
					errors]
				);
			} else {
				var err= result.error[0];
				var errors = [{
						Message: err.message,
						Reason: err.error
				}];

				dojo.publish("uimessage/showErrors", [
					this.dictionary.get('Error'),
					this.dictionary.get('Save'),
					errors]
				);
			}
		},

		setStartUpValue: function( val ) {
			this.attr( 'startupValue', val );
			this.validate();
			
			return this;
		}
	};

	epages.widget.Saveinput = function( options, domNode ){
		this.destroy();
		
		var widget = new epages.widget.Validateinput( options, domNode );
		
			widget = dj.mixin( widget, _saveInput );
			
			widget.postCreate();

		return widget;
	};
	epages.widget.Saveinput.prototype = new dijit._Widget();


})(dojo);

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Toolbox"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Toolbox"] = true;
/*
	Copyright	(c)	2006-2007, epages	Software GmbH
	All	Rights Reserved.

	epages.cartridges.de_epages.presentation.widget.Toolbox

*/
dojo.provide("epages.cartridges.de_epages.presentation.widget.Toolbox");




dojo.declare("epages.cartridges.de_epages.presentation.widget.Toolbox",
	[dijit._Widget, dijit._Templated, dijit._Container, dijit._Contained],
	{
		/**
		 * public properties
		 */
		caption				:	"",
		_menuWidget		: null,
		showCollectionName : '0',
		'class'       : '',

		/**
		 * public properties
		 */
		_lastSelectedMenuItem: null,
		_lastSelectedToolCollection: null,

		/**
		 * widget properties
		 */
		templateString:"<div class=\"ToolBox EnableHover\" id=\"${id}\" >\n  <div class=\"LayoutContainer\">\n    <div class=\"Body\" dojoAttachPoint=\"containerNode\"></div>\n    <div class=\"BoxTitle\"\n         dojoAttachPoint=\"boxTitleNode\"\n         dojoAttachEvent=\"onclick:showMenu\"\n         >\n      <span dojoAttachPoint=\"titleNode\">${caption}</span>\n      <span class=\"dijitInline dijitArrowNode dijitMenuExpandInner\">+</span>\n      <div class=\"Expander\">&nbsp;</div>\n    </div>\n  </div>\n</div>\n",
		imagePath:     epages.themeUrl('images'),

		// override
		startup:	function() {
                // summary: creates a menu of nested "Toolcollection" widgets
			this.inherited("startup", arguments);
			// add old classes
			dojo.addClass(this.domNode, this['class']);

			var childrenArray=this.getChildren();
			if(childrenArray.length>1) {
				this._menuWidget= new epages.widget.Menu();

				for(var	i=0,l=childrenArray.length; i<l; i++)	{
					if(childrenArray[i].declaredClass=="epages.cartridges.de_epages.presentation.widget.Toolcollection"){
						this._addRow(this.getChildren()[i]);
					}
				}
				dojo.addClass(this.boxTitleNode, "WithMenu");
			}

			if(childrenArray[0] !== undefined){
				this.switchTool(childrenArray[0], (this._menuWidget !== null && this._menuWidget.getChildren().length>0) ? this._menuWidget.getChildren()[0] : null);
			}
		},

		_addRow: function(/*Widget*/toolCollection) {
		// summary: add menu entry (link)
			var parentWidget=this;
			this._menuWidget.addChild(new dijit.MenuItem({
				label: toolCollection.caption,
				iconClass: 'MinimizeIcon',
				onClick: function() {
					parentWidget.switchTool(toolCollection, this);
				}
			}));
		},

		// menu / popup
		showMenu:	function()	{
		// summary: show menu
			dijit.popup.open({
				parent: this.domNode,
				orient: {'BL':'TL', 'BR':'TR', 'TL':'BL', 'TR':'BR'},
				popup : this._menuWidget,
				around: this.domNode
			});
		},

		_onBlur: function () {
			dijit.popup.close(this._menuWidget);
		},

		// event handler
		switchTool:	function(/* widget */toolCollection, /* widget */menuItem) {
                    	// summary: switch to the toolcollectio with the passed widgetid
			dijit.popup.close(this._menuWidget);
			if(this._lastSelectedMenuItem !== null){
				dojo.removeClass(this._lastSelectedMenuItem, "Selected");
			}
			if(this._lastSelectedToolCollection !== null){
				this._lastSelectedToolCollection.style.display="none";
			}

			// change toolbox title
			if(this.showCollectionName =='1') {
				var boxTitle=this.caption;
				boxTitle+=(toolCollection.caption!='' && this.caption !='') ? ":" : '';
				boxTitle+=toolCollection.caption;
				this.titleNode.innerHTML=boxTitle;
			}

			// show tool colection
			toolCollection.domNode.style.display="";
			// save selected toolcollection
			this._lastSelectedToolCollection=toolCollection.domNode;

			if(menuItem !== null) {
				// highlight menuitem (selected)
				dojo.addClass(menuItem.domNode, "Selected");
				// save selected menuItem
				this._lastSelectedMenuItem=menuItem.domNode;
			}
		}
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Toolcollection"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.presentation.widget.Toolcollection"] = true;
dojo.provide("epages.cartridges.de_epages.presentation.widget.Toolcollection");



dojo.declare(
	"epages.cartridges.de_epages.presentation.widget.Toolcollection",
	[epages.widget.TypedWidget, dijit._Contained],
	{
		/**
		 * public properties
		 */
		caption : "",

		/**
		 * widget properties
		 */
		templateType       : "table",
		defaultTemplateType: "table", // read-only!
		templateString:"<table class=\"ToolCollection\" id=\"${id}\" style=\"display:none\">\n  <tbody dojoAttachPoint=\"containerNode\"></tbody>\n</table>\n",
		_templateMapping : {
			'table' : {templateString:"<table class=\"ToolCollection\" id=\"${id}\" style=\"display:none\">\n  <tbody dojoAttachPoint=\"containerNode\"></tbody>\n</table>\n"},
			'div'   : {templateString:"<div class=\"ToolCollection\" id=\"${id}\" dojoAttachPoint=\"containerNode\" style=\"display:none\"></div>\n"}
		},

		postMixInProperties: function(){
			this._templateDirectory = dojo.moduleUrl('epages.cartridges.presentation.design.widget' , 'templates');
			this.inherited("postMixInProperties", arguments);
		}
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolbuttonimages"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolbuttonimages"] = true;
/*
	Copyright (c) 2006-2010, ePages GmbH
	All Rights Reserved.
*/

dojo.provide("epages.cartridges.de_epages.design.widget.Toolbuttonimages");



dojo['require']("epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery");



dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolbuttonimages",
	[epages.widget.LocalizedWidget], {
		/**
		 * public properties
		 */
		label						: "",
		fileNameLeft		: "",
		imageSetHidden	: "",
		imagesetLeft		: "",
		imagesetRight		: "",
		imageTiling			: "",
		imageType				: "",
		navBar					: "",
		objectId				: epages.vars.ObjectID,
		slaveWidgetId		: "",
		slaveWidget			: undefined,
		/**
		 * widget properties
		 */

		widgetType        : "Toolbuttonimages",
		templateString:"<tr class=\"ToolbackgroundImage LeftButton\">\n  <td class=\"InputLabelling\">\n    <span class=\"Label\">${label}</span><br />\n    <div class=\"UploadArea AlignCenter\">\n    </div>\n  </td>\n  <td class=\"BackgroundImageUploadSettings\">\n    <div dojoAttachPoint=\"clearImageLeftNode\"\n          class=\"CommandSmallWithLink NoPadding\"\n          style=\"display:none; background: url(${imagePath}/ico_s_delete.png) no-repeat;\"\n          >{Delete}</div>\n\n    <input dojoAttachPoint=\"fileNameLeftNode\"\n           id=\"${navBar}${imageType}\"\n           name=\"${objectId}:${navBar}${imageType}\"\n           value=\"${fileNameLeft}\"\n           type=\"hidden\"\n           />\n\n    <div dojoAttachPoint=\"clearImageSetNode\"\n          class=\"CommandSmallWithLink\"\n          style=\"display:none; background: url(${imagePath}/ico_s_delete.png) no-repeat; padding-left:18px;\"\n          >{ClearImageSet}</div>\n\n    <div dojoAttachPoint=\"restoreImageSetNode\"\n          class=\"CommandSmallWithLink\"\n          style=\"display:none; background: url(${imagePath}/ico_s_redo.png) no-repeat;\"\n          >{RestoreImageSet}</div>\n\n    <!-- clear image set -->\n    <input dojoAttachPoint=\"imageSetHiddenNode\"\n           id=\"${navBar}${imageType}Hidden\"\n           name=\"${objectId}:${navBar}${imageType}Hidden\"\n           value=\"${imageSetHidden}\"\n           type=\"hidden\"\n           />\n\n    <!-- style rule container for image set names -->\n    <input dojoAttachPoint=\"imageSetNode\"\n           id=\"ImageSetLeft${navBar}${imageType}\"\n           name=\"ImageSetLeft${navBar}${imageType}\"\n           value=\"${imagesetLeft}\"\n           type=\"hidden\"\n           ep_noundo=\"1\"\n           />\n    <input id=\"ImageSetRight${navBar}${imageType}\"\n           name=\"ImageSetRight${navBar}${imageType}\"\n           value=\"${imagesetRight}\"\n           type=\"hidden\"\n           ep_noundo=\"1\"\n           />\n\n    <div dojoType=\"epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery\"\n         dojoAttachPoint=\"toolMediaGalleryWidget\"\n         multiSelect=\"false\"\n         validFileTypes=\"jpe;jpg;jpeg;gif;png\"\n         opener=\"Toolbuttonimages\"\n         ></div>\n\n    <div dojoAttachPoint=\"tilingAreaNode\">\n      <input dojoAttachPoint=\"tilingCheckboxNode\"\n             name=\"TilingCheckBox\"\n             class=\"Checkbox\"\n             type=\"text\"\n             ep_noundo=\"1\"\n             />{Tiling}\n      <input dojoAttachPoint=\"imageTilingNode\"\n             type=\"hidden\"\n             name=\"${objectId}:${navBar}${imageType}Tiling\"\n             id=\"${navBar}${imageType}Tiling\"\n             value=\"${imageTiling}\" />\n    </div>\n  </td>\n</tr>\n",
		translationName   : dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates/translation'),
		imagePath         : epages.themeUrl('images'),
		widgetsInTemplate : true,

		// override
		postCreate	: function() {
		 // summary: initalize file upload widget and other background image related events
			this.inherited("postCreate", arguments);

			// pass callback function to toolMediaGalleryWidget
			var me=this;
			this.toolMediaGalleryWidget.onApply = function(pathFromSite) {
				me.setFileName(pathFromSite);
			};

			this.tilingCheckboxNode = new epages.widget.FormElement({}, this.tilingCheckboxNode).elementNode;

			// init events
			this._appendEvents();
		},

		startup: function() {
			this.inherited("startup", arguments);
			if(this.slaveWidgetId != "") {
				this.slaveWidget=$$(this.slaveWidgetId);
				if(this.slaveWidget === undefined) {
					console.warn('SlaveWidget with id ="'+this.slaveWidgetId+'" not found in '+this.declaredClass);
				}
				else {
					dojo.subscribe(this.slaveWidgetId+'/filenamechanged', this, '_showButtons');
				}
			} else {
					console.warn('No slaveWidgetId in '+this.declaredClass+'. Slave functions will be ignored.');
				}

			// init buttons
			this._showButtons();
		},

		setFileName: function(pathFromSite){
			this.fileNameLeftNode.value = pathFromSite;
			epages.event.fire(this.fileNameLeftNode, "change");
		},

		/**
		 * private methods
		 */
		_appendEvents: function() {
		// summary: append onclick and onchange events to buttons and inputs

			// add button events
			this.connect(this.clearImageLeftNode,   'onclick', '_clearImageLeft');
			this.connect(this.clearImageSetNode,    'onclick', '_clearImageSet');
			this.connect(this.restoreImageSetNode,  'onclick', '_restoreImageSet');
			this.connect(this.tilingCheckboxNode,		'onclick', '_toggleImageTiling');

			// add input events (listen to value changes and update display)
			this.connect(this.fileNameLeftNode,			'onchange', '_showButtons');
			this.connect(this.imageSetHiddenNode,  	'onchange', '_showButtons');
			this.connect(this.imageTilingNode,  		'onchange', '_showButtons');
		},

		_clearImageLeft: function(evt) {
		// summary: clears the value of left image file name input and throw change event
			this.fileNameLeftNode.value="";
			epages.event.fire(this.fileNameLeftNode,"change");
		},

		_clearImageSet: function(evt) {
		// summary: set value of "imageSetHidden" input to "1" and throw change event
			this.imageSetHiddenNode.value="1";
			epages.event.fire(this.imageSetHiddenNode,"change");
		},

		_restoreImageSet: function(evt) {
		// summary: set value of "imageSetHidden" input to "0" and throw change events
			this.imageSetHiddenNode.value="0";
			epages.event.fire(this.imageSetHiddenNode,"change");	// trigger undo, redo for this element
			epages.event.fire(this.imageSetNode,"change");				// trigger style rule to display ImageSet images
		},

		_showButtons: function() {
		// summary: decides which button is visible

			if(this.imageTilingNode.value=='1') {
				this.tilingCheckboxNode.checked=true;			// Checkbox checked->true if value in hidden input=1. This happens if the user presses the undo or redo button
			}
			else {
				this.tilingCheckboxNode.checked=false;
			}

			var fileNameRightNodeValue= "";
			if(this.slaveWidget) {
				fileNameRightNodeValue= this.slaveWidget.getFileName();
			}

			if(this.fileNameLeftNode.value!="" || fileNameRightNodeValue!="" ) {
				if(this.fileNameLeftNode.value!="") {
				// show hide clear button left
					this.clearImageLeftNode.style.display="";
				} else {
					this.clearImageLeftNode.style.display="none";
				}

				if(this.fileNameLeftNode.value!='' && fileNameRightNodeValue=='') {
					this.tilingAreaNode.style.display="";		// (image tiling=yes) && (left image) && (no right image) --> show tiling checkbox |else --> hide tiling checkbox
				}
				else {
					this.tilingAreaNode.style.display="none";
				}

				// hide: clear imageset / restore imageset
				this.clearImageSetNode.style.display="none";
				this.restoreImageSetNode.style.display="none";
			} else if(this.imageSetHiddenNode.value!="1"){
				this.clearImageLeftNode.style.display="none";
				this.clearImageSetNode.style.display="";
				this.restoreImageSetNode.style.display="none";
				this.tilingAreaNode.style.display="none";
			}	else {
				this.clearImageLeftNode.style.display="none";
				this.clearImageSetNode.style.display="none";
				this.restoreImageSetNode.style.display="";
				this.tilingAreaNode.style.display="none";
			}
		},

		_toggleImageTiling: function(evt) {
		// summary: hidden input / checkbox handler set
		// description: Handles the value of the hidden input element which depends on the visible checkbox.
		//		Afterwards it fires an change event to trigger the display handler (_showButtons).
			if(this.tilingCheckboxNode.checked==true) {
				this.imageTilingNode.value=1;
			} else {
				this.imageTilingNode.value=0;
			}
			epages.event.fire(this.imageTilingNode,"change");
		}
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolbuttonimageright"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolbuttonimageright"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/

dojo.provide("epages.cartridges.de_epages.design.widget.Toolbuttonimageright");



epages.require('ep_shop_upload', 'epages.uploader');


dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolbuttonimageright",
	[epages.widget.LocalizedWidget], {
		/**
		 * public properties
		 */
		label						: "",
		fileNameRight		: "",
		imageType				: "",
		objectId				: epages.vars.ObjectID,
		/**
		 * widget properties
		 */

		widgetType        : "Toolbuttonimageright",
		templateString:"<tr class=\"ToolbackgroundImage RightButton\">\n  <td class=\"InputLabelling\">\n    <span class=\"Label\">${label}</span><br />\n    <div class=\"UploadArea AlignCenter\">\n    </div>\n  </td>\n  <td class=\"BackgroundImageUploadSettings\">\n    <input dojoAttachPoint=\"fileNameRightNode\"\n           id=\"${imageType}\"\n           name=\"${objectId}:${imageType}\"\n           value=\"${fileNameRight}\"\n           type=\"hidden\"\n           />\n\n    <div dojoAttachPoint=\"clearImageRightNode\"\n          class=\"CommandSmallWithLink\"\n          style=\"display:none; background: url(${imagePath}/ico_s_delete.png) no-repeat;\"\n          >{Delete}</div>\n\n    <div dojoType=\"epages.cartridges.de_epages.mediagallery.widget.Toolmediagallery\"\n         dojoAttachPoint=\"toolMediaGalleryWidget\"\n         multiSelect=\"false\"\n         validFileTypes=\"jpe;jpg;jpeg;gif;png\"\n         opener=\"Toolbuttonimageright\"\n         ></div>\n  </td>\n</tr>\n",
		translationName   : dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates/translation'),
		imagePath         : epages.themeUrl('images'),
		widgetsInTemplate : true,

		// override
		postCreate	: function() {
		// summary: initalize file upload widget and other background image related events
			this.inherited("postCreate", arguments);

			// pass callback function to toolMediaGalleryWidget
			var me=this;
			this.toolMediaGalleryWidget.onApply = function(pathFromSite) {
				me.setFileName(pathFromSite);
			};

			// init events
			this._appendEvents();

			// init buttons
			this._showButtons();
		},

		getFileName: function() {
			return this.fileNameRightNode.value;
		},

		setFileName: function(pathFromSite){
			this.fileNameRightNode.value = pathFromSite;
			epages.event.fire(this.fileNameRightNode, "change");
		},

		/**
		 * private methods
		 */
		_appendEvents: function() {
		// summary: append onclick and onchange events to buttons and inputs

			// add button events
			this.connect(this.clearImageRightNode,  'onclick', '_clearImageRight');

			// add input events (listen to value changes and update display)
			this.connect(this.fileNameRightNode,		'onchange', '_showButtons');
		},

		_clearImageRight: function(evt) {
		// summary: clears the value of left image file name input and throw change event
			this.fileNameRightNode.value="";
			epages.event.fire(this.fileNameRightNode,"change");
		},

		_showButtons: function() {
		// summary: decides which button is visible
			dojo.publish(this.id+'/filenamechanged', [this.getFileName()]);
			if(this.fileNameRightNode.value!="") {
				this.clearImageRightNode.style.display="";			// show hide clear button right
			}
			else {
				this.clearImageRightNode.style.display="none";
			}
		}

});

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolsimpleinput"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolsimpleinput"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/

dojo.provide("epages.cartridges.de_epages.design.widget.Toolsimpleinput");




dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolsimpleinput",
	[epages.widget.LocalizedWidget, dijit._Container, dijit._Contained],
	{
		/**
		 * public properties
		 */
		label           : '',
		value           : '',
		inputType       : '',
		objectId        : '',
		lockLevel       : '', /* locklevel > 0 => attribute locked */
		validationType  : '',
		inputCssClass		: '',
		settings        : '',
		inputId         : '',
		customId        : true,
		/**
		 * widget properties
		 */
		templateString:"<tr>\n  <td class=\"InputLabelling\">${label}</td>\n  <td colspan=\"4\">\n    <input dojoType=\"epages.widget.Validateinput\"\n           validationType=\"${validationType}\"\n           dojoAttachPoint=\"inputWidget\"\n           id=\"${inputId}\"\n           name=\"${objectId}:${inputType}\"\n           value=\"${value}\"\n           class=\"${inputCssClass}\"\n           type=\"text\"\n           settings=\"${settings}\"\n           />\n  </td>\n  <td></td>\n</tr>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates/translation'),
		imagePath       : epages.themeUrl('images'),
		widgetsInTemplate : true,

		postMixInProperties: function(){
			this.inherited("postMixInProperties", arguments);
			if(this.customId){
				this.inputId = this.inputType;
			}
		},

		// override
		postCreate  : function() {
			// summary: initalize widget
			// description: show lock icon and disable input field if locklevel is passed
			this.inherited("postCreate", arguments);
			if(this.lockLevel == '1' || this.lockLevel == '2') {
					this.inputWidget.domNode.disabled=true;
					this.domNode.className+=" disabled";
			}
		}
	});

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolalignment"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolalignment"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.design.widget.Toolalignment");








dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolalignment",
	[epages.widget.LocalizedWidget,dijit._Container],
	{
		/**
		 * public properties
		 */
		alignment						: '',
		alignType						: '',
		objectId						: '',

		/**
		 * widget properties
		 */
		declaredClass		: 'epages.design.Toolalignment',
		templateString:"<tr>\n  <td class=\"InputLabelling NoWrap\">{Align}</td>\n  <td>\n    <select dojoAttachPoint=\"selectNode\"\n            name=\"${objectId}:${alignType}\"\n            id=\"${alignType}\"\n            class=\"SelectAlign\" >\n      <option value=\"left\"   >{AlignLeft}</option>\n      <option value=\"center\" >{AlignCenter}</option>\n      <option value=\"right\"  >{AlignRight}</option>\n      <option value=\"custom\">{AlignCustom}</option>\n    </select>\n    <input type=\"hidden\" name=\"${objectId}:${alignType}Helper\" id=\"${alignType}Helper\"/>\n  </td>\n</tr>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'),

		// override
		postCreate	: function() {

      // summary: Set font select node value
			this.inherited("postCreate", arguments);
			this.selectWidget = new epages.widget.FormElement({}, this.selectNode);

			// Added "custom" alignment option for *horizontal* navbars (EPG-26482).
			if (this.alignType !== 'HeaderAlign' && this.alignType !== 'FooterAlign' && this.alignType !== 'RoofAlign' && this.alignType !== 'TopAlign' && this.alignType !== 'BottomAlign') {
				if (dojo.query('option[value="custom"]', this.selectWidget.domNode).length) {
					dojo.destroy(dojo.query('option[value="custom"]', this.selectWidget.domNode)[0]);
				}
			}

			this.selectWidget.elementNode.value = this.alignment;
			this.selectWidget.elementNode.startupSelected = this.selectWidget.elementNode.selectedIndex;
			this.selectWidget.elementNode.startupIndex = this.selectWidget.elementNode.selectedIndex;
			this.selectWidget.elementNode.startupValue = this.selectWidget.elementNode.value;
			this.startUpChangeInterval = setInterval(dojo.hitch(this, function() {
				if(this.selectWidget.domNode.className.match("Changed")) {
					dojo.removeClass(this.selectWidget.domNode, "Changed");
					clearInterval(this.startUpChangeInterval);
				}
			}), 500);
		}
	});


}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Navbarpreview"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Navbarpreview"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.design.widget.Navbarpreview");



dojo.declare(
	"epages.cartridges.de_epages.design.widget.Navbarpreview",
	[epages.widget.LocalizedWidget,dijit._Contained],
	{
		/**
		 * public properties
		 */
		templateType: 'Layout1',
		defaultTemplateType: 'Layout1',

		_templateMapping:{
			'Layout1' : {templateString:"<div class=\"NavbarPreviewLayout1 ${cssClass}\">\n  <div dojoAttachpoint=\"roofNode\" class=\"NavbarPreviewRoof EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"headerNode\" class=\"NavbarPreviewHeader EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"topNode\" class=\"NavbarPreviewTop EnableHover\" style=\"display:none\"></div>\n  <div class=\"NavbarPreviewThreeColumns\">\n    <div class=\"NavbarPreviewContent\"></div>\n    <div dojoAttachpoint=\"leftNode\" class=\"NavbarPreviewLeft EnableHover\" style=\"display:none\"></div>\n    <div dojoAttachpoint=\"rightNode\" class=\"NavbarPreviewRight EnableHover\" style=\"display:none\"></div>\n  </div>\n  <div dojoAttachpoint=\"bottomNode\" class=\"NavbarPreviewBottom EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"footerNode\" class=\"NavbarPreviewFooter EnableHover\" style=\"display:none\"></div>\n</div>\n"},
			'Layout2' : {templateString:"<div class=\"NavbarPreviewLayout2 ${cssClass}\">\n  <div dojoAttachpoint=\"roofNode\" class=\"NavbarPreviewRoof EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"headerNode\" class=\"NavbarPreviewHeader EnableHover\" style=\"display:none\"></div>\n  <div class=\"NavbarPreviewThreeColumns\">\n    <div class=\"NavbarPreviewContent\"></div>\n    <div dojoAttachpoint=\"topNode\" class=\"NavbarPreviewTop EnableHover\" style=\"display:none\"></div>\n    <div dojoAttachpoint=\"bottomNode\" class=\"NavbarPreviewBottom EnableHover\" style=\"display:none\"></div>\n    <div dojoAttachpoint=\"leftNode\" class=\"NavbarPreviewLeft EnableHover\" style=\"display:none\"></div>\n    <div dojoAttachpoint=\"rightNode\" class=\"NavbarPreviewRight EnableHover\" style=\"display:none\"></div>\n  </div>\n  <div dojoAttachpoint=\"footerNode\" class=\"NavbarPreviewFooter EnableHover\" style=\"display:none\"></div>\n</div>\n"},
			'Layout3' : {templateString:"<div class=\"NavbarPreviewLayout3 ${cssClass}\">\n  <div class=\"NavbarPreviewThreeColumns\">\n    <div class=\"NavbarPreviewContent\"></div>\n    <div class=\"NavbarPreviewHeaderAndTop\">\n  \t\t<div dojoAttachpoint=\"roofNode\" class=\"NavbarPreviewRoof EnableHover\" style=\"display:none\"></div>\n      <div dojoAttachpoint=\"headerNode\" class=\"NavbarPreviewHeader EnableHover\" style=\"display:none\"></div>\n      <div dojoAttachpoint=\"topNode\" class=\"NavbarPreviewTop EnableHover\" style=\"display:none\"></div>\n    </div>\n    <div class=\"NavbarPreviewBottomAndFooter\">\n      <div dojoAttachpoint=\"bottomNode\" class=\"NavbarPreviewBottom EnableHover\" style=\"display:none\"></div>\n      <div dojoAttachpoint=\"footerNode\" class=\"NavbarPreviewFooter EnableHover\" style=\"display:none\"></div>\n    </div>\n    <div dojoAttachpoint=\"leftNode\" class=\"NavbarPreviewLeft EnableHover\" style=\"display:none\"></div>\n    <div dojoAttachpoint=\"rightNode\" class=\"NavbarPreviewRight EnableHover\" style=\"display:none\"></div>\n  </div>\n</div>\n"}
		},
		cssClass : '',
		visibleNavBars: undefined,

		/**
		 * widget properties
		 */
		imagePath       : epages.themeUrl('images'),
		templateString:"<div class=\"NavbarPreviewLayout1 ${cssClass}\">\n  <div dojoAttachpoint=\"roofNode\" class=\"NavbarPreviewRoof EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"headerNode\" class=\"NavbarPreviewHeader EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"topNode\" class=\"NavbarPreviewTop EnableHover\" style=\"display:none\"></div>\n  <div class=\"NavbarPreviewThreeColumns\">\n    <div class=\"NavbarPreviewContent\"></div>\n    <div dojoAttachpoint=\"leftNode\" class=\"NavbarPreviewLeft EnableHover\" style=\"display:none\"></div>\n    <div dojoAttachpoint=\"rightNode\" class=\"NavbarPreviewRight EnableHover\" style=\"display:none\"></div>\n  </div>\n  <div dojoAttachpoint=\"bottomNode\" class=\"NavbarPreviewBottom EnableHover\" style=\"display:none\"></div>\n  <div dojoAttachpoint=\"footerNode\" class=\"NavbarPreviewFooter EnableHover\" style=\"display:none\"></div>\n</div>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'),

		postCreate: function() {
			this.templateDirectory = dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates');
			this.inherited('postCreate', arguments);
			this.visibleNavBars = epages.NavBars;
			if(this.visibleNavBars) {
				for(var el in this.visibleNavBars) {
					var navString=this.visibleNavBars[el][2];
					if(navString != "Delete") {
						this.enableBar(navString.toLowerCase());
						this.addNavbarEvents(navString, el);
					}
				}
			} else {
				console.warn("epages.NavBars not defined in "+this.declaredClass);
			}
		},

		addNavbarEvents : function(/* string */ navbar, /* string */ epObjectId) {
			var navbarlc = navbar.toLowerCase();
			var navbarNode = this[navbarlc + 'Node']
			navbarNode.ep_objectId = epObjectId;
			navbarNode.ep_navbar = navbar;
			this.connect(navbarNode, "onclick", '_publishSelect');
		},

		_publishSelect: function(evt) {
			var node = evt.currentTarget;
			dojo.stopEvent(evt);
			dojo.publish(this.id+'/select', [{ navbar: node.ep_navbar, objectId: node.ep_objectId }]);
		},

		enableBar: function (navbar) {
			this[navbar + 'Node'].style.display="";
		},

		disableBar: function (navbar) {
			this[navbar + 'Node'].style.display="none";
		},

		switchBar: function (navbar) {
			if (this[navbar + 'Node'].style.display=="none") {
				this.enableBar(navbar);
			} else {
				this.disableBar(navbar);
			}
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Navbarselect"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Navbarselect"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.design.widget.Navbarselect");








dojo.declare(
	"epages.cartridges.de_epages.design.widget.Navbarselect",
	[epages.widget.LocalizedWidget,dijit._Container],
	{
		/**
		 * public properties
		 */
		lockLevel:  		'0',
		layout:     		'Layout1',
		objectId:			'',
		undobuttonsId :		'undoWidget',
		imageUrl:           epages.vars.StoreRoot + '/BO/icons',

		roofIsVisible: 		'1',
		headerIsVisible: 	'1',
		topIsVisible: 		'1',
		bottomIsVisible: 	'1',
		footerIsVisible: 	'1',
		leftIsVisible: 		'1',
		rightIsVisible: 	'1',
		leftrightonlyatstartpageIsVisible: '1',

		/**
		 * private properties
		 */
		_dialogWidget: null,
		_dialogWidgetTarget: null,

		/**
		 * widget properties
		 */
		templateString:"<table><tr><td>\n  <input dojoAttachpoint=\"isVisibleRoofNode\" type=\"hidden\" id=\"RoofIsVisible\" name=\"${objectId}:RoofIsVisible\" value=\"${roofIsVisible}\" />\n  <input dojoAttachpoint=\"isVisibleHeaderNode\" type=\"hidden\" id=\"HeaderIsVisible\" name=\"${objectId}:HeaderIsVisible\" value=\"${headerIsVisible}\" />\n  <input dojoAttachpoint=\"isVisibleTopNode\" type=\"hidden\" id=\"TopIsVisible\"    name=\"${objectId}:TopIsVisible\"    value=\"${topIsVisible}\"    />\n  <input dojoAttachpoint=\"isVisibleBottomNode\" type=\"hidden\" id=\"BottomIsVisible\" name=\"${objectId}:BottomIsVisible\" value=\"${bottomIsVisible}\" />\n  <input dojoAttachpoint=\"isVisibleFooterNode\" type=\"hidden\" id=\"FooterIsVisible\" name=\"${objectId}:FooterIsVisible\" value=\"${footerIsVisible}\" />\n  <input dojoAttachpoint=\"isVisibleLeftNode\" type=\"hidden\" id=\"LeftIsVisible\"   name=\"${objectId}:LeftIsVisible\"   value=\"${leftIsVisible}\"   />\n  <input dojoAttachpoint=\"isVisibleRightNode\" type=\"hidden\" id=\"RightIsVisible\"  name=\"${objectId}:RightIsVisible\"  value=\"${rightIsVisible}\"  />\n  <input dojoAttachpoint=\"isVisibleLeftRightOnlyAtStartPageNode\" type=\"hidden\" id=\"LeftRightOnlyAtStartPageIsVisible\"  name=\"${objectId}:LeftRightOnlyAtStartPageIsVisible\"  value=\"${leftrightonlyatstartpageIsVisible}\"  />\n  <div style=\"position:relative;top:-2px\">\n    <div class=\"ClearBoth\"><input class=\"Checkbox\" dojoType=\"epages.widget.FormElement\" id=\"CheckRoofIsVisible\" type=\"text\" value=\"Roof\" ep_noundo=\"1\" /><label for=\"CheckRoofIsVisible\">{NavbarHeader} 1</label></div>\n    <div class=\"ClearBoth negativeMarginTop\"><input class=\"Checkbox\" dojoType=\"epages.widget.FormElement\" id=\"CheckHeaderIsVisible\" type=\"text\" value=\"Header\" ep_noundo=\"1\" /><label for=\"CheckHeaderIsVisible\">{NavbarHeader} 2</label></div>\n    <div class=\"ClearBoth negativeMarginTop\"><input class=\"Checkbox\" dojoType=\"epages.widget.FormElement\" id=\"CheckTopIsVisible\"    type=\"text\" value=\"Top\" ep_noundo=\"1\" /><label for=\"CheckTopIsVisible\">{Top}</label></div>\n    <div class=\"ClearBoth negativeMarginTop\"><input class=\"Checkbox\" dojoType=\"epages.widget.FormElement\" id=\"CheckBottomIsVisible\" type=\"text\" value=\"Bottom\" ep_noundo=\"1\" /><label for=\"CheckBottomIsVisible\">{Bottom}</label></div>\n    <div class=\"ClearBoth negativeMarginTop\"><input class=\"Checkbox\" dojoType=\"epages.widget.FormElement\" id=\"CheckFooterIsVisible\" type=\"text\" value=\"Footer\" ep_noundo=\"1\" /><label for=\"CheckFooterIsVisible\">{NavbarFooter}</label></div>\n    <div class=\"ClearBoth negativeMarginTop TopMargin\"><input class=\"Checkbox\" dojoType=\"epages.widget.FormElement\" id=\"CheckLeftIsVisible\"  type=\"text\" value=\"Left\" ep_noundo=\"1\" /><label for=\"CheckLeftIsVisible\">{Left}</label></div>\n    <div class=\"ClearBoth negativeMarginTop\"><input class=\"Checkbox\" dojoType=\"epages.widget.FormElement\" id=\"CheckRightIsVisible\" type=\"text\" value=\"Right\" ep_noundo=\"1\" /><label for=\"CheckRightIsVisible\">{Right}</label></div>\n  </div>\n</td>\n<td class=\"LeftPadding\">\n  <div dojoType=\"epages.cartridges.de_epages.design.widget.Navbarpreview\" dojoAttachpoint=\"Navbarpreview\"\n    layout=\"${layout}\"></div>\n  <div class=\"ClearBoth\">\n    <input class=\"Checkbox\" dojoType=\"epages.widget.FormElement\" id=\"CheckLeftRightOnlyAtStartPageIsVisible\" type=\"text\" value=\"LeftRightOnlyAtStartPage\" ep_noundo=\"1\" /><label for=\"CheckLeftRightOnlyAtStartPageIsVisible\">{OnStartPageOnly}</label>\n    <img src=\"${imageUrl}/ico_s_bubblehelp.png\" alt=\"\" class=\"BubbleHelp TopSmallMargin\" />\n    <span class=\"Tooltip ep-js\" data-js=\".uiTooltip({});\">{BubbleHelpOnStartPageOnly}</span>\n  </div>\n</td></tr></table>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'),
		widgetsInTemplate :true,

		// override
		postCreate  : function() {
			this.inherited("postCreate", arguments);
			this.lockLevel = parseInt(this.lockLevel);

			$A(['Roof', 'Header', 'Top', 'Left', 'Right', 'Bottom', 'Footer', 'LeftRightOnlyAtStartPage']).each( function (el) {
				var el_lc = el.toLowerCase();  // header
				var v = el_lc + 'IsVisible';   // attribute name: headerIsVisible
				var checkNode = $('Check' + el + 'IsVisible'); // checkHeaderNode
				var checkNodeLabel = dojo.query('label[for="Check' + el + 'IsVisible"]');
				var visibleNode = this['isVisible'+el+'Node']; // isVisibleHeaderNode
				var checkWidget = dijit.byNode(checkNode);
				this[v] = this[v] == '1' ? true : false;
				if (this.lockLevel > 0){
					 checkWidget.attr('disabled ',true);
				}
				// if (this._htmlUndo) this._htmlUndo.setDefaultValue(visibleNode);
				this.connect(checkNode,   'onclick', 'clickBar');
				this.connect(visibleNode, 'onchange', 'onChangeIsVisible');
				checkWidget.attr('checked',this[v]);
				if(el !== 'LeftRightOnlyAtStartPage'){
					if (this[v]) {
						this.Navbarpreview.enableBar(el_lc);
					}
					else {
						this.Navbarpreview.disableBar(el_lc);
					}	
				}
				else{
					if(this['rightIsVisible'] == '0' && this['leftIsVisible'] == '0'){
						dojo.addClass(checkNodeLabel[0], 'Disabled');
						dojo.attr(checkNode, 'disabled', 'disabled');
					}
				}
			}, this);
		},

		setBar: function (navbar, check) {
			if(navbar !== 'LeftRightOnlyAtStartPage'){
				$$('Check' + navbar + 'IsVisible').attr('checked',check);
				if (check) {
					this.Navbarpreview.enableBar(navbar.toLowerCase());
				}
				else {
					this.Navbarpreview.disableBar(navbar.toLowerCase());
				}
			}
		},

		_createDialog: function(){
			var messageWidget = new epages.widget.Message({
				headline:this.translation.get("SaveQuestion"),
				message: this.translation.get("ChangeNavbarsDescription"),
				sizeClass:"Large",
				typeClass:"Warning"
			});

			var me =this;
			var buttons = [{
				label: this.translation.get("Save"),
				cssClass: 'Active',
				onclick: function() {
					this._modalDialogWidget.hide();
					me.sendChanges(me._dialogWidgetTarget);
				}
			},
			{
				label: this.translation.get("Cancel"),
				onclick: function() {
					this._modalDialogWidget.hide();
					me._undoChange(me._dialogWidgetTarget);
				}
			}];
			this._dialogWidget = new epages.widget.Modaldialog({
				id: "Designtoolcontroller_DialogWidget",
				options:{
					title : this.translation.get("ChangeOnNavbars"),
					width : 400,
					height: 120,
					content: messageWidget
				},
				buttons : buttons

			});
			document.body.appendChild(this._dialogWidget.domNode);
		},

		sendChanges: function (t) {
			var navbar = t.value;
			var vNode = this['isVisible'+navbar+'Node'];
			vNode.value = t.checked ? '1' : '0';
			epages.event.fire(vNode,'change');
			if ($$(this.undobuttonsId)) {
				$$(this.undobuttonsId).sendChanges({
					text : this.translate("BusyWhileSavingData"),
					permanent : true
				});
				window.setTimeout(function(){
					window.location.href = window.location.href;
				},1000);
			}
		},

		clickBar: function (evt) {
			var u = $$(this.undobuttonsId);
			if(u){
				if(u.existsChanges()){
					if(!this._dialogWidget){
						 this._createDialog();
					}
					this._dialogWidgetTarget = evt.currentTarget;
					this._dialogWidget.show();
				} else{
					this.sendChanges(evt.currentTarget);
				}
			} else {
				this.sendChanges(evt.currentTarget);
			}
		},

		onChangeIsVisible: function (evt) {
			var t = evt.currentTarget;
			this.setBar(t.id.replace(/IsVisible$/, ''), t.value == '1' ? true : false);
		},

		_undoChange: function(t){
			t.checked = !t.checked;
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolspacesheadline"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolspacesheadline"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.design.widget.Toolspacesheadline");


dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolspacesheadline",
	[epages.widget.LocalizedWidget],
	{
		templateString:"<tr>\n  <td></td>\n  <td class=\"InputPadding\">{Top}</td>\n  <td class=\"InputPadding\">{Bottom}</td>\n  <td class=\"InputPadding\">{Left}</td>\n  <td class=\"InputPadding\">{Right}</td>\n  <td></td>\n</tr>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget', 'templates/translation')
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolspaces"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolspaces"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.design.widget.Toolspaces");




dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolspaces",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		label           : '',
		top             : '',
		bottom          : '',
		left            : '',
		right           : '',
		spaceType       : '', /* Margin, Padding */
		objectId        : '',
		lockLevel       : '', /* locklevel > 0 => attribute locked */
		/**
		 * widget properties
		 */

		templateString:"<tr class=\"ToolSpaces\">\n  <td class=\"InputLabelling\">${label}</td>\n  <td class=\"SpaceInput\">\n    <input dojoType=\"epages.widget.Validateinput\"\n           validationType=\"Size\"\n           settings=\"negativeAllowed: true, autoAllowed: true\"\n           dojoAttachPoint=\"topInputWidget\"\n           id=\"${spaceType}Top\"\n           name=\"${objectId}:${spaceType}Top\"\n           value=\"${top}\"\n           type=\"text\"\n           />\n  </td>\n  <td class=\"SpaceInput\">\n    <input dojoType=\"epages.widget.Validateinput\"\n           validationType=\"Size\"\n           settings=\"negativeAllowed: true, autoAllowed: true\"\n           dojoAttachPoint=\"bottomInputWidget\"\n           id=\"${spaceType}Bottom\"\n           name=\"${objectId}:${spaceType}Bottom\"\n           value=\"${bottom}\"\n           type=\"text\"\n           />\n  </td>\n  <td class=\"SpaceInput\">\n    <input dojoType=\"epages.widget.Validateinput\"\n           validationType=\"Size\"\n           settings=\"negativeAllowed: true, autoAllowed: true\"\n           dojoAttachPoint=\"leftInputWidget\"\n           id=\"${spaceType}Left\"\n           name=\"${objectId}:${spaceType}Left\"\n           value=\"${left}\"\n           type=\"text\"\n           />\n  </td>\n  <td class=\"SpaceInput\">\n    <input dojoType=\"epages.widget.Validateinput\"\n           validationType=\"Size\"\n           settings=\"negativeAllowed: true, autoAllowed: true\"\n           dojoAttachPoint=\"rightInputWidget\"\n           id=\"${spaceType}Right\"\n           name=\"${objectId}:${spaceType}Right\"\n           value=\"${right}\"\n           type=\"text\"\n           />\n  </td>\n  <td>\n      <img src=\"${imagePath}/ico_s_bubblehelp.png\" alt=\"\" class=\"BubbleHelp\"\n         dojoattachPoint=\"bubbleHelpPaddingNode\"\n         style=\"display: none\"/>\n       <span class=\"Tooltip ep-js\"  data-js=\".uiTooltip({})\">\n        <div class=\"InfoPaddings\">\n          <div class=\"ExplainPaddings\">{ExplainPaddings}</div>\n            <div class=\"InfoPaddingsAdjustPosition\">\n              <div class=\"InfoPaddingsImageContainer\">\n                <img src=\"${imagePath}/infolayer_img_paddings.png\"\n                     alt=\"{ExplainPaddings}\"\n                     class=\"InfoPaddingsImage\" />\n                <div class=\"InfoPaddingsLabelTop\"   >{TopPadding}</div>\n                <div class=\"InfoPaddingsLabelLeft\"  >{LeftPadding}</div>\n                <div class=\"InfoPaddingsLabelBottom\">{BottomPadding}</div>\n                <div class=\"InfoPaddingsLabelRight\" >{RightPadding}</div>\n              </div>\n            </div>\n          </div>\n        </div>\n      </span>\n\n      <img src=\"${imagePath}/ico_s_bubblehelp.png\" alt=\"\" class=\"BubbleHelp\"\n         dojoattachPoint=\"bubbleHelpMarginNode\"\n         style=\"display: none;\"/>\n       <span class=\"Tooltip Wide ep-js\"  data-js=\".uiTooltip({})\">\n        <div class=\"InfoMargins\" >\n          <div class=\"ExplainMargins\">{ExplainMargins}</div>\n          <div class=\"InfoMarginsImageContainer\">\n            <img src=\"${imagePath}/infolayer_img_margins.png\"\n                 alt=\"{ExplainMargins}\"\n                 class=\"InfoMarginImage\" />\n            <div class=\"InfoText InfoMarginsLabelTop\"   >{TopMargin}</div>\n            <div class=\"InfoText InfoMarginsLabelLeft\"  >{LeftMargin}</div>\n            <div class=\"InfoText InfoMarginsLabelBottom\">{BottomMargin}</div>\n            <div class=\"InfoText InfoMarginsLabelRight\" >{RightMargin}</div>\n          </div>\n        </div>\n      </tt>\n  </td>\n\n</tr>\n\n",
		translationName   : dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates/translation'),
		imagePath         : epages.themeUrl('images'),
		widgetsInTemplate : true,

		// override
		postCreate  : function() {
                // summary: initalize widget
		// description: show lock icon and disable input fields if locklevel is passed
			if(this.spaceType.match("Margin")){
				this.bubbleHelpMarginNode.style.display="";
			}else if(this.spaceType.match("Padding")){
				this.bubbleHelpPaddingNode.style.display="";
			}
			this.inherited("postCreate", arguments);
			if(this.lockLevel == '1' || this.lockLevel == '2') {
					this.topInputWidget.domNode.disabled=true;
					this.bottomInputWidget.domNode.disabled=true;
					this.leftInputWidget.domNode.disabled=true;
					this.rightInputWidget.domNode.disabled=true;
					this.domNode.className+=" disabled";
			}
		}
});

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolfont"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Toolfont"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.design.widget.Toolfont");








dojo.declare(
	"epages.cartridges.de_epages.design.widget.Toolfont",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		label               : '',
		label_formatted     : '',
		size                : '',
		color               : '',
		isBold              : '',
		isItalic            : '',
		isUnderline         : '',
		isBoldInactive      : '',
		isItalicInactive    : '',
		isUnderlineInactive : '',
		isSizeInactive      : '',
		isSizeVisible       : '1',
		fontType            : '', /* Headline, Paragraph, Link, ... */
		objectId            : '',
		/**
		 * private properties
		 */
		_inputMapping   : undefined,
		_buttonMapping  : undefined,
		/**
		 * constants
		 */
		COLORPICKER_OFFSET_X: 18,
		COLORPICKER_OFFSET_Y: 0,
		/**
		 * widget properties
		 */
		declaredClass   : 'epages.design.Toolfont',
		templateString:"<tr class=\"Toolfont\">\n  <td class=\"InputLabelling NoWrap\"><span dojoAttachPoint=\"labelNode\">${label_formatted}</span></td>\n  <td class=\"FontSize\" dojoAttachPoint=\"fontSizeColumnNode\">\n    <input dojoType=\"epages.widget.Validateinput\"\n           dojoAttachPoint=\"fontSizeWidget\"\n           class=\"FontSize FloatLeft\"\n           id=\"${fontType}Size\"\n           validationType=\"Size\"\n           name=\"${objectId}:${fontType}Size\"\n           value=\"${size}\"\n           type=\"text\" />\n  </td>\n  <td>\n    <div class=\"ButtonWrapper\">\n      <div dojoType=\"epages.cartridges.de_epages.presentation.widget.Toolcolor\"\n           color=\"${color}\"\n           colorType=\"${fontType}Color\"\n           objectId=\"${objectId}\"\n           templateType=\"colorbox\"\n           ></div>\n\n      <div dojoAttachPoint=\"boldDivNode\"\n           class=\"FontAttributeInactiveBox Bold\"\n           title=\"{Bold}\">{BoldAbbreviation}</div>\n      <input dojoAttachPoint=\"boldInputNode\"\n             id=\"${fontType}Bold\"\n             name=\"${objectId}:${fontType}Bold\"\n             value=\"${isBold}\"\n             type=\"hidden\" />\n\n      <div dojoAttachPoint=\"italicDivNode\"\n           class=\"FontAttributeInactiveBox Italic\"\n           title=\"{Italic}\">{ItalicAbbreviation}</div>\n      <input dojoAttachPoint=\"italicInputNode\"\n             id=\"${fontType}Italic\"\n             name=\"${objectId}:${fontType}Italic\"\n             value=\"${isItalic}\"\n             type=\"hidden\" />\n\n      <div dojoAttachPoint=\"underlineDivNode\"\n           class=\"FontAttributeInactiveBox Underline\"\n           title=\"{Underline}\">{UnderlineAbbreviation}</div>\n      <input dojoAttachPoint=\"underlineInputNode\"\n             id=\"${fontType}Underline\"\n             name=\"${objectId}:${fontType}Underline\"\n             value=\"${isUnderline}\"\n             type=\"hidden\" />\n    </div>\n  </td>\n</tr>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'),
		widgetsInTemplate : true,

		postMixInProperties: function() {
			this.inherited("postMixInProperties", arguments);
			this.label_formatted = epages.format.slice(this.label, 15);
		},

		postCreate  : function() {
			// summary: Initialize widget: disable inactive buttons, set button state, add button events
			this.inherited("postCreate", arguments);

			this.boldDivNode.inputmappingkey='bold';
			this.italicDivNode.inputmappingkey='italic';
			this.underlineDivNode.inputmappingkey='underline';

			this._inputMapping = new epages.lang.Hash({
				bold     : this.boldInputNode,
				italic   : this.italicInputNode,
				underline: this.underlineInputNode
			});
			this._buttonMapping = new epages.lang.Hash({
				bold     : this.boldDivNode,
				italic   : this.italicDivNode,
				underline: this.underlineDivNode
			});

			if(this.label_formatted !== this.label){
				this.labelNode.title = this.label;
			}

			this._disableInactiveElements();
			this._displayButtonState();
			this._appendEvents();
		},

		/**
		 * private methods
		 */

		_appendEvents: function() {
		// summary: append events to buttons (bold, italic, underline)

			// add value handler
			this.connect(this.boldDivNode,      'onclick', '_toggleValue');
			this.connect(this.italicDivNode,    'onclick', '_toggleValue');
			this.connect(this.underlineDivNode, 'onclick', '_toggleValue');

			// add display handler
			this.connect(this.boldInputNode,      'onchange', '_displayButtonState');
			this.connect(this.italicInputNode,    'onchange', '_displayButtonState');
			this.connect(this.underlineInputNode, 'onchange', '_displayButtonState');
		},


		_disableInactiveElements: function() {
		// summary: disable inactive elements (buttons/inputfields)

			if(this.isSizeVisible=='0') {
				this.fontSizeColumnNode.style.display='none';
			}

			if(this.isSizeInactive=='1') {
				this.fontSizeWidget.domNode.style.display='none';
				this.fontSizeWidget.domNode.disabled=true;
			}
			if(this.isBoldInactive=='1') {
				this.boldDivNode.style.display='none';
				this.boldInputNode.disabled=true;
			}
			if(this.isItalicInactive=='1') {
				this.italicDivNode.style.display='none';
				this.italicInputNode.disabled=true;
			}
			if(this.isUnderlineInactive=='1') {
				this.underlineDivNode.style.display='none';
				this.underlineInputNode.disabled=true;
			}
		},

		_displayButtonState: function() {
		// summary: display button state (pressed, not pressed)

			var me=this;
			var Iterator = function(pair) {
				var ButtonInput=me._inputMapping.get(pair.key);
				var ButtonDiv=me._buttonMapping.get(pair.key);
				if(ButtonInput.value=='1') {
					ButtonDiv.className=ButtonDiv.className.replace('FontAttributeInactiveBox','FontAttributeBox');
				} else {
					ButtonDiv.className=ButtonDiv.className.replace('FontAttributeBox','FontAttributeInactiveBox');
				}
			};
			this._inputMapping.each(Iterator);
		},

		_toggleValue: function(/*Event*/evt) {
		// summary: event handler for button values (bold, italic, underline)
		// description: Toggles between values '0' and '1' of button input fields and throws an onchange event
		//    on the input field. (This triggers the display handler)

			var InputMappingKey=evt.currentTarget.inputmappingkey;
			var InputField=this._inputMapping.get(InputMappingKey);

			// toggle button value
			if(InputField.value=='1') {
				InputField.value='0';
			} else {
				InputField.value='1';
			}

			// throw change event on input field
			epages.event.fire(InputField,"change");
		}
	}
);

}

if(!dojo._hasResource['epages.cartridges.de_epages.design.mcecontent']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.design.mcecontent'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.cartridges.de_epages.design.mcecontent');









epages.cartridges.de_epages.design.MceContent = epages.Class();

epages.cartridges.de_epages.design.MceContent.prototype = {
	/* constants */
	DIALOG_HEIGHT : "400",	// synchronized with .GadgetTable in BackOfficeStyle.css
	DIALOG_WIDTH  : "830",	// synchronized with .GadgetTable in BackOfficeStyle.css
	/* properties */
	navElementId: '',
	contentClass : 'epages.cartridges.de_epages.design.MceContent',
	base64 : new epages.string.Base64,
	preview: '', 						// path to the MBO preview images, e.g.: epages.vars.StoreRoot + '/BO/icons/content_ico_m_navelementgroup_flash.gif
	transparent: epages.vars.StoreRoot + '/BO/icons/general_img_transparentpixel.gif',
	dictionary : new epages.io.Translation(dojo.moduleUrl('epages.cartridges.de_epages.design.widget', "templates/translation"),"auto"),
	title:  'content',
	width : 400,
	height: 400,
	doInsertDom: true,
	form     : undefined,
	group: null,
	formData : $H(),
	directPreview: true,

	initialize: function(options){
		this.save(options);
	},

	updateForm: function() {
		if (this.form !== undefined) {
			this.formData = $H(this.formData);
			(new epages.html.Form(this.form)).set(this.formData,true);
		}
	},

	saveForm: function() {
		if (this.form !== undefined){
			var formElements = this.form.elements;
			for( var i=0,iLength=formElements.length ; i<iLength ; i++ ){
				if(formElements[i].value){
					formElements[i].value = epages.validate.string.filterInvalidChars(formElements[i].value);
				}
			}
			this.formData = (new epages.html.Form(this.form)).get();
		}
	},

	save: function (options) {
		if (options !== undefined) {
			dojo.mixin(this, options);
			this.formData = $H(this.formData);
		}
	},

	info: function () {
		return {
			width        : this.width,
			height       : this.height,
			contentClass : this.contentClass,
			navElementId : this.navElementId,
			formData     : this.formData,
			preview      : this.preview,
			title        : this.title,
			group        : (epages.vars.externalcontent && epages.vars.externalcontent.currentGroupAlias) ? epages.vars.externalcontent.currentGroupAlias : '',
			autostart		 : this.autostart ? this.autostart : '',
			loop				 : this.loop ? this.loop : ''
		};
	},

	toString: function() {
		return "new " + this.contentClass + "(" + $H(this.info()).toString() + ")";
	},

	encodeInfo: function(info) {
		return this.base64.encode($H(info).toString());
	},

	decodeInfo: function(string) {
		var info = eval("(" + this.base64.decode(string) + ")");
		if (info.formData !== undefined){
			info.formData = $H(info.formData);
		}
		return info;
	},

	mceOpenWindow: function (editor_id, groupid) {
		var inst = tinyMCE.editors[editor_id];
		//var focusElm = inst.getFocusElement();
		var focusElm = inst.selection.getNode();

		var wrapper = null;
		// Is selection a image
		if (focusElm != null) {
			if (focusElm.nodeName.toLowerCase() == "img" && tinymce.DOM.getAttrib(focusElm, 'class').indexOf('epItemContent') > -1){
				wrapper = focusElm;
			}
		}

		var template = {};
		if (epages.vars.BaseUrl === undefined){
			epages.vars.BaseUrl = '';
		}
		template['url'] = epages.vars.BaseUrl +'?ViewAction=MBO-ViewPluginEpContent&ObjectID=' + epages.vars.ObjectID;
		if (epages.vars.DefaultParams != null){
			template['url'] += epages.vars.DefaultParams;
		}
		if (wrapper != null) {
		  var ep_info = tinymce.DOM.getAttrib(wrapper, 'ep_info');
			template['url'] += '&ContentData=' + ep_info;
			var navElementId = (this.decodeInfo(ep_info)).navElementId;
			if (navElementId !== undefined){
			  template['url'] += '&NavElementID=' + navElementId;
			}
		}
		if (groupid != null){
			template['url'] += '&GroupID=' + groupid;
		}

		template['width']  = this.DIALOG_WIDTH;
		template['height'] = this.DIALOG_HEIGHT;
		template['scrollbars'] = "yes";
		template['resizable'] = "yes";
		template['title'] = this.dictionary.get("InsertGadget");

		inst.windowManager.open(template, {editor_id : editor_id, inline : "yes", mce_replacevariables:false });
	},

	contentString: function(info) {
		return ['<img src="' + info.preview,
			'width="'  + info.width,
			'height="' + info.height,
			'alt="'    + this.title,
			'title="'  + this.title,
			'/>'
		].join('" ');
	},

	previewString: function(info) {
		var width = (info.width.toString().match(/%/)) ? info.width : info.width+'px';
		var height = (info.height.toString().match(/%/)) ? info.height : info.height+'px';
		return ['<img class="epItemContent',
			'src="' + this.transparent,
			'style="background-image: url('+ info.preview+');height:'+height+'; width:'+width+';"',
			'ep_style="background-image: url('+ info.preview+');height:'+height+'; width:'+width+';"',
			'width="'  + info.width,
			'height="' + info.height,
			'alt="'  + this.title,
			'title="'  + this.title,
			'ep_info="' + this.encodeInfo(info),
			'ep_dom="' + (this.doInsertDom ? 'true' : 'false'),
			'ep_group="' + info.group,
			'/>'
		].join('" ');
	},

	mceInsertContent: function (info) {
		if (info === undefined){
			info = this.info();
		}
		if (typeof (window.ep_InsertContent) == 'function') {
			window.ep_InsertContent(this,info);
		} else {
			var html = this.previewString(info);
			//go back to saved bookmark necessary for ie
			tinyMCE.activeEditor.selection.moveToBookmark(tinymce.WindowManager.bookmark);
			tinyMCE.execCommand("mceInsertContent", true, html);
		}
	},

	parseAttributes : function (string) {
		if (string == null || string.length < 2){
			return {};
		}

		var attributeName = "";
		var attributeValue = "";
		var attributes = {};
		var whiteSpaceRegExp = new RegExp('^[ \n\r\t]+', 'g');

		var withInName = false, withInValue = false;

		for( var i=0,iLength=string.length ; i<iLength ; i++ ) {
			var chr = string.charAt(i);

			if ((chr == '"' || chr == "'") && !withInValue){
				withInValue = true;
			}else if ((chr == '"' || chr == "'") && withInValue) {
				withInValue = false;

				var pos = attributeName.lastIndexOf(' ');
				if (pos != -1){
					attributeName = attributeName.substring(pos+1);
				}

				attributes[attributeName.toLowerCase()] = attributeValue.substring(1);

				attributeName = "";
				attributeValue = "";
			} else if (!whiteSpaceRegExp.test(chr) && !withInName && !withInValue){
				withInName = true;
			}
			if (chr == '=' && withInName){
				withInName = false;
			}
			if (withInName){
				attributeName  += chr;
			}
			if (withInValue){
				attributeValue += chr;
			}
		}

		return attributes;
	},

	mceEditor2String: function (/*String*/content) {
		// replace preview images with epItemContent divs
		var startPos = -1;
		while ((startPos = content.indexOf('<img', startPos+1)) != -1) {
			var endPos = content.indexOf('>', startPos) + 1;
			var attributesString = content.substring(startPos + 4, endPos);
			var attribs = this.parseAttributes(attributesString);
			if (attribs['class'] == "epItemContent") {
				// replace
				var start = content.substring(0, startPos);
				var end   = content.substring(endPos);
				var old   = content.substring(startPos, endPos);
				var info = this.decodeInfo(attribs['ep_info']);
				var object = epages.cartridges.de_epages.design.MceContent.prototype.LOAD(info);
				if (object !== undefined) {
					// ATTENTION: do not change the order of these attributes
					var newString = '<!-- BEGIN_GADGET -->\n<div class="epItemContent ep_info:' + attribs['ep_info'] + '">' + object.contentString(info) + '<'+'/div>\n<!-- END_GADGET -->';
					content = start + newString + end;
				} else {
					startPos = endPos;
				}
			} else {
				startPos = endPos;
			}
		}
		return content; //String
	},

	load: function (domObject) {
		domObject.innerHTML = this.contentString(this.info(), false);
	},

	getIframeDocument: function (domObject) {
		return $E(domObject).getIframeDocument();
	},

	loadPreview: function (domObject) {
		var iframeDoc = this.getIframeDocument(domObject),
			iframeWin = iframeDoc.defaultView,
			bodyNode = iframeDoc.getElementsByTagName('body')[0],
			scriptType,
			scriptContent,
			scripts,
			script;

		if( bodyNode && iframeWin ){
			bodyNode.innerHTML = this.contentString(this.info(), true);

			scripts = bodyNode.getElementsByTagName('script') || [];

			for( var i=0,iLength=scripts.length ; i<iLength ; i++ ){
				script = scripts[i];
				scriptType = dojo.attr( script, 'type' );
				if( !scriptType || /javascript/i.test(scriptType) ){
					scriptContent = script.innerHTML;
					if( scriptContent && /\S/.test( scriptContent ) ){
						(function( scriptContent ){
							var window = iframeWin,
								document = window.document;
							iframeWin['eval'].call( iframeWin, scriptContent );
						})( scriptContent );
					}
				}
			}
		}
		else{
			console.warn('loadPreview: ' + ( iframeWin ? 'iframe body' : 'window object of iframe' ) + ' not found in epages.cartridges.de_epages.design.MceContent');
		}
	},

	saveFormAndLoadPreview: function (domObject) {
		this.saveForm();
		this.loadPreview(domObject);
	},

	saveFormAndMceInsertContent: function () {
		this.saveForm();
		this.mceInsertContent();
	},

	LOAD: function(options) {
		if (options.contentClass === undefined || options.contentClass == '') {
			console.error('cant load object without contentClass.');
			return undefined;
		}
		if (window[options.contentClass] === undefined){
			dojo["require"](options.contentClass.toLowerCase());
		}
		var obj = new(eval(options.contentClass))(options);
		return obj;
	},

	string2Preview:function(content){
		//summary: replace Gadget with place holder for editing
		//regular Expression to find ep_info on old gadget where ep_info was an attribute and on new gadget where ep_info is inside style attribute
		var epInfoRegEx = new RegExp ("<!--\\s*BEGIN_GADGET\\s*-->[\\s\\S]*?<div\\s+(class=\"epItemContent\"\\s+ep_info=\"|class=\"epItemContent ep_info:)(.+?)\"?>[\\s\\S]*?<!--\\s*END_GADGET\\s*-->","mig");
		var regExResult;
		var resultContent = content;
		// while-loop is necessary to find all gadgets inside the content string regExp-object uses internal method do find the next match
		// so we habe to do it till we find the last match
		while((regExResult = epInfoRegEx.exec(content))){
			if(regExResult && regExResult[2]){ //check if new ep_info was found
				var decodedInfo = this.decodeInfo(regExResult[2]);
				var gadgetObject = epages.cartridges.de_epages.design.MceContent.prototype.LOAD(decodedInfo);
				var replaceContent = gadgetObject.previewString(decodedInfo);
				//need  copy of content for correct working RegExp-object while looping through all gadgets inside content
				//replace gadget with preview image
				resultContent = resultContent.replace(regExResult[0],replaceContent);
			}
		}
		return resultContent;
	}
};

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.Navigationelement"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.Navigationelement"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.design.widget.Navigationelement");














epages.cartridges.de_epages.design.widget.Navigation = {
	dndHandler        : undefined,	// epages.cartridges.de_epages.presentation.dragdrop - drag and dro handler

	createElement : function (/*String*/navElementId, /*String*/styleId, /*String*/navBarAlias, /*String*/url, /*String*/navElAlign, /*Boolean*/positioning) {
		// summary:
		//			function to create a new widget
		// description:
		//			load template snippet, initalizes and insert the widget
		// navElementId:
		//			navigation element type id
		// styleId:
		//			ObjectID of current style
		// navBarAlias:
		//			alias of navbar e.g. "Right"
		// url:
		//			request url (default is '?')
		// navElAlign:
		//			alignment of new widget (default is 'left')
		// positioning:
		//			show/hide alignNode of new widget (default is 'false')

		if (url === undefined){
			url = '?';
		}
		if (navElAlign === undefined){
			navElAlign = 'left';
		}
		if (navElAlign!== 'left') {
			navElAlign = 'right';
		}
		var j = new epages.io.Json();
		var output = j.loadSync(url, {
			ChangeAction: 'AddNavElement',
			ChangeObjectID: styleId,
			NavElementID: navElementId,
			NavBarAlias: navBarAlias,
			Alignment: navElAlign.charAt(0).toUpperCase() + navElAlign.slice(1),
			ViewAction: 'JSONNavBarElementSnippet',
			IsEditorNavElements: 1,
			IsEditorModeEnabled: 1
		});
		if(output.error){
			if(output.error.data && output.error.data.Errors) {
				//highjack translations
				hl = epages.cartridges.de_epages.design.widget.Navigationelement.prototype.translate("ErrorCreateNewPageElement");
				tb = epages.cartridges.de_epages.design.widget.Navigationelement.prototype.translate("CreateNewPageElement");
				dojo.publish("uimessage/showErrors", [hl, tb,	output.error.data.Errors]);
			}
			return false;
		}	else if(output.data){
			var navbar = epages.NavBars[output.data.navbarid][3];
			var doc = navbar.ownerDocument;
			var e = doc.createElement("div");
			e.innerHTML = output.data.snippet;
			e.id = 'Element' + output.data.id;
			epages.html.disableHrefsAndActions(e);

			epages.cartridges.de_epages.design.widget.Navigation.getNavBarDelete(doc).appendChild(e);

			var scriptTags = e.getElementsByTagName('script');
			for(var i = 0, iLength = scriptTags.length; i < iLength; i++){
				//eval is needed to execute script for navigation elements that use jquery
				//doc.defaultView is needed to change context of eval to the context of the iframe
				//by using plain eval or new Function the context for the script would be wrong
				doc.defaultView.eval(scriptTags[i].innerHTML);
			}

			var win = (doc.parentWindow) ? doc.parentWindow : doc.defaultView;

			var widgetClass = 'epages.cartridges.de_epages.design.widget.Navigationelement';

			if(win.epages.vars.NavigationElementWidgetTypes) {
				if(win.epages.vars.NavigationElementWidgetTypes[navElementId]) {
					widgetClass = win.epages.vars.NavigationElementWidgetTypes[navElementId];			//catch widget type
					win.dojo["require"](widgetClass);
				}
			}
			widgetClass='win.'+widgetClass;

			var w = new(eval(widgetClass))({
				elementId: e.id,
				objectId: output.data.id,
				navbar: 'Delete',
				isCustomizable: output.data.isCustomizable,
				position: output.data.position,
				alignment: navElAlign,
				doc : doc,
				positioning: positioning
			});
			w.setNavBar(output.data.navbarid);
			return w;
		}
	},
	getNavBarDelete: function( doc ){
		var node = this.getNavBarDelete.node || ( this.getNavBarDelete.node = $('NavBarDelete',doc) );

		if ( !node ) {
			node = this.getNavBarDelete.node = doc.createElement("div");

			node.id = 'NavBarDelete';
			node.style.display = 'none';

			doc.getElementsByTagName("body")[0].appendChild(node);
		}

		return node;
	}
};

dojo.declare(
	"epages.cartridges.de_epages.design.widget.Navigationelement",
	[epages.widget.LocalizedWidget,dijit._Container],
	{
		/**
		 * public properties
		 */
		objectId            : '',           // String - epages objectid of navigation element
		position            : '',           // String - current position in navbar
		alignment						: 'left',				// String - 'left' or 'right' in navbar.
		left 								: 'auto',				// String - pixel value or 'auto' for css property 'left'.
		top 								: 'auto',				// String - pixel value or 'auto' for css property 'top'.
		positioning					: false,				// Boolean - indicates whether to show the alignment/positioning tool.
		navbar              : '',           // String - current navbar identifier
		orientation         : '',           // String - current navbar orientation e.g. UpDown
		elementId           : '',           // String - id of the navigationelement domnode
		storeRoot           : epages.vars.StoreRoot,	// [readonly] String - epages store root path
		undoWidgetId        : 'undoWidget', // String - id of undo widget
		isCustomizable      : '',           // Boolean - indicates weather the navigation element has an edit dialog or not
		url                 : '?',          // String - request url string
		languageId          : epages.vars.Locale.languageId,  // string - current language id
		emptyString         : '',           // String - will be displayed in empty customizable html areas
		doc                 : undefined,    // document - navigation elements document
		reloadOnOrientationChange: false,   // Boolean - indicates weather the html code of an navigation element needs to be reloaded after changing the navbar (some navigation elements use a different html code base for navigation bars with different orientations)
		nameOrAlias         : "",           // String - #NameOrAlias
		_widgetsA           : [],           // Array - list of navelement widgets for each navbar('s left part) (prototype Array)
		_widgetsARight      : [],						// Array - list of navelement widgets for each navbar's right part (prototype Array). Only for horizontal navbars!
		_htmlUndo           : undefined,    // epages.cartridges.de_epages.presentation.widget.Undobuttons - html undo object to register changes
		_inputs             : undefined,    // domnode[] - list of editor inputs in edit dialog (name starts with editor_)
		positionNode        : undefined,  	// domnode - input field to enable undo for position
		alignmentNode				: undefined,		// domnode - input field to enable undo for alignment inside navbar
		leftNode						: undefined,		// domnode - input field to enable undo for setting css property 'left'
		topNode							: undefined,		// domnode - input field to enable undo for alignment setting css property 'top'
		navbarChangeNode    : undefined,    // domnode  - input field to enable undo for navbar
		navElementNode      : undefined,    // domnode - node of the original navigation element
		_navElementNodeCache: undefined,    // hash - caches elementnodes for different navelement views (UpDown/LeftRight)
		_deleteConfirmation : false,        // [readonly] Boolean - flag that indicates weather the delete confirmation dialog will be shown or not (flag source: top.epages.vars.SessionUserDeleteConfirmation)

		/**
		 * widget properties
		 */
		imagePath       : epages.themeUrl('images'),   // String - path to widget image folder
		templateString:"<div style=\"position: relative;\" class=\"NavigationElementWidget\">\n  <div dojoAttachPoint=\"contentNode\"><div dojoAttachPoint=\"replaceNode\"></div></div>\n  <div class=\"ButtonsAndMetainfo\" dojoAttachEvent=\"mouseenter:mouseenter_ButtonAndMetainfo,mouseleave:mouseleave_ButtonAndMetainfo\"><div class=\"Container\">\n    <i dojoAttachPoint=\"deleteNode\" class=\"DeleteNode Sprite ico_s_delete\" title=\"{Delete}\"></i>\n    <i dojoAttachPoint=\"editNode\" class=\"EditNode Sprite ico_s_edit\" title=\"{Edit}\"></i>\n    <i dojoAttachPoint=\"alignNode\" class=\"AlignNode Sprite ico_s_visualaid\" title=\"{Align}\"></i>\n    <span dojoAttachPoint=\"dndNode\"\n         title=\"{Move}\"\n         class=\"DndNode\"\n         ></span>\n  </div></div>\n</div>\n", // String - path to widget template
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget','templates/translation'), // String - path to widget translation

		loadNavBarElement : function (navElementId, styleId, navBarAlias, url) {
		// summary: get and insert navbar element snippet
			if (url === undefined){
				url = '?';
			}
			var j = new epages.io.Json();
			var output = j.loadSync(url, {
				ObjectID: styleId,
				NavElementID: navElementId,
				NavBarAlias: navBarAlias,
				ViewAction: 'JSONNavBarElementSnippet',
				IsEditorNavElements: 1,
				IsEditorModeEnabled: 1
			});

			if(output.error){
				return false;
			} else if(output.data){
				var navbar = epages.NavBars[output.data.navbarid][3];
				var doc = navbar.ownerDocument;
				var e = doc.createElement("div");
				e.innerHTML = output.data.snippet;
				e.id = 'Element' + output.data.id;
				epages.html.disableHrefsAndActions(e);
				return e;
			}
		},

		elementNode : function () {
			// summary:
			//			returns the element domnode which will be moved via dnd
			// description:
			//   		the domnode that will be moved can be the widgets root dom
			//			node or the parent node of the dom node (td-tag)
			return this.orientation == 'UpDown' ? this.domNode : this.domNode.parentNode;		// dom node
		},

		navbarNode : function () {
			// summary:
			//			returns the container node for dnd elements
			return this.elementNode().parentNode;
		},

		elementNodes: function () {
			// summary:
			//			returns all draggable nodes in the current navigation bar
			return dojo.filter(this.navbarNode().childNodes, function (el) { // DomNode[]
				return el.nodeType == 1;
			});
		},

		siblingWidgets: function () {
			// summary:
			//			returns all draggable navbar widgets in the current navigation bar
			//			with *left* alignment
			if (this._widgetsA && this._widgetsA[this.navbar]) {
				return [].concat(this._widgetsA[this.navbar]);
			}
			return []
		},

		siblingWidgetsRight: function () {
			// summary:
			//			returns all draggable navbar widgets in the current navigation bar
			//			with *right* alignment
			if (this._widgetsARight && this._widgetsARight[this.navbar]) {
				return [].concat(this._widgetsARight[this.navbar]);
			}
			return []
		},

		currentIndex: function () {
			// summary: returns the navigation bar index of the element
			return $A(this._widgetsA[this.navbar]).find(this); // Integer
		},

		existsPosition: function (/*integer*/ position, /*integer*/ navbarid, /*string*/ alignment) {
		// summary: check weather the specified position exits in specified navbar
			if (navbarid === undefined){
				navbarid = this.navbar;
			}
			if (alignment === undefined){
				alignment = this.alignment;
			}
			var a = $A(this['_widgetsA' + ((this.alignment === 'right') ? 'Right' : '')][navbarid]).grep(function (el) {
				return parseInt(el.positionNode.value) == position; // Boolean
			});
			return a.length > 0; // Boolean
		},

		postMixInProperties: function() {
		// summary: prepare defaults
			this.inherited("postMixInProperties", arguments);
			if(this.doc === undefined || this.doc == ''){
				this.doc = document;
			}
			if (typeof this.isCustomizable == 'string') {
				this.isCustomizable = epages.string.toBoolean(this.isCustomizable);
			} else {
				this.isCustomizable = this.isCustomizable == 0 ? false : true;
			}
			this._inputs = [];
			this.emptyString = '- '+this.translate('ClickToChangeContent')+' -';
			if(top.epages.vars.SessionUserDeleteConfirmation == 1){
				this._deleteConfirmation = true;
			}
		},

		postCreate  : function() {
			// summary:
			//			prepare navelement widget nodes / events / ...
			this.inherited("postCreate", arguments);

			this.positionNode = this.doc.createElement("input");
			this.positionNode.type  = 'hidden';
			this.positionNode.name  = this.objectId + ':Position';
			this.positionNode.value = this.position;

			this.alignmentNode = this.doc.createElement("input");
			this.alignmentNode.type  = 'hidden';
			this.alignmentNode.name  = this.objectId + ':Alignment';
			this.alignmentNode.value = this.alignment.charAt(0).toUpperCase() + this.alignment.slice(1);

			this.leftNode = this.doc.createElement("input");
			this.leftNode.type  = 'hidden';
			this.leftNode.name  = this.objectId + ':Left';
			this.leftNode.value = this.left;

			this.topNode = this.doc.createElement("input");
			this.topNode.type  = 'hidden';
			this.topNode.name  = this.objectId + ':Top';
			this.topNode.value = this.top;

			this.navbarChangeNode = this.doc.createElement("input");
			this.navbarChangeNode.type  = 'hidden';
			this.navbarChangeNode.name  = this.objectId + ':NavBar';
			this.navbarChangeNode.value = this.navbar;

			// IE fix onchange event
			if (epages.Browser.engine == 'MSIE') {
				this.doc.getElementsByTagName('body')[0].appendChild(this.positionNode);
				this.doc.getElementsByTagName('body')[0].appendChild(this.navbarChangeNode);
				this.doc.getElementsByTagName('body')[0].appendChild(this.alignmentNode);
				this.doc.getElementsByTagName('body')[0].appendChild(this.leftNode);
				this.doc.getElementsByTagName('body')[0].appendChild(this.topNode);
			}

			epages.cartridges.de_epages.design.widget.Navigation.getNavBarDelete(this.doc);

			if (epages.NavBars !== undefined) {
				epages.NavBars['Delete'] = ['Delete', 'UpDown', 'Delete'];
			}
			if (!this.isCustomizable){
				this.editNode.style.display = 'none';
			}
			if (!this.positioning) {
				dojo.query(this.alignNode).orphan();
			}

			// get undo object for add inputs
			if (this._htmlUndo === undefined) {
				var undoWidget = $$(this.undoWidgetId);
				if (undoWidget === undefined) {
					console.warn('undo widget not found in '+this.declaredClass +'. (undoWidgetId = ' + this.undoWidgetId + ')');
				} else {
					this._htmlUndo = undoWidget.getUndoObject();
				}
			}

			// move navelement in my widget
			var element = $(this.elementId,this.doc);
			if (element) {
				$E(this.replaceNode.parentNode).replaceChild(element,this.replaceNode);
			} else {
				console.warn("widget Navigationelement can't find element:" + this.elementId);
			}

			var child = element.firstChild;
			while(child != null && this.navElementNode === undefined) {
				if(child.nodeType==1) {
					this.navElementNode = child;
				}
				child=child.nextSibling;
			}
			if(this.navElementNode){
				this._adjustGeomtry(this.navElementNode);
			}


			// initialize navbar
			if (this.alignment === 'right') {
				if (this._widgetsARight[this.navbar] === undefined){
					this._widgetsARight[this.navbar] = [];
				}
				this._widgetsARight[this.navbar].push(this);
			} else {	// standard = left alignment
				if (this._widgetsA[this.navbar] === undefined){
					this._widgetsA[this.navbar] = [];
				}
				this._widgetsA[this.navbar].push(this);
			}

			if (this._htmlUndo) {
				this._htmlUndo.setDefaultValue(this.positionNode);
				this._htmlUndo.setDefaultValue(this.navbarChangeNode);
				this._htmlUndo.setDefaultValue(this.alignmentNode);
				this._htmlUndo.setDefaultValue(this.leftNode);
				this._htmlUndo.setDefaultValue(this.topNode);
			}

			// add global drag and drop handler if it isn't already added
			if(epages.cartridges.de_epages.design.widget.Navigationelement.dndHandler === undefined) {
				epages.cartridges.de_epages.design.widget.Navigationelement.dndHandler=$DND("NavElements", [], $('Content'));
			}

			var win = (this.doc.parentWindow) ? this.doc.parentWindow : this.doc.defaultView;

			var dndHandler = win.epages.cartridges.de_epages.design.widget.Navigationelement.dndHandler;
			// register widget as drag and drop element
			dndHandler.addElement({
				clickNode: this.dndNode,
				moveNode: this.domNode,
				widget: this,
				onDropInList: function(opt) {
					this.widget.onDropInList(opt);
				},
				onDrop: function () {
					this.widget._resetPosition();
				},
				forceSize: true
			});

			// connect events
			this.connect(this.deleteNode, 'onclick', 'onclickDeleteNode');
			if (this.isCustomizable){
				this.connect(this.editNode, 'onclick', 'onclickEditNode');
			}

			if (epages.NavBars !== undefined) {
				this.connect(this.navbarChangeNode, 'onchange', 'onchangeNavbarChangeNode');
				this.orientation = epages.NavBars[this.navbar][1];
			}

			// In advanced and quick design we reset
			// the *top* and *left* css attributes set by SF-Style.StyleSheet.css
			// and do the *top* and *left* positiong via javascript i.e. the style attribute.
			// This way we can easily update these values without having to regenerate the CSS.
			// see EPG-26482: Possibility to float page elements individually

			// reset top and left css
			var navbarelem = dojo.query('> [id^="Element"]> [class*="NavBarElement"]', this.contentNode)[0];

			if(navbarelem){
				dojo.style(navbarelem, 'left', 'auto');
				dojo.style(navbarelem, 'top', 'auto');
			}

			// init top and left css
			dojo.style(this.domNode, 'left', this.left === 'auto' ? null : this.left + 'px');
			dojo.style(this.domNode, 'top', this.top === 'auto' ? null : this.top + 'px');

			// prepare for orientation change (differnet views of some navelements)
			this.reloadOnOrientationChange = (this.navElementNode && this.navElementNode.className.match("ReloadOnOrientationChange")) ? true : false;
			this._navElementNodeCache = $H();
			this._navElementNodeCache.set(this.orientation, this.navElementNode);
			this.connect(this.positionNode, 'onchange', 'onchangePositionNode');
			this.connect(this.alignmentNode, 'onchange', 'onchangeAlignmentNode');
			this.connect(this.leftNode, 'onchange', 'onchangeLeftNode');
			this.connect(this.topNode, 'onchange', 'onchangeTopNode');
		},

		setNodePosition: function (position) {
			// summary:
			//			set new position
			this.positionNode.value = position;
			if (this._htmlUndo){
				this._htmlUndo.addInput(this.positionNode);
			}
		},

		onchangeLeftNode : function (evt) {
			dojo.stopEvent(evt);
			this.left = this.leftNode.value;
			dojo.style(this.domNode, 'left', this.left === 'auto' ? null : this.left + 'px');
			if (this._htmlUndo){
				this._htmlUndo.addInput(this.leftNode);
			}
		},

		onchangeTopNode : function (evt) {
			dojo.stopEvent(evt);
			this.top = this.topNode.value;
			dojo.style(this.domNode, 'top', this.top === 'auto' ? null : this.top + 'px');
			if (this._htmlUndo){
				this._htmlUndo.addInput(this.topNode);
			}
		},

		onchangeAlignmentNode: function (evt) {
			// summary:
			//			set new alignment
			//			really, this is only ever called by the htmlundo widget.
			dojo.stopEvent(evt);
			this.setNavBar(this.navbar, true, this.orientation,this.alignmentNode.value.toLowerCase());
		},

		onchangePositionNode: function (evt) {
			// summary:
			//			called when position node fired a change / adjusts _widgetsA
			//			and dom node postion
			// tags:
			//			callback
			dojo.stopEvent(evt);

			// remove current (changed)
			var position = parseInt(this.positionNode.value);
			var waArray = $A(this['_widgetsA' + ((this.alignment === 'right') ? 'Right' : '')][this.navbar]);
			var oldlength = waArray.length;
			waArray.remove(waArray.find(this));

			// add changed on right place
			var wa = waArray.grep(function (el) {
				return parseInt(el.positionNode.value) <= position;
			}).concat(this, waArray.grep(function (el) {
				return parseInt(el.positionNode.value) > position;
			}));
			if (oldlength != wa.length){
				console.warn('Widget Navigationelement list changed!! oldlength:' + oldlength +'!= new length:'+ wa.length);
			}
			this['_widgetsA' + ((this.alignment === 'right') ? 'Right' : '')][this.navbar] = wa;

			// correct dom nodes
			for( var i=0,l=wa.length ; i<l ; i++ ) {
				wa[i].navbarNode().appendChild(wa[i].elementNode());
				// renumber classnames
				var className = wa[i].navElementNode.className;
				var className = className.replace(/NavBarElement\d*/,"NavBarElement"+i);
				wa[i].navElementNode.className = className;
			}

			this.adjustNewGhostEol();
		},

		onclickDeleteNode: function (evt) {
		// summary:
		//			called when delete node was clicked / shows a delete confirmation dialog
		// tags:
		//			callback
			dojo.stopEvent(evt);
			if(this._deleteConfirmation){
				var me = this;
				epages.topDojo.publish("uimessage/show", [ this.translate('AcceptDeletePageElement'), "", 'Dialog', {
					titleBar: this.translate('DeletePageElement'),
					typeClass: 'Confirmation',
					buttons: [{
						cssClass: 'Active ep-button ep-button-cta',
						label: '{Delete}',
						onclick: function() {
							me.deleteNavigationElement();
							this._modalDialogWidget.hide();
						}
					},{
						cssClass: 'ep-button ep-button-cancel',
						label: '{Cancel}',
						onclick: function() { this._modalDialogWidget.hide(); }
					}]
				}
				]);
			}	else {
				this.deleteNavigationElement();
			}
		},

		deleteNavigationElement: function(){
		// summary:
		//			move navigation element into delete navigation bar
			this.setNavBar('Delete', false);
			dojo.publish("Navigationelement/DeleteFinished", []);
		},

		setNavBar: function (navbarid, pushOnEnd, orientation, alignment) {
		// summary:
		//			move navigation element into specified navigation bar
			if (this.navbar == navbarid && this.alignment == alignment){
				return;
			}
			if (alignment === undefined) {
				alignment = this.alignment;
			}
			if (pushOnEnd === undefined){
				pushOnEnd = true;
			}
			if (epages.NavBars !== undefined) {
				orientation = epages.NavBars[navbarid][1];
			}

			this._resetPosition();

			// reload element view for different orient (if necessary)
			if(orientation !== this.orientation && this.reloadOnOrientationChange) {
				var el = this._navElementNodeCache.get(orientation);
				if(el === undefined) {
					el = this.loadNavBarElement(this.elementId, this.objectId, epages.NavBars[navbarid][2]);
					if(el !== false){
						// chache element
						this._navElementNodeCache.set(orientation, el);
					}else{
						console.warn('Could not load different view of navigation element');
					}
				}
				// replace domnode
				this.navElementNode.parentNode.replaceChild(el, this.navElementNode);
				// assign new domnode to object property
				this.navElementNode = el;
			}

			var navbar = $('NavBar' + ((navbarid === 'Delete') ? navbarid : (navbarid + ((alignment === 'right') ? 'Right' : ''))), this.doc);
			if (navbar == null && alignment === 'right') {
				console.warn('Element NavBar' + navbarid + ' has no right part.');
				navbar = $('NavBar' + navbarid, this.doc);
				if (navbar) {this.alignment=alignment;}
			}
			if (navbar == null) {
				console.error('Element NavBar' + navbarid + ' not found.');
				return;
			}
			// add to new list
			if (this._widgetsA[navbarid] === undefined){
				this._widgetsA[navbarid] = [];
			}
			if (this._widgetsARight[navbarid] === undefined){
				this._widgetsARight[navbarid] = [];
			}
			var wa = this['_widgetsA' + ((alignment === 'right') ? 'Right' : '')][navbarid];
			var position = parseInt(this.positionNode.value);
			var positionChanged = false;
			if (wa.length) {
				if (!pushOnEnd && this.existsPosition(position, navbarid, this.alignment)){
					pushOnEnd = true;
				}
				if (pushOnEnd) {
					var i = wa.length;
					var last = wa[i - 1];
					var lastPos = parseInt(last.positionNode.value);
					if (position <= lastPos) {
						position = lastPos + 10;
						positionChanged = true;
					}
				}
			}

			// change dom nodes
			if (this.orientation == orientation) {
				$E(navbar).appendChild(this.elementNode());
			} else {
				if (orientation == 'LeftRight') {
					// move from div to tr (add td)
					var td = this.doc.createElement('td');
					$E(navbar).appendChild(td);
					td.appendChild(this.elementNode());
				} else {
					// move from tr to div (remove td)
					var td = this.elementNode();
					$E(navbar).appendChild(this.domNode);
					td.parentNode.removeChild(td);
				}
				this.orientation = orientation;
			}
			if (positionChanged){
				this.positionNode.value = position;
			}
			this.navbarChangeNode.value = navbarid;

			// remove from old list and add to new
			var waOld = this['_widgetsA' + ((this.alignment === 'right') ? 'Right' : '')][this.navbar];
			waOld.splice($A(waOld).find(this), 1);
			wa.push(this);
			this.navbar = navbarid;


			if(!pushOnEnd) {
				// move to correct position (enables buttons also)
				epages.event.fire(this.positionNode,'change');
			}

			// set html elements for undo
			if (this._htmlUndo) {
				if (positionChanged){
					this._htmlUndo.addInput(this.positionNode);
				}
				this._htmlUndo.addInput(this.navbarChangeNode);
					if (this.alignment !== alignment) {
					this.alignment = alignment;
					this.alignmentNode.value = alignment.charAt(0).toUpperCase() + alignment.slice(1);
					this._htmlUndo.addInput(this.alignmentNode);
				}
			}
			dojo.publish('droplistNavBar'+this.navbar+'/change', []);
			if (this.alignment === "right") {
				dojo.publish('droplistNavBar'+this.navbar + 'Right' + '/change', []);
			}



			this.adjustNewGhostEol();
			this.alignment = alignment;
		},

		adjustNewGhostEol: function() {
		// summary: correct position of new ghost (always last domnode)
			var navbarNodes=$('NavBar' + ((this.navbar === 'Delete') ? this.navbar : (this.navbar + ((this.alignment === 'right') ? 'Right' : ''))), this.doc).childNodes;
			for(var el in navbarNodes){
				if(navbarNodes[el] !== undefined && navbarNodes[el].className=="Ghost New"){
					$('NavBar' + ((this.navbar === 'Delete') ? this.navbar : (this.navbar + ((this.alignment === 'right') ? 'Right' : ''))), this.doc).appendChild(navbarNodes[el]);
				}
			}
		},

		onchangeNavbarChangeNode: function (evt) {
		// summary:
		//			called when NavbarChangeNode (idicates an navifation bar change)
		//			changed / adjusts elements navbar assignment and publish droplist
		//			change messages
		// tags:
		//			callback
			dojo.stopEvent(evt);

			this.setNavBar(this.navbarChangeNode.value, false);
			// publish change event to old and new droplists
			if(this.domNode.ep_droplistid) {
				dojo.publish('droplist'+this.domNode.ep_droplistid+'/change', []);
			}
			dojo.publish('droplistNavBar'+this.navbar + '/change', []);
			if (this.alignment === "right") {
				dojo.publish('droplistNavBar'+this.navbar + 'Right' + '/change', []);
			}
			this.domNode.ep_droplistid='NavBar'+this.navbar;
		},

		onDropInList: function(/*Object*/options) {
		// summary:
		//			called by droplist handler / adjust new positon of navigation alement
		// tags:
		//			callback
			var newNavbarid = options.listObject.options.navbarid;
			var newAlignment = options.listObject.options.alignment;
			//var newNavbarid = options.listContainer.options.navbarid;
			var successor = options.insertBefore;

			var isNewNavbar = this.navbar !== newNavbarid;
			if(isNewNavbar || (this.alignment !== newAlignment)) {
				this.setNavBar(newNavbarid, isNewNavbar, undefined,  newAlignment);  // always push to end insert
			}

			var wa = this['_widgetsA' + ((newAlignment === 'right') ? 'Right' : '')][newNavbarid];

			if(successor != null && successor.className!="Ghost New") {
				var successorFound=false;
				for(var w in wa) {
					if(wa[w].domNode === successor) {
						var posPredecessor = (wa[w-1]) ? parseInt(wa[w-1].positionNode.value) : 0;
						var posSuccessor = parseInt(wa[w].positionNode.value);
						var posSuperSuccessor = (wa[w+1]) ? wa[w+1] : parseInt(wa[w].positionNode.value) + 10;
						var posDistance = parseInt((posSuperSuccessor-posPredecessor) / 3);
						var newPosDropped = posPredecessor + posDistance;
						var newPosSuccessor = posPredecessor + 2 * posDistance;
						var successorPositonNode = wa[w].positionNode;

						successorPositonNode.value = newPosSuccessor;
						epages.event.fire(successorPositonNode, 'change');

						this.positionNode.value = newPosDropped;
						epages.event.fire(this.positionNode, 'change');

						if (this._htmlUndo) {
							this._htmlUndo.addInput(successorPositonNode);
							this._htmlUndo.addInput(this.positionNode);
						}

						successorFound=true;
						break;
					}
				}
				if(!successorFound) {
					console.warn("Navigationelement.onDropInList: successor dom node not found");
				}
			} else if(!isNewNavbar) { // insert as last element
					var last = wa[wa.length - 1];
					var lastPos = parseInt(last.positionNode.value);
					this.positionNode.value = lastPos + 10;

					epages.event.fire(this.positionNode, 'change');

					if (this._htmlUndo){
						this._htmlUndo.addInput(this.positionNode);
					}
			}

			// fire click event to select navbar
			epages.event.fire($('NavBar'+this.navbar,this.doc), 'click');

			dojo.publish("Navigationelement/onDropInListFinished", []);
		},

		onclickEditNode: function (evt) {
		// summary:
		//			show dialog for customizable navigation elements
		// tags:
		//			callback
			if (evt !== undefined){
				 dojo.stopEvent(evt);
			}
			if (this._editorWidget === undefined) {   // create new dialog
				this.createEditDialog();
				this.initEditDialog();
			} else {                                  // dialog is already up and running
				this.resetEditDialogInputValues();
			}
			this.onbeforeShowDialog();
			this._editorWidget.show();
		},

		createEditDialog: function() {
		// summary:
		//			create edit dialog for customizable navigation elements
		// description:
		//  		load dialog data and instanciates diaolg within a modal dialog widget
		// tags:
		//			protected

			// load dialog template
			
			var json = new epages.io.Json();
			var result = json.loadSync(this.url, {
				'ViewAction': 'JSONSnippet',
				'TemplateAction': 'EditSnippet',
				'TemplateLanguageID': this.languageId,
				'ObjectID': this.objectId
			});

			// create and setup dialog
			var _navigationElementWidget = this;

			// Create an undo stack for dialogs
			top.epages.html.UnDo.prototype.undoNavigationElementWidgetStack.push(_navigationElementWidget);

			top.dojo["require"]('epages.widget.Modaldialog');
			var newDiv = top.document.createElement('div');												// dialog insert point
			top.document.getElementsByTagName('body')[0].appendChild(newDiv);
			var nameOrAlias = this.nameOrAlias != "" ? ": "+this.nameOrAlias : "";

			this._editorWidget = new top.epages.widget.Modaldialog({
				options:{
					title : _navigationElementWidget.translate('EditNavElement')+nameOrAlias,
					content: result.data.snippet,
					scroll: 'hidden'
				},
				buttons: [{
					cssClass: 'Active ep-button ep-button-cta',
					label: _navigationElementWidget.translate('Apply'),
					onclick: function() {
					// apply function - fire change on hidden element node
						this._modalDialogWidget.hide();
						_navigationElementWidget.applyEditorDialogInputValues();
						dojo.publish("Navigationelement/EditFinished", []);
					}
				}, {
					cssClass: 'ep-button ep-button-cancel',
					label: _navigationElementWidget.translate('Cancel'),
					onclick: function() {
					//cancel action, just hide dialog
						this._modalDialogWidget.hide();
						_navigationElementWidget.resetEditDialogInputValues();
					}
				}]
			}, newDiv);
		},

		initEditDialog: function() {
		// summary:
		//			called after edit dialog was created
		// description:
		//			registers all relevant input elements (inputs starting with "editor_" followed by ObjectID:Attributname:LanguageID e.g. editor_12345:MyAttribute:1)
		// tags:
		//			protected
			var undo = $$(this.undoWidgetId).undoObject;
			var _this = this;
			var iterator = dojo.hitch(this, function (el) {
			// parse dialog inputs, build a copy in parent window and register them to undo widget

				if (el.name === undefined || !el.name.match(/^editor_/)){
					return;		// skip unnamed inputs and inputs wich do not start with "editor_"
				}
				var hid = el.parentNode.ownerDocument.createElement('input');				// create a hidden input element in main window
				hid.name =el.name.substr(7);																				// cut "editor_" away
				hid.type ='hidden';
				hid.value = $E(el).get();																						// e.g. <input type="hidden" name="12345:MyAttribute" value="MyValue" />

				if(el.getAttribute("ep_noundo")=="1") {
					hid.setAttribute("ep_noundo","1");
				}

				var ep_publishmessage = el.getAttribute("ep_publishmessage");
				el.parentNode.appendChild(hid);
				_this._inputs.push({																								// save nodes to this._inputs array
					'editorNode' : el,																								// editor node (edit node in dialog) -> format example: <inupt type="hidden" name="editor_1234:Logo:1" value="myvalue" />
					'hiddenNode' : hid,																								// hidden input node (real value container for undo widget) -> <input type="hidden" name="1234:Logo::1" value="myvalue" />
					'ep_publishmessage' : ep_publishmessage														// pass input message identifier
				});
				undo.registerInput(hid);																						// register the hidden input node to undo widget
				epages.topDojo.connect(hid, 'onchange', _this, 'setPreview');				// connect inputs to preview function
			});

			// make copy because getElementsByTagName will be change during the iterator
			var aCopy = [];
			dojo.forEach(this._editorWidget.domNode.getElementsByTagName("input"), function (el) { aCopy.push(el); });
			dojo.forEach(aCopy, iterator);
			dojo.forEach(this._editorWidget.domNode.getElementsByTagName("select"),   iterator);
			dojo.forEach(this._editorWidget.domNode.getElementsByTagName("textarea"), iterator);
		},

		onbeforeShowDialog: function() {
		// summary:
		//			override function - called before dialog widget is shown
		// tags: callback extension protected
		},


		applyEditorDialogInputValues : function() {
		// summary:
		//			apply editor inputs (this._inputs) to hidden inputs (data storage)

			var _this = this;

			// set timeout because CKE needs some time to write back WYSIWYG data
			window.setTimeout(function(){
				dojo.forEach(_this._inputs, function (el) {
					var value = $E(el.editorNode).get();

					if(el.editorNode.type=='radio' || el.editorNode.type=='checkbox'){ // special handling for radio buttons
						if(el.editorNode.checked == true){
							el.hiddenNode.value = value;
							_this.onbeforePreview(el.hiddenNode);
							epages.event.fire(el.hiddenNode,'change');
						}else{
				            var topLength = top.document.getElementsByName(el.hiddenNode.name).length;
				            var selfLength = document.getElementsByName(el.hiddenNode.name).length;

				            if(((topLength!==undefined)&&(topLength>1)) || ((selfLength!==undefined)&&(selfLength>1))){
				            	el.hiddenNode.value = "";
				            }

				        }
					} else if (el.hiddenNode.value != value) {											// fire only if value is different
						el.hiddenNode.value = value;
						_this.onbeforePreview(el.hiddenNode);
						epages.event.fire(el.hiddenNode,'change');
					}
				}, _this);
			}, 300);
		},

		resetEditDialogInputValues: function() {
		// summary:
		//			reset input values / set values from hiddenNode
		//			(data storage to editor inputs (this._inputs)
		// tags:
		//			protected

			dojo.forEach(this._inputs, function (el) {
				var formElement = $E(el.editorNode);
				var elValue = formElement.get();
				var hiddenValue = el.hiddenNode.value;
				if(elValue != hiddenValue) {		// set value only if changed
					formElement.set(hiddenValue);
					formElement.callOnChange();
				}
			});
		},

		onbeforePreview: function(/*domnode*/ inputNode) {
		// summary:
		//			called before setPreview (change is fired on input node) -
		//			publishes a message on all input that have specified a message
		//			identifier (ep_publishmessage)
		// description:
		//			You may override this function but don't forget to call
		//			this.inherited("onbeforePreview", arguments);
		// inputNode:
		//			input node that has changed in dialog
		// tags:
		//			callback protected extension
			if(inputNode['ep_publishmessage']) {																// publish input specific message before change is fired, pass input node
				dojo.publish(inputNode['ep_publishmessage']+'/beforeChangeFired', [inputNode]);
			}
		},

		setPreview: function(evt) {
		// summary:
		//			update navigation element preview (called onchange: input node)
		// description:
		//      	Update content (texts / file url) of displayed naviagtion elements.
		//      	format example preview nodes: <img id="eid_1234:Logo:1" src="myurl" />
		// tags:
		//			callback protected
			var el = evt.target;																					// get input node (changed content)
			var node = $('eid_' + el.name, this.domNode.ownerDocument);		// get target node
			if (node) {
				var value = el.value == '' ? this.emptyString : el.value;		// get value;
				if(node.nodeName.match(/input|textarea|select/i)) {					// set value to form fields
					node.value = value;
				} else if(node.nodeName.match(/img/i)) {										// set value to image
					node.src=el.value;
				} else {																										// set value as html content
					node.innerHTML = el.value == '' ? this.emptyString : el.value;
					node.innerHTML = epages.cartridges.de_epages.design.MceContent.prototype.string2Preview(node.innerHTML);
					epages.html.disableHrefsAndActions(node);
					this._adjustGeomtry(node);
				}
				jQuery('body').trigger('updatepreview');
			} else {
				// no updates
				console.warn("node '%s' not found, possible not in template ("+this.declaredClass+")", 'eid_' + el.name);
			}
		},

		_adjustGeomtry: function(node) {
		// summary:
		//			adjust gemoetry of the original navigation element / force minimal size
		// tags:
		//			protected
			dojo.removeClass(node, "ForceMinSize");
			var cn = node.className;
			if((node.clientWidth < 11 && node.offsetWidth < 11 ||
					node.clientHeight < 11 && node.offsetHeight < 11) &&
					cn.match("NavigationText")){
					dojo.addClass(node, "ForceMinSize");
			}
		},

		_resetPosition: function() {
		// summary:
		//			reset *top* and *left* values to "auto", if necessary.
		// tags:
		//			protected
			if (this.left !== 'auto') {
				this.leftNode.value = 'auto';
				epages.event.fire(this.leftNode, 'change');
			}
			if (this.top !== 'auto') {
				this.topNode.value = 'auto';
				epages.event.fire(this.topNode, 'change');
			}
		},



		// dojoAttachEvent
		mouseenter_ButtonAndMetainfo: function() {
		// summary:
		//			show ButtonAndMetaInfo layer
		// tags:
		//			callback protected
			var el= this.elementNode();
			if(el && !epages.cartridges.de_epages.design.widget.Navigation.dndHandler) {
				dojo.addClass(el, "SetOver");
			}
		},

		mouseleave_ButtonAndMetainfo: function(evt) {
		// summary:
		//			hide ButtonAndMetaInfo layer
		// tags:
		//			callback protected
			var el_t = evt.target;
			var el_c = evt.currentTarget;
			var el= this.elementNode();
			if(el && el_t === el_c){
				dojo.removeClass(this.elementNode(), "SetOver");
			}
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.design.widget.ToolNewNavElement"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.design.widget.ToolNewNavElement"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/

dojo.provide("epages.cartridges.de_epages.design.widget.ToolNewNavElement");







epages.cartridges.de_epages.design.widget.ToolNewNavElementDialog = undefined;

dojo.declare(
	"epages.cartridges.de_epages.design.widget.ToolNewNavElement",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		objectId        : '', // style id
		navBar          : '', // navbar name
		languageId      : epages.vars.Locale.languageId,// language for snippet
		url             : '?',
		shopId          : epages.vars.SiteID, // shop identifier for feature request
		isAdvancedDesign : false, // If false, the context is QuickDesign. If true, nomen est omen.

		/**
		 * privat properties
		 */
		_disabledUserDefined : false,
		_isScrolling         : false, 				// flag - indcates that scrolling is active at the moment
		_modalDialog         : undefined,

		/**
		 * widget properties
		 */
		templateString:"<div class=\"ToolNewNavElement WithXLIcon\">\n  <div class=\"CommandPane ExtraLarge\" dojoAttachPoint=\"clickNode\" dojoAttachEvent=\"onclick:onOpenClick\">\n    <i class=\"Sprite ico_xl_navelement_new\" title=\"{CreateNewPageElement}\"></i><br />\n    {New}\n  </div>\n</div>\n",
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.design.widget' , 'templates/translation'),
		imagePath       : epages.themeUrl('images'),
		navBarSelectTemplate: '<b class="RightPadding">{InsertElementToArea}</b>',

		insertToNavbar: function(/* string */ navbar, /* string */ alignment) {
			this.navBar = navbar;
			this.alignment = alignment || 'left';
			this.onOpenClick();
		},

		onOpenClick: function (/* event */ evt, /* string? */ highlightArea, /* string? */ selectElement) {
		// summary: open insert dialog (creates and initalizes the dialog content)
		// parameters
		//  evt            passed event object
		//  highlightArea  alias of navbar group e.g. Default (scroll to that area)
		//  selectElement  alias of element e.g. Default

			// hide NavbarSelection if exists
			var nsNode = $('NavbarSelection');
			if(nsNode) {
				nsNode.style.display="none";
			}
			if(this._modalDialog) {
				this._modalDialog.showInnerButtonBar();
			}

			//check UserDefinedNavBarElements Feature and UserDefinedNavBarElementCount
			var json = new epages.io.Json();
			var result = json.loadSync(this.url, {
				'ViewAction': 'JSONGet',
				'Attributes': 'UserDefinedNavBarElementCount',
				'ObjectID'  : this.objectId
			});
			if(!result.error){
				var userDefinedNavBarElementCount = result.data.UserDefinedNavBarElementCount;
			}
			var result = json.loadSync(this.url, {
				'ViewAction': 'JSONGetFeature',
				'Features'  : 'UserDefinedNavBarElements',
				'ObjectID'  : this.shopId
			});
			if(!result.error){
				var userDefinedNavBarElements = result.data.UserDefinedNavBarElements.max;
			}

			// create / open dialog widget
			var widgetFolder = epages.cartridges.de_epages.design.widget;
			if (widgetFolder.ToolNewNavElementDialog === undefined) {
				
				var json = new epages.io.Json();
				var result = json.loadSync(this.url, {
					'ViewAction': 'JSONSnippet',
					'TemplateAction': 'NewNavElementSnippet',
					'TemplateLanguageID': this.languageId,
					'ObjectID': this.objectId
				});
				var w = new epages.widget.Modaldialog({
					'class' : 'ContentNoPadding',
					options:{
						title:   this.translate('CreateNewPageElement'),
						content: result.data.snippet,
						width : 810,
						height: 450,
						scroll: "hidden",  // y, x, scroll
						toolBox: this
					},
					buttons: [{
						cssClass: 'Active ep-button ep-button-cta',
						label: this.translate('Insert'),
						buttonId : 'Insert',
						onclick: function() {
							this._modalDialogWidget.options.toolBox.onNewClick(this._modalDialogWidget.domNode);
						}
					}, {
						cssClass: 'ep-button ep-button-cancel',
						label: this.translate('Cancel'),
						onclick: function() {
							this._modalDialogWidget.options.toolBox.onAbortClick(this._modalDialogWidget.domNode);
						}
					}]
				});
				top.document.body.appendChild(w.domNode);
				widgetFolder.ToolNewNavElementDialog = w;
				this._modalDialog = w;

				// assign events to dialog elements
				var _this = this;
				var navElementLines = dojo.query(".ListRow.ItemLine", w.domNode);						// get all navelement types
				dojo.forEach(navElementLines, function(el) {
					var classname = el.className;
					if(!classname.match("FeatureDisabled")) {
						_this.connect(el, "onclick", "setSelectedNavElement");
					}
				});

				var selectElementLinks = dojo.query(".SelectNavElementGroup", w.domNode);		// get all navelement groups
				dojo.forEach(selectElementLinks, function(el) {
					_this.connect(el, "onclick", "evtSlideToNavElementGroup");
				});

				this.connect(window, "keypress", "onKeypress");
				dojo.subscribe('InsertElementNavbarpreview/select', this, '_selectNavbar');

			} else {
				widgetFolder.ToolNewNavElementDialog.options.toolBox=this;
			}

			// reset form (unselect all checkboxes)
			var newNavElementDialog = widgetFolder.ToolNewNavElementDialog;
			var newform=newNavElementDialog.containerNode.getElementsByTagName("form")[0];
			if(newform){
				newform.reset();
			}

			// highlight navelement group
			if(highlightArea) {
				var groupNo = epages.vars.navElementGroupMapping[highlightArea];
				if(groupNo) {
					this.slideToNavElementGroup(groupNo, 2000);
				}
			} else {
				this.slideToNavElementGroup(0, 500);
			}

			// preselect navelement
			var nodes = dojo.query("[ep_alias="+selectElement+"]", this._modalDialog.domNode);
			dojo.forEach(nodes, function(el) {
				epages.event.fire(el, "click");
				// wait because there is an animation
				window.setTimeout(function(){
					var offTop = el.offsetTop - 90; // 90 = head area hight
					var pNode = el.parentNode;
					offTop = (offTop > 0) ? offTop : 0;
					pNode.scrollTop = offTop;
				}, 100);
			});

			if(userDefinedNavBarElements != null && userDefinedNavBarElementCount != null){
				var userdefinedItems = $('SlideUserDefined');
				var elements = dojo.query("[ep_feature=UserDefinedNavBarElements]", userdefinedItems);

				if(userDefinedNavBarElementCount >= userDefinedNavBarElements){
					//disable
					this._disabledUserDefined = true;
					//disable UserDefined Navbar and add FeatureLimitReached Message
					for( var i=0,iLength=elements.length ; i<iLength ; i++ ){
						dojo.addClass(elements[i], 'FeatureDisabled');
						dojo.removeClass(elements[i], 'EnableHover');
						elements[i].title=this.translate('FeatureLimitReached');
					}
				} else if(this._disabledUserDefined == true){
					this._disabledUserDefined = false;
					//enable UserDefined Navbar and remove FeatureLimitReached message
					for( var i=0,iLength=elements.length ; i<iLength ; i++ ){
						dojo.removeClass(elements[i], 'FeatureDisabled');
						dojo.addClass(elements[i], 'EnableHover');
						elements[i].title='';
					}
				}
			}

			//need Timeout for Position error to avoid wrong position of dialog
			window.setTimeout(dojo.hitch(this,function(){
				newNavElementDialog.show();
			}),1);

		},

		onAbortClick: function(node) {
			this._hideDialog();
		},

		_showNavBarSelectLayer: function() {
			var nsNode = $('NavbarSelection');
			nsNode.style.display="";
			this._modalDialog.hideInnerButtonBar();
		},

		_selectNavbar: function(opt) {
			this.navBar = opt.navbar;
			this._insertNewElement();
		},

		_hideDialog: function() {
			this._modalDialog.hide();
			var nsNode = $('NavbarSelection');
			nsNode.style.display="none";
			this._modalDialog.showInnerButtonBar();
		},

		_insertNewElement : function() {
			this._hideDialog();
			dojo.publish("uimessage/startBusy", ["ToolNewNavElement", this.translate("InsertingPageElement")]);
			var newNavElementDialog = epages.cartridges.de_epages.design.widget.ToolNewNavElementDialog;
			var targetNavBar = this.navBar;
			if(newNavElementDialog.navBarSelectorNode !== undefined && this.navBar == '' && newNavElementDialog.navBarSelectorNode.value){
				targetNavBar = newNavElementDialog.navBarSelectorNode.value;
			}
			var widgets = [];
			var n = epages.cartridges.de_epages.design.widget.Navigation;

			// create new navelement widget
			var el = $('NavelementsAddID');
			var w = n.createElement(el.value, this.objectId, targetNavBar, undefined, this.alignment || 'left', this.isAdvancedDesign ? true : false);
			if(w == false) {
				console.warn('Navelement',this.id,'can not create Element');
				return false;
			} else {
				var starNode = $('ItemStarContainer'+el.value);
				if (starNode) {
					starNode.innerHTML="*";
				}
			}
			if (w.isCustomizable){
				widgets.push(w);
			}

			if (widgets.length == 1){
				widgets[0].onclickEditNode();
			}
			dojo.publish("uimessage/stopBusy", ["ToolNewNavElement"]);
			dojo.publish("ToolNewNavElement/onNewClickFinshed",[]);
		},

		onNewClick:function (node) {
			if(this.navBar != "") {
				this._insertNewElement();
			} else {
				this._showNavBarSelectLayer();
			}
		},

		setSelectedNavElement: function(/* event or string */ evt) {
		// summary: set navelementtype id to hidden input
			var newId = (evt != "") ? evt.currentTarget.getAttribute("ep_objectId") : "";			// event or empty string
			if(evt) {
				dojo.stopEvent(evt);	// don't pass click to body to avoid cssfix updateStyle
			}
			var classname = "";
			if(evt) {
				classname = evt.currentTarget.className;
			}

			var hiddenInputNode = $('NavelementsAddID');
			var oldId = hiddenInputNode.value;
			if(newId == oldId || classname.match("FeatureDisabled")) {  // deselect if its the same value again or feature not allowed
				newId="";
			}

			hiddenInputNode.value=newId;

			var pesaNode = $('PageElementsScrollArea');
			var selNodes = dojo.query(".Selected", pesaNode);

			//remove old selection
			if(selNodes) {
				dojo.forEach(selNodes, function(node) {
					dojo.removeClass(node, "Selected");
				});
			}

			if(newId != "") {
				var newSelectedDiv = $('ListRowPageElement_'+newId);
				dojo.addClass(newSelectedDiv, "Selected");
				this._modalDialog.enableButton("Insert");
			} else {
				this._modalDialog.disableButton("Insert");
			}
		},

		slideToNavElementGroup: function(/* integer */ itemNo , /* integer? */ delay) {
		//summary: slides the screen to specfied page element category
			this._isScrolling = true;
			if(!delay) {
				delay=0;
			}

			//reset selection selection display
			this.setSelectedNavElement("");

			var x = itemNo * 810 * -1;
			var fsblNode = $('FancySidebarLinks');
			var selNodes = dojo.query(".Selected", fsblNode);
			for(var el in selNodes) {
				dojo.removeClass(selNodes[el], "Selected");
			}

			var node = $('SelectNavElementGroup'+itemNo);
			if(node) {
				dojo.addClass(node, "Selected");
			}

			var pesaNode = $('PageElementsScrollArea');
			var listWrapperNodes = dojo.query(".SlideListContent",pesaNode);

			dojo.forEach(listWrapperNodes, function(node) {
				node.style.overflowY="hidden";
			});
			var _this = this;
			dojo.fx.slideTo({
				node: $('PageElementsScrollArea'),
				left: x,
				top: "0",
				unit:"px",
				delay: delay,
				duration: 650,
				easing: dojo.fx.easing.quadOut,
				onEnd: function() {
					dojo.forEach(listWrapperNodes, function(node) {
						node.style.overflowY="auto";
					});
					_this._isScrolling = false;
				}
			}).play();
		},

		evtSlideToNavElementGroup: function(evt)  {
		// summary: catch event props and then start to slide
			dojo.stopEvent(evt);	// don't pass click to body to avoid cssfix updateStyle
			if(!this._isScrolling) {
				var node = evt.currentTarget;
				itemNo = node.getAttribute("ep_groupcount");
				this.slideToNavElementGroup(itemNo);
			}
		},


		onKeypress: function(evt) {
		// summary: keypress event handler
			if(evt.keyCode == dojo.keys.ESCAPE) {		// deselect on ESCAPE
				this.setSelectedNavElement("");
			}
		}

});

}

if(!dojo._hasResource['epages.cartridges.de_epages.design.widget.NavigationelementLogo']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.design.widget.NavigationelementLogo'] = true;
dojo.provide('epages.cartridges.de_epages.design.widget.NavigationelementLogo');



dojo.declare(
	"epages.cartridges.de_epages.design.widget.NavigationelementLogo",
	[epages.cartridges.de_epages.design.widget.Navigationelement],
	{

	initEditDialog : function() {
	//summary:
	//			initalize widgets in dialog / subscribe to topics
		this.inherited("initEditDialog", arguments);
		top.dojo.subscribe('LogoDialogFilebrowser'+this.objectId+'Filelist/select', function(/* FileListItem */ item) {
		// publish generalized message (for use of more than one logo widget)
			dojo.publish("LogoDialogFilebrowserFilelist/select", [item]);
		});

		// subscribe to generalized message
		//dojo.subscribe("LogoDialogFilebrowserFilelist/select", this, 'synchronizeLogo');

		// cut away media gallery path
		/*var filenameNode = top.$('LogoDialogName'+this.objectId);
		var filename = filenameNode.innerHTML;
		filename = filename.replace(/MediaGallery\//, "");
		filenameNode.innerHTML=filename;*/
	},

	synchronizeLogo : function(/* FileListItem */item) {
	// summary:
	//			update logo preview widget, logoname and filesize in dialog
		if(item.fullpath.match("MediaGallery")) {       // only Mediagallery files / skip image db
			var logoPrev = top.$$('LogoDialogPreview'+this.objectId);
			logoPrev.addImage({ image: item.fullpath }, true);

			var lnNode = top.$('LogoDialogName'+this.objectId);
			dojo.addClass(lnNode, "Bold");
			lnNode.innerHTML = item.name;

			var liNode = top.$('LogoDialogInfo'+this.objectId);
			liNode.innerHTML ="("+item.imagewidth + " x "+item.imageheight+" / "+item.size+")";

			var inpNode = top.$('LogoDialogNameInput'+this.objectId);
			inpNode.value=item.fullpath;

			var mNode = top.$('LogoDialogOnApplyMessage'+this.objectId);
			mNode.style.display="";
		}
	},

	onbeforePreview: function(/* domnode */ inputNode) {
	// summary:
	//			shows busylayer before the logo got modified
	// inputNode:
	//			input node that has changed in dialog
		this.inherited("onbeforePreview", arguments);

		var name = inputNode.name;

		if(name.match("Logo")) { // logo name node was changed
			top.dojo.publish("uimessage/startBusy", ["logoPreviewupdate", this.translate("UpdatingLogoPreview")]);

			// do request to generate new logo
			var value = inputNode.value;
			value = value.replace(epages.vars.SiteRoot+'/', "");
			
			var json = new epages.io.Json();

			var result = json.loadSync(this.url, {
				'ChangeAction' : 'SaveLogo',
				'Logo'         : value,
				'ObjectID'     : epages.vars.SiteID,
				'ViewAction'   : 'JSONViewResponse'
			});

			// modify node value (all logos used in style object are named as logo.<old extension>)
			var splitArr = value.split(".");
			var ext = undefined;
			if(splitArr.length) {
				ext = splitArr[splitArr.length-1];
			}

			if(ext) {
				inputNode.value=top.epages.vars.EditorStyleWebPath+'/logo.'+ext;
			}

			if(! top.epages.vars.EditorStyleWebPath) {
				console.warn("top.epages.vars.EditorStyleWebPath not defined in "+this.declaredClass);
			}
		}
	},

	setPreview: function(evt) {
	// summary:
	//			update preview for all logo navelements (onchange: input node)
			var el = evt.target;																					// get input node
			var node = $('eid_' + el.name, this.domNode.ownerDocument);		// get target node

			if(node) {
				var value = el.value == '' ? this.emptyString : el.value;		// get value;
				var NavigationElements = dojo.query('.NavigationElementWidget');
				var logoWidget = undefined;

				for( var i=0,iLength=NavigationElements.length ; i<iLength ; i++ ){
					var navElWidget = $$(NavigationElements[i].id);
					var ShopLogoNodes = dojo.query('.ShopLogo',navElWidget.contentNode);   // has logo?
					if(ShopLogoNodes.length != 0) {
						navElWidget.setLogo(value);

						// reset all filebrowser widgets (open root folder)
						var fileBrowser = top.$$('LogoDialogFilebrowser'+navElWidget.objectId);
						if(fileBrowser) {
							fileBrowser.openRootFolder();
						}

					}
				}
			} else {
				console.warn("node '%s' not found, possible not in template ("+this.declaredClass+")", 'eid_' + el.name);
			}
			top.dojo.publish("uimessage/stopBusy", ["logoPreviewupdate", 1500]);
		},

		setLogo : function(/* string */ value) {
		// summary:
		//			set src attribute of logo node
			var logoNode = $('eid_'+this.objectId+':Logo:'+this.languageId);
			if(logoNode) {
				var date = new Date();
				logoNode.src=value+'?CachePrevention='+date.getTime();
			} else {
				console.warn('logo node not found in '+this.declaredClass);
			}
		}

});

}

if(!dojo._hasResource['epages.cartridges.de_epages.design.widget.NavigationelementIcon']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.design.widget.NavigationelementIcon'] = true;
dojo.provide('epages.cartridges.de_epages.design.widget.NavigationelementIcon');


dojo.declare(
	"epages.cartridges.de_epages.design.widget.NavigationelementIcon",
	[epages.cartridges.de_epages.design.widget.Navigationelement],
	{

	_ICON_SIZES : ['S', 'M', 'L', 'XL'],	// array - array with possible icon size stings

	setPreview: function(evt) {
	// summary:
	//			update preview of icon
			var el = evt.target;																					// get input node
			var node = $('eid_' + el.name, this.domNode.ownerDocument);		// get target node
			if (node) {
				for(var e in this._ICON_SIZES) {
					dojo.removeClass(node, this._ICON_SIZES[e])
				}
				dojo.addClass(node, el.value);
			} else {
				// no updates
				console.warn("node '%s' not found, possible not in template ("+this.declaredClass+")", 'eid_' + el.name);
			}
		}

});

}

if(!dojo._hasResource['epages.event.selectables']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.event.selectables'] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide('epages.event.selectables');





epages.event.Selectables = epages.Class();

epages.event.Selectables.prototype = {
	selectables:        undefined,
	currentSelected:    undefined,
	currentHighlighted: undefined,
	callback:           undefined,
	strHighlighted: 'Highlighted',
	strUnselected:  'Unselected',
	strSelected:    'Selected',
	selectionGuides : undefined,

	initialize: function(/*ArrayLike*/enumselectables, doc) {
		if(doc === undefined){
			doc = document;
		}
		var win = epages.getDocumentWindow(doc);
		if (this.selectables === undefined){
			this.selectables = new Array();
		}
		var sel = this.selectables;
		var existsUndefined = -1;
		var counter = -1;
		this.selectionGuides = {};

		this.selectionGuides.North = doc.createElement("div");
		this.selectionGuides.South = doc.createElement("div");
		this.selectionGuides.West  = doc.createElement("div");
		this.selectionGuides.East  = doc.createElement("div");
		for(var item in this.selectionGuides) {
			var div = this.selectionGuides[item];
			div.className="SelectionGuide "+item;
			doc.getElementsByTagName("body")[0].appendChild(div);
		}

		$A(enumselectables).each(function(el) {
			counter++;
			if (el) {
				sel.push(el);

					var contentDiv = win.dojo.query(".ContentAreaInner", el)[0];
					var effectLayer = el.ownerDocument.createElement("div");
					effectLayer.className = "EffectLayer";

					if(el.tagName.toLowerCase() == "td") {
						effectLayer.style.marginLeft = "-" + el.getElementsByTagName("div")[0].offsetLeft + "px";
						effectLayer.style.marginTop = "-" + el.getElementsByTagName("div")[0].offsetTop + "px";
					}

					if(contentDiv && epages.Browser.engine == "MSIE" || el.attributes["class"].nodeValue.indexOf("ContentArea") > -1 && el.tagName.toLowerCase() == "div"){
						el.style.position = "relative";
						dojo.style(effectLayer, {
							left : "0",
							top  :"0",
							marginLeft : "0",
							marginTop  : "0"
						});
					}
					el.insertBefore(effectLayer, el.firstChild);

					//ugly way to check if element has been resized...do not have a better idea for now
					var tempResizeCheck = function() {
						if(parseInt(effectLayer.style.height) != el.offsetHeight) {
							effectLayer.style.height = el.offsetHeight + "px";
						}
						if(parseInt(effectLayer.style.width) != el.offsetWidth) {
							effectLayer.style.width = el.offsetWidth + "px";
						}
					};

					dojo.connect(window, "resize", tempResizeCheck);
					dojo.subscribe('selectables/SetSelectionGuidelines',tempResizeCheck);
			}else if (existsUndefined == -1) {
				existsUndefined = counter;
			}
		});
		if (existsUndefined != -1){
			console.warn('element ' + existsUndefined + ' is not defined and can\'t be selected');
		}
		dojo.connect(window, "resize", this,"setSelectionGuides");
		dojo.connect($("EmbeddedStorefront"), "resize", this, "setSelectionGuides");

		this.preparePage();
	},

	unselect: /*void*/function(/*HTMLElement*/sel) {
		var className = sel.className.replace(this.strHighlighted,this.strUnselected).replace(this.strSelected,this.strUnselected);
		if ( !className.match( this.strUnselected )){
			className += ' ' + this.strUnselected;
		}
		sel.className = className;
	},

	reEnterElement: /*void*/function (/*HTMLElement*/sel) {
		this.unselect(sel);
		this.appendEvents(sel);
		if(sel == this.currentSelected){
			this.currentSelected = undefined;
		}
		this.selectables.push(sel);
	},

	destroy: /*void*/function () {
		for( var i=0,l=this.selectables.length ; i<l ; i++ ) {
			var className = this.selectables[i].className;
			[this.strHighlighted, this.strUnselected, this.strSelected].each(function (str) {
				className.replace(str,'');
			});
			this.selectables[i].className = className;
		}
	},

	appendEvents: /*void*/function(/*HTMLElement*/sel) {
		if(sel.tagName == "BODY" && epages.Browser.engine == "MSIE") {
			sel.onmouseover = function() {
				this.setCapture();
			};
			sel.onmouseout = function() {
				this.releaseCapture();
			};
		}
		dojo.connect(sel, 'onmouseover', this, 'onMouseOver');
		dojo.connect(sel, 'onmousedown', this, 'onClick');
		dojo.connect(sel, 'onclick', this, 'onClick');
	},

	preparePage: /*void*/function() {
		for( var i=0,l=this.selectables.length ; i<l ; i++ ) {
			var sel = this.selectables[i];
			this.unselect(sel);
			this.appendEvents(sel);
		}
	},

	onMouseOver: /*void*/function(/*Event*/evt) {
		dojo.stopEvent(evt);
		if(!$("EmbeddedStorefront").contentWindow.epages.html.getElementsByClassName("IsDragging", evt.currentTarget)[0]) {
			var newHighlighted = evt.currentTarget;
			if(!this.oldHighlighted) {
				this.oldHighlighted = newHighlighted;
			}
			if(this.oldHighlighted != newHighlighted) {
				epages.html.replaceClass(this.oldHighlighted, this.strUnselected, this.strHighlighted);
				epages.html.replaceClass(newHighlighted, this.strHighlighted, this.strUnselected);
				this.oldHighlighted = newHighlighted;
			}
		}
	},

	onClick: /*void*/function(/*Event*/evt) {
		dojo.stopEvent(evt);
		var newSelected = evt.currentTarget;
		if(newSelected != this.currentSelected) {
			var oldSelected = this.currentSelected;
			if (oldSelected !== undefined) {
				epages.html.replaceClass(oldSelected, this.strUnselected, this.strSelected);
				epages.html.replaceClass(oldSelected, this.strUnselected, this.strHighlighted);
			}
			epages.html.replaceClass(newSelected, this.strSelected, this.strUnselected);
			epages.html.replaceClass(newSelected, this.strSelected, this.strHighlighted);
			this.currentSelected = newSelected;
			if (this.callback !== undefined){
				this.callback(oldSelected, newSelected, evt);
			}
			this.setSelectionGuides();
		}
	},

	setSelectionGuides: function() {
		if(this.currentSelected) {
			var el = $E(this.currentSelected);
			var pos = el.getAbsolutePosition();

			pos.width = this.currentSelected.offsetWidth;
			pos.height = this.currentSelected.offsetHeight;

			//insert some jquery magic because dojo magic is calcuating wrong in this case
			var posJq = jq(this.currentSelected).offset();
			pos.x = posJq.left;
			pos.y = posJq.top;

			pos.x2 = pos.x + pos.width -1;
			pos.y2 = pos.y + pos.height -1;

			this.selectionGuides.East.style.top = pos.y+"px";
			this.selectionGuides.East.style.height = pos.height+"px";
			this.selectionGuides.East.style.left = pos.x+"px";

			this.selectionGuides.West.style.top = pos.y+"px";
			this.selectionGuides.West.style.height = pos.height+"px";
			this.selectionGuides.West.style.left = pos.x2+"px";

			this.selectionGuides.North.style.top = pos.y+"px";
			this.selectionGuides.North.style.width = pos.width+"px";
			this.selectionGuides.North.style.left = pos.x+"px";

			this.selectionGuides.South.style.top = pos.y2+"px";
			this.selectionGuides.South.style.width = pos.width+"px";
			this.selectionGuides.South.style.left = pos.x+"px";
		}
		dojo.publish('selectables/SetSelectionGuidelines');
	}
};

}

if(!dojo._hasResource['epages.event.displaydispatcher']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.event.displaydispatcher'] = true;
/*  EPages DesignToolbars JavaScript module
 *  (c) 2006 ePages GmbH
 *--------------------------------------------------------------------------
 */
dojo.provide('epages.event.displaydispatcher');



epages.event.DisplayDispatcher = function() {};

epages.event.DisplayDispatcher.prototype = {
	currentActiveID   : undefined,

	add: function(slaveID, masterClassName, doc) {
	  var doc = doc || dojo.doc;
	  var win = epages.getDocumentWindow(doc);
	  if (masterClassName == null) {
	  	// no class given => body
			var firstMaster = doc.body;
		} else {
			// find first node with given class
			var firstMaster = win.dojo.query("." + masterClassName, doc.body)[0];
		}
		if(firstMaster) {
			var me = this;
			var eventListenerCallback = function (evt) {
				dojo.stopEvent(evt);
				me.switchTo(slaveID);
			};
			if (firstMaster.addEventListener) {
				// W3C
				firstMaster.addEventListener("click", eventListenerCallback, false);
			} else {
				// IE
				firstMaster.attachEvent("onclick", eventListenerCallback);
			}
		}
	},

	switchTo: function(slaveID) {
		if(this.currentActiveID != slaveID) { // switch only if a different area is shown
			var s = $(slaveID);

			if (typeof (s.show) == 'function'){
				s.show();
			}
			else if(dojo.hasClass(s, 'NavBarInvisible')) {
				// if first child is a comment, then insert as innerHTML and parse it
				if (s.firstChild.nodeType == 8) {
					// using timeout for quicker and smoother fadein
					window.setTimeout(function() {
						s.innerHTML = s.firstChild.data;
						dojo.parser.parse(s);
						var navBarName = slaveID.replace(/^Tools(?:NavBar)?/i, '');
						dojo.publish('displaydispatcher/onCreateToolbar', [navBarName, s]);
					}, 1);
				}
			  epages.html.replaceClass(s, 'NavBarVisible', 'NavBarInvisible');
			}else{
				s.style.display = "block";
			}

			if (this.currentActiveID !== undefined) {
				var c = $(this.currentActiveID);
				if (typeof (c.hide) == 'function'){
					c.hide();
				}else if(dojo.hasClass(c, 'NavBarVisible')) {
				  epages.html.replaceClass(c, 'NavBarInvisible', 'NavBarVisible');
				}else{ 
					c.style.display = "";
				}
			}
			this.currentActiveID=slaveID;
		}
		top.dojo.publish('displaydispatcher/switchTo', [slaveID]);
	}
};

}


/* package: ep_calendar.js.uncompressed */
/*
	Copyright (c) 2004-2011, The Dojo Foundation All Rights Reserved.
	Available via Academic Free License >= 2.1 OR the modified BSD license.
	see: http://dojotoolkit.org/license for details
*/

/*
	This is an optimized version of Dojo, built for deployment and not for
	development. To get sources and documentation, please visit:

		http://dojotoolkit.org
*/

if(!dojo._hasResource["epages.cartridges.de_epages.calendar.widget.Appointment"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.calendar.widget.Appointment"] = true;
dojo.provide("epages.cartridges.de_epages.calendar.widget.Appointment");



dojo.declare(
	"epages.cartridges.de_epages.calendar.widget.Appointment",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */

		Alias:          '',
		AddressInfo:    '',
		ContactInfo:    '',
		ProductInfo:    '',
		StartDate:      '',
		EndDate:        '',
		StartDate_Time: '',
		EndDate_Time:   '',
		objectId:       '', // AppointmentId
		productId:      '',
		_StartDateTime: '',
		_EndDateTime: 	'',
		url:            '?',
		/**
		 * dojo widget properties
		 */
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.calendar.widget','templates/translation'),
		templateString:"<span>${AddressInfo.Company} ${AddressInfo.FirstName} ${AddressInfo.LastName}</span>\n",

		postMixInProperties: function () {
			this.inherited('postMixInProperties',arguments);
			// select template
			if (this.AddressInfo == '') {
				this.AddressInfo = this.translate('EMPTY_ADDRESS');
			}
			var pad = dojo.string.pad;
			var start = dojo.date.stamp.fromISOString(this.StartDate);
			this._StartDateTime = pad(start.getHours(),2) + ':' + pad(start.getMinutes(),2);
			var end = dojo.date.stamp.fromISOString(this.EndDate);
			this._EndDateTime = pad(end.getHours(),2) + ':' + pad(end.getMinutes(),2);
		},

		postCreate: function(){
			this.inherited('postCreate',arguments);
			if(this.AddressInfo){
				if(this.AddressInfo.CancelledOn){
					dojo.addClass(this.domNode,'Cancelled');
				}
				if(this.AddressInfo.AcceptedOn){
					dojo.addClass(this.domNode,'Accepted');
				}
			}
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.calendar.widget.Appointmenttimeitem"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.calendar.widget.Appointmenttimeitem"] = true;
dojo.provide("epages.cartridges.de_epages.calendar.widget.Appointmenttimeitem");




dojo.declare(
	"epages.cartridges.de_epages.calendar.widget.Appointmenttimeitem",
	[epages.widget.LocalizedWidget],
	{

		/**
		 * public properties
		 */
		objectId:       '', // CalendarId
		productId:      '',
		StartDate:      '',
		EndDate:        '',
		IsBusiness:			'',
		IsBookingHours: '',
		_StartDateTime: '',
		Appointments:   [],
		url:            '?',
		isinactive:			'0',
		availableQuantity: '',

		/**
		 * dojo widget properties
		 */
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.calendar.widget','templates/translation'),
		templateString:"<tr class=\"AppointmentItem Small\">\n  <td class=\"Time\">${_StartDateTime}</td>\n  <td class=\"NumberOfDates\" dojoAttachPoint=\"numberOfDatesNode\"></td>\n  <td class=\"BookedBy\" dojoAttachpoint=\"appointmentsNode\"></td>\n</tr>\n",
		widgetsInTemplate:true,

		postMixInProperties: function () {
			this.inherited('postMixInProperties',arguments);
			var pad = dojo.string.pad;
			var start = dojo.date.stamp.fromISOString(this.StartDate);
			this._StartDateTime = pad(start.getHours(),2) + ':' + pad(start.getMinutes(),2);
		},

		postCreate: function () {
			// summary: Create instance of an Appointmentitem.
			// description: This method is used to show the list of booked resources for one day when
			// mouse-overed a day in the appointment list. To show the number of booked appointment slots
			// for this day, all booked appontments are traversed and the quantity of booked slots is
			// summed up.
			// Then the name and status of each booked appointment is listed which results in the appropiate
			// dom nodes. A dom node is marked as overbooked if more slots were booked for the day than
			// available (which is set by the stock value for the resource product).
			this.inherited('postCreate',arguments);

			// calculate sum of used slots
			var sumQuantities = 0.0;
			for( var i=0,l=this.Appointments.length ; i<l ; i++ ) {
				sumQuantities += parseFloat(this.Appointments[i].Quantity);
			}

			// create overview list
			for( var i=0,l=this.Appointments.length ; i<l ; i++ ) {
				var d = this.Appointments[i];
				d.productId = this.productId;
				d.url = this.url;
				// if number of used slots is higher than number of available ones, mark as overbooked
				if(sumQuantities > parseFloat(this.availableQuantity)){
					dojo.addClass(this.domNode,'Overbooked');
				}
				var w = new epages.cartridges.de_epages.calendar.widget.Appointment(d);
				// if any appointments for this time, list them
				if(i>0) {
					var s = document.createTextNode(", ");
					$(this.appointmentsNode).appendChild(s);
				}
				$(this.appointmentsNode).appendChild(w.domNode);
			}
			if (this.isinactive == '1') {
				if (this.inactiveNode != undefined){
					this.inactiveNode.style.display = '';
				}
				if (this.activeNode != undefined){
					this.activeNode.style.display = 'none';
				}
			}
			if(this.numberOfDatesNode){
				this.numberOfDatesNode.innerHTML = sumQuantities + ' / ' +this.availableQuantity;
			}
		}
	}
);

}

if(!dojo._hasResource["epages.cartridges.de_epages.calendar.widget.Appointmentcalendar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.calendar.widget.Appointmentcalendar"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.calendar.widget.Appointmentcalendar");








dojo.declare(
	"epages.cartridges.de_epages.calendar.widget.Appointmentcalendar",
	epages.widget.Calendar,
	{

		/**
		 * public properties
		 */
		objectId: '', // CalendarId
		productId: '',
		datastoreId: 'Datastore',
		waitForFloating: '500',
		availableQuantity: '',
		requestedQuantity: '',
		requestedMinutes: '',

		url: '?',
		classNames: null,
		appointmentClassNames: {
			'IsLocked': 'Locked',
			'IsUsed'  : 'Used',
			'IsBusy'  : 'Busy'
		},

		_appListSmallTemplateString :	'<div class="AppointmentListSmall"><table><thead>'
			+'	<tr class="AppointmentItem Small">'
			+'		<th class="Time">{Time}</td>'
			+'		<th class="NumberOfDates">{NumberOfDates}</td>'
			+'		<th class="BookedBy">{BookedBy}</td>'
			+'	</tr></thead>'
			+'<tfoot></tfoot><tbody><tr class="NoDates"><td colspan="3">{NoDates}</td></tbody></table></div>',

		_timeoutShortList: undefined, // _onOver, _onOut, resetTimeouts
		_timeoutListDate: undefined,  // _onOver, _onOut, resetTimeouts
		_visibleFloating: undefined,  // _onOver, _onOut, resetTimeouts
		_visibleOverview: undefined,  // _onClick

		_dictionary: undefined,

		_dateFormats: null,
		_datastore: undefined,
		_monthMoveCount: undefined,
		_moveCountInterval: undefined,

		postMixInProperties: function () {
			this.inherited('postMixInProperties',arguments);
			this.classNames= [];
			this._dateFormats = {};
			this._monthMoveCount = {
				step: 0,
				amount: ''
			};
			for(var name in this.appointmentClassNames) {
				if (this.classNames[name] === undefined){
					this.classNames[name] = this.appointmentClassNames[name];
				}
			}
			if($$(this.datastoreId)){
				this._datastore = $$(this.datastoreId);
			}
			// prepare template
			
			this._dictionary = new epages.io.Translation(dojo.moduleUrl('epages.cartridges.de_epages.calendar.widget', "templates/translation"), "auto");
			this._appListSmallTemplateString = this._dictionary.replaceLanguageTags(this._appListSmallTemplateString);
		},

		postCreate: function () {
			this.inherited('postCreate',arguments);
			this.connect(this.domNode, "onmouseover", "_onOver");
			this.connect(this.domNode, "onmouseout",  "_onOut");
			this.connect(this.domNode, "onmousedown", "_onClick");
			//change connects for increment/decrement month/year to avoid errors with reloaded content
			this.connect(this.incrementMonth ,"onmousedown", function(){
				this._countMonthMoves('month',1);
			});
			this.connect(this.incrementMonth ,"onmouseup", '_doMonthMoves');
			this.connect(this.decrementMonth ,"onmousedown", function(){
				this._countMonthMoves('month', -1);
			});
			this.connect(this.decrementMonth ,"onmouseup", '_doMonthMoves');
			this.connect(this.nextYearLabelNode ,"onclick", function(){
				this._adjustDisplay('year', 1);
			});
			this.connect(this.previousYearLabelNode ,"onclick", function(){
				this._adjustDisplay('year', -1);
			});
		},

		_countMonthMoves: function(amount,step){
			this._addMonthStep(amount,step);
			this._moveCountInterval = window.setInterval(dojo.hitch(this,function(amount,step){
				this._addMonthStep(amount,step);
			},amount,step),500);
		},

		_doMonthMoves: function(){
			window.clearInterval(this._moveCountInterval);
			this._adjustDisplay(this._monthMoveCount.amount, this._monthMoveCount.step);
			this._monthMoveCount.amount = '';
			this._monthMoveCount.step = 0;
		},

		_addMonthStep:function(amount,step){
			this._monthMoveCount.amount = amount;
			this._monthMoveCount.step = this._monthMoveCount.step + step;
			var month = dojo.date.add(this.displayMonth, this._monthMoveCount.amount, this._monthMoveCount.step);
			// Fill in localized month name
			var monthNames = dojo.date.locale.getNames('months', 'wide', 'standAlone', this.lang);
			this._setText(this.monthLabelNode, monthNames[month.getMonth()]);
		},

		_onReceiveRequest: function (result) {
			if(!result){
				return false;
			}
			var pad = dojo.string.pad;
			dojo.query(".dijitCalendarDateLabel", this.domNode).forEach(function(label, i){
				var node = this._dateNode(label);
				if(node){//in some wired cases node can be undefined
					var nodeDate = new Date(node.dijitDateValue);
					var datekey = [pad(nodeDate.getFullYear(), 4), pad(nodeDate.getMonth() + 1, 2), pad(nodeDate.getDate(), 2)].join("-");
					var dateData = result[datekey+'T00:00:00'];
					for(var key in dateData) {
						if(this.classNames[key]){
							if (dateData[key] == 1) {
								dojo.addClass(node, this.classNames[key]);
							} else {
								dojo.removeClass(node, this.classNames[key]);
							}
						}
					}
				}
			}, this);
		},

		_originalPopulateGrid: function(){
			var month = this.displayMonth;
			month.setDate(1);
			var firstDay = month.getDay();
			var daysInMonth = dojo.date.getDaysInMonth(month);
			var daysInPreviousMonth = dojo.date.getDaysInMonth(dojo.date.add(month, "month", -1));
			var today = new Date();
			var selected = this.value;

			var dayOffset = dojo.cldr.supplemental.getFirstDayOfWeek(this.lang);
			if(dayOffset > firstDay){ dayOffset -= 7; }

			// Iterate through dates in the calendar and fill in date numbers and style info
			dojo.query(".dijitCalendarDateTemplate", this.domNode).forEach(function(template, i){
				i += dayOffset;
				var date = new Date(month);
				var number, clazz = "dijitCalendar", adj = 0;

				if(i < firstDay){
					number = daysInPreviousMonth - firstDay + i + 1;
					adj = -1;
					clazz += "Previous";
				}else if(i >= (firstDay + daysInMonth)){
					number = i - firstDay - daysInMonth + 1;
					adj = 1;
					clazz += "Next";
				}else{
					number = i - firstDay + 1;
					clazz += "Current";
				}

				if(adj){
					date = dojo.date.add(date, "month", adj);
				}
				date.setDate(number);

				if(!dojo.date.compare(date, today, "date")){
					clazz = "dijitCalendarCurrentDate " + clazz;
				}

				if(!dojo.date.compare(date, selected, "date")){
					clazz = "dijitCalendarSelectedDate " + clazz;
				}

				if(this.isDisabledDate(date, this.lang)){
					clazz = "dijitCalendarDisabledDate " + clazz;
				}

				template.className =  clazz + "Month dijitCalendarDateTemplate";
				template.dijitDateValue = date.valueOf();
				var label = dojo.query(".dijitCalendarDateLabel", template)[0];
				this._setText(label, date.getDate());
			}, this);

			// Fill in localized month name
			var monthNames = dojo.date.locale.getNames('months', 'wide', 'standAlone', this.lang);
			this._setText(this.monthLabelNode, monthNames[month.getMonth()]);

			// Fill in localized prev/current/next years
			var y = month.getFullYear() - 1;
			var d = new Date();
			dojo.forEach(["previous", "current", "next"], function(name){
				d.setFullYear(y++);
				this._setText(this[name+"YearLabelNode"], d.getFullYear() );
			}, this);
		},

		_populateGrid: function (days) {
			this.inherited('_populateGrid', arguments);
			this._originalPopulateGrid();
			this.displayMonth.setMinutes(0);
			this.displayMonth.setSeconds(0);
			this.displayMonth.setHours(0);
			if(this._datastore){
				this._onReceiveRequest(this._datastore.getDateFormats({
					objectId  : this.objectId,
					startDate : this.displayMonth,
					endDate   : dojo.date.add(this.displayMonth, "day", dojo.date.getDaysInMonth(this.displayMonth)),
					available : this.availableQuantity,
					requested : this.requestedQuantity,
					requestedMinutes : this.requestedMinutes
				}));
			}
		},

		resetTimeouts: function() {
			clearTimeout(this._timeoutShortList);
		},

		_onOver: function (evt) {

			this.resetTimeouts();
			var dateNode = this._dateNode(evt.target);
			if (!dateNode){
				return;
			}
			this._timeoutListDate = dateNode.dijitDateValue;
			var x = evt.clientX + document.documentElement.scrollLeft;
			var y = evt.clientY + document.documentElement.scrollTop;
			this._timeoutShortList = setTimeout(epages.lang.hitch(this, this.showShortList, [dateNode, x, y]), Number(this.waitForFloating));
		},

		_onOut: function (evt) {
			this.resetTimeouts();
		},

		_onClick: function (evt) {
			this.resetTimeouts();

			var dateNode = this._dateNode(evt.target);
			if (!dateNode){
				return;
			}
			var dateString = dateNode.dijitDateValue;
			dojo.publish(this.id+'/select',[{date: new Date(dateString)}]);
		},

		findDateElement: function (dateString) {
			var dateNode = null;
			dojo.query(".dijitCalendarDateLabel", this.domNode).forEach(function(label, i){
				var node = this._dateNode(label);
				if (node.dijitDateValue == dateString){
					dateNode = node;
				}
			});
			return dateNode;
		},

		loadLists: function(dateString, listName) {
			if ($(listName +'_' + dateString) == null) {
				// load data from datastore
				var data = this._datastore.getDayList(new Date(Number(dateString)));

				// create floating list
				// for positioning var dateTd = this.findDateElement(dateString);
				var floatingDiv = document.createElement('div');
				floatingDiv.id = 'floating_' + dateString;
				floatingDiv.style.display = 'none';
				floatingDiv.className="AppointmentListSmallWrapper";
				floatingDiv.innerHTML=this._appListSmallTemplateString;

				$(this.domNode.parentNode).insertBefore(floatingDiv, this.domNode);

				// fill lists with data
				// filelist.setChildren(data);
				var e,d;
				for( var i=0,l=data.length ; i<l ; i++ ) {
					d = data[i];
					d.objectId = this.objectId;
					d.productId  = this.productId;
					d.url = this.url;
					d.isinactive = (dojo.date.stamp.fromISOString(d.EndDate) < new Date()) ? '1' : '0';
					d.availableQuantity = this.availableQuantity;

					if (d.IsBusiness || d.Appointments.length > 0) {
						e = document.createElement('tr');
						floatingDiv.getElementsByTagName("tbody")[0].appendChild(e);
						new epages.cartridges.de_epages.calendar.widget.Appointmenttimeitem(d, e);
					}
				}

				// remove NoDates node if empty
				var tbody=floatingDiv.getElementsByTagName("tbody")[0];
				if(tbody.lastChild.className != "NoDates" ){
					tbody.removeChild(tbody.firstChild);
				}

			}
		},

		showShortList: function(dateNode, x,y) {
			oldTooltip = $$(this._visibleFloating);

			this.loadLists(this._timeoutListDate, 'floating');
			this._visibleFloating = 'floating_' + this._timeoutListDate;

			var tooltip = $$(this._visibleFloating);
			if(tooltip !== oldTooltip){
				oldTooltip.hide();
			}

			if(tooltip === undefined) {
				tooltip = new epages.widget.Tooltip({
					tooltipArea: dateNode,
					interactive: true,
					forceOrientation: 'B',
					'class' : 'Wide Plain'
				}, $(this._visibleFloating));
				tooltip.show(x,y);
			}
		},

		_onDayClick: function(){
				this.inherited('_onDayClick',arguments);
			if (this.timer != null){
				this.timer.fillTimes(this.value);
			}
		}
});


}

if(!dojo._hasResource["epages.cartridges.de_epages.calendar.widget.Calendar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.cartridges.de_epages.calendar.widget.Calendar"] = true;
/*
	Copyright (c) 2006-2007, ePages GmbH
	All Rights Reserved.
*/
dojo.provide("epages.cartridges.de_epages.calendar.widget.Calendar");






dojo.declare(
	"epages.cartridges.de_epages.calendar.widget.Calendar",
	epages.widget.Calendar,
	{

		/**
		 * public properties
		 */
		objectId: '', // CalendarId
		productId: '',
		containerId: '',
		availableQuantity: '',
		requestedQuantity: '',
		minOrderQuantity: '',
		timer: null,
		requestedMinutes: '',
		datastoreId: 'Datastore',
		quantityInput: undefined,

		url: '?',
		_loadedFormats: undefined,
		_loadedList:    undefined,
		_readyForClick: true, // flag to disable click events if calendar is loading
		_firstLoading: true,
		_datastore: undefined,

		postMixInProperties: function () {
			this.inherited('postMixInProperties',arguments);
			if($$(this.datastoreId)){
				this._datastore = $$(this.datastoreId);
				dojo.subscribe(this.datastoreId+'/load',this,'_onReceiveRequest');
			}
			this._loadedFormats = {};
			this._loadedList = {};
			if(this.quantityInput){
				this.connect(this.quantityInput, 'change', '_onQunatitiyInputChange');
				this.requestedQuantity = this.quantityInput.value;
			}
		},

		postCreate: function () {
			this.inherited('postCreate',arguments);
			if (this.timer != null){ 
				this.timer.fillTimes = dojo.hitch(this, '_fillTimes');
			}
		},

		getDateKey: function (date) {
			var pad = dojo.string.pad;
			return [pad(date.getFullYear(), 4), pad(date.getMonth() + 1, 2), pad(date.getDate(), 2)].join("-")+'T00:00:00';
		},

		_onReceiveRequest: function (result,month) {
			if(!result || month != dojo.date.stamp.toISOString(this.displayMonth)){ 
				return false;
			}
			//correct visible dates and times
			for(var el in result){
				if(el){
					var date1 = new Date(dojo.date.stamp.fromISOString(el));
					date1.setHours(00);
					var newString = dojo.date.stamp.toISOString(date1);
					newString = newString.substring(0,19);
					result[newString] = result[el];
					//delete result[el];
				}
			}

			this._loadedFormats[this.displayMonth] = result;
			dojo.query(".dijitCalendarDateLabel", this.domNode).forEach(function(label, i){
				var node = this._dateNode(label);
				var datekey = this.getDateKey(new Date(node.dijitDateValue));
				var dateData = result[datekey];
				if (dateData !== undefined) {
					var me = this;
					this._loadedList[datekey] = [];
					for( var i=0,iLength=dateData['DayList'].length ; i<iLength ; i++ ){
						//calculate available Quantity for this timeslot
						var availableQuantity = me.availableQuantity - dateData['DayList'][i][1];
						//check if requested Quantity is equal or higher as minOrder and if it is lower or equal than availableQuantity
						if((parseFloat(me.requestedQuantity) >= parseFloat(me.minOrderQuantity))
						&& (parseInt(me.requestedQuantity) <= parseInt(availableQuantity))){
							this._loadedList[datekey].push(dojo.date.stamp.fromISOString(dateData['DayList'][i]));
						}
					}
					if(this._loadedList[datekey] && this._loadedList[datekey].length == 0){
						dojo.addClass(node,'dijitCalendarDisabledDate');
					}else{
						dojo.removeClass(node,'dijitCalendarDisabledDate');
					}
				} else {
					dojo.addClass(node,'dijitCalendarDisabledDate');
				}
			}, this);
			dojo.publish("interactionRestrictor/permit", ["CalendarRestrictor"]);
			this._readyForClick = true;
			if(this._firstLoading){
				//fill Timer after first Loading
				this.timer.fillTimes(this.value);
				this._firstLoading = false;
				this._checkSelectedDay();  // disable because of EPG-14391
			}
		},

		_populateGrid: function (days) {
			this.inherited('_populateGrid',arguments);
			this.displayMonth.setMinutes(0);
			this.displayMonth.setSeconds(0);
			this.displayMonth.setHours(0);
			if(this._datastore){
				dojo.publish("interactionRestrictor/suspend", ["CalendarRestrictor", this.domNode.getElementsByTagName("tbody")[0]]);
				this._readyForClick = false;
				this._datastore.getDateFormatsSF({
					objectId  : this.objectId,
					startDate : this.displayMonth,
					endDate   : dojo.date.add(this.displayMonth, "day", dojo.date.getDaysInMonth(this.displayMonth)),
					available : this.availableQuantity,
					requestedMinutes : this.requestedMinutes
				});
			}
		},

		_fillTimes: function (date) {
			var dateKey = this.getDateKey(date);
			var times = this._loadedList[dateKey];
			this.timer.setTimes(times);
		},

		isDisabledDate: function(/*Date*/dateObject, /*String?*/locale){
			//disable date if there are no appointments available
			if(this._loadedList[this.getDateKey(dateObject)] && this._loadedList[this.getDateKey(dateObject)].length == 0){
				 return true;
			}
			return false; // Boolean
		},

		_onDayClick: function(/*Event*/evt){
			if(this._readyForClick){
				this.inherited('_onDayClick',arguments);
				if (this.timer != null){
					this.timer.fillTimes(this.value);
				}
			}
		},

		_onQunatitiyInputChange : function(evt){
			this.requestedQuantity = this.quantityInput.value;
			this._populateGrid();
			this.timer.fillTimes(this.value);
		},

		setRequestedMinutes: function(minutes){
			this.requestedMinutes = minutes;
			this._populateGrid();
			this.timer.fillTimes(this.value);
		},

		_checkSelectedDay: function(){
			//summary: check if selected Day is selectable if not switch to next available day in this month
			var currentDay = this.value.getDate();
			var nextAvailableDate;
			var testDate = new Date(this.value);
			if(currentDay && currentDay < 31){
				for(var i = currentDay; i <= 31; i++){
					testDate.setDate(i);
					var testDateKey = this.getDateKey(testDate);
					if(this._loadedList[testDateKey] && this._loadedList[testDateKey].length != 0){
						nextAvailableDate = testDate;
						break;
					}
				}
			}
			if(nextAvailableDate){
				this.attr('value',nextAvailableDate);
				return true;
			}
			else{
				return false;
			}
		}

});

}

if(!dojo._hasResource['epages.cartridges.de_epages.calendar.widget.Datastore']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.calendar.widget.Datastore'] = true;
dojo.provide('epages.cartridges.de_epages.calendar.widget.Datastore');





dojo.declare(
	"epages.cartridges.de_epages.calendar.widget.Datastore",
	[dijit._Widget],
	{
		/**
		 * public properties
		 */

		url          :'?',
		objectId     : undefined,

		_dayLists    : undefined,
		_dateFormatsBO : undefined,
		_dateFormatsSF : undefined,

		postMixInProperties: function () {
			this.inherited('postMixInProperties',arguments);
			this._dayLists = {};
			this._dateFormatsBO = {};
			this._dateFormatsSF = {};
		},

		getDayList: function(date){
			date = epages.localize.formatDateTime(date,epages.vars.Locale.datetimeFormat);
			if(this._dayLists[date]){ 
				return this._dayLists[date];
			}
			// load data from server
			var json = new epages.io.Json;
			var result = json.loadSync(this.url, {
				'ViewAction': 'JSON-DayList',
				'ObjectID':   this.objectId,
				'StartDate':  date
			});
			if(!result.error){
				var data = result.data;
				this._dayLists[date] = data;
				return data;
			}else{ 
				return false;
			}
		},

		getDateFormats: function(request) {
			var startDate = dojo.date.stamp.toISOString(request.startDate);
			var endDate = dojo.date.stamp.toISOString(request.endDate);
			var requestKey = request.objectId
											+':'+ startDate
											+':'+ endDate
											+':'+ request.available
											+':'+request.requestedMinutes;
			if(this._dateFormatsBO[requestKey]){
				return this._dateFormatsBO[requestKey];
			}
			else {
				var me = this;
				var json = new epages.io.Json;

				var result = json.loadSync(this.url,{
					'ViewAction': 'JSON-BO-AppointmentCalendar',
					'ObjectID':   request.objectId,
					'StartDate':  startDate,
					'EndDate':    endDate,
					'Available':  request.available,
					'RequestedMinutes' : request.requestedMinutes
					//'Requested':  request.requested
				});
				if(!result.error){
					this._dateFormatsBO[requestKey] = result.data;
					return result.data;
				}
				return false;
			}
		},

		getDateFormatsSF: function(request){
			var key = request.objectId
							+':'+dojo.date.stamp.toISOString(request.startDate)
							+':'+dojo.date.stamp.toISOString(request.endDate)
							+':'+request.available
							+':'+request.requestedMinutes;
			if(this._dateFormatsSF[key]){
				var result = this._dateFormatsSF[key];
				dojo.publish(this.id+'/load',[result,dojo.date.stamp.toISOString(request.startDate)]);
			}
			else {
				var me = this;
				var json = new epages.io.Json;
				json.loadAsync(this.url,
				function(result){
					me._dateFormatsSF[key] = result.data;
					dojo.publish(me.id+'/load',[result.data,dojo.date.stamp.toISOString(request.startDate)]);
				}
				,{
					'ViewAction': 'JSON-AppointmentCalendar',
					'ObjectID':   request.objectId,
					'StartDate':  dojo.date.stamp.toISOString(request.startDate),
					'EndDate':    dojo.date.stamp.toISOString(request.endDate),
					'Available':  request.available,
					'RequestedMinutes' : request.requestedMinutes
				});
			}
		}
});

}

if(!dojo._hasResource['epages.cartridges.de_epages.calendar.widget.Schedule']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['epages.cartridges.de_epages.calendar.widget.Schedule'] = true;
dojo.provide('epages.cartridges.de_epages.calendar.widget.Schedule');







dojo.declare(
	"epages.cartridges.de_epages.calendar.widget.Schedule",
	[epages.widget.LocalizedWidget],
	{
		/**
		 * public properties
		 */
		url                :'?',
		calendarId         : 'Appointmentcalendar',
		datastoreId        : 'Datastore',
		objectId           : undefined, // id of the current business hours
		productId          : undefined, //id of the current product
		activeDate         : undefined, //current active/visible Date
		availableQuantity  : undefined, //totla quantitity of current product
		height             : '480px', //height of schedule widget
		colRatio           : '10.23', //ratio for col0 to rest of cols e.g. 1:10.23
		intervall          : '30',
		insideArea         : false,
		useDoubleHeight    : false,

		_datastore         : undefined,
		_times             : undefined,
		_appointments      : undefined,
		_now               : undefined,

		_colNode           : undefined,
		_cellNode          : undefined,
		_trNode            : undefined,
		_headThNode        : undefined,
		_hoverNode         : undefined,
		_rowsQuantity      : 0,

		_currentHoverValue : undefined,
		_currentHoverNode  : undefined,
		_startBusinessHoursMinute : undefined, 	// start time of buisness hours in minutes
		_intervallheight   : undefined,
		/**
		 * dojo widget properties
		 */
		imagePath       : epages.themeUrl('images'),
		translationName : dojo.moduleUrl('epages.cartridges.de_epages.calendar.widget','templates/translation'),
		templateString  :'<div class="Schedule Day"></div>',

		//template snippets for innerTable working with strings is in ie faster than with dom nodes
		_template: {
			'DateTableHeadTop'     : '<div class="DateTableHeadWrapper"><table class="DateTableHead"><colgroup>',
			'DateTableHeadBottomCols'  : '</colgroup>',
			'DateTableHeadBottom'  : '</table></div>',
			'ColElementTop'        : '<col ',
			'ColElementBottom'     : '></col>',
			'HeadTrTop'            : '<tr>',
			'HeadTrBottom'         : '</tr>',
			'HeadThTop'            : '<th>',
			'HeadThBottom'         : '</th>',
			'CellTop'              : '<td',
			'CellBottom'           : '</td>',
			'DateTableTop'         : '<div class="DateTableWrapper"><table class="DateTable"><colgroup>',
			'DateTableBottomCols'  : '</colgroup>',
			'DateTableBottom'      : '</table></div>',
			'TrTop'                : '<tr',
			'TrBottom'             : '</tr>',
			'ThTop'                : '<th class="Timeline">',
			'ThBottom'             : '</th>',
			'TimeTop'              : '<div class="Wrapper"><div class="Time">',
			'TimeBottom'           : '</div>',
			'WrapperBottom'        : '</div>',
			'HourTop'              : '<span class="Hour">',
			'HourBottom'           : '</span>',
			'MinutesTop'           : '<span class="Minutes">',
			'MinutesBottom'        : '</span>',
			'LockTop'              : '<div',
			'LockBottom'           : '</div>',
			'NowTop'               : '<div class="Now" style="',
			'NowBottom'            : '"></div>',
			'NewEvent'             : '', //template filled in postMixInProperties to translate language tags
			'AppointmentWrapperTop': '<div class="Wrapper" ',
			'AppointmentEventTop'  : '><div class="Event EnableHover',
			'AppointmentWrapperBottom' : '</div>',
			'AppointmentTop'       : '', //template filled in postMixInProperties to translate language tags
			'AppointmentInfoTitleTop'    : '<span class="Bold">',
			'AppointmentInfoTitleBottom'    : '</span>',
			'AppointmentInfoTop'       : '<span>',
			'AppointmentInfoBottom'    : '</span>',
			'AppointmentBottom'        : '</div></div>',
			'TTTitleTop'                    : '<tt dojoType="epages.widget.Tooltip" class="ScheduleTT" target="previous"><div class="Bold" dojoAttachPoint="ttTitleNode">',
			'TTTitleBottom'                 : '</div>',
			'TTContentTop'                  : '<div dojoAttachPoint="ttContentNode">',
			'TTContentBottom'               : '</div><br /></tt>'
		},
		_resultTable : new Array(), //table to store strings of resulting table doing only one string join at the end is faster then joining the strings every time something is added


		postMixInProperties: function () {
			this.inherited('postMixInProperties',arguments);
			this._appointments = {};
			this._times = {};
			this._now = new Date();
			this.colRatio = parseFloat(this.colRatio);
			if(this.intervall == '' || this.intervall == undefined){
				this.intervall = '30';
			}
			this.intervall = parseInt(this.intervall);
			this.connect(window, 'onresize', '_resizeWrapper');
			dojo.subscribe(this.calendarId+'/select',this,'_onCalendarSelect');
			//dojo.subscribe('Lock/change',this,'_onLockChange');
			if(this.insideArea){
				this.connect(epagesDialog,'showArea', '_onShowArea');
			}
			if(!this.useDoubleHeight && this.intervall >= 30){
				this.useDoubleHeight = true;
			}
			this._intervallheight = this.useDoubleHeight ? 40 : 20;
			//add double height classs to top of the data table
			if(this.useDoubleHeight){
				this._template['DateTableTop'] = '<div class="DateTableWrapper"><table class="DateTable IntervallDoubleHeight"><colgroup>';
			}
			//some templates need translation
			this._template['NewEvent'] = '<div class="Wrapper newAppointment"><div class="NewEvent"><div class="NewAppointmentNode">'+this.translate("NewAppointment")+'</div></div></div>';
			this._template['AppointmentTop'] = '<div class="TopLeft"><div class="TopRight"></div></div>'
									+'<div class="BottomLeft"><div class="BottomRight"></div></div>'
									+'<div class="OverlayButtons"><div class="Container">'
									+'<span class="Command DeleteButton" dojoAttachEvent="onclick:_onDeleteClick">'
									+'<img class="DeleteImage" src="'+this.imagePath+'/ico_s_delete.png" alt="'+this.translate("Delete")+'" title="'+this.translate("Delete")+'" />'+this.translate("Delete")+'</span></div></div>'
									+'<div class="Body" ><span class="StatusIcon"></span>';
		},

		_resizeWrapper:function(){
			var dateTableWrapper = epages.html.getElementsByClassName('DateTableWrapper',this.domNode);
			if(dateTableWrapper[0]){
				datetablewidth = dateTableWrapper[0].clientWidth;
				dateTableWrapper[0].style.height = this.height;
			}
			var dataTable = epages.html.getElementsByClassName('DateTable',this.domNode);
			if(dataTable[0]&& datetablewidth){
				dataTable[0].style.width = datetablewidth + "px";
			}
			var dataTableHead = epages.html.getElementsByClassName('DateTableHead',this.domNode);
			if(dataTableHead[0] && datetablewidth){
				dataTableHead[0].style.width = datetablewidth + "px";
			}
		},

		_calculateUsedRows: function(startDate,endDate){
			startDate = dojo.date.stamp.fromISOString(startDate);
			endDate = dojo.date.stamp.fromISOString(endDate);
			//check if start and end date are differnet to the active date
			var compare1 = dojo.date.compare(this.activeDate, startDate,'date');
			var compare2 = dojo.date.compare(this.activeDate, endDate,'date');
			if(compare1 != 0){
				startDate.setDate(this.activeDate.getDate());
				startDate.setMonth(this.activeDate.getMonth());
				startDate.setYear(this.activeDate.getFullYear());
				startDate.setHours(0);
				startDate.setMinutes(0);
				startDate.setSeconds(0);
			}
			if(compare2 != 0){
				endDate.setDate(this.activeDate.getDate());
				endDate.setMonth(this.activeDate.getMonth());
				endDate.setYear(this.activeDate.getFullYear());
				endDate.setHours(23);
				endDate.setMinutes(59);
				endDate.setSeconds(59);
			}
			var timeDiff = dojo.date.difference(startDate,endDate,'minute');
			var cellCount = Math.ceil(timeDiff/this.intervall);
			return cellCount;
		},

		_createInnerTable: function(){
			//this function creates the inner table of the widget
			this._startBusinessHoursMinute = undefined;
			//destroy old tooltip widget if another day is loaded
			var tooltips = epages.html.getElementsByClassName('ScheduleTT',this.domNode);
			for( var i=0,iLength=tooltips.length ; i<iLength ; i++ ){
				var widget = $$(tooltips[i].id);
				if(widget){
					widget.destroy();
				}
			}
			this.domNode.innerHTML = '';
			this._resultTable = new Array();
			this._resultTable.push(this._template['DateTableHeadTop']);

			//calculate col width with given colRatio in percentage
			var totalWidth = 100;
			var col0Width = parseFloat(totalWidth)/(this.colRatio+1);
			var remainWidth = totalWidth - col0Width;
			var colWidth = remainWidth / this._rowsQuantity;

			//create head table
			var cols = new Array;
			var headCells = new Array;
			cols.push(this._template['ColElementTop']+'style="width:'+col0Width+'%;"'+this._template['ColElementBottom']);
			for(var i = 0; i< this._rowsQuantity;i++){
				cols.push(this._template['ColElementTop']+'style="width:'+colWidth+'%;"'+this._template['ColElementBottom']);
				headCells.push(this._template['CellTop']+'>'+(i+1)+this._template['CellBottom']);
			}
			this._resultTable = this._resultTable.concat(cols);
			this._resultTable.push(this._template['DateTableHeadBottomCols']);
			this._resultTable.push(this._template['HeadTrTop']);
			this._resultTable.push(this._template['HeadThTop']);
			this._resultTable.push(this._template['HeadThBottom']);
			this._resultTable = this._resultTable.concat(headCells);
			this._resultTable.push(this._template['HeadTrBottom']);
			this._resultTable.push(this._template['DateTableHeadBottom']);
			this._resultTable.push(this._template['DateTableTop']);
			this._resultTable = this._resultTable.concat(cols);
			this._resultTable.push(this._template['DateTableBottomCols']);
			this._resultTable.push(this._template['DateTableBottomCols']);

			//create currentTime in Minutes only if acctual shown date is same as acctual date
			if(dojo.date.compare(this.activeDate,this._now,'date') == 0){
				var currentTime = this._now.getHours()*60;
				var minutes = this._now.getMinutes();
				var minutesSlotDistance = Math.floor(minutes / this.intervall) * this.intervall;
				var remainderMinutes = minutes - minutesSlotDistance;
				currentTime += minutesSlotDistance;
				minutes = remainderMinutes;
			}
			//create a table row which is not visible with the information of the width of each colum necessary for ie
			this._resultTable.push('<tr style="height:0px;">');
			this._resultTable.push('<td style="width:'+col0Width+'%;"></td>');
			for(var i = 0; i < this._rowsQuantity;i++){
					this._resultTable.push('<td style="width:'+colWidth+'%;"></td>');
			}
			this._resultTable.push('</tr>');
			//create tableRows foreach time
			for(time in this._times){
				var el = this._times[time];

				//set CSS classes for tr
				var trClasses = 'EnableHover IntervallRow';
				if(el.Minute < currentTime || dojo.date.compare(this.activeDate,this._now,'date') < 0){
					trClasses +=' Past';
				}
				if(!el.IsBookingHours){
					trClasses +=' OutsideBusinesshours';
				}
				if(el.IsBookingHours && this._startBusinessHoursMinute === undefined){
					this._startBusinessHoursMinute = el.Minute;
				}
				if(el.Minute%60 == 0 && el.Minute != 0){
					trClasses +=' Seperator';
				}
				if(el.IsOpened){
					trClasses +=' UnLocked';
				}
				if(el.IsLocked){
					trClasses +=' Locked';
				}
				this._resultTable.push(this._template['TrTop']+' class="'+trClasses+'">');

				//create cells
				//time cell
				var hour ='';
				var minute = '';
				if(el.Minute%60 == 0){
					hour = el.Minute/60;
					minute = '00';
				}
				this._resultTable.push(this._template['ThTop']);
				this._resultTable.push(this._template['TimeTop']);
				this._resultTable.push(this._template['HourTop']);
				this._resultTable.push(hour);
				this._resultTable.push(this._template['HourBottom']);
				this._resultTable.push(this._template['MinutesTop']);
				this._resultTable.push(minute);
				this._resultTable.push(this._template['MinutesBottom']);
				this._resultTable.push(this._template['TimeBottom']);

				//lock
				if(el.Minute < currentTime || dojo.date.compare(this.activeDate,this._now,'date') < 0) {
					this._resultTable.push(this._template['LockTop']+'>'+this._template['LockBottom']);
				}
				else {
					var LockingState = el.IsBusiness === 0 ? this.translate("Locked") : this.translate("Unlocked");
					this._resultTable.push(this._template['LockTop']+' class="Lock" startdate="'+el.StartDate+'" enddate="'+el.EndDate+'" isopen="'+el.IsBusiness+'" title="'+ LockingState +'">'+this._template['LockBottom']);
				}
				this._resultTable.push(this._template['WrapperBottom']);
				//now
				if(currentTime){
					if(el.Minute == currentTime){
						var height= Math.floor((minutes / this.intervall) * this._intervallheight);
						this._resultTable.push(this._template['NowTop']+(height-20)+'px;'+this._template['NowBottom']);
					}
				}
				this._resultTable.push(this._template['ThBottom']);
				//other cells
				for(var j = 0; j < this._rowsQuantity; j++){
					var cellClasses = 'Cell';
					var cellAppointment = '';
					//check if slot is valid or not
					if((j+1) > this.availableQuantity){
						cellClasses += ' Invalid';
					}
					var slotEmpty = true;
					currentSlot = 'slot'+j;
					if(el.Appointments.length != 0){
						if(this._startBusinessHoursMinute === undefined) {
							this._startBusinessHoursMinute = el.Minute;
						}
						//loop trough appointments, create items and block slots
						for(var lauf=0, iLength=el.Appointments.length; lauf<iLength; lauf++){
							var appointment = this._appointments[el.Appointments[lauf].objectId];
							if(appointment.slots == undefined){
								appointment.slots = [];
							}
							//check if currentSlot is empty
							if(slotEmpty == true){
								//check if appointment is already using this slot
								if($A(appointment.slots).exists(currentSlot)){
									slotEmpty = false;
									cellClasses += ' Used';
								}
								else{
									//check if appointment has already an item
									if(appointment.item == undefined){
										//create scheduleitem
										appointment.item = 'defined';
										cellAppointment = this._generateAppointmentCell(appointment,el);
										cellClasses +=' Used';
										slotEmpty = false;
										appointment.slots.push(currentSlot);
									}
									else{
										//block slot if appointment needs more slots
										if(appointment.slots.length == 0 || appointment.slots.length < appointment.Quantity){
											cellClasses += ' Used';
											slotEmpty = false;
											appointment.slots.push(currentSlot);
										}
									}
								}
							}
						}
					}

					if(slotEmpty == true || cellAppointment != ''){
					this._resultTable.push(this._template['CellTop']);
					if(cellAppointment != ''){
						this._resultTable.push('class="'+cellClasses+'" '+cellAppointment.cols+' '+cellAppointment.rows+'>');
						this._resultTable.push(cellAppointment.content);
					}
					if(slotEmpty == true){
						this._resultTable.push('startdate="'+el.StartDate+'" ');
						this._resultTable.push('class="'+cellClasses+'">');
					}
					this._resultTable.push(this._template['CellBottom']);
					}
				}
			this._resultTable.push(this._template['TrBottom']);
			}

			this._resultTable.push(this._template['DateTableBottom']);
			this.domNode.innerHTML= this._resultTable.join("\n");
			dojo.parser.parse(this.domNode);
			this._resizeWrapper();

			//// scroll bar position
			if(this._startBusinessHoursMinute !== undefined){
				var dateTableWrapper = epages.html.getElementsByClassName('DateTableWrapper',this.domNode);
				if(dateTableWrapper[0]){
					dateTableWrapper[0].scrollTop = Math.floor((this._startBusinessHoursMinute / this.intervall) * this._intervallheight);
				}
			}
			dojo.publish("interactionRestrictor/permit", ["ScheduleRestrictor"]);
		},

		_generateAppointmentCell:function(appointment,el){
			//generate Cell for appointment with adressinfo if defined and calculate used rows and cols
			var accepted = '';
			if(appointment.AddressInfo.AcceptedOn){
				accepted = ' Accepted';
			}
			var cellCount = this._calculateUsedRows(appointment.StartDate,appointment.EndDate);
			startDate = dojo.date.stamp.fromISOString(appointment.StartDate);
			endDate = dojo.date.stamp.fromISOString(appointment.EndDate);
			//check startMinute of appointment
			var minutesAppointment = startDate.getHours()*60 + startDate.getMinutes();

			// Are current and start date at the same day
			var isSameDay = !dojo.date.compare(startDate, endDate, 'date');

			if(cellCount != 0 || cellCount != 1){
				if(minutesAppointment > el.Minute && isSameDay){
					//block one cell more if appointment is out of standard alignment
					var cellRowspan = ' rowspan="'+(cellCount+1)+'"';
				}
				else{
					var cellRowspan = ' rowspan="'+cellCount+'"';
				}
			}
			//set Adress Info
			if(appointment.AddressInfo){
				var nameStringArray = [];
				if(appointment.AddressInfo.Company){
					nameStringArray.push(appointment.AddressInfo.Company+',');
				}
				if(appointment.AddressInfo.Title){
					nameStringArray.push(appointment.AddressInfo.Title);
				}
				if(appointment.AddressInfo.FirstName){
					nameStringArray.push(appointment.AddressInfo.FirstName);
				}
				if(appointment.AddressInfo.MiddleName){
					nameStringArray.push(appointment.AddressInfo.MiddleName);
				}
				if(appointment.AddressInfo.LastName){
					nameStringArray.push(appointment.AddressInfo.LastName);
				}

				//set infoTitleNode
				var nameString = nameStringArray.join(' ') + " ";
				//setInfoContentNode
				var addressStringArray = [];
				if(appointment.AddressInfo.EMail){
					addressStringArray.push(appointment.AddressInfo.EMail);
				}
				if(appointment.AddressInfo.Phone){
					addressStringArray.push(appointment.AddressInfo.Phone);
				}
				var addressString = addressStringArray.join(', ');
				if(appointment.AddressInfo.Comment){
					addressString += ', '+this.translate('Comment')+': '+appointment.AddressInfo.Comment;
				}

				var dayDiff = dojo.date.difference(startDate,endDate,'day');
				var startTimeHours = startDate.getHours();
				var startTimeMinutes = startDate.getMinutes();
				var endTimeHours = endDate.getHours();
				var endTimeMinutes = endDate.getMinutes();
				var _startTime = ' ';
				var _endTime = ' ';
				if(dayDiff != 0){
					_startTime = epages.localize.formatDateTime(startDate)+' ';
					_endTime = epages.localize.formatDateTime(endDate)+' ';
				}
				if(startTimeHours < 10){
					startTimeHours = '0'+startTimeHours;
				}
				if(startTimeMinutes < 10){
					startTimeMinutes = '0'+startTimeMinutes;
				}
				if(endTimeHours < 10){
					endTimeHours = '0'+endTimeHours;
				}
				if(endTimeMinutes < 10){
					endTimeMinutes = '0'+endTimeMinutes;
				}
				_startTime += startTimeHours+':'+startTimeMinutes;
				_endTime += endTimeHours+':'+endTimeMinutes;

				//set ttTitleNode
				var ttTitleString  = _startTime+' - '+_endTime;
				ttTitleString += ' '+nameStringArray.join(' ');
				//set ttContentNode
				var ttContentString = addressStringArray.join('<br />');
				if(appointment.AddressInfo.Comment){
					ttContentString += '<br />'+this.translate('Comment')+': '+appointment.AddressInfo.Comment;
				}
				if(appointment.AddressInfo.CustomerComment){
					ttContentString += '<br />'+this.translate('UserComment')+': '+appointment.AddressInfo.CustomerComment;
				}
				//set AcceptedOn CancelledOn
				if(appointment.AddressInfo.AcceptedOn) {
					if(!appointment.AddressInfo.CancelledOn){
						ttContentString += '<br />'+this.translate('Status')+': <b>'+this.translate('DateAccepted')+'</b>';
					}
				}
				if(!appointment.AddressInfo.AcceptedOn){
					ttContentString += '<br />'+this.translate('Status')+': <b>'+this.translate('DateUnconfirmed')+'</b>';
				}
			}

			//check if  is out of standard alignment and correct position
			var diffPixels = Math.floor(((minutesAppointment - el.Minute) /  (this.intervall /4)) * 10);
			if(diffPixels == undefined || diffPixels == 'NaN'){
				diffPixels = 0;
			}
			// Recalculate offset if appointment goes over more than one day
			var	diffElemPixels = isSameDay ? diffPixels : 0;

			return {
				'rows' : cellRowspan ? cellRowspan: '',
				'cols' : ' colspan="'+appointment.Quantity+'"',
				'content' : this._template['AppointmentWrapperTop']+'style="margin-top:'+diffElemPixels+'px;"'+this._template['AppointmentEventTop']+accepted+'" style="height: '
				+ (cellCount*this._intervallheight) +'px;" appointmentid="'+appointment.objectId+'">'
				+this._template['AppointmentTop']
				+this._template['AppointmentInfoTitleTop']+nameString
				+this._template['AppointmentInfoTitleBottom']
				+this._template['AppointmentInfoTop']+addressString
				+this._template['AppointmentInfoBottom']
				+this._template['AppointmentBottom']
				+this._template['TTTitleTop']+ttTitleString
				+this._template['TTTitleBottom']
				+this._template['TTContentTop']+ttContentString
				+this._template['TTContentBottom']
				+this._template['AppointmentWrapperBottom']
			};
		},

		changeDay:function(date){
			dojo.publish("interactionRestrictor/suspend", ["ScheduleRestrictor", this.domNode]);
			this._rowsQuantity = 0;
			if(this.activeDate != date){
				this.activeDate = date;
			}
			var dayList = this._datastore.getDayList(date);
			if(dayList){

				this._now = new Date( dayList[0].CurrentDateTime.replace(/-/g,'/').replace(/T/g,' ') );

				for( var i=0,iLength=dayList.length ; i<iLength ; i++ ){
					//check requested quantity for acctual Time Slot
					var quantityForTime = 0;
					//parse Appointments
					for( var j=0,jLength=dayList[i].Appointments.length ; j<jLength ; j++ ){
						quantityForTime += parseInt(dayList[i].Appointments[j].Quantity);
						if(!this._appointments[dayList[i].Appointments[j].objectId]){
							this._appointments[dayList[i].Appointments[j].objectId] = dayList[i].Appointments[j];
							if(this._appointments[dayList[i].Appointments[j].objectId].slots){
								this._appointments[dayList[i].Appointments[j].objectId].slots = undefined;
							}
							if(this._appointments[dayList[i].Appointments[j].objectId].item){
								this._appointments[dayList[i].Appointments[j].objectId].item = undefined;
							}
						}
						else{
							if(this._appointments[dayList[i].Appointments[j].objectId].slot){
								this._appointments[dayList[i].Appointments[j].objectId].slot = [];
							}
						}
					}
					if(this._rowsQuantity < quantityForTime){
						this._rowsQuantity = quantityForTime;
					}
					if(this._rowsQuantity < dayList[i].Appointments.length){
						this._rowsQuantity = dayList[i].Appointments.length;
					}
					this._times[dayList[i].Minute] = dayList[i];
				}
				if(this._rowsQuantity < this.availableQuantity){
					this._rowsQuantity = this.availableQuantity;
				}
				this._createInnerTable();
			}
			else{
				console.warn('unable to load daylist from Server');
			}
		},

		postCreate: function(){
			this.inherited('postCreate',arguments);
			if($$(this.datastoreId)){
				this._datastore = $$(this.datastoreId);
			}
			if(!this.activeDate){
				this.activeDate = new Date();
			}
			if(typeof(this.activeDate) == 'string'){
				this.activeDate = new Date(this.activeDate);
			}
			//load acctual day and appointments, but use other thread to avoid total blocking inside ie
				dojo.addOnLoad(dojo.hitch(this,function(){
					dojo.publish("interactionRestrictor/suspend", ["ScheduleRestrictor", this.domNode]);
					window.setTimeout(dojo.hitch(this,function(){
						this.changeDay(this.activeDate);
					}),10);
					this._resizeWrapper();
				}));
				this.connect(this.domNode,'onclick', '_onSchedulerClick');
				this.connect(this.domNode,'mouseover', '_onSchedulerMouseOver');
		},

		startup: function(){
			this.inherited('startup',arguments);
			this._resizeWrapper();
		},

		_onCalendarSelect: function(opt){
			//if another day on calendar was selected clear appointments and times and load day
			this._appointments = null;
			this._appointments = {};
			this._times = null;
			this._times = {};
			this.changeDay(opt.date);
		},

		_onShowArea: function(opt){
			this._resizeWrapper();
		},

		_onLockChange: function(opt){
			//if lock change was succesfull add/remove Css class on parent table row
			var lock = $$(opt.id);
			var tableRow = lock.domNode.parentNode.parentNode.parentNode.parentNode;
					if(opt.isOpen == true){
						tableRow.setAttribute('title',this.translate("Locked"));
						dojo.addClass(tableRow,'UnLocked');
						dojo.removeClass(tableRow,'Locked');
					}
					else{
						tableRow.setAttribute('title',this.translate("Unlocked"));
						dojo.addClass(tableRow,'Locked');
						dojo.removeClass(tableRow,'UnLocked');
					}
		},

		_onClickNewAppointment: function(startDate){
			epages.locationHref('?ViewAction=MBO-ViewNewAppointment&ObjectID='+this.productId +'&StartDate='+startDate);
		},

		_onSchedulerClick: function(evt){
			var targetNode = evt.target;
			if(dojo.hasClass(targetNode,'NewAppointmentNode')){
				var cell = targetNode.parentNode.parentNode.parentNode;
				this._onClickNewAppointment(cell.getAttribute('startdate'));

			}
			if(dojo.hasClass(targetNode,'Lock')){
				this._onClickLock(targetNode);
			}
			//check if a cell was clicked
			/*if(dojo.hasClass(targetNode,'Cell')){
				if(dojo.hasClass(targetNode,'Used')){
					//console.debug('appointment Clicked');
				}
				else{
					//console.debug('empty Cell Clicked');
				}
			}*/
			if(dojo.hasClass(targetNode,'BottomRight') || dojo.hasClass(targetNode,'Body') || dojo.hasClass(targetNode,'BottomLeft')
			|| dojo.hasClass(targetNode,'StatusIcon')|| dojo.hasClass(targetNode,'TopRight')|| dojo.hasClass(targetNode,'TopLeft')){
				if(dojo.hasClass(targetNode.parentNode,'Event')){
					var eventNode = targetNode.parentNode;
				}
				if(dojo.hasClass(targetNode.parentNode.parentNode,'Event')){
					var eventNode = targetNode.parentNode.parentNode;
				}
				if(eventNode){
					var appointmentId = eventNode.getAttribute('appointmentid');
					if(appointmentId){
						epages.locationHref(this.url+'ViewAction=MBO-ViewGeneral&ObjectID='+appointmentId);
					}
				}
			}
			if(dojo.hasClass(targetNode,'DeleteButton')){
				var appointmentId = targetNode.parentNode.parentNode.parentNode.getAttribute('appointmentid');
				if(appointmentId){
						epages.locationHref(this.url+'ChangeAction=Delete&ChangeObjectID='+appointmentId+'&ObjectID='+this.productId);
					}
			}
			if(dojo.hasClass(targetNode,'DeleteImage')){
				var appointmentId = targetNode.parentNode.parentNode.parentNode.parentNode.getAttribute('appointmentid');
				if(appointmentId){
						epages.locationHref(this.url+'ChangeAction=Delete&ChangeObjectID='+appointmentId+'&ObjectID='+this.productId);
					}
			}

		},

		_onSchedulerMouseOver: function(evt){
			var targetNode = evt.target;
			if(targetNode){
				if(this._currentHoverNode && !dojo.hasClass(targetNode,'NewAppointmentNode')){
					this._currentHoverNode.innerHTML = '';
				}
				if(!dojo.hasClass(targetNode,'Used') && dojo.hasClass(targetNode,'Cell')){
					targetNode.innerHTML = this._template['NewEvent'];
					this._currentHoverNode = targetNode;
				}
			}
		},

		_onClickLock: function(node){
			var isopen = node.getAttribute('isopen');
			
			var json = new epages.io.Json();
			var output = json.loadSync(this.url, {
				ObjectID:       this.objectId,
				ChangeAction:   isopen == 1 ? 'LockPeriod' : 'UnlockPeriod',
				ViewAction:     'JSONViewResponse',
				StartDate:      node.getAttribute('startdate'),
				EndDate:        node.getAttribute('enddate')
			});
			if(!output.error){
				var tableRow = node.parentNode.parentNode.parentNode;
				if(isopen == 1){
					node.setAttribute('isopen',0);
					node.setAttribute('title',this.translate("Locked"));
					dojo.addClass(tableRow,'Locked');
					dojo.removeClass(tableRow,'UnLocked');
				}
				else{
					node.setAttribute('isopen',1);
					node.setAttribute('title',this.translate("Unlocked"));
					dojo.addClass(tableRow,'UnLocked');
					dojo.removeClass(tableRow,'Locked');
				}
			}
		}
	}
);

}

if(!dojo._hasResource["epages.widget.Timeselector"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["epages.widget.Timeselector"] = true;
dojo.provide("epages.widget.Timeselector");




dojo.declare(
	"epages.widget.Timeselector",
	[dijit._Widget, dijit._Templated],
	{

		/**
		 * public properties
		 */
		templateString:"<div class=\"Timeselector\">\n  <div class=\"Date\" dojoAttachPoint=\"dateNode\">\n\n  </div>\n  <div class=\"TimesContainer\" dojoAttachPoint=\"timesContainerNode\">\n    <div class=\"Times\" dojoAttachpoint=\"timesNode\">\n    </div>\n  </div>\n</div>\n",
		delta:     '5', // String - increment is 5 minutes by default
		value:     '',

		_selected: undefined,

		valuePattern:   epages.vars.Locale.datetimeFormat || "%d.%m.%y %H:%M", // String - epages datetime pattern
		displayPattern: epages.vars.Locale.timeFormat     || "%H:%M", // String - epages time pattern

		postMixInProperties: function() {
			// create dojo datetime pattern
			if (typeof this.value == 'string'){
				this.value = epages.localize.parseDateTime(this.value, this.valuePattern);
			}
			if (typeof this.delta == 'string'){
				this.delta = new Number(this.delta);
			}
			if (this.delta<=0){
				this.delta=30;
			}
		},

		postCreate: function() {
			this.inherited('postCreate', arguments);
			var date = this.value;
			this.value = null;
			this.setValue('value',date);
		},

		getValue: function() {
			// summary:
			//    returns the value as a date object, day is 1970-01-01
			return this.value;
		},

		setValue: function(/*Date*/date) {
			if (date === undefined){
				date = new Date();
			}else if (typeof date == "string"){
				date = epages.localize.parseDateTime(date, this.valuePattern);
			}

			if(!this.value || dojo.date.compare(date, this.value)){
				this.value = new Date(date);
				this.fillTimes(date);
				this.domNode.value = date == null ? undefined : date.valueOf();
			}
			if(this.value){
				this.dateNode.innerHTML = epages.localize.formatDateTime(this.value);
			}
		},

		fillTimes: function (date) {
			// summary: fill new options
			var date = new Date(this.value);
			date.setHours(0,0,0,0);
			this.dateNode.innerHTML = epages.localize.formatDateTime(date);
			var end = dojo.date.add(date, 'day', 1);
			var dates = [];
			while (date<end) {
				dates.push(date);
				date = dojo.date.add(date,'minute',this.delta);
			}
			this.setTimes(dates);
		},

		setTimes: function (opts) {
			this.dateNode.innerHTML = epages.localize.formatDateTime(this.value);
			var node = this.timesNode;
			// remove children
			while(node.firstChild){ node.removeChild(node.firstChild); }
			// add new options
			var lastCompare = undefined;
			var selected = false;
			var alternate = 0;
			dojo.forEach(opts, function (date) {
				o=document.createElement("div");
				o.innerHTML = epages.localize.formatDateTime(date, this.displayPattern);
				o.setAttribute('value',date.valueOf());
				if (!dojo.date.compare(this.value, date)){
					dojo.addClass(o,'Selected');
					this._selected = o;
					selected = true;
				}
				if(lastCompare == 1 && dojo.date.compare(this.value, date) == -1){
					dojo.addClass(o,'Selected');
					this._selected = o;
					this.value = date;
					selected = true;
				}
				lastCompare = dojo.date.compare(this.value, date);
				if(alternate){
					dojo.addClass(o,'Alternate');
				}
				node.appendChild(o);
				this.connect(o,'onclick', 'onChange');
				alternate=1-alternate;
			}, this);
			if(selected == false && lastCompare){
				if(lastCompare == 1){
					node.lastChild.selected = true;
					dojo.addClass(node.lastChild,'Selected');
					this._selected = node.lastChild;
					this.value = opts[opts.length-1];
				}
				else{
					dojo.addClass(node.firstChild,'Selected');
					this._selected = node.firstChild;
					node.firstChild.selected = true;
					this.value = opts[0];
				}
			}
		},

		onChange: function (evt) {
			var target = evt.currentTarget;
			dojo.removeClass(this._selected,'Selected');
			dojo.addClass(target,'Selected');
			this._selected = target;
			this.value = new Date(Number(target.getAttribute('value')));
			dojo.publish(this.id + '/onChange', [this.value]);
		}
	}
);

}

